(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1130832,      71024]*)
(*NotebookOutlinePosition[   1132107,      71064]*)
(*  CellTagsIndexPosition[   1132063,      71060]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Miscellaneous`Sampling`
A package for computing 1-sampling equilibria\
\>", "Title",
  TextAlignment->Center,
  Background->GrayLevel[0.900008]],

Cell["\<\
by Michael Ramsza
Warsaw School of Economics
web: http://akson.sgh.waw.pl/~mramsz/
mail: mramsz@sgh.waw.pl\
\>", "Subsubtitle",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  Background->GrayLevel[0.900008]],

Cell["\<\
This notebook describes the package Miscellaneous`Sampling` - a \
package for dealing with 1-sampling equilibria with some support for \
1-sampling dynamics. This is second version of the package. The main addition \
in this version is support for n-player possibly asymmetric normal form \
games. For more information on sampling equilibria and sampling dynamics \
refer to Osborne M. J., Rubinstein A. - \"Games with procedurally rational \
players\" - American Economic Review (1998) 88: 834-847; Sethi R. - \
\"Stability of equilibria in games with procedurally rational players\" - \
working paper, Barnard College, Columbia University, 1998 (also \
ewp-game/9811003). 

I found this package quite useful, however I am not taking any responsibility \
for using or not using this package. I am not claiming the way I chose to \
deal with 1-sampling equilibria is the most efficient or even correct. If you \
find any bugs, please, report it to mramsz@sgh.waw.pl. I will appreciate any \
feedback. Let's start ...\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Installing the package", "Section",
  Background->GrayLevel[0.900008]],

Cell[TextData[{
  "Basically you have to copy the file Sampling.m to directory \
StandardPackages/Miscellaneous in your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " directory. That'a all!"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using the package", "Section",
  Background->GrayLevel[0.900008]],

Cell["\<\
Everything what follows assumes that the package is installed \
properly. Have fun!\
\>", "Text"],

Cell[CellGroupData[{

Cell["How to read it in?", "Subsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
Once the package is installed properly it can be read in by using \
one of the following functions (I prefer the second one):\
\>", "Text"],

Cell[BoxData[
    \(<< Miscellaneous`Sampling`\)], "Input",
  CellLabel->"In[2]:="],

Cell["or", "Text"],

Cell[BoxData[
    \(Needs["\<Miscellaneous`Sampling`\>"]\)], "Input",
  CellLabel->"In[2]:="],

Cell["As you can see the new context is added to context list", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \($ContextPath\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \({"Miscellaneous`Sampling`", "Graphics`Animation`", "Global`", "System`"}
      \)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["\<\
This is complete listing of all defined functions in the \
package\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Miscellaneous`Sampling`*\)\)], "Input",
  CellLabel->"In[6]:="],

Cell["\<\
EquilibriumFilter       SamplingEquilibriumEqs  VarList             \
    WinningProbability      WinningProbabilityDiff
Game                    SamplingEquilibriumRoot VarListRoot\
\>", "Print",
  CellLabel->"From In[6]:="]
}, Open  ]],

Cell["\<\
I will cover all of them starting with the most basic and moving to \
others that I found useful but you might think differently.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["What is Game[]?", "Subsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
Well, Game[] is a special (but simple) way of describing normal \
form game. If we deal only with 2-palyer normal form games it's enough to \
have two matrices to describe the whole game. Once we have three or more \
player the describtion has to be more complex. Game[] is not really a \
function, rather it workes as a wrapper only. This is the help for Game[] \
structure.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Game\)\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \("Game[payoff, strs] is just a form of describing n-player normal form \
game. Arguments are: <payoff> - a list of pure functions being  payoff \
functions; <strs> - a list of numbers of pure strategiesfor each player. \
Example: 2-player normal form game would be g = Game[{(#[[1]].A.#[[2]]&), \
(#[[1]].B.#[[2]]&)}, {3,2}] where A and B are matrices 3 by 2 containing \
payoffs for first player - A - and second player - B. First player has three \
pure strategies, second player has two pure strategies. Variable g can be \
used later on with other functions."\)], "Print"]
}, Open  ]],

Cell["\<\
Let's define 2-player asymmetric normal form game. First we define \
two payoff matrices and see how they look.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(A\  = \ {\ {10, \ 2}, {0, 8}, \ {3, 7}}; \n
    B\  = \ {{1, 2}, \ {2, 1}, \ {2, 3}}; \nMatrixForm[A]\), 
    \(MatrixForm[B]\n\)}], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"10", "2"},
            {"0", "8"},
            {"3", "7"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[6]//MatrixForm="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "2"},
            {"2", "1"},
            {"2", "3"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[7]//MatrixForm="]
}, Open  ]],

Cell["Next we define a game.", "Text"],

Cell[BoxData[
    \(\(g\  = \ 
      Game[{\((#[\([1]\)] . A . #[\([2]\)]\ &)\), \ 
          \((#[\([1]\)] . B . #[\([2]\)]\ &)\)}, \ {3, 2}]; \)\)], "Input",
  CellLabel->"In[8]:="],

Cell["\<\
The first part of Game[] is a list of payoff functions in pure \
function form. The second part is a list  saying that the first player has \
three pure strategies, the second has two pure strategies. We will use the \
game defined here later on. We can in general use pure function as above, \
however I found it pretty usfull to define payoff functions seperately with \
some names - it was especially useful when dealing with more then just two \
players. Please, note the proper form of arguments of payoff functions, \
namely a profile of vectors belonging to unit simplex!\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing winning probabilities", "Subsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
We can compute winning probabilities of each player using \
WinningProbability[] function. This is a help provided with the package.\
\>",
   "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?WinningProbability\)\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \("WinningProbability[game, player, vars] returns a list of winning \
probabilities for player <player> in game <game> in terms of variables \
<vars>. Arguments are: <game> - a game in Game[] form; <player> - number of \
player; <vars> - a list of names of variables."\)], "Print"]
}, Open  ]],

Cell["\<\
These are probabilities of winning for each pure strategies of \
first player in game g (defined above).\
\>", "Text",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(WinningProbability[\ g, \ 1, \ {x, y}]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({y[1]\^3 + 2\ y[1]\^2\ y[2] + y[1]\ y[2]\^2, y[1]\ y[2]\^2 + y[2]\^3, 
      y[1]\^2\ y[2] + y[1]\ y[2]\^2}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell["\<\
As you can note these probabilities depend only on the second \
variable! We can sum these up and see that we come up with 1.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[\ % /. List -> Plus]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(\((y[1] + y[2])\)\^3\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["\<\
Those are probabilities for the second player. They sum up to 1 as \
well.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(WinningProbability[\ g, \ 2, \ {x, y}]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({x[1]\ x[2] + x[2]\^2 + 1\/2\ x[1]\ x[3] + x[2]\ x[3], 
      x[1]\^2 + x[1]\ x[2] + 3\/2\ x[1]\ x[3] + x[2]\ x[3] + x[3]\^2}\)], 
  "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[\ % /. List -> Plus]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(\((x[1] + x[2] + x[3])\)\^2\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing 1-sampling equilibria", "Subsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
We can compute 1-sampling equilibria using SamplingEquilibriumEqs[] \
function together with Solve[] function. This is help provided with the \
package for SamplingEquilibriumEqs[] function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?SamplingEquilibriumEqs\)\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \("SamplingEquilibriumEqs[ game, vars, k] returns a system of equations \
describing all k-sampling equlibria. Arguments are: <game> - a game in Game[] \
form; <vars> - a list of names of all variables; <k> - integer discribing \
what k-sampling equilibria we want (Note: this is not implemented yet, hence \
you will get an error message if you specify anything else then 1 here. Since \
1 is a default value you can skip this argument.)."\)], "Print"]
}, Open  ]],

Cell["\<\
Now let's see all the equations describing 1-sampling equilibria \
for the game g defined above.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SamplingEquilibriumEqs[g, \ {x, y}]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({\(-x[1]\) + y[1]\^3 + 2\ y[1]\^2\ y[2] + y[1]\ y[2]\^2 == 0, 
      \(-x[2]\) + y[1]\ y[2]\^2 + y[2]\^3 == 0, 
      \(-x[3]\) + y[1]\^2\ y[2] + y[1]\ y[2]\^2 == 0, 
      x[1]\ x[2] + x[2]\^2 + 1\/2\ x[1]\ x[3] + x[2]\ x[3] - y[1] == 0, 
      x[1]\^2 + x[1]\ x[2] + 3\/2\ x[1]\ x[3] + x[2]\ x[3] + x[3]\^2 - 
          y[2] == 0, x[1] + x[2] + x[3] == 1, y[1] + y[2] == 1}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell["We can also list them in a column to make it easier to read.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SamplingEquilibriumEqs[g, \ {x, y}] // ColumnForm\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(\(-x[1]\) + y[1]\^3 + 2\ y[1]\^2\ y[2] + y[1]\ y[2]\^2 == 0\)},
          {\(\(-x[2]\) + y[1]\ y[2]\^2 + y[2]\^3 == 0\)},
          {\(\(-x[3]\) + y[1]\^2\ y[2] + y[1]\ y[2]\^2 == 0\)},
          {
            \(x[1]\ x[2] + x[2]\^2 + 1\/2\ x[1]\ x[3] + x[2]\ x[3] - y[1] == 0
              \)},
          {
            \(x[1]\^2 + x[1]\ x[2] + 3\/2\ x[1]\ x[3] + x[2]\ x[3] + 
                x[3]\^2 - y[2] == 0\)},
          {\(x[1] + x[2] + x[3] == 1\)},
          {\(y[1] + y[2] == 1\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {
        Equal[ 
          Plus[ 
            Times[ -1, 
              x[ 1]], 
            Power[ 
              y[ 1], 3], 
            Times[ 2, 
              Power[ 
                y[ 1], 2], 
              y[ 2]], 
            Times[ 
              y[ 1], 
              Power[ 
                y[ 2], 2]]], 0], 
        Equal[ 
          Plus[ 
            Times[ -1, 
              x[ 2]], 
            Times[ 
              y[ 1], 
              Power[ 
                y[ 2], 2]], 
            Power[ 
              y[ 2], 3]], 0], 
        Equal[ 
          Plus[ 
            Times[ -1, 
              x[ 3]], 
            Times[ 
              Power[ 
                y[ 1], 2], 
              y[ 2]], 
            Times[ 
              y[ 1], 
              Power[ 
                y[ 2], 2]]], 0], 
        Equal[ 
          Plus[ 
            Times[ 
              x[ 1], 
              x[ 2]], 
            Power[ 
              x[ 2], 2], 
            Times[ 
              Rational[ 1, 2], 
              x[ 1], 
              x[ 3]], 
            Times[ 
              x[ 2], 
              x[ 3]], 
            Times[ -1, 
              y[ 1]]], 0], 
        Equal[ 
          Plus[ 
            Power[ 
              x[ 1], 2], 
            Times[ 
              x[ 1], 
              x[ 2]], 
            Times[ 
              Rational[ 3, 2], 
              x[ 1], 
              x[ 3]], 
            Times[ 
              x[ 2], 
              x[ 3]], 
            Power[ 
              x[ 3], 2], 
            Times[ -1, 
              y[ 2]]], 0], 
        Equal[ 
          Plus[ 
            x[ 1], 
            x[ 2], 
            x[ 3]], 1], 
        Equal[ 
          Plus[ 
            y[ 1], 
            y[ 2]], 1]}],
      Editable->False]], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell["\<\
Now, we can try to solve this system of algebraic equations using \
Solve[] function. To do this we will use the function VarList[] to generate \
list of all variables. This is help for VarList[] function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?VarList\)\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \("VarList[game, vars] returns a list of variables suitable to use with \
Solve[] like modules. Arguments are: <game> - a game in Game[] form; <vars> - \
a list of names ( if the list is {x,y} thr returned list will be sth. like \
{x[1], ..., y[1], ...} depending on number of pure straegies)."\)], "Print"]
}, Open  ]],

Cell["Let's see how it works.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(VarList[g, {x, y}]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({x[1], x[2], x[3], y[1], y[2]}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["\<\
Now, that we have all necessary components for Solve[] function we \
can try to actually use it.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquilibriumFilter[\ 
      Solve[\ SamplingEquilibriumEqs[g, \ {x, y}]\ , \ VarList[g, {x, y}]]]
      \)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \({{x[1.`] \[Rule] 0.403928362016678477`, 
        x[2.`] \[Rule] 0.355301397608120295`, 
        x[3.`] \[Rule] 0.240770240375201227`, 
        y[1.`] \[Rule] 0.403928362016678477`, 
        y[2.`] \[Rule] 0.596071637983321522`}}\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell["\<\
As you can note we have one real solution, but in general we can \
get (1) complex solution (2) solutions that are not probability \
distributions. To get rid of these cases there is a function \
EquilibriumFilter[]. The describion is as follows.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?EquilibriumFilter\)\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \("EquilibriumFilter[ sol] is a filter removing all complex solutions and \
those not on unit simplex. Suitable to apply on list of solutions returned by \
Solve[]. Arguments are: <sol> - list of solutions returned by Solve[] or \
other modules provided the list is of the same form."\)], "Print"]
}, Open  ]],

Cell["And see how it works.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquilibriumFilter[\ 
      Solve[\ SamplingEquilibriumEqs[g, \ {x, y}]\ , \ VarList[g, {x, y}]]]
      \)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({{x[1.`] \[Rule] 0.403928362016678477`, 
        x[2.`] \[Rule] 0.355301397608120295`, 
        x[3.`] \[Rule] 0.240770240375201227`, 
        y[1.`] \[Rule] 0.403928362016678477`, 
        y[2.`] \[Rule] 0.596071637983321522`}}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell["\<\
As above we can list the solutions in a more readable format.\
\>", 
  "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquilibriumFilter[\ 
        Solve[\ SamplingEquilibriumEqs[g, \ {x, y}]\ , \ 
          VarList[g, {x, y}]]] // ColumnForm\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            \({x[1.`] \[Rule] 0.403928362016678477`, 
              x[2.`] \[Rule] 0.355301397608120295`, 
              x[3.`] \[Rule] 0.240770240375201227`, 
              y[1.`] \[Rule] 0.403928362016678477`, 
              y[2.`] \[Rule] 0.596071637983321522`}\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {{x[ 1.0] -> .40392836201667848, x[ 
        2.0] -> .3553013976081203, x[ 3.0] -> .24077024037520123, y[ 
        1.0] -> .40392836201667848, y[ 2.0] -> .59607163798332152}}],
      Editable->False]], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell["\<\
Since we have only one solution it looks almost the same (but note \
missing brackets!).\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical equilibrium search", "Subsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[{
  "Sometimes (mostyl) it may happen that the system of algebraic equations \
describing all 1-sampling equilibria is just to complicated to be solved by \
Solve[] function. We can then try another approach, namely numerical search. \
In order to get solutions in this way we will use three functions: FindRoot[] \
which is ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function and two other functions defined in the packaeg."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?SamplingEquilibriumRoot\)\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \("SamplingEquilibriumRoot[ game, vars, k] returns the same list as \
SamplingEquilibriumEqs[] except for equations describing unit siplex. \
Argements are the same. Suitable to mix with VarListRoot[] and FindRoot[] \
modules for numerical search of 1-sampling equilibrium."\)], "Print"]
}, Open  ]],

Cell["\<\
VarListRoot[] function is very similar to VarList[] function but \
additionaly it also puts some numerical values to all variables. It is \
neccessary if we want to use FindRoot[] function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?VarListRoot\)\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \("VarListRoot[ game, vars, conds] returns a list of numerical initial \
conditions suitable to use as initial condtions for FindRoot[] or NDSolve[]. \
Arguments are: <game> - a game in Game[] form; <vars> - a list of names of \
variables; <conds> - a list of numerical initial conditions describing a \
point on a unit simplex."\)], "Print"]
}, Open  ]],

Cell["\<\
Let's see how these two work. First we defined system of equations.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(equs\  = \ SamplingEquilibriumRoot[\ g, \ {x, y}]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \({\(-x[1]\) + y[1]\^3 + 2\ y[1]\^2\ y[2] + y[1]\ y[2]\^2 == 0, 
      \(-x[2]\) + y[1]\ y[2]\^2 + y[2]\^3 == 0, 
      \(-x[3]\) + y[1]\^2\ y[2] + y[1]\ y[2]\^2 == 0, 
      x[1]\ x[2] + x[2]\^2 + 1\/2\ x[1]\ x[3] + x[2]\ x[3] - y[1] == 0, 
      x[1]\^2 + x[1]\ x[2] + 3\/2\ x[1]\ x[3] + x[2]\ x[3] + x[3]\^2 - 
          y[2] == 0}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell["\<\
Then we defined initial conditions where we start our searching \
from.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ini\  = \ 
      VarListRoot[\ g, \ {x, y}, \ {{ .3, \  .6, \  .1}, \ { .2, \  .8}}]\)], 
  "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    RowBox[{"Sequence", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\(x[1]\), ",", 
            StyleBox["0.3`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\(x[2]\), ",", 
            StyleBox["0.6`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\(x[3]\), ",", 
            StyleBox["0.1`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\(y[1]\), ",", 
            StyleBox["0.2`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\(y[2]\), ",", 
            StyleBox["0.8`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}], "}"}]}], "]"}]], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell["Now we only need to apply FindRoot[] function.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[equs, \ Evaluate[ini]]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \({x[1] \[Rule] 0.403928360931566565`, 
      x[2] \[Rule] 0.355301398717993777`, x[3] \[Rule] 0.240770240350439701`, 
      y[1] \[Rule] 0.403928360931566565`, y[2] \[Rule] 0.596071639068433434`}
      \)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sampling dynamics", "Subsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
Well, I included some support for sampling dynamics (evolutionary \
approach to sampling equilibria), but this support is far from being \
complete! None the less we can see some nice plots. We start with defining \
right hand sides of system of differential equations using \
WinningProbabilityDiff[] function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?WinningProbabilityDiff\)\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \("WinningProbabilityDiff[game,vars] gives a list of left hand sides of \
equation discribing 1-sampling equilibrium suitable to construct system of \
differential equation discribing 1-sampling dynamics. Arguments are: <game> - \
describtion of a game in Game[] form; <vars> - a list of names of variables."\
\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ode\  = \ WinningProbabilityDiff[g, {x, y}]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \({\(-x[1]\) + y[1]\^3 + 2\ y[1]\^2\ y[2] + y[1]\ y[2]\^2, 
      \(-x[2]\) + y[1]\ y[2]\^2 + y[2]\^3, 
      \(-x[3]\) + y[1]\^2\ y[2] + y[1]\ y[2]\^2, 
      x[1]\ x[2] + x[2]\^2 + 1\/2\ x[1]\ x[3] + x[2]\ x[3] - y[1], 
      x[1]\^2 + x[1]\ x[2] + 3\/2\ x[1]\ x[3] + x[2]\ x[3] + x[3]\^2 - y[2]}
      \)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell["\<\
Now the phase space is basically 6-dimensional. So in order to plot \
the vector field we have to drop something.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ode\  = \ Drop[ode, {5}]; \ ode\  = \ Drop[ode, \ {3}]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \({\(-x[1]\) + y[1]\^3 + 2\ y[1]\^2\ y[2] + y[1]\ y[2]\^2, 
      \(-x[2]\) + y[1]\ y[2]\^2 + y[2]\^3, 
      x[1]\ x[2] + x[2]\^2 + 1\/2\ x[1]\ x[3] + x[2]\ x[3] - y[1]}\)], 
  "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["\<\
Next we make use of equations describing unit simplex to get rid of \
variables related to dimensions we've just got rid of.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ode\  = \ 
      \(ode\  /. \ x[3] -> \((1 - x[1] - x[2])\)\) /. 
        y[2] -> \((1 - y[1])\)\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \({\(-x[1]\) + \((1 - y[1])\)\^2\ y[1] + 2\ \((1 - y[1])\)\ y[1]\^2 + 
        y[1]\^3, \(-x[2]\) + \((1 - y[1])\)\^3 + \((1 - y[1])\)\^2\ y[1], 
      1\/2\ x[1]\ \((1 - x[1] - x[2])\) + x[1]\ x[2] + 
        \((1 - x[1] - x[2])\)\ x[2] + x[2]\^2 - y[1]}\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["Now, we need a package to plot 3-d vector field.", "Text"],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  CellLabel->"In[32]:="],

Cell["And finally we can plot our vector field.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlotVectorField3D[ode, \ {x[1], \ 0, \ 1}, \n\ \ \ \ {x[2], \ 0, \ 1}, 
      \ {y[1], \ 0, \ 1}, \ PlotPoints\  -> \ 10, \n\ \ \ \ 
      VectorHeads\  -> \ True, \ ColorFunction -> Hue]\)], "Input",
  CellLabel->"In[33]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.08945 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0583709 1.16948 0 1.16948 [
[ 0 0 0 0 ]
[ 1 1.08945 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08847 .24498 m
0 .80663 L
s
0 .80663 m
.40122 1.08945 L
s
.40122 1.08945 m
.41873 .58224 L
s
.41873 .58224 m
.08847 .24498 L
s
.67137 0 m
.92714 .4158 L
s
.92714 .4158 m
1 .95223 L
s
1 .95223 m
.70506 .5889 L
s
.70506 .5889 m
.67137 0 L
s
.08847 .24498 m
0 .80663 L
s
0 .80663 m
.70506 .5889 L
s
.70506 .5889 m
.67137 0 L
s
.67137 0 m
.08847 .24498 L
s
.41873 .58224 m
.92714 .4158 L
s
.92714 .4158 m
1 .95223 L
s
1 .95223 m
.40122 1.08945 L
s
.40122 1.08945 m
.41873 .58224 L
s
0 0 m
1 0 L
1 1.08945 L
0 1.08945 L
closepath
clip
newpath
.156 0 1 r
.5 Mabswid
.42433 .5839 m
.42327 .61635 L
s
.42639 .61274 m
.41854 .6114 L
s
.42843 .60822 m
.42639 .61274 L
s
.42327 .61635 m
.42639 .61274 L
s
.41854 .6114 m
.42056 .60687 L
s
.41854 .6114 m
.42327 .61635 L
s
.42056 .60687 m
.42843 .60822 L
s
.42327 .61635 m
.42843 .60822 L
s
.47336 .56789 m
.46888 .60154 L
s
.42056 .60687 m
.42327 .61635 L
s
0 .2 1 r
.42282 .62999 m
.4214 .65418 L
s
.156 0 1 r
.47478 .59367 m
.47263 .59774 L
s
.47263 .59774 m
.46479 .59584 L
s
.47263 .59774 m
.46888 .60154 L
s
.46479 .59584 m
.46692 .59176 L
s
.46479 .59584 m
.46888 .60154 L
s
0 .308 1 r
.39521 .55409 m
.39633 .58551 L
s
.156 0 1 r
.46692 .59176 m
.47478 .59367 L
s
.46888 .60154 m
.47478 .59367 L
s
.46888 .60154 m
.46692 .59176 L
s
.157 0 1 r
.52332 .55156 m
.5153 .58605 L
s
0 .308 1 r
.3988 .58136 m
.39163 .58066 L
s
.40058 .57771 m
.3988 .58136 L
s
.3988 .58136 m
.39633 .58551 L
s
.39163 .58066 m
.3934 .577 L
s
.39633 .58551 m
.39163 .58066 L
s
0 .2 1 r
.42189 .65337 m
.41633 .64932 L
s
.42705 .64926 m
.42189 .65337 L
s
.4214 .65418 m
.42189 .65337 L
s
.157 0 1 r
.52191 .57854 m
.51971 .58215 L
s
.51971 .58215 m
.51192 .57967 L
s
.51971 .58215 m
.5153 .58605 L
s
0 .257 1 r
.47256 .61419 m
.46778 .63945 L
s
.157 0 1 r
.51192 .57967 m
.51411 .57605 L
s
.51192 .57967 m
.5153 .58605 L
s
0 .2 1 r
.41633 .64932 m
.42149 .6452 L
s
.41633 .64932 m
.4214 .65418 L
s
0 .308 1 r
.3934 .577 m
.40058 .57771 L
s
.40058 .57771 m
.39633 .58551 L
s
0 .2 1 r
.42149 .6452 m
.42705 .64926 L
s
.4214 .65418 m
.42705 .64926 L
s
0 .308 1 r
.39633 .58551 m
.3934 .577 L
s
0 .2 1 r
.42149 .6452 m
.4214 .65418 L
s
0 .277 1 r
.44483 .5375 m
.44239 .57039 L
s
.157 0 1 r
.51411 .57605 m
.52191 .57854 L
s
.5153 .58605 m
.52191 .57854 L
s
.5153 .58605 m
.51411 .57605 L
s
.163 0 1 r
.57427 .53492 m
.56253 .56988 L
s
0 .288 1 r
.42127 .67747 m
.41999 .69383 L
s
0 .277 1 r
.44157 .56603 m
.43775 .56287 L
s
.44802 .56468 m
.44157 .56603 L
s
.44157 .56603 m
.44239 .57039 L
s
0 .771 1 r
.39324 .60057 m
.39396 .62338 L
s
0 .277 1 r
.44421 .56151 m
.44802 .56468 L
s
.44802 .56468 m
.44239 .57039 L
s
0 .257 1 r
.47129 .63797 m
.46411 .6358 L
s
.4734 .63289 m
.47129 .63797 L
s
.46778 .63945 m
.47129 .63797 L
s
.46411 .6358 m
.4662 .63071 L
s
.46411 .6358 m
.46778 .63945 L
s
.163 0 1 r
.56985 .56283 m
.56763 .56595 L
s
.56763 .56595 m
.55995 .56286 L
s
.56763 .56595 m
.56253 .56988 L
s
.55995 .56286 m
.56215 .55973 L
s
.55995 .56286 m
.56253 .56988 L
s
0 .277 1 r
.43775 .56287 m
.44421 .56151 L
s
.44239 .57039 m
.43775 .56287 L
s
0 .306 1 r
.52328 .59807 m
.51501 .62403 L
s
0 .277 1 r
.44239 .57039 m
.44421 .56151 L
s
0 .257 1 r
.4662 .63071 m
.4734 .63289 L
s
.46778 .63945 m
.4734 .63289 L
s
.4662 .63071 m
.46778 .63945 L
s
0 .695 1 r
.36504 .52321 m
.36855 .5537 L
s
.163 0 1 r
.56215 .55973 m
.56985 .56283 L
s
.56253 .56988 m
.56985 .56283 L
s
.56253 .56988 m
.56215 .55973 L
s
0 .24 1 r
.49543 .52058 m
.4893 .55459 L
s
0 .695 1 r
.37031 .54897 m
.36376 .54895 L
s
.37193 .54619 m
.37031 .54897 L
s
.37031 .54897 m
.36855 .5537 L
s
.178 0 1 r
.62621 .51795 m
.61059 .55301 L
s
0 .695 1 r
.36376 .54895 m
.36537 .54617 L
s
.36855 .5537 m
.36376 .54895 L
s
0 .405 1 r
.47175 .66189 m
.46717 .6792 L
s
0 .771 1 r
.39242 .62201 m
.38933 .61786 L
s
.3983 .61971 m
.39242 .62201 L
s
.39396 .62338 m
.39242 .62201 L
s
.39522 .61555 m
.3983 .61971 L
s
.39396 .62338 m
.3983 .61971 L
s
0 .24 1 r
.48762 .54915 m
.48606 .54588 L
s
.495 .54962 m
.48762 .54915 L
s
.48762 .54915 m
.4893 .55459 L
s
0 .288 1 r
.42028 .69531 m
.41491 .69047 L
s
.42559 .69057 m
.42028 .69531 L
s
.41999 .69383 m
.42028 .69531 L
s
0 .695 1 r
.36537 .54617 m
.37193 .54619 L
s
.37193 .54619 m
.36855 .5537 L
s
.36855 .5537 m
.36537 .54617 L
s
0 .24 1 r
.49346 .54635 m
.495 .54962 L
s
.495 .54962 m
.4893 .55459 L
s
0 .771 1 r
.38933 .61786 m
.39522 .61555 L
s
.38933 .61786 m
.39396 .62338 L
s
0 .306 1 r
.52095 .62158 m
.51375 .62135 L
s
.51375 .62135 m
.51239 .61599 L
s
.51375 .62135 m
.51501 .62403 L
s
0 .288 1 r
.42023 .68572 m
.42559 .69057 L
s
.41999 .69383 m
.42559 .69057 L
s
.41491 .69047 m
.42023 .68572 L
s
.41491 .69047 m
.41999 .69383 L
s
.178 0 1 r
.61859 .54653 m
.61641 .54913 L
s
.61641 .54913 m
.60889 .5454 L
s
.61641 .54913 m
.61059 .55301 L
s
0 .771 1 r
.39522 .61555 m
.39396 .62338 L
s
.178 0 1 r
.60889 .5454 m
.61104 .54278 L
s
.60889 .5454 m
.61059 .55301 L
s
0 .306 1 r
.51962 .61622 m
.52095 .62158 L
s
.51501 .62403 m
.52095 .62158 L
s
0 .806 1 r
.4436 .58418 m
.44082 .60835 L
s
0 .288 1 r
.42023 .68572 m
.41999 .69383 L
s
0 .24 1 r
.48606 .54588 m
.49346 .54635 L
s
.4893 .55459 m
.48606 .54588 L
s
.4893 .55459 m
.49346 .54635 L
s
0 .306 1 r
.51239 .61599 m
.51962 .61622 L
s
.51239 .61599 m
.51501 .62403 L
s
0 .344 1 r
.575 .58163 m
.56308 .60791 L
s
0 .306 1 r
.51501 .62403 m
.51962 .61622 L
s
0 .157 1 r
.41967 .72639 m
.41907 .73537 L
s
.178 0 1 r
.61059 .55301 m
.61859 .54653 L
s
.61059 .55301 m
.61104 .54278 L
s
0 .635 1 r
.41527 .50601 m
.41508 .53826 L
s
.178 0 1 r
.61104 .54278 m
.61859 .54653 L
s
0 .194 1 r
.54703 .50333 m
.53706 .53809 L
s
0 .635 1 r
.41549 .53346 m
.41021 .53188 L
s
.42002 .53168 m
.41549 .53346 L
s
.41549 .53346 m
.41508 .53826 L
s
0 .922 1 r
.39121 .64846 m
.39205 .66313 L
s
.209 0 1 r
.67919 .50064 m
.65947 .53544 L
s
0 .806 1 r
.4437 .60634 m
.43732 .60478 L
s
.44544 .60217 m
.4437 .60634 L
s
.44082 .60835 m
.4437 .60634 L
s
0 .635 1 r
.41021 .53188 m
.41473 .5301 L
s
.41508 .53826 m
.41021 .53188 L
s
0 .51 1 r
.52323 .646 m
.51521 .66388 L
s
0 .635 1 r
.41473 .5301 m
.42002 .53168 L
s
.42002 .53168 m
.41508 .53826 L
s
0 .806 1 r
.43732 .60478 m
.43905 .6006 L
s
.43732 .60478 m
.44082 .60835 L
s
0 .194 1 r
.53556 .53171 m
.53505 .5288 L
s
.54307 .5334 m
.53556 .53171 L
s
.53556 .53171 m
.53706 .53809 L
s
0 .405 1 r
.46917 .68025 m
.46302 .67635 L
s
.47317 .67506 m
.46917 .68025 L
s
.46717 .6792 m
.46917 .68025 L
s
0 .194 1 r
.54258 .5305 m
.54307 .5334 L
s
.54307 .5334 m
.53706 .53809 L
s
0 .344 1 r
.57031 .60485 m
.56404 .60561 L
s
.56404 .60561 m
.56065 .60037 L
s
.56404 .60561 m
.56308 .60791 L
s
0 .635 1 r
.41508 .53826 m
.41473 .5301 L
s
0 .405 1 r
.46302 .67635 m
.46702 .67114 L
s
.46302 .67635 m
.46717 .6792 L
s
0 1 .713 r
.36257 .57006 m
.36565 .59161 L
s
.209 0 1 r
.66813 .52962 m
.66605 .53171 L
s
.66605 .53171 m
.65874 .52729 L
s
.66605 .53171 m
.65947 .53544 L
s
0 .806 1 r
.43905 .6006 m
.44544 .60217 L
s
.44082 .60835 m
.44544 .60217 L
s
.209 0 1 r
.65874 .52729 m
.66079 .52519 L
s
.65874 .52729 m
.65947 .53544 L
s
0 .405 1 r
.46702 .67114 m
.47317 .67506 L
s
.46717 .6792 m
.47317 .67506 L
s
0 .806 1 r
.43905 .6006 m
.44082 .60835 L
s
0 .405 1 r
.46702 .67114 m
.46717 .6792 L
s
0 .344 1 r
.56065 .60037 m
.56692 .5996 L
s
.56065 .60037 m
.56308 .60791 L
s
.56692 .5996 m
.57031 .60485 L
s
.56308 .60791 m
.57031 .60485 L
s
0 .825 1 r
.49495 .56747 m
.48855 .59261 L
s
0 .194 1 r
.53706 .53809 m
.54258 .5305 L
s
.53706 .53809 m
.53505 .5288 L
s
.53505 .5288 m
.54258 .5305 L
s
.209 0 1 r
.65947 .53544 m
.66813 .52962 L
s
.65947 .53544 m
.66079 .52519 L
s
0 .366 1 r
.62775 .56487 m
.61199 .59107 L
s
0 .978 1 r
.33376 .49118 m
.33989 .52088 L
s
0 .344 1 r
.56308 .60791 m
.56692 .5996 L
s
.209 0 1 r
.66079 .52519 m
.66813 .52962 L
s
0 .978 1 r
.3409 .51552 m
.33486 .51624 L
s
.34246 .51361 m
.3409 .51552 L
s
.3409 .51552 m
.33989 .52088 L
s
0 .328 1 r
.47091 .71106 m
.46705 .72087 L
s
0 .561 1 r
.4665 .48846 m
.46248 .52211 L
s
0 .978 1 r
.33486 .51624 m
.33641 .51433 L
s
.33989 .52088 m
.33486 .51624 L
s
0 1 .713 r
.36677 .5895 m
.36137 .58871 L
s
.36869 .58584 m
.36677 .5895 L
s
.36565 .59161 m
.36677 .5895 L
s
0 .561 1 r
.46208 .51663 m
.4584 .51447 L
s
.46817 .51625 m
.46208 .51663 L
s
.46208 .51663 m
.46248 .52211 L
s
0 1 .713 r
.36137 .58871 m
.36328 .58504 L
s
.36565 .59161 m
.36137 .58871 L
s
0 .978 1 r
.33989 .52088 m
.33641 .51433 L
s
.34246 .51361 m
.33989 .52088 L
s
0 .922 1 r
.39132 .66419 m
.38734 .65973 L
s
.39642 .66059 m
.39132 .66419 L
s
.39205 .66313 m
.39132 .66419 L
s
0 .978 1 r
.33641 .51433 m
.34246 .51361 L
s
0 .134 1 r
.59966 .48573 m
.58567 .52087 L
s
0 1 .713 r
.36328 .58504 m
.36869 .58584 L
s
.36869 .58584 m
.36565 .59161 L
s
0 .922 1 r
.39244 .65613 m
.39642 .66059 L
s
.39205 .66313 m
.39642 .66059 L
s
0 1 .968 r
.44232 .63231 m
.43971 .6482 L
s
0 .157 1 r
.41906 .73901 m
.41358 .73341 L
s
.4248 .73368 m
.41906 .73901 L
s
.41907 .73537 m
.41906 .73901 L
s
0 .825 1 r
.49434 .58889 m
.48882 .59025 L
s
.48882 .59025 m
.48533 .5862 L
s
.48882 .59025 m
.48855 .59261 L
s
0 .922 1 r
.38734 .65973 m
.39244 .65613 L
s
.38734 .65973 m
.39205 .66313 L
s
0 .157 1 r
.41932 .72808 m
.4248 .73368 L
s
.41907 .73537 m
.4248 .73368 L
s
0 .561 1 r
.4645 .51409 m
.46817 .51625 L
s
.46817 .51625 m
.46248 .52211 L
s
0 .157 1 r
.41358 .73341 m
.41932 .72808 L
s
.41358 .73341 m
.41907 .73537 L
s
0 1 .713 r
.36328 .58504 m
.36565 .59161 L
s
0 .134 1 r
.58474 .51369 m
.58475 .51125 L
s
.5922 .51638 m
.58474 .51369 L
s
.58474 .51369 m
.58567 .52087 L
s
.265 0 1 r
.73323 .48299 m
.70917 .51715 L
s
0 .157 1 r
.41932 .72808 m
.41907 .73537 L
s
0 .922 1 r
.39244 .65613 m
.39205 .66313 L
s
0 .134 1 r
.59223 .51396 m
.5922 .51638 L
s
.5922 .51638 m
.58567 .52087 L
s
0 .51 1 r
.519 .66449 m
.51233 .66164 L
s
.51233 .66164 m
.51466 .65603 L
s
.51233 .66164 m
.51521 .66388 L
s
0 .561 1 r
.4584 .51447 m
.4645 .51409 L
s
.46248 .52211 m
.4584 .51447 L
s
0 .51 1 r
.52134 .65888 m
.519 .66449 L
s
.51521 .66388 m
.519 .66449 L
s
0 .366 1 r
.61998 .5879 m
.61465 .58894 L
s
.61465 .58894 m
.61036 .58369 L
s
.61465 .58894 m
.61199 .59107 L
s
0 .598 1 r
.57575 .62979 m
.56413 .64783 L
s
0 .825 1 r
.49085 .58484 m
.49434 .58889 L
s
.48855 .59261 m
.49434 .58889 L
s
0 .561 1 r
.46248 .52211 m
.4645 .51409 L
s
0 .825 1 r
.48533 .5862 m
.49085 .58484 L
s
.48533 .5862 m
.48855 .59261 L
s
.265 0 1 r
.71848 .51209 m
.71658 .51366 L
s
.71658 .51366 m
.70952 .50851 L
s
.71658 .51366 m
.70917 .51715 L
s
.70952 .50851 m
.7114 .50693 L
s
.70952 .50851 m
.70917 .51715 L
s
.121 0 1 r
.41802 .77682 m
.41865 .77884 L
s
0 .366 1 r
.61036 .58369 m
.61568 .58264 L
s
.61036 .58369 m
.61199 .59107 L
s
0 .51 1 r
.51466 .65603 m
.52134 .65888 L
s
.51466 .65603 m
.51521 .66388 L
s
0 1 .7 r
.41355 .55307 m
.41298 .57625 L
s
0 .51 1 r
.51521 .66388 m
.52134 .65888 L
s
0 .825 1 r
.48855 .59261 m
.49085 .58484 L
s
0 .134 1 r
.58567 .52087 m
.59223 .51396 L
s
.58567 .52087 m
.58475 .51125 L
s
0 .366 1 r
.61568 .58264 m
.61998 .5879 L
s
.61199 .59107 m
.61998 .5879 L
s
0 .134 1 r
.58475 .51125 m
.59223 .51396 L
s
.265 0 1 r
.70917 .51715 m
.71848 .51209 L
s
.70917 .51715 m
.7114 .50693 L
s
0 .825 1 r
.54735 .55042 m
.53716 .57616 L
s
0 .366 1 r
.61199 .59107 m
.61568 .58264 L
s
0 .798 1 r
.38911 .69785 m
.39062 .7048 L
s
.265 0 1 r
.7114 .50693 m
.71848 .51209 L
s
0 .892 1 r
.38742 .49958 m
.38189 .49923 L
s
.39096 .49823 m
.38742 .49958 L
s
.38742 .49958 m
.38688 .50509 L
s
0 .361 1 r
.68156 .54777 m
.66176 .57352 L
s
0 .892 1 r
.3846 .47334 m
.38688 .50509 L
s
0 .484 1 r
.52318 .69542 m
.51593 .70566 L
s
0 1 .7 r
.41519 .57366 m
.40958 .57274 L
s
.41662 .57042 m
.41519 .57366 L
s
.41519 .57366 m
.41298 .57625 L
s
0 .892 1 r
.38189 .49923 m
.38543 .49788 L
s
.38688 .50509 m
.38189 .49923 L
s
0 .474 1 r
.51877 .47056 m
.51076 .50526 L
s
.51024 .49893 m
.50773 .49678 L
s
.517 .49982 m
.51024 .49893 L
s
.51024 .49893 m
.51076 .50526 L
s
0 1 .7 r
.40958 .57274 m
.411 .5695 L
s
.41298 .57625 m
.40958 .57274 L
s
0 .892 1 r
.38543 .49788 m
.39096 .49823 L
s
.39096 .49823 m
.38688 .50509 L
s
.38688 .50509 m
.38543 .49788 L
s
0 1 .477 r
.36002 .61838 m
.3632 .63143 L
s
0 1 .968 r
.44082 .6488 m
.43583 .6453 L
s
.44465 .64468 m
.44082 .6488 L
s
.43971 .6482 m
.44082 .6488 L
s
0 .825 1 r
.54372 .57196 m
.53956 .5738 L
s
.53956 .5738 m
.5347 .57 L
s
.53956 .5738 m
.53716 .57616 L
s
0 1 .968 r
.43583 .6453 m
.43966 .64117 L
s
.43583 .6453 m
.43971 .6482 L
s
0 .056 1 r
.65336 .46777 m
.63514 .50294 L
s
0 .474 1 r
.51451 .49767 m
.517 .49982 L
s
.517 .49982 m
.51076 .50526 L
s
0 .328 1 r
.46832 .72412 m
.46246 .71922 L
s
.47321 .71854 m
.46832 .72412 L
s
.46705 .72087 m
.46832 .72412 L
s
0 1 .7 r
.411 .5695 m
.41662 .57042 L
s
.41662 .57042 m
.41298 .57625 L
s
0 .328 1 r
.46246 .71922 m
.46734 .71365 L
s
.46246 .71922 m
.46705 .72087 L
s
0 1 .968 r
.43966 .64117 m
.44465 .64468 L
s
.43971 .6482 m
.44465 .64468 L
s
0 .056 1 r
.63499 .49504 m
.63525 .49311 L
s
.64232 .49867 m
.63499 .49504 L
s
.63499 .49504 m
.63514 .50294 L
s
0 .328 1 r
.46734 .71365 m
.47321 .71854 L
s
.46705 .72087 m
.47321 .71854 L
s
0 1 .879 r
.49446 .61582 m
.48828 .63255 L
s
0 .056 1 r
.6426 .49674 m
.64232 .49867 L
s
.64232 .49867 m
.63514 .50294 L
s
0 1 .7 r
.41298 .57625 m
.411 .5695 L
s
0 .598 1 r
.56952 .64804 m
.5628 .6462 L
s
.5628 .6462 m
.56343 .64033 L
s
.5628 .6462 m
.56413 .64783 L
s
0 .328 1 r
.46734 .71365 m
.46705 .72087 L
s
0 1 .968 r
.43966 .64117 m
.43971 .6482 L
s
0 .825 1 r
.5347 .57 m
.53886 .56815 L
s
.5347 .57 m
.53716 .57616 L
s
0 .361 1 r
.67035 .5706 m
.66578 .57154 L
s
.66578 .57154 m
.66116 .56608 L
s
.66578 .57154 m
.66176 .57352 L
s
.355 0 1 r
.76965 .49394 m
.768 .49498 L
s
.768 .49498 m
.76124 .48904 L
s
.768 .49498 m
.75969 .49813 L
s
.76124 .48904 m
.76287 .48798 L
s
.76124 .48904 m
.75969 .49813 L
s
0 .474 1 r
.51076 .50526 m
.51451 .49767 L
s
.51076 .50526 m
.50773 .49678 L
s
.355 0 1 r
.78837 .46498 m
.75969 .49813 L
s
0 .598 1 r
.57017 .64217 m
.56952 .64804 L
s
.56413 .64783 m
.56952 .64804 L
s
0 .474 1 r
.50773 .49678 m
.51451 .49767 L
s
0 .825 1 r
.53886 .56815 m
.54372 .57196 L
s
.53716 .57616 m
.54372 .57196 L
s
0 .361 1 r
.66116 .56608 m
.66571 .56512 L
s
.66116 .56608 m
.66176 .57352 L
s
0 .661 1 r
.62933 .61325 m
.61393 .63106 L
s
0 1 .285 r
.33075 .53842 m
.33642 .55881 L
s
0 .598 1 r
.56343 .64033 m
.57017 .64217 L
s
.56343 .64033 m
.56413 .64783 L
s
0 .056 1 r
.63514 .50294 m
.6426 .49674 L
s
.63514 .50294 m
.63525 .49311 L
s
0 .094 1 r
.47004 .76176 m
.46746 .76451 L
s
0 .825 1 r
.53716 .57616 m
.53886 .56815 L
s
0 .598 1 r
.56413 .64783 m
.57017 .64217 L
s
.355 0 1 r
.75969 .49813 m
.76965 .49394 L
s
.75969 .49813 m
.76287 .48798 L
s
0 .361 1 r
.66571 .56512 m
.67035 .5706 L
s
.66176 .57352 m
.67035 .5706 L
s
0 1 .713 r
.46557 .53572 m
.46123 .56017 L
s
0 1 .871 r
.3105 .48095 m
.30484 .48249 L
s
.31217 .47989 m
.3105 .48095 L
s
.3105 .48095 m
.31031 .48701 L
s
0 .056 1 r
.63525 .49311 m
.6426 .49674 L
s
0 .361 1 r
.66176 .57352 m
.66571 .56512 L
s
0 1 .871 r
.30484 .48249 m
.3065 .48144 L
s
.31031 .48701 m
.30484 .48249 L
s
.355 0 1 r
.76287 .48798 m
.76965 .49394 L
s
0 1 .285 r
.33432 .55673 m
.33195 .55484 L
s
.33861 .55459 m
.33432 .55673 L
s
.33642 .55881 m
.33432 .55673 L
s
0 .802 1 r
.60081 .53303 m
.58665 .55898 L
s
0 1 .871 r
.30129 .45795 m
.31031 .48701 L
s
.31031 .48701 m
.3065 .48144 L
s
.31217 .47989 m
.31031 .48701 L
s
0 1 .285 r
.33625 .5527 m
.33861 .55459 L
s
.33861 .55459 m
.33642 .55881 L
s
0 .786 1 r
.43493 .48257 m
.43029 .48161 L
s
.43995 .48216 m
.43493 .48257 L
s
.43493 .48257 m
.43478 .48858 L
s
0 .978 1 r
.441 .68194 m
.43911 .69 L
s
0 1 .871 r
.3065 .48144 m
.31217 .47989 L
s
0 1 .477 r
.3613 .632 m
.35898 .62792 L
s
.36614 .62968 m
.3613 .632 L
s
.3632 .63143 m
.3613 .632 L
s
.36382 .62559 m
.36614 .62968 L
s
.3632 .63143 m
.36614 .62968 L
s
0 .321 1 r
.73647 .53032 m
.71239 .55523 L
s
0 .786 1 r
.43649 .45513 m
.43478 .48858 L
s
0 1 .285 r
.33195 .55484 m
.33625 .5527 L
s
.33642 .55881 m
.33195 .55484 L
s
0 .798 1 r
.38986 .70809 m
.38552 .703 L
s
.39511 .70378 m
.38986 .70809 L
s
.39062 .7048 m
.38986 .70809 L
s
.39077 .69869 m
.39511 .70378 L
s
.39062 .7048 m
.39511 .70378 L
s
.121 0 1 r
.4246 .77867 m
.41826 .78452 L
s
.41879 .77234 m
.4246 .77867 L
s
.41865 .77884 m
.4246 .77867 L
s
0 1 .285 r
.33625 .5527 m
.33642 .55881 L
s
.121 0 1 r
.41244 .77819 m
.41879 .77234 L
s
.41879 .77234 m
.41865 .77884 L
s
0 1 .477 r
.35898 .62792 m
.36382 .62559 L
s
.35898 .62792 m
.3632 .63143 L
s
0 .619 1 r
.57652 .67946 m
.56572 .68971 L
s
0 1 .713 r
.4654 .5544 m
.46454 .5573 L
s
.46454 .5573 m
.4588 .55611 L
s
.46454 .5573 m
.46123 .56017 L
s
.121 0 1 r
.41826 .78452 m
.41244 .77819 L
s
.41865 .77884 m
.41826 .78452 L
s
0 .798 1 r
.38552 .703 m
.39077 .69869 L
s
.38552 .703 m
.39062 .7048 L
s
0 1 .477 r
.36382 .62559 m
.3632 .63143 L
s
.121 0 1 r
.41244 .77819 m
.41865 .77884 L
s
0 .798 1 r
.39077 .69869 m
.39062 .7048 L
s
0 1 .713 r
.4588 .55611 m
.45965 .5532 L
s
.4588 .55611 m
.46123 .56017 L
s
0 .371 1 r
.55974 .48051 m
.55797 .47864 L
s
.56677 .48254 m
.55974 .48051 L
s
.55974 .48051 m
.55993 .48768 L
s
0 .786 1 r
.43531 .4812 m
.43995 .48216 L
s
.43995 .48216 m
.43478 .48858 L
s
.43029 .48161 m
.43531 .4812 L
s
.43478 .48858 m
.43029 .48161 L
s
.43478 .48858 m
.43531 .4812 L
s
0 .371 1 r
.57211 .45229 m
.55993 .48768 L
s
.478 0 1 r
.41632 .82884 m
.41877 .82431 L
s
0 1 .879 r
.49147 .63263 m
.48571 .63037 L
s
.49336 .62797 m
.49147 .63263 L
s
.48828 .63255 m
.49147 .63263 L
s
.48571 .63037 m
.48759 .62571 L
s
.48571 .63037 m
.48828 .63255 L
s
0 .371 1 r
.56502 .48067 m
.56677 .48254 L
s
.56677 .48254 m
.55993 .48768 L
s
0 .802 1 r
.59379 .55493 m
.59039 .5566 L
s
.59039 .5566 m
.58521 .55259 L
s
.59039 .5566 m
.58665 .55898 L
s
0 .484 1 r
.51857 .70857 m
.51238 .70444 L
s
.51238 .70444 m
.51623 .6986 L
s
.51238 .70444 m
.51593 .70566 L
s
.048 0 1 r
.68626 .47574 m
.68658 .47432 L
s
.69341 .48027 m
.68626 .47574 L
s
.68626 .47574 m
.68546 .48427 L
s
0 1 .367 r
.41178 .60161 m
.41136 .61617 L
s
0 .484 1 r
.52243 .70273 m
.51857 .70857 L
s
.51593 .70566 m
.51857 .70857 L
s
.048 0 1 r
.69376 .47887 m
.69341 .48027 L
s
.69341 .48027 m
.68546 .48427 L
s
0 .661 1 r
.62057 .63103 m
.61423 .62991 L
s
.61423 .62991 m
.61351 .6239 L
s
.61423 .62991 m
.61393 .63106 L
s
.491 0 1 r
.82164 .47516 m
.82031 .47568 L
s
.82031 .47568 m
.8139 .46889 L
s
.82031 .47568 m
.81104 .47837 L
s
.8139 .46889 m
.8152 .46834 L
s
.8139 .46889 m
.81104 .47837 L
s
0 .802 1 r
.58521 .55259 m
.5886 .55091 L
s
.58521 .55259 m
.58665 .55898 L
s
0 1 .713 r
.45965 .5532 m
.4654 .5544 L
s
.46123 .56017 m
.4654 .5544 L
s
0 .321 1 r
.72152 .55281 m
.7176 .5535 L
s
.7176 .5535 m
.71295 .54764 L
s
.7176 .5535 m
.71239 .55523 L
s
.048 0 1 r
.70816 .44945 m
.68546 .48427 L
s
0 1 .713 r
.46123 .56017 m
.45965 .5532 L
s
0 .484 1 r
.51623 .6986 m
.52243 .70273 L
s
.51623 .6986 m
.51593 .70566 L
s
0 1 .879 r
.48759 .62571 m
.49336 .62797 L
s
.48828 .63255 m
.49336 .62797 L
s
.48759 .62571 m
.48828 .63255 L
s
0 .484 1 r
.51593 .70566 m
.52243 .70273 L
s
0 .371 1 r
.55993 .48768 m
.56502 .48067 L
s
.55993 .48768 m
.55797 .47864 L
s
0 .321 1 r
.71295 .54764 m
.71685 .54693 L
s
.71295 .54764 m
.71239 .55523 L
s
0 1 .818 r
.54768 .599 m
.53776 .61617 L
s
0 .661 1 r
.61986 .62501 m
.62057 .63103 L
s
.61393 .63106 m
.62057 .63103 L
s
0 .371 1 r
.55797 .47864 m
.56502 .48067 L
s
0 .661 1 r
.61351 .6239 m
.61986 .62501 L
s
.61351 .6239 m
.61393 .63106 L
s
.048 0 1 r
.68546 .48427 m
.69376 .47887 L
s
.68546 .48427 m
.68658 .47432 L
s
0 .802 1 r
.5886 .55091 m
.59379 .55493 L
s
.58665 .55898 m
.59379 .55493 L
s
.491 0 1 r
.84463 .4466 m
.81104 .47837 L
s
0 .488 1 r
.38695 .74878 m
.3897 .74845 L
s
.491 0 1 r
.81104 .47837 m
.82164 .47516 L
s
.81104 .47837 m
.8152 .46834 L
s
0 .802 1 r
.58665 .55898 m
.5886 .55091 L
s
0 .691 1 r
.68401 .59638 m
.66461 .61354 L
s
0 1 .291 r
.38237 .52077 m
.38424 .5431 L
s
0 .661 1 r
.61393 .63106 m
.61986 .62501 L
s
.048 0 1 r
.68658 .47432 m
.69376 .47887 L
s
0 .321 1 r
.71685 .54693 m
.72152 .55281 L
s
.71239 .55523 m
.72152 .55281 L
s
.71239 .55523 m
.71685 .54693 L
s
0 .291 1 r
.52313 .7464 m
.5172 .74944 L
s
0 1 .974 r
.35798 .46454 m
.35244 .46528 L
s
.3611 .46385 m
.35798 .46454 L
s
.35798 .46454 m
.35776 .47084 L
s
.491 0 1 r
.8152 .46834 m
.82164 .47516 L
s
0 1 .755 r
.51865 .51803 m
.51038 .54336 L
s
0 1 .588 r
.35739 .66822 m
.36124 .67322 L
s
0 1 .291 r
.38572 .53988 m
.38079 .53966 L
s
.38694 .53758 m
.38572 .53988 L
s
.38572 .53988 m
.38424 .5431 L
s
0 1 .974 r
.35244 .46528 m
.35555 .46458 L
s
.35776 .47084 m
.35244 .46528 L
s
.35776 .47084 m
.35555 .46458 L
s
.3611 .46385 m
.35776 .47084 L
s
.35277 .43943 m
.35776 .47084 L
s
0 .661 1 r
.48368 .46463 m
.4799 .46347 L
s
.48963 .4653 m
.48368 .46463 L
s
.48368 .46463 m
.4836 .47135 L
s
0 1 .291 r
.38079 .53966 m
.38201 .53735 L
s
.38424 .5431 m
.38079 .53966 L
s
0 .747 1 r
.65537 .51527 m
.63703 .54106 L
s
0 1 .974 r
.35555 .46458 m
.3611 .46385 L
s
0 1 .367 r
.41129 .61629 m
.40774 .61308 L
s
.41515 .6134 m
.41129 .61629 L
s
.41136 .61617 m
.41129 .61629 L
s
0 1 .868 r
.49396 .6657 m
.48854 .67447 L
s
0 1 .367 r
.4116 .61019 m
.41515 .6134 L
s
.41136 .61617 m
.41515 .6134 L
s
0 .978 1 r
.43964 .69284 m
.43489 .68845 L
s
.4441 .68829 m
.43964 .69284 L
s
.43911 .69 m
.43964 .69284 L
s
0 1 .291 r
.38201 .53735 m
.38694 .53758 L
s
.38694 .53758 m
.38424 .5431 L
s
0 1 .367 r
.40774 .61308 m
.4116 .61019 L
s
.40774 .61308 m
.41136 .61617 L
s
0 .978 1 r
.43489 .68845 m
.43934 .6839 L
s
.43489 .68845 m
.43911 .69 L
s
0 1 .755 r
.51545 .53809 m
.51428 .54047 L
s
.51428 .54047 m
.50864 .53845 L
s
.51428 .54047 m
.51038 .54336 L
s
0 .661 1 r
.48586 .46414 m
.48963 .4653 L
s
.48963 .4653 m
.4836 .47135 L
s
0 .094 1 r
.46814 .7698 m
.46215 .7641 L
s
.46215 .7641 m
.46782 .7581 L
s
.46215 .7641 m
.46746 .76451 L
s
0 1 .291 r
.38424 .5431 m
.38201 .53735 L
s
0 .246 1 r
.61041 .46141 m
.60907 .45992 L
s
.61753 .4645 m
.61041 .46141 L
s
.61041 .46141 m
.60999 .46936 L
s
0 .234 1 r
.79252 .51251 m
.76387 .53619 L
s
0 .661 1 r
.48944 .43654 m
.4836 .47135 L
s
0 .094 1 r
.46782 .7581 m
.47381 .7638 L
s
.46782 .7581 m
.46746 .76451 L
s
0 .978 1 r
.43934 .6839 m
.4441 .68829 L
s
.43911 .69 m
.4441 .68829 L
s
0 .094 1 r
.47381 .7638 m
.46814 .7698 L
s
.46746 .76451 m
.46814 .7698 L
s
0 1 .755 r
.50864 .53845 m
.50979 .53607 L
s
.50864 .53845 m
.51038 .54336 L
s
0 .094 1 r
.46746 .76451 m
.47381 .7638 L
s
0 .978 1 r
.43934 .6839 m
.43911 .69 L
s
0 1 .367 r
.4116 .61019 m
.41136 .61617 L
s
0 1 .818 r
.54274 .61571 m
.53695 .61463 L
s
.53695 .61463 m
.53678 .60971 L
s
.53695 .61463 m
.53776 .61617 L
s
0 .661 1 r
.4836 .47135 m
.48586 .46414 L
s
.4836 .47135 m
.4799 .46347 L
s
0 .725 1 r
.63096 .66317 m
.61642 .67302 L
s
.067 1 0 r
.32765 .58715 m
.33341 .59869 L
s
0 .246 1 r
.61622 .46302 m
.61753 .4645 L
s
.61753 .4645 m
.60999 .46936 L
s
0 .661 1 r
.4799 .46347 m
.48586 .46414 L
s
.186 0 1 r
.73855 .45575 m
.73878 .45484 L
s
.74546 .46122 m
.73855 .45575 L
s
.73855 .45575 m
.73664 .46486 L
s
0 .747 1 r
.64475 .53745 m
.64187 .53877 L
s
.64187 .53877 m
.63668 .53431 L
s
.64187 .53877 m
.63703 .54106 L
s
0 .619 1 r
.5697 .69236 m
.56337 .68899 L
s
.56337 .68899 m
.56611 .68292 L
s
.56337 .68899 m
.56572 .68971 L
s
.681 0 1 r
.87444 .45573 m
.87353 .45575 L
s
.87353 .45575 m
.86752 .44802 L
s
.87353 .45575 m
.86321 .45786 L
s
.86752 .44802 m
.8684 .44796 L
s
.86752 .44802 m
.86321 .45786 L
s
0 1 .818 r
.54258 .61078 m
.54274 .61571 L
s
.53776 .61617 m
.54274 .61571 L
s
.186 0 1 r
.74572 .46034 m
.74546 .46122 L
s
.74546 .46122 m
.73664 .46486 L
s
0 .691 1 r
.67218 .61352 m
.66646 .6128 L
s
.66646 .6128 m
.66487 .60665 L
s
.66646 .6128 m
.66461 .61354 L
s
0 .246 1 r
.62655 .43365 m
.60999 .46936 L
s
.23 0 1 r
.46915 .81408 m
.46842 .81017 L
s
0 .747 1 r
.63668 .53431 m
.63955 .53298 L
s
.63668 .53431 m
.63703 .54106 L
s
0 .619 1 r
.57245 .68629 m
.5697 .69236 L
s
.56572 .68971 m
.5697 .69236 L
s
0 .234 1 r
.77353 .53446 m
.77022 .53482 L
s
.77022 .53482 m
.76571 .52842 L
s
.77022 .53482 m
.76387 .53619 L
s
0 1 .818 r
.53678 .60971 m
.54258 .61078 L
s
.53678 .60971 m
.53776 .61617 L
s
0 .246 1 r
.60999 .46936 m
.61622 .46302 L
s
.60999 .46936 m
.60907 .45992 L
s
0 .619 1 r
.56611 .68292 m
.57245 .68629 L
s
.56611 .68292 m
.56572 .68971 L
s
0 .234 1 r
.76571 .52842 m
.76901 .52803 L
s
.76571 .52842 m
.76387 .53619 L
s
0 1 .755 r
.51038 .54336 m
.51545 .53809 L
s
.51038 .54336 m
.50979 .53607 L
s
.50979 .53607 m
.51545 .53809 L
s
0 1 .294 r
.4646 .58449 m
.46046 .60019 L
s
0 .619 1 r
.56572 .68971 m
.57245 .68629 L
s
0 .691 1 r
.66487 .60665 m
.6706 .60735 L
s
.66487 .60665 m
.66461 .61354 L
s
0 1 .818 r
.53776 .61617 m
.54258 .61078 L
s
.186 0 1 r
.73664 .46486 m
.74572 .46034 L
s
.73664 .46486 m
.73878 .45484 L
s
.76409 .43075 m
.73664 .46486 L
s
.681 0 1 r
.86321 .45786 m
.87444 .45573 L
s
.86321 .45786 m
.8684 .44796 L
s
.90206 .42783 m
.86321 .45786 L
s
0 .246 1 r
.60907 .45992 m
.61622 .46302 L
s
0 1 .871 r
.27908 .44522 m
.27362 .44767 L
s
.28104 .44497 m
.27908 .44522 L
s
.27908 .44522 m
.27976 .45203 L
s
0 .691 1 r
.6706 .60735 m
.67218 .61352 L
s
.66461 .61354 m
.67218 .61352 L
s
0 .747 1 r
.63703 .54106 m
.64475 .53745 L
s
.63703 .54106 m
.63955 .53298 L
s
.63955 .53298 m
.64475 .53745 L
s
0 1 .792 r
.60199 .58183 m
.58816 .59905 L
s
.005 1 0 r
.29771 .50556 m
.30624 .52494 L
s
0 1 .871 r
.27362 .44767 m
.27557 .44743 L
s
.27976 .45203 m
.27362 .44767 L
s
0 .234 1 r
.76387 .53619 m
.77353 .53446 L
s
.76387 .53619 m
.76901 .52803 L
s
0 1 .871 r
.27976 .45203 m
.27557 .44743 L
s
.28104 .44497 m
.27976 .45203 L
s
.26759 .42345 m
.27976 .45203 L
s
0 .72 1 r
.43964 .73315 m
.43904 .73382 L
s
0 .691 1 r
.66461 .61354 m
.6706 .60735 L
s
.186 0 1 r
.73878 .45484 m
.74572 .46034 L
s
0 .234 1 r
.76901 .52803 m
.77353 .53446 L
s
.005 1 0 r
.30698 .52078 m
.30284 .52264 L
s
.30623 .51947 m
.30698 .52078 L
s
.30698 .52078 m
.30624 .52494 L
s
.30284 .52264 m
.30208 .52133 L
s
.30624 .52494 m
.30284 .52264 L
s
.681 0 1 r
.8684 .44796 m
.87444 .45573 L
s
0 .673 1 r
.73982 .57915 m
.71618 .59527 L
s
0 1 .338 r
.43506 .50276 m
.433 .52665 L
s
0 .895 1 r
.40637 .44719 m
.40124 .44737 L
s
.41076 .44717 m
.40637 .44719 L
s
.40637 .44719 m
.40617 .45395 L
s
0 1 .871 r
.27557 .44743 m
.28104 .44497 L
s
.067 1 0 r
.33457 .59769 m
.33032 .59866 L
s
.33419 .59408 m
.33457 .59769 L
s
.33341 .59869 m
.33457 .59769 L
s
0 .465 1 r
.57732 .73071 m
.56788 .73362 L
s
.067 1 0 r
.33032 .59866 m
.32993 .59505 L
s
.33341 .59869 m
.33032 .59866 L
s
.478 0 1 r
.41864 .81855 m
.42494 .8256 L
s
.4116 .82486 m
.41864 .81855 L
s
.41864 .81855 m
.41877 .82431 L
s
.005 1 0 r
.30624 .52494 m
.30208 .52133 L
s
.30623 .51947 m
.30624 .52494 L
s
0 1 .588 r
.3644 .67286 m
.3597 .67614 L
s
.36122 .66829 m
.3644 .67286 L
s
.36124 .67322 m
.3644 .67286 L
s
.478 0 1 r
.42494 .8256 m
.41791 .83192 L
s
.41877 .82431 m
.42494 .8256 L
s
0 1 .588 r
.3597 .67614 m
.35652 .67157 L
s
.36124 .67322 m
.3597 .67614 L
s
0 .488 1 r
.39445 .74897 m
.38868 .75385 L
s
.38961 .74319 m
.39445 .74897 L
s
.3897 .74845 m
.39445 .74897 L
s
.005 1 0 r
.30208 .52133 m
.30623 .51947 L
s
.067 1 0 r
.32993 .59505 m
.33419 .59408 L
s
.33419 .59408 m
.33341 .59869 L
s
0 .488 1 r
.38383 .74807 m
.38961 .74319 L
s
.38961 .74319 m
.3897 .74845 L
s
0 1 .828 r
.57284 .49996 m
.56045 .52581 L
s
.868 0 1 r
.41456 .88252 m
.41946 .87184 L
s
0 1 .338 r
.43272 .52315 m
.42979 .52133 L
s
.43703 .52239 m
.43272 .52315 L
s
.43272 .52315 m
.433 .52665 L
s
0 1 .588 r
.35652 .67157 m
.36122 .66829 L
s
.36122 .66829 m
.36124 .67322 L
s
.478 0 1 r
.41791 .83192 m
.4116 .82486 L
s
.4116 .82486 m
.41877 .82431 L
s
0 .488 1 r
.38868 .75385 m
.38383 .74807 L
s
.3897 .74845 m
.38868 .75385 L
s
.067 1 0 r
.32993 .59505 m
.33341 .59869 L
s
0 1 .588 r
.35652 .67157 m
.36124 .67322 L
s
0 .488 1 r
.38383 .74807 m
.3897 .74845 L
s
0 .895 1 r
.40617 .45395 m
.40563 .44734 L
s
.40617 .45395 m
.40124 .44737 L
s
.41076 .44717 m
.40617 .45395 L
s
.40532 .42051 m
.40617 .45395 L
s
0 .516 1 r
.53368 .44587 m
.53055 .44479 L
s
.54018 .44763 m
.53368 .44587 L
s
.53368 .44587 m
.53334 .45337 L
s
.478 0 1 r
.41877 .82431 m
.41791 .83192 L
s
0 .895 1 r
.40124 .44737 m
.40563 .44734 L
s
.40563 .44734 m
.41076 .44717 L
s
0 1 .388 r
.40995 .6517 m
.41024 .6581 L
s
0 1 .338 r
.4341 .52056 m
.43703 .52239 L
s
.43703 .52239 m
.433 .52665 L
s
0 1 .294 r
.463 .59969 m
.45814 .59804 L
s
.46445 .59601 m
.463 .59969 L
s
.46046 .60019 m
.463 .59969 L
s
.45814 .59804 m
.45959 .59436 L
s
.45814 .59804 m
.46046 .60019 L
s
0 .653 1 r
.71106 .49715 m
.6883 .52239 L
s
0 1 .338 r
.42979 .52133 m
.4341 .52056 L
s
.433 .52665 m
.42979 .52133 L
s
0 1 .868 r
.49049 .67691 m
.48535 .67332 L
s
.49392 .67208 m
.49049 .67691 L
s
.48854 .67447 m
.49049 .67691 L
s
0 .516 1 r
.53707 .44656 m
.54018 .44763 L
s
.54018 .44763 m
.53334 .45337 L
s
0 1 .868 r
.48535 .67332 m
.48877 .66848 L
s
.48535 .67332 m
.48854 .67447 L
s
0 .095 1 r
.66219 .44162 m
.66106 .44057 L
s
.66929 .44574 m
.66219 .44162 L
s
.66219 .44162 m
.66095 .45029 L
s
0 .291 1 r
.51901 .75441 m
.51288 .74937 L
s
.51288 .74937 m
.51779 .74323 L
s
.51288 .74937 m
.5172 .74944 L
s
0 1 .828 r
.56631 .52106 m
.56512 .52294 L
s
.56512 .52294 m
.55957 .52018 L
s
.56512 .52294 m
.56045 .52581 L
s
.55957 .52018 m
.56075 .5183 L
s
.55957 .52018 m
.56045 .52581 L
s
0 1 .338 r
.433 .52665 m
.4341 .52056 L
s
0 .291 1 r
.51779 .74323 m
.52393 .74827 L
s
.51779 .74323 m
.5172 .74944 L
s
0 1 .744 r
.54802 .64913 m
.53891 .65819 L
s
0 .291 1 r
.52393 .74827 m
.51901 .75441 L
s
.5172 .74944 m
.51901 .75441 L
s
0 1 .792 r
.59435 .59828 m
.58913 .59791 L
s
.58913 .59791 m
.58754 .59288 L
s
.58913 .59791 m
.58816 .59905 L
s
0 .516 1 r
.53334 .45337 m
.53707 .44656 L
s
.53334 .45337 m
.53055 .44479 L
s
.5435 .41757 m
.53334 .45337 L
s
0 1 .294 r
.45959 .59436 m
.46445 .59601 L
s
.46046 .60019 m
.46445 .59601 L
s
.368 0 1 r
.79183 .43506 m
.79185 .43465 L
s
.79848 .44152 m
.79183 .43506 L
s
.79183 .43506 m
.78868 .44469 L
s
0 .095 1 r
.66818 .4447 m
.66929 .44574 L
s
.66929 .44574 m
.66095 .45029 L
s
0 .291 1 r
.5172 .74944 m
.52393 .74827 L
s
0 1 .868 r
.48877 .66848 m
.49392 .67208 L
s
.48854 .67447 m
.49392 .67208 L
s
.48877 .66848 m
.48854 .67447 L
s
0 1 .294 r
.45959 .59436 m
.46046 .60019 L
s
0 .725 1 r
.62163 .67551 m
.6154 .67283 L
s
.6154 .67283 m
.61709 .66656 L
s
.6154 .67283 m
.61642 .67302 L
s
.368 0 1 r
.79852 .44114 m
.79848 .44152 L
s
.79848 .44152 m
.78868 .44469 L
s
0 .653 1 r
.69661 .5194 m
.69419 .52031 L
s
.69419 .52031 m
.68912 .51526 L
s
.69419 .52031 m
.6883 .52239 L
s
0 .089 1 r
.84973 .49433 m
.8162 .51639 L
s
0 .078 1 r
.38472 .80135 m
.38932 .79416 L
s
0 .089 1 r
.8264 .51551 m
.82368 .51551 L
s
.82368 .51551 m
.81945 .50844 L
s
.82368 .51551 m
.8162 .51639 L
s
0 .673 1 r
.72447 .59551 m
.71944 .59494 L
s
.71944 .59494 m
.71742 .58855 L
s
.71944 .59494 m
.71618 .59527 L
s
0 .653 1 r
.68912 .51526 m
.69153 .51433 L
s
.68912 .51526 m
.6883 .52239 L
s
0 .516 1 r
.53055 .44479 m
.53707 .44656 L
s
0 .089 1 r
.81945 .50844 m
.82215 .50841 L
s
.81945 .50844 m
.8162 .51639 L
s
0 1 .792 r
.58754 .59288 m
.59277 .59324 L
s
.58754 .59288 m
.58816 .59905 L
s
0 .789 1 r
.68653 .64655 m
.66804 .65558 L
s
.185 1 0 r
.38006 .56973 m
.38207 .58309 L
s
0 1 .792 r
.59277 .59324 m
.59435 .59828 L
s
.58816 .59905 m
.59435 .59828 L
s
0 .095 1 r
.66095 .45029 m
.66818 .4447 L
s
.66095 .45029 m
.66106 .44057 L
s
.68212 .41462 m
.66095 .45029 L
s
0 .725 1 r
.62333 .66923 m
.62163 .67551 L
s
.61642 .67302 m
.62163 .67551 L
s
.61709 .66656 m
.62333 .66923 L
s
.61709 .66656 m
.61642 .67302 L
s
0 1 .828 r
.56045 .52581 m
.56631 .52106 L
s
.56045 .52581 m
.56075 .5183 L
s
0 .673 1 r
.71742 .58855 m
.72245 .5891 L
s
.71742 .58855 m
.71618 .59527 L
s
.368 0 1 r
.78868 .44469 m
.79852 .44114 L
s
.78868 .44469 m
.79185 .43465 L
s
.82118 .41165 m
.78868 .44469 L
s
0 1 .828 r
.56075 .5183 m
.56631 .52106 L
s
0 0 1 r
.52308 .79901 m
.51904 .79527 L
s
0 .725 1 r
.61642 .67302 m
.62333 .66923 L
s
0 1 .792 r
.58816 .59905 m
.59277 .59324 L
s
0 .653 1 r
.6883 .52239 m
.69661 .5194 L
s
.6883 .52239 m
.69153 .51433 L
s
0 .095 1 r
.66106 .44057 m
.66818 .4447 L
s
0 1 .264 r
.51853 .56702 m
.51051 .58345 L
s
0 .673 1 r
.72245 .5891 m
.72447 .59551 L
s
.71618 .59527 m
.72447 .59551 L
s
0 .089 1 r
.8162 .51639 m
.8264 .51551 L
s
.8162 .51639 m
.82215 .50841 L
s
0 1 .979 r
.32734 .42832 m
.32177 .4301 L
s
.33042 .42834 m
.32734 .42832 L
s
.32734 .42832 m
.32768 .43546 L
s
0 .653 1 r
.69153 .51433 m
.69661 .5194 L
s
0 1 .941 r
.35468 .71966 m
.35979 .71705 L
s
.368 0 1 r
.79185 .43465 m
.79852 .44114 L
s
0 .673 1 r
.71618 .59527 m
.72245 .5891 L
s
0 .089 1 r
.82215 .50841 m
.8264 .51551 L
s
0 1 .015 r
.34998 .48723 m
.35454 .50885 L
s
0 1 .81 r
.65744 .5643 m
.63947 .58117 L
s
0 1 .979 r
.32768 .43546 m
.32484 .43013 L
s
.32768 .43546 m
.32177 .4301 L
s
.33042 .42834 m
.32768 .43546 L
s
.31971 .4042 m
.32768 .43546 L
s
.32177 .4301 m
.32484 .43013 L
s
0 1 .015 r
.35523 .50494 m
.35085 .50548 L
s
.3564 .50355 m
.35523 .50494 L
s
.35523 .50494 m
.35454 .50885 L
s
0 .927 1 r
.49344 .71719 m
.48934 .71844 L
s
0 .739 1 r
.45584 .42892 m
.45122 .42882 L
s
.46121 .42977 m
.45584 .42892 L
s
.45584 .42892 m
.45552 .4363 L
s
0 1 .015 r
.35085 .50548 m
.35202 .50409 L
s
.35454 .50885 m
.35085 .50548 L
s
0 1 .979 r
.32484 .43013 m
.33042 .42834 L
s
0 .596 1 r
.7968 .56157 m
.76863 .57624 L
s
0 1 .424 r
.48885 .48438 m
.4827 .50946 L
s
.185 1 0 r
.38021 .58248 m
.37906 .57945 L
s
.38426 .58135 m
.38021 .58248 L
s
.38207 .58309 m
.38021 .58248 L
s
.38312 .57832 m
.38426 .58135 L
s
.38207 .58309 m
.38426 .58135 L
s
.23 0 1 r
.46863 .80456 m
.47497 .81099 L
s
.46217 .81093 m
.46863 .80456 L
s
.46863 .80456 m
.46842 .81017 L
s
0 1 .015 r
.35454 .50885 m
.35202 .50409 L
s
.3564 .50355 m
.35454 .50885 L
s
.35202 .50409 m
.3564 .50355 L
s
0 1 .388 r
.40996 .66049 m
.40639 .65661 L
s
.41398 .65701 m
.40996 .66049 L
s
.41024 .6581 m
.40996 .66049 L
s
0 .607 1 r
.63265 .7147 m
.6195 .71704 L
s
0 1 .024 r
.32445 .63745 m
.33088 .64059 L
s
.23 0 1 r
.47497 .81099 m
.46851 .81737 L
s
.46842 .81017 m
.47497 .81099 L
s
0 1 .388 r
.4104 .65313 m
.41398 .65701 L
s
.41024 .6581 m
.41398 .65701 L
s
.23 0 1 r
.46851 .81737 m
.46217 .81093 L
s
.46217 .81093 m
.46842 .81017 L
s
0 1 .424 r
.48212 .505 m
.48065 .50315 L
s
.48721 .50571 m
.48212 .505 L
s
.48212 .505 m
.4827 .50946 L
s
0 .72 1 r
.43924 .72862 m
.44422 .73375 L
s
.4341 .73362 m
.43924 .72862 L
s
.43924 .72862 m
.43904 .73382 L
s
.44422 .73375 m
.43908 .73875 L
s
.43904 .73382 m
.44422 .73375 L
s
0 1 .388 r
.40639 .65661 m
.4104 .65313 L
s
.40639 .65661 m
.41024 .6581 L
s
0 .72 1 r
.43908 .73875 m
.4341 .73362 L
s
.4341 .73362 m
.43904 .73382 L
s
.43904 .73382 m
.43908 .73875 L
s
0 .35 1 r
.58486 .42636 m
.58218 .42552 L
s
.59169 .4292 m
.58486 .42636 L
s
.58486 .42636 m
.584 .43464 L
s
0 .739 1 r
.45552 .4363 m
.45659 .42967 L
s
.45552 .4363 m
.45122 .42882 L
s
.46121 .42977 m
.45552 .4363 L
s
.45898 .40121 m
.45552 .4363 L
s
.185 1 0 r
.37906 .57945 m
.38312 .57832 L
s
.37906 .57945 m
.38207 .58309 L
s
.38312 .57832 m
.38207 .58309 L
s
0 1 .388 r
.4104 .65313 m
.41024 .6581 L
s
0 .739 1 r
.45659 .42967 m
.46121 .42977 L
s
.23 0 1 r
.46842 .81017 m
.46851 .81737 L
s
0 1 .937 r
.62816 .48152 m
.61145 .5075 L
s
.593 0 1 r
.46823 .86808 m
.46997 .85792 L
s
0 1 .424 r
.48576 .50386 m
.48721 .50571 L
s
.48721 .50571 m
.4827 .50946 L
s
0 1 .264 r
.51509 .58215 m
.51039 .58202 L
s
.51039 .58202 m
.50915 .57813 L
s
.51039 .58202 m
.51051 .58345 L
s
0 .739 1 r
.45122 .42882 m
.45659 .42967 L
s
.088 0 1 r
.71505 .42112 m
.71394 .42053 L
s
.72205 .42629 m
.71505 .42112 L
s
.71505 .42112 m
.7128 .43045 L
s
0 .35 1 r
.58902 .42837 m
.59169 .4292 L
s
.59169 .4292 m
.584 .43464 L
s
0 1 .226 r
.46361 .63483 m
.46022 .64223 L
s
0 1 .744 r
.5423 .6603 m
.53695 .65752 L
s
.53695 .65752 m
.53919 .65242 L
s
.53695 .65752 m
.53891 .65819 L
s
0 .465 1 r
.57084 .73837 m
.56464 .734 L
s
.56464 .734 m
.56875 .7277 L
s
.56464 .734 m
.56788 .73362 L
s
0 1 .264 r
.51386 .57826 m
.51509 .58215 L
s
.51051 .58345 m
.51509 .58215 L
s
0 1 .937 r
.61807 .50337 m
.61697 .50475 L
s
.61697 .50475 m
.61155 .50121 L
s
.61697 .50475 m
.61145 .5075 L
s
.61155 .50121 m
.61263 .49982 L
s
.61155 .50121 m
.61145 .5075 L
s
.601 0 1 r
.84612 .41365 m
.84582 .41373 L
s
.85245 .42116 m
.84612 .41365 L
s
.84612 .41365 m
.84158 .42375 L
s
0 1 .744 r
.54455 .6552 m
.5423 .6603 L
s
.53891 .65819 m
.5423 .6603 L
s
0 1 .81 r
.6465 .58042 m
.642 .58033 L
s
.642 .58033 m
.63968 .57512 L
s
.642 .58033 m
.63947 .58117 L
s
.601 0 1 r
.85217 .42127 m
.85245 .42116 L
s
.85245 .42116 m
.84158 .42375 L
s
.088 0 1 r
.72096 .42572 m
.72205 .42629 L
s
.72205 .42629 m
.7128 .43045 L
s
0 1 .424 r
.4827 .50946 m
.48576 .50386 L
s
.4827 .50946 m
.48065 .50315 L
s
0 .465 1 r
.56875 .7277 m
.57495 .73207 L
s
.56875 .7277 m
.56788 .73362 L
s
0 .35 1 r
.584 .43464 m
.58902 .42837 L
s
.584 .43464 m
.58218 .42552 L
s
.59869 .3982 m
.584 .43464 L
s
0 1 .424 r
.48065 .50315 m
.48576 .50386 L
s
0 1 .264 r
.50915 .57813 m
.51386 .57826 L
s
.50915 .57813 m
.51051 .58345 L
s
0 .465 1 r
.57495 .73207 m
.57084 .73837 L
s
.56788 .73362 m
.57084 .73837 L
s
0 .51 1 r
.76793 .47864 m
.74045 .50295 L
s
0 .789 1 r
.6743 .65804 m
.6684 .65592 L
s
.6684 .65592 m
.66925 .64946 L
s
.6684 .65592 m
.66804 .65558 L
s
.123 0 1 r
.88013 .49593 m
.87803 .49558 L
s
.87803 .49558 m
.87417 .4877 L
s
.87803 .49558 m
.86939 .49582 L
s
0 .51 1 r
.74937 .50073 m
.74741 .50121 L
s
.74741 .50121 m
.74256 .49544 L
s
.74741 .50121 m
.74045 .50295 L
s
0 1 .744 r
.53919 .65242 m
.54455 .6552 L
s
.53919 .65242 m
.53891 .65819 L
s
0 .596 1 r
.77753 .57697 m
.77321 .57638 L
s
.77321 .57638 m
.77107 .56961 L
s
.77321 .57638 m
.76863 .57624 L
s
0 .51 1 r
.74256 .49544 m
.74451 .49493 L
s
.74256 .49544 m
.74045 .50295 L
s
.123 0 1 r
.87417 .4877 m
.87625 .48802 L
s
.87417 .4877 m
.86939 .49582 L
s
0 .465 1 r
.56788 .73362 m
.57495 .73207 L
s
0 1 .744 r
.53891 .65819 m
.54455 .6552 L
s
0 1 .81 r
.63968 .57512 m
.64418 .57521 L
s
.63968 .57512 m
.63947 .58117 L
s
0 1 .264 r
.51051 .58345 m
.51386 .57826 L
s
0 1 .663 r
.60322 .63221 m
.59023 .64115 L
s
.499 1 0 r
.29402 .5547 m
.30262 .56486 L
s
.088 0 1 r
.7128 .43045 m
.72096 .42572 L
s
.7128 .43045 m
.71394 .42053 L
s
.73886 .39518 m
.7128 .43045 L
s
.601 0 1 r
.84158 .42375 m
.85217 .42127 L
s
.84158 .42375 m
.84582 .41373 L
s
.87949 .39216 m
.84158 .42375 L
s
0 .789 1 r
.66925 .64946 m
.67516 .65158 L
s
.66925 .64946 m
.66804 .65558 L
s
0 .596 1 r
.77107 .56961 m
.77539 .57018 L
s
.77107 .56961 m
.76863 .57624 L
s
0 .35 1 r
.58218 .42552 m
.58902 .42837 L
s
0 .978 1 r
.24657 .40825 m
.24116 .41172 L
s
.24901 .40878 m
.24657 .40825 L
s
.24657 .40825 m
.24819 .41588 L
s
0 1 .937 r
.61145 .5075 m
.61807 .50337 L
s
.61145 .5075 m
.61263 .49982 L
s
.123 0 1 r
.90814 .47576 m
.86939 .49582 L
s
0 .347 1 r
.43824 .78602 m
.43952 .77972 L
s
0 .789 1 r
.67516 .65158 m
.6743 .65804 L
s
.66804 .65558 m
.6743 .65804 L
s
0 1 .81 r
.64418 .57521 m
.6465 .58042 L
s
.63947 .58117 m
.6465 .58042 L
s
0 .978 1 r
.24819 .41588 m
.24358 .41226 L
s
.24819 .41588 m
.24116 .41172 L
s
.24901 .40878 m
.24819 .41588 L
s
.23257 .3876 m
.24819 .41588 L
s
.24116 .41172 m
.24358 .41226 L
s
0 1 .937 r
.61263 .49982 m
.61807 .50337 L
s
0 .51 1 r
.74045 .50295 m
.74937 .50073 L
s
.74045 .50295 m
.74451 .49493 L
s
.123 0 1 r
.86939 .49582 m
.88013 .49593 L
s
.86939 .49582 m
.87625 .48802 L
s
0 .798 1 r
.74328 .62957 m
.72057 .63735 L
s
.244 1 0 r
.43358 .55194 m
.4317 .56673 L
s
0 .789 1 r
.66804 .65558 m
.67516 .65158 L
s
0 1 .81 r
.63947 .58117 m
.64418 .57521 L
s
.102 1 0 r
.27453 .48535 m
.27077 .48765 L
s
.27468 .48482 m
.27453 .48535 L
s
.27453 .48535 m
.27505 .48994 L
s
.088 0 1 r
.71394 .42053 m
.72096 .42572 L
s
0 .596 1 r
.77539 .57018 m
.77753 .57697 L
s
.76863 .57624 m
.77753 .57697 L
s
.102 1 0 r
.27077 .48765 m
.27091 .48712 L
s
.27505 .48994 m
.27077 .48765 L
s
0 .205 1 r
.57815 .78363 m
.57063 .77962 L
s
0 .51 1 r
.74451 .49493 m
.74937 .50073 L
s
0 .596 1 r
.76863 .57624 m
.77539 .57018 L
s
.868 0 1 r
.41889 .86679 m
.42577 .87454 L
s
.41114 .87348 m
.41889 .86679 L
s
.41889 .86679 m
.41946 .87184 L
s
.601 0 1 r
.84582 .41373 m
.85217 .42127 L
s
.499 1 0 r
.30179 .5643 m
.29883 .56433 L
s
.30297 .56132 m
.30179 .5643 L
s
.30262 .56486 m
.30179 .5643 L
s
0 .978 1 r
.24358 .41226 m
.24901 .40878 L
s
0 .877 1 r
.37653 .41053 m
.37105 .41181 L
s
.38068 .41108 m
.37653 .41053 L
s
.37653 .41053 m
.37659 .41814 L
s
.123 0 1 r
.87625 .48802 m
.88013 .49593 L
s
.102 1 0 r
.27505 .48994 m
.27091 .48712 L
s
.27468 .48482 m
.27505 .48994 L
s
.26339 .47142 m
.27505 .48994 L
s
0 1 .283 r
.57359 .54918 m
.56151 .56595 L
s
1 0 .739 r
.41275 .93794 m
.42074 .92148 L
s
.868 0 1 r
.42577 .87454 m
.41803 .88125 L
s
.41946 .87184 m
.42577 .87454 L
s
0 .078 1 r
.38887 .7897 m
.39435 .79617 L
s
.38242 .79506 m
.38887 .7897 L
s
.38887 .7897 m
.38932 .79416 L
s
.499 1 0 r
.3 .56135 m
.30297 .56132 L
s
.30297 .56132 m
.30262 .56486 L
s
0 1 .024 r
.33261 .64084 m
.32859 .64311 L
s
.33057 .63681 m
.33261 .64084 L
s
.33088 .64059 m
.33261 .64084 L
s
0 .078 1 r
.39435 .79617 m
.38791 .80154 L
s
.38932 .79416 m
.39435 .79617 L
s
.102 1 0 r
.27091 .48712 m
.27468 .48482 L
s
0 1 .941 r
.36328 .71823 m
.35815 .72214 L
s
.35936 .71302 m
.36328 .71823 L
s
.35979 .71705 m
.36328 .71823 L
s
.499 1 0 r
.29883 .56433 m
.3 .56135 L
s
.30262 .56486 m
.29883 .56433 L
s
0 1 .941 r
.35423 .71693 m
.35936 .71302 L
s
.35936 .71302 m
.35979 .71705 L
s
0 1 .679 r
.40806 .70342 m
.40965 .70209 L
s
.868 0 1 r
.41803 .88125 m
.41114 .87348 L
s
.41114 .87348 m
.41946 .87184 L
s
0 1 .024 r
.32859 .64311 m
.32655 .63908 L
s
.33088 .64059 m
.32859 .64311 L
s
.32655 .63908 m
.33057 .63681 L
s
.33057 .63681 m
.33088 .64059 L
s
0 .877 1 r
.37659 .41814 m
.3752 .41236 L
s
.37659 .41814 m
.37105 .41181 L
s
.38068 .41108 m
.37659 .41814 L
s
.37294 .38455 m
.37659 .41814 L
s
0 1 .091 r
.40407 .48788 m
.40033 .48742 L
s
.40712 .48719 m
.40407 .48788 L
s
.40407 .48788 m
.40382 .49201 L
s
0 .078 1 r
.38791 .80154 m
.38242 .79506 L
s
.38242 .79506 m
.38932 .79416 L
s
.499 1 0 r
.3 .56135 m
.30262 .56486 L
s
0 1 .941 r
.35815 .72214 m
.35423 .71693 L
s
.35979 .71705 m
.35815 .72214 L
s
0 1 .024 r
.32655 .63908 m
.33088 .64059 L
s
0 1 .941 r
.35423 .71693 m
.35979 .71705 L
s
0 1 .883 r
.71406 .5464 m
.69171 .56251 L
s
0 1 .091 r
.40336 .46852 m
.40382 .49201 L
s
0 .877 1 r
.37105 .41181 m
.3752 .41236 L
s
.868 0 1 r
.41946 .87184 m
.41803 .88125 L
s
0 .078 1 r
.38932 .79416 m
.38791 .80154 L
s
0 .561 1 r
.50646 .4098 m
.50229 .40964 L
s
.51254 .41163 m
.50646 .4098 L
s
.50646 .4098 m
.50584 .4179 L
s
0 .877 1 r
.3752 .41236 m
.38068 .41108 L
s
0 1 .899 r
.54837 .70089 m
.54062 .70229 L
s
.244 1 0 r
.43354 .5656 m
.42955 .56459 L
s
.43461 .56292 m
.43354 .5656 L
s
.4317 .56673 m
.43354 .5656 L
s
0 1 .091 r
.40033 .48742 m
.40338 .48673 L
s
.40382 .49201 m
.40033 .48742 L
s
.40338 .48673 m
.40712 .48719 L
s
.40712 .48719 m
.40382 .49201 L
s
.244 1 0 r
.42955 .56459 m
.43062 .56191 L
s
.42955 .56459 m
.4317 .56673 L
s
0 0 1 r
.51959 .78991 m
.52596 .79571 L
s
.51376 .79636 m
.51959 .78991 L
s
.51959 .78991 m
.51904 .79527 L
s
0 1 .091 r
.40382 .49201 m
.40338 .48673 L
s
0 0 1 r
.52013 .80216 m
.51376 .79636 L
s
.51376 .79636 m
.51904 .79527 L
s
0 1 .226 r
.46142 .64416 m
.45737 .6411 L
s
.46444 .64038 m
.46142 .64416 L
s
.46022 .64223 m
.46142 .64416 L
s
0 .448 1 r
.85499 .54361 m
.82198 .55642 L
s
0 1 .548 r
.54378 .4656 m
.53337 .49151 L
s
.371 0 1 r
.38241 .85563 m
.38951 .84197 L
s
0 1 .548 r
.53322 .48614 m
.5324 .48464 L
s
.5385 .488 m
.53322 .48614 L
s
.53322 .48614 m
.53337 .49151 L
s
0 .157 1 r
.6372 .4061 m
.63476 .40559 L
s
.64419 .41003 m
.6372 .4061 L
s
.6372 .4061 m
.6356 .41513 L
s
0 1 .226 r
.45737 .6411 m
.46038 .63731 L
s
.45737 .6411 m
.46022 .64223 L
s
0 .927 1 r
.49053 .72299 m
.48541 .71852 L
s
.48541 .71852 m
.48981 .71338 L
s
.48541 .71852 m
.48934 .71844 L
s
0 .561 1 r
.50584 .4179 m
.50839 .41147 L
s
.50584 .4179 m
.50229 .40964 L
s
.51254 .41163 m
.50584 .4179 L
s
.51377 .38149 m
.50584 .4179 L
s
.50839 .41147 m
.51254 .41163 L
s
0 .927 1 r
.48981 .71338 m
.49493 .71784 L
s
.48981 .71338 m
.48934 .71844 L
s
0 0 1 r
.52596 .79571 m
.52013 .80216 L
s
.51904 .79527 m
.52596 .79571 L
s
0 .927 1 r
.49493 .71784 m
.49053 .72299 L
s
.48934 .71844 m
.49053 .72299 L
s
.244 1 0 r
.43062 .56191 m
.43461 .56292 L
s
.4317 .56673 m
.43461 .56292 L
s
0 1 .226 r
.46038 .63731 m
.46444 .64038 L
s
.46022 .64223 m
.46444 .64038 L
s
0 .927 1 r
.48934 .71844 m
.49493 .71784 L
s
0 0 1 r
.51904 .79527 m
.52013 .80216 L
s
0 1 .548 r
.5377 .4865 m
.5385 .488 L
s
.5385 .488 m
.53337 .49151 L
s
0 1 .283 r
.56713 .56433 m
.56329 .56475 L
s
.56329 .56475 m
.56075 .56083 L
s
.56329 .56475 m
.56151 .56595 L
s
0 1 .226 r
.46038 .63731 m
.46022 .64223 L
s
.244 1 0 r
.43062 .56191 m
.4317 .56673 L
s
0 .703 1 r
.68914 .69835 m
.67207 .69969 L
s
.216 1 0 r
.37768 .62028 m
.3804 .62512 L
s
.312 0 1 r
.76897 .39989 m
.76773 .39977 L
s
.77581 .40615 m
.76897 .39989 L
s
.76897 .39989 m
.76554 .40984 L
s
0 .157 1 r
.64177 .40953 m
.64419 .41003 L
s
.64419 .41003 m
.6356 .41513 L
s
0 1 .663 r
.59492 .64304 m
.58966 .64098 L
s
.58966 .64098 m
.59078 .63566 L
s
.58966 .64098 m
.59023 .64115 L
s
0 .607 1 r
.62357 .72167 m
.61744 .71794 L
s
.61744 .71794 m
.62075 .71148 L
s
.61744 .71794 m
.6195 .71704 L
s
0 .561 1 r
.50229 .40964 m
.50839 .41147 L
s
0 .912 1 r
.66456 .48153 m
.66544 .48062 L
s
.66983 .4859 m
.66456 .48153 L
s
.66456 .48153 m
.66337 .48842 L
s
.312 0 1 r
.7746 .40605 m
.77581 .40615 L
s
.77581 .40615 m
.76554 .40984 L
s
0 .912 1 r
.67072 .485 m
.66983 .4859 L
s
.66983 .4859 m
.66337 .48842 L
s
.68466 .46268 m
.66337 .48842 L
s
.337 0 1 r
.52303 .85334 m
.52148 .84323 L
s
0 1 .883 r
.6994 .5621 m
.6956 .562 L
s
.6956 .562 m
.69301 .55645 L
s
.6956 .562 m
.69171 .56251 L
s
0 .157 1 r
.6356 .41513 m
.64177 .40953 L
s
.6356 .41513 m
.63476 .40559 L
s
.65506 .37842 m
.6356 .41513 L
s
0 1 .283 r
.56075 .56083 m
.56459 .5604 L
s
.56075 .56083 m
.56151 .56595 L
s
0 .311 1 r
.80303 .48141 m
.80156 .48148 L
s
.80156 .48148 m
.79699 .47487 L
s
.80156 .48148 m
.79351 .48273 L
s
0 .798 1 r
.7277 .64 m
.7223 .63825 L
s
.7223 .63825 m
.7226 .63157 L
s
.7223 .63825 m
.72057 .63735 L
s
0 .607 1 r
.62075 .71148 m
.62689 .7152 L
s
.62075 .71148 m
.6195 .71704 L
s
0 1 .548 r
.53337 .49151 m
.5377 .4865 L
s
.53337 .49151 m
.5324 .48464 L
s
0 .448 1 r
.83142 .55786 m
.82781 .55716 L
s
.82781 .55716 m
.82579 .54985 L
s
.82781 .55716 m
.82198 .55642 L
s
0 .311 1 r
.79699 .47487 m
.79845 .47478 L
s
.79699 .47487 m
.79351 .48273 L
s
0 1 .663 r
.59604 .63771 m
.59492 .64304 L
s
.59023 .64115 m
.59492 .64304 L
s
.59078 .63566 m
.59604 .63771 L
s
.59078 .63566 m
.59023 .64115 L
s
0 1 .283 r
.56459 .5604 m
.56713 .56433 L
s
.56151 .56595 m
.56713 .56433 L
s
0 .607 1 r
.62689 .7152 m
.62357 .72167 L
s
.6195 .71704 m
.62357 .72167 L
s
.312 0 1 r
.76554 .40984 m
.7746 .40605 L
s
.76554 .40984 m
.76773 .39977 L
s
.79681 .37534 m
.76554 .40984 L
s
0 1 .112 r
.5184 .61761 m
.51118 .62559 L
s
0 1 .548 r
.5324 .48464 m
.5377 .4865 L
s
0 1 .883 r
.69301 .55645 m
.6968 .55655 L
s
.69301 .55645 m
.69171 .56251 L
s
0 .448 1 r
.82579 .54985 m
.82941 .55053 L
s
.82579 .54985 m
.82198 .55642 L
s
0 .798 1 r
.7226 .63157 m
.72801 .63331 L
s
.7226 .63157 m
.72057 .63735 L
s
0 .607 1 r
.6195 .71704 m
.62689 .7152 L
s
0 1 .663 r
.59023 .64115 m
.59604 .63771 L
s
0 .311 1 r
.826 .45975 m
.79351 .48273 L
s
0 .585 1 r
.35187 .77279 m
.35887 .76298 L
s
0 1 .283 r
.56151 .56595 m
.56459 .5604 L
s
0 .912 1 r
.66337 .48842 m
.67072 .485 L
s
.66337 .48842 m
.66544 .48062 L
s
0 .157 1 r
.63476 .40559 m
.64177 .40953 L
s
0 .311 1 r
.79351 .48273 m
.80303 .48141 L
s
.79351 .48273 m
.79845 .47478 L
s
0 .798 1 r
.72801 .63331 m
.7277 .64 L
s
.72057 .63735 m
.7277 .64 L
s
0 .878 1 r
.29555 .39084 m
.28984 .39371 L
s
.29886 .3916 m
.29555 .39084 L
s
.29555 .39084 m
.29659 .39888 L
s
.639 1 0 r
.3471 .5366 m
.35178 .54888 L
s
0 1 .636 r
.65958 .61492 m
.6425 .62334 L
s
0 1 .883 r
.6968 .55655 m
.6994 .5621 L
s
.69171 .56251 m
.6994 .5621 L
s
0 .912 1 r
.66544 .48062 m
.67072 .485 L
s
0 1 .883 r
.69171 .56251 m
.6968 .55655 L
s
0 .878 1 r
.29659 .39888 m
.29315 .39448 L
s
.29659 .39888 m
.28984 .39371 L
s
.29886 .3916 m
.29659 .39888 L
s
.28535 .36759 m
.29659 .39888 L
s
0 .798 1 r
.72057 .63735 m
.72801 .63331 L
s
0 .448 1 r
.82198 .55642 m
.83142 .55786 L
s
.82198 .55642 m
.82941 .55053 L
s
.312 0 1 r
.76773 .39977 m
.7746 .40605 L
s
0 .592 1 r
.4929 .77035 m
.49072 .76451 L
s
0 .448 1 r
.82941 .55053 m
.83142 .55786 L
s
0 .311 1 r
.79845 .47478 m
.80303 .48141 L
s
0 .878 1 r
.28984 .39371 m
.29315 .39448 L
s
.08 1 0 r
.32369 .46878 m
.31965 .47019 L
s
.32503 .46827 m
.32369 .46878 L
s
.32369 .46878 m
.32384 .47344 L
s
0 .738 1 r
.80123 .61223 m
.77403 .61835 L
s
.238 1 0 r
.48824 .53378 m
.48232 .54961 L
s
.593 0 1 r
.4698 .85307 m
.47664 .8602 L
s
.46259 .85977 m
.4698 .85307 L
s
.4698 .85307 m
.46997 .85792 L
s
.08 1 0 r
.31965 .47019 m
.32098 .46968 L
s
.32384 .47344 m
.31965 .47019 L
s
0 .702 1 r
.42673 .39186 m
.42148 .39282 L
s
.43183 .39312 m
.42673 .39186 L
s
.42673 .39186 m
.42649 .40006 L
s
0 .878 1 r
.29315 .39448 m
.29886 .3916 L
s
0 .375 1 r
.63439 .76792 m
.62319 .76318 L
s
0 1 .431 r
.32114 .6894 m
.32885 .68458 L
s
.639 1 0 r
.35118 .54785 m
.34857 .54714 L
s
.35311 .54569 m
.35118 .54785 L
s
.35178 .54888 m
.35118 .54785 L
s
.08 1 0 r
.32384 .47344 m
.32098 .46968 L
s
.32503 .46827 m
.32384 .47344 L
s
.31633 .45237 m
.32384 .47344 L
s
.593 0 1 r
.47664 .8602 m
.46943 .86691 L
s
.46997 .85792 m
.47664 .8602 L
s
0 .347 1 r
.43947 .77537 m
.44494 .78122 L
s
.43358 .78077 m
.43947 .77537 L
s
.43947 .77537 m
.43952 .77972 L
s
.639 1 0 r
.35051 .54498 m
.35311 .54569 L
s
.35311 .54569 m
.35178 .54888 L
s
0 1 .358 r
.62983 .53095 m
.61346 .54768 L
s
.962 0 1 r
.46727 .92385 m
.47213 .90781 L
s
.08 1 0 r
.32098 .46968 m
.32503 .46827 L
s
.593 0 1 r
.46943 .86691 m
.46259 .85977 L
s
.46259 .85977 m
.46997 .85792 L
s
.216 1 0 r
.38276 .62464 m
.37925 .62701 L
s
.38045 .62128 m
.38276 .62464 L
s
.3804 .62512 m
.38276 .62464 L
s
0 .347 1 r
.44494 .78122 m
.43905 .78662 L
s
.43952 .77972 m
.44494 .78122 L
s
.216 1 0 r
.37925 .62701 m
.37693 .62365 L
s
.3804 .62512 m
.37925 .62701 L
s
.639 1 0 r
.34857 .54714 m
.35051 .54498 L
s
.35178 .54888 m
.34857 .54714 L
s
0 .702 1 r
.42649 .40006 m
.42657 .39409 L
s
.42649 .40006 m
.42148 .39282 L
s
.43183 .39312 m
.42649 .40006 L
s
.42731 .36447 m
.42649 .40006 L
s
0 1 .679 r
.40961 .69809 m
.4136 .70265 L
s
.40506 .70208 m
.40961 .69809 L
s
.40961 .69809 m
.40965 .70209 L
s
.4136 .70265 m
.40904 .70663 L
s
.40965 .70209 m
.4136 .70265 L
s
0 1 .217 r
.45418 .4696 m
.45132 .46881 L
s
.45836 .47 m
.45418 .4696 L
s
.45418 .4696 m
.45408 .4744 L
s
0 .347 1 r
.43905 .78662 m
.43358 .78077 L
s
.43358 .78077 m
.43952 .77972 L
s
.216 1 0 r
.37693 .62365 m
.38045 .62128 L
s
.38045 .62128 m
.3804 .62512 L
s
0 1 .679 r
.40904 .70663 m
.40506 .70208 L
s
.40506 .70208 m
.40965 .70209 L
s
.40965 .70209 m
.40904 .70663 L
s
.216 1 0 r
.37693 .62365 m
.3804 .62512 L
s
0 1 .45 r
.46258 .68682 m
.46052 .68637 L
s
0 .36 1 r
.55825 .38986 m
.55442 .38981 L
s
.56483 .39273 m
.55825 .38986 L
s
.55825 .38986 m
.55712 .39872 L
s
.593 0 1 r
.46997 .85792 m
.46943 .86691 L
s
.639 1 0 r
.35051 .54498 m
.35178 .54888 L
s
0 .347 1 r
.43952 .77972 m
.43905 .78662 L
s
0 .702 1 r
.42657 .39409 m
.43183 .39312 L
s
.42148 .39282 m
.42657 .39409 L
s
.238 1 0 r
.48635 .5471 m
.48352 .54822 L
s
.48352 .54822 m
.48067 .54576 L
s
.48352 .54822 m
.48232 .54961 L
s
0 .979 1 r
.77189 .52811 m
.74487 .54308 L
s
0 1 .217 r
.45787 .44941 m
.45408 .4744 L
s
.4555 .4692 m
.45836 .47 L
s
.45836 .47 m
.45408 .4744 L
s
0 .205 1 r
.57157 .77458 m
.57793 .77974 L
s
.56639 .78112 m
.57157 .77458 L
s
.57157 .77458 m
.57063 .77962 L
s
.57274 .78628 m
.56639 .78112 L
s
.56639 .78112 m
.57063 .77962 L
s
0 1 .217 r
.45408 .4744 m
.4555 .4692 L
s
.45408 .4744 m
.45132 .46881 L
s
.066 0 1 r
.69066 .38509 m
.68829 .38496 L
s
.69771 .39013 m
.69066 .38509 L
s
.69066 .38509 m
.68813 .39485 L
s
0 1 .112 r
.51394 .62712 m
.50959 .62494 L
s
.50959 .62494 m
.51133 .62085 L
s
.50959 .62494 m
.51118 .62559 L
s
0 1 .899 r
.54298 .70655 m
.53779 .70277 L
s
.53779 .70277 m
.5414 .69746 L
s
.53779 .70277 m
.54062 .70229 L
s
0 1 .712 r
.5856 .4666 m
.58502 .46553 L
s
.59092 .46948 m
.5856 .4666 L
s
.5856 .4666 m
.58499 .47278 L
s
0 .36 1 r
.55712 .39872 m
.56102 .39269 L
s
.55712 .39872 m
.55442 .38981 L
s
.56483 .39273 m
.55712 .39872 L
s
.56974 .36135 m
.55712 .39872 L
s
.238 1 0 r
.48067 .54576 m
.4835 .54463 L
s
.48067 .54576 m
.48232 .54961 L
s
0 1 .217 r
.45132 .46881 m
.4555 .4692 L
s
0 .36 1 r
.56102 .39269 m
.56483 .39273 L
s
0 1 .112 r
.51568 .62303 m
.51394 .62712 L
s
.51118 .62559 m
.51394 .62712 L
s
0 1 .769 r
.60448 .68424 m
.59289 .68536 L
s
.445 1 0 r
.2902 .60547 m
.29948 .60686 L
s
0 1 .899 r
.5414 .69746 m
.54659 .70124 L
s
.5414 .69746 m
.54062 .70229 L
s
.582 0 1 r
.82395 .37793 m
.82245 .37827 L
s
.83057 .38532 m
.82395 .37793 L
s
.82395 .37793 m
.81919 .38844 L
s
.238 1 0 r
.4835 .54463 m
.48635 .5471 L
s
.48232 .54961 m
.48635 .5471 L
s
0 1 .712 r
.59036 .46842 m
.59092 .46948 L
s
.59092 .46948 m
.58499 .47278 L
s
0 1 .899 r
.54659 .70124 m
.54298 .70655 L
s
.54062 .70229 m
.54298 .70655 L
s
0 1 .358 r
.61979 .54621 m
.6167 .54663 L
s
.6167 .54663 m
.61372 .54243 L
s
.6167 .54663 m
.61346 .54768 L
s
0 .205 1 r
.57793 .77974 m
.57274 .78628 L
s
.57063 .77962 m
.57793 .77974 L
s
.57063 .77962 m
.57274 .78628 L
s
.066 0 1 r
.69537 .39002 m
.69771 .39013 L
s
.69771 .39013 m
.68813 .39485 L
s
0 1 .112 r
.51133 .62085 m
.51568 .62303 L
s
.51133 .62085 m
.51118 .62559 L
s
.582 0 1 r
.8291 .38569 m
.83057 .38532 L
s
.83057 .38532 m
.81919 .38844 L
s
0 .703 1 r
.67716 .70431 m
.67125 .70116 L
s
.67125 .70116 m
.67389 .69453 L
s
.67125 .70116 m
.67207 .69969 L
s
0 1 .636 r
.64825 .62517 m
.64337 .62364 L
s
.64337 .62364 m
.64363 .61811 L
s
.64337 .62364 m
.6425 .62334 L
s
0 1 .899 r
.54062 .70229 m
.54659 .70124 L
s
0 .22 1 r
.91442 .52527 m
.87621 .53582 L
s
0 1 .712 r
.59988 .44643 m
.58499 .47278 L
s
.073 0 1 r
.43679 .84062 m
.44059 .82776 L
s
0 1 .112 r
.51118 .62559 m
.51568 .62303 L
s
0 .713 1 r
.71862 .46111 m
.71921 .46067 L
s
.72369 .46638 m
.71862 .46111 L
s
.71862 .46111 m
.71623 .46855 L
s
.7243 .46596 m
.72369 .46638 L
s
.72369 .46638 m
.71623 .46855 L
s
0 .047 1 r
.85759 .46143 m
.85667 .46109 L
s
.85667 .46109 m
.85245 .45354 L
s
.85667 .46109 m
.84745 .46173 L
s
.066 0 1 r
.68813 .39485 m
.69537 .39002 L
s
.68813 .39485 m
.68829 .38496 L
s
.71264 .35821 m
.68813 .39485 L
s
0 .22 1 r
.88618 .53814 m
.88328 .53728 L
s
.88328 .53728 m
.88156 .52928 L
s
.88328 .53728 m
.87621 .53582 L
s
.238 1 0 r
.48232 .54961 m
.4835 .54463 L
s
0 .979 1 r
.75316 .54323 m
.75003 .54298 L
s
.75003 .54298 m
.74744 .53692 L
s
.75003 .54298 m
.74487 .54308 L
s
0 1 .358 r
.61372 .54243 m
.6168 .54199 L
s
.61372 .54243 m
.61346 .54768 L
s
0 .738 1 r
.78188 .62138 m
.77708 .61986 L
s
.77708 .61986 m
.77713 .61286 L
s
.77708 .61986 m
.77403 .61835 L
s
0 .047 1 r
.85245 .45354 m
.85336 .45385 L
s
.85245 .45354 m
.84745 .46173 L
s
.582 0 1 r
.81919 .38844 m
.8291 .38569 L
s
.81919 .38844 m
.82245 .37827 L
s
.85601 .35506 m
.81919 .38844 L
s
0 .703 1 r
.67389 .69453 m
.67981 .69767 L
s
.67389 .69453 m
.67207 .69969 L
s
0 .36 1 r
.55442 .38981 m
.56102 .39269 L
s
0 1 .712 r
.58499 .47278 m
.59036 .46842 L
s
.58499 .47278 m
.58502 .46553 L
s
0 .695 1 r
.21293 .36999 m
.2074 .37457 L
s
.21601 .37126 m
.21293 .36999 L
s
.21293 .36999 m
.21556 .37852 L
s
.21556 .37852 m
.21047 .37585 L
s
.21556 .37852 m
.2074 .37457 L
s
.21601 .37126 m
.21556 .37852 L
s
.19615 .35032 m
.21556 .37852 L
s
0 1 .636 r
.64363 .61811 m
.64852 .61963 L
s
.64363 .61811 m
.6425 .62334 L
s
0 .739 1 r
.74685 .68165 m
.7256 .68154 L
s
.401 1 0 r
.43205 .60274 m
.43093 .60888 L
s
0 .22 1 r
.88156 .52928 m
.88446 .5301 L
s
.88156 .52928 m
.87621 .53582 L
s
0 .979 1 r
.74744 .53692 m
.75056 .53716 L
s
.74744 .53692 m
.74487 .54308 L
s
0 .738 1 r
.77713 .61286 m
.78193 .61436 L
s
.77713 .61286 m
.77403 .61835 L
s
0 1 .636 r
.64852 .61963 m
.64825 .62517 L
s
.6425 .62334 m
.64825 .62517 L
s
0 .703 1 r
.67981 .69767 m
.67716 .70431 L
s
.67207 .69969 m
.67716 .70431 L
s
0 .695 1 r
.2074 .37457 m
.21047 .37585 L
s
0 1 .358 r
.6168 .54199 m
.61979 .54621 L
s
.61346 .54768 m
.61979 .54621 L
s
0 1 .712 r
.58502 .46553 m
.59036 .46842 L
s
0 .713 1 r
.74236 .44344 m
.71623 .46855 L
s
.108 0 1 r
.579 .83828 m
.574 .82776 L
s
0 .713 1 r
.71623 .46855 m
.7243 .46596 L
s
.71623 .46855 m
.71921 .46067 L
s
0 .047 1 r
.84745 .46173 m
.85759 .46143 L
s
.84745 .46173 m
.85336 .45385 L
s
.88531 .44045 m
.84745 .46173 L
s
1 0 .739 r
.41955 .9171 m
.42707 .92554 L
s
.41115 .92411 m
.41955 .9171 L
s
.41955 .9171 m
.42074 .92148 L
s
0 1 .358 r
.61346 .54768 m
.6168 .54199 L
s
0 .703 1 r
.67207 .69969 m
.67981 .69767 L
s
0 1 .019 r
.24109 .44854 m
.23754 .45163 L
s
.24206 .44876 m
.24109 .44854 L
s
.24109 .44854 m
.24281 .45375 L
s
0 1 .636 r
.6425 .62334 m
.64852 .61963 L
s
0 1 .058 r
.57437 .60001 m
.56312 .60818 L
s
.725 1 0 r
.25906 .52098 m
.27079 .52989 L
s
1 0 .36 r
.41088 .99518 m
.42264 .97329 L
s
.066 0 1 r
.68829 .38496 m
.69537 .39002 L
s
0 1 .019 r
.23754 .45163 m
.2385 .45186 L
s
.24281 .45375 m
.23754 .45163 L
s
.24281 .45375 m
.2385 .45186 L
s
.24206 .44876 m
.24281 .45375 L
s
.22771 .43593 m
.24281 .45375 L
s
0 .738 1 r
.78193 .61436 m
.78188 .62138 L
s
.77403 .61835 m
.78188 .62138 L
s
0 .979 1 r
.74487 .54308 m
.75316 .54323 L
s
.74487 .54308 m
.75056 .53716 L
s
0 .22 1 r
.87621 .53582 m
.88618 .53814 L
s
.87621 .53582 m
.88446 .5301 L
s
1 0 .739 r
.42707 .92554 m
.41867 .93259 L
s
.42074 .92148 m
.42707 .92554 L
s
.371 0 1 r
.38854 .83828 m
.39474 .84545 L
s
.38139 .84403 m
.38854 .83828 L
s
.38854 .83828 m
.38951 .84197 L
s
0 .979 1 r
.75056 .53716 m
.75316 .54323 L
s
0 .713 1 r
.71921 .46067 m
.7243 .46596 L
s
0 .887 1 r
.40611 .75684 m
.40962 .74822 L
s
.725 1 0 r
.26836 .52948 m
.26689 .52939 L
s
.27 .52682 m
.26836 .52948 L
s
.27079 .52989 m
.26836 .52948 L
s
0 .695 1 r
.21047 .37585 m
.21601 .37126 L
s
0 .734 1 r
.34546 .37257 m
.33963 .37496 L
s
.3497 .37376 m
.34546 .37257 L
s
.34546 .37257 m
.34601 .38112 L
s
.582 0 1 r
.82245 .37827 m
.8291 .38569 L
s
.725 1 0 r
.26853 .52672 m
.27 .52682 L
s
.27 .52682 m
.27079 .52989 L
s
.371 0 1 r
.39474 .84545 m
.3876 .85123 L
s
.38951 .84197 m
.39474 .84545 L
s
0 .738 1 r
.77403 .61835 m
.78193 .61436 L
s
0 .585 1 r
.35798 .75981 m
.36272 .76571 L
s
.35218 .76421 m
.35798 .75981 L
s
.35798 .75981 m
.35887 .76298 L
s
0 .22 1 r
.88446 .5301 m
.88618 .53814 L
s
.445 1 0 r
.29972 .60765 m
.29659 .60903 L
s
.29865 .60413 m
.29972 .60765 L
s
.29948 .60686 m
.29972 .60765 L
s
0 .047 1 r
.85336 .45385 m
.85759 .46143 L
s
1 0 .739 r
.41867 .93259 m
.41115 .92411 L
s
.41115 .92411 m
.42074 .92148 L
s
0 .585 1 r
.36272 .76571 m
.35693 .77012 L
s
.35887 .76298 m
.36272 .76571 L
s
0 1 .431 r
.33105 .6864 m
.32664 .68936 L
s
.32795 .68175 m
.33105 .6864 L
s
.32885 .68458 m
.33105 .6864 L
s
0 1 .677 r
.71716 .59727 m
.69573 .60473 L
s
.687 1 0 r
.40133 .51811 m
.40196 .53212 L
s
0 1 .431 r
.32354 .6847 m
.32795 .68175 L
s
.32795 .68175 m
.32885 .68458 L
s
0 .734 1 r
.34601 .38112 m
.34386 .37616 L
s
.34601 .38112 m
.33963 .37496 L
s
.3497 .37376 m
.34601 .38112 L
s
.33926 .34715 m
.34601 .38112 L
s
0 1 .019 r
.2385 .45186 m
.24206 .44876 L
s
.445 1 0 r
.29551 .60551 m
.29865 .60413 L
s
.29865 .60413 m
.29948 .60686 L
s
.725 1 0 r
.27079 .52989 m
.26689 .52939 L
s
.26853 .52672 m
.27079 .52989 L
s
.371 0 1 r
.3876 .85123 m
.38139 .84403 L
s
.38139 .84403 m
.38951 .84197 L
s
.725 1 0 r
.26689 .52939 m
.26853 .52672 L
s
.445 1 0 r
.29659 .60903 m
.29551 .60551 L
s
.29948 .60686 m
.29659 .60903 L
s
0 1 .013 r
.37365 .45122 m
.36973 .45192 L
s
.37626 .45113 m
.37365 .45122 L
s
.37365 .45122 m
.37364 .45618 L
s
0 .804 1 r
.54874 .75436 m
.54293 .74853 L
s
1 0 .739 r
.42074 .92148 m
.41867 .93259 L
s
0 .585 1 r
.35693 .77012 m
.35218 .76421 L
s
.35218 .76421 m
.35887 .76298 L
s
0 1 .431 r
.32664 .68936 m
.32354 .6847 L
s
.32885 .68458 m
.32664 .68936 L
s
.445 1 0 r
.29551 .60551 m
.29948 .60686 L
s
0 .734 1 r
.33963 .37496 m
.34386 .37616 L
s
0 1 .431 r
.32354 .6847 m
.32885 .68458 L
s
.371 0 1 r
.38951 .84197 m
.3876 .85123 L
s
0 .585 1 r
.35887 .76298 m
.35693 .77012 L
s
.337 0 1 r
.52173 .83868 m
.52852 .84517 L
s
.51507 .84539 m
.52173 .83868 L
s
.52173 .83868 m
.52148 .84323 L
s
0 .502 1 r
.47804 .37232 m
.47303 .37314 L
s
.48392 .37444 m
.47804 .37232 L
s
.47804 .37232 m
.47739 .3812 L
s
0 .595 1 r
.86042 .59452 m
.8284 .59854 L
s
.164 1 0 r
.54407 .51523 m
.53393 .5317 L
s
.823 0 1 r
.38003 .9117 m
.39029 .89196 L
s
0 .734 1 r
.34386 .37616 m
.3497 .37376 L
s
0 1 .013 r
.37364 .45618 m
.37233 .45184 L
s
.37364 .45618 m
.36973 .45192 L
s
.37626 .45113 m
.37364 .45618 L
s
.3704 .43291 m
.37364 .45618 L
s
.687 1 0 r
.40303 .5303 m
.39982 .52999 L
s
.40384 .52863 m
.40303 .5303 L
s
.40303 .5303 m
.40196 .53212 L
s
0 1 .013 r
.36973 .45192 m
.37233 .45184 L
s
.337 0 1 r
.52186 .8519 m
.51507 .84539 L
s
.51507 .84539 m
.52148 .84323 L
s
0 .592 1 r
.49108 .76037 m
.49653 .76556 L
s
.48579 .76583 m
.49108 .76037 L
s
.49108 .76037 m
.49072 .76451 L
s
.687 1 0 r
.39982 .52999 m
.40063 .52832 L
s
.40196 .53212 m
.39982 .52999 L
s
.337 0 1 r
.52852 .84517 m
.52186 .8519 L
s
.52148 .84323 m
.52852 .84517 L
s
0 1 .013 r
.37233 .45184 m
.37626 .45113 L
s
0 .497 1 r
.69184 .75187 m
.67674 .74595 L
s
0 1 .119 r
.37522 .67251 m
.37925 .66927 L
s
0 .502 1 r
.47739 .3812 m
.47891 .37527 L
s
.47739 .3812 m
.47303 .37314 L
s
.48392 .37444 m
.47739 .3812 L
s
.48285 .34396 m
.47739 .3812 L
s
.401 1 0 r
.43126 .61025 m
.4284 .6077 L
s
.4339 .60759 m
.43126 .61025 L
s
.43093 .60888 m
.43126 .61025 L
s
0 .592 1 r
.49124 .77103 m
.48579 .76583 L
s
.48579 .76583 m
.49072 .76451 L
s
0 1 .389 r
.50574 .4504 m
.50347 .44968 L
s
.51049 .4519 m
.50574 .4504 L
s
.50574 .4504 m
.50534 .45602 L
s
0 .592 1 r
.49653 .76556 m
.49124 .77103 L
s
.49072 .76451 m
.49653 .76556 L
s
0 1 .45 r
.46083 .68247 m
.46492 .68634 L
s
.45696 .68658 m
.46083 .68247 L
s
.46083 .68247 m
.46052 .68637 L
s
.46105 .69045 m
.45696 .68658 L
s
.45696 .68658 m
.46052 .68637 L
s
.401 1 0 r
.4284 .6077 m
.43104 .60503 L
s
.4284 .6077 m
.43093 .60888 L
s
0 .134 1 r
.6112 .36913 m
.60758 .3693 L
s
.61812 .37308 m
.6112 .36913 L
s
.6112 .36913 m
.60936 .37875 L
s
.401 1 0 r
.43104 .60503 m
.4339 .60759 L
s
.43093 .60888 m
.4339 .60759 L
s
.687 1 0 r
.40063 .52832 m
.40384 .52863 L
s
.40384 .52863 m
.40196 .53212 L
s
0 1 .45 r
.46492 .68634 m
.46105 .69045 L
s
.46052 .68637 m
.46492 .68634 L
s
.46052 .68637 m
.46105 .69045 L
s
.337 0 1 r
.52148 .84323 m
.52186 .8519 L
s
0 1 .496 r
.68728 .51234 m
.66638 .52861 L
s
.684 0 1 r
.52297 .90947 m
.52455 .89337 L
s
0 .502 1 r
.47891 .37527 m
.48392 .37444 L
s
0 .592 1 r
.49072 .76451 m
.49124 .77103 L
s
.401 1 0 r
.43104 .60503 m
.43093 .60888 L
s
.687 1 0 r
.40196 .53212 m
.40063 .52832 L
s
0 1 .389 r
.50824 .45119 m
.51049 .4519 L
s
.51049 .4519 m
.50534 .45602 L
s
.164 1 0 r
.53862 .52921 m
.53665 .53024 L
s
.53665 .53024 m
.53331 .52758 L
s
.53665 .53024 m
.53393 .5317 L
s
0 .375 1 r
.62631 .76973 m
.62005 .7652 L
s
.62005 .7652 m
.62461 .75856 L
s
.62005 .7652 m
.62319 .76318 L
s
.62461 .75856 m
.63088 .76308 L
s
.62461 .75856 m
.62319 .76318 L
s
.325 0 1 r
.74524 .36332 m
.74279 .36361 L
s
.75227 .36951 m
.74524 .36332 L
s
.74524 .36332 m
.74159 .37377 L
s
0 .502 1 r
.47303 .37314 m
.47891 .37527 L
s
0 1 .267 r
.51827 .66987 m
.51241 .66986 L
s
0 1 .058 r
.56725 .6094 m
.56301 .60799 L
s
.56301 .60799 m
.56352 .60366 L
s
.56301 .60799 m
.56312 .60818 L
s
0 .134 1 r
.60936 .37875 m
.61452 .37326 L
s
.60936 .37875 m
.60758 .3693 L
s
.61812 .37308 m
.60936 .37875 L
s
.62692 .34077 m
.60936 .37875 L
s
0 1 .769 r
.59639 .68944 m
.59125 .68631 L
s
.59125 .68631 m
.59407 .68083 L
s
.59125 .68631 m
.59289 .68536 L
s
.164 1 0 r
.53331 .52758 m
.53528 .52655 L
s
.53331 .52758 m
.53393 .5317 L
s
0 1 .389 r
.50534 .45602 m
.50824 .45119 L
s
.50534 .45602 m
.50347 .44968 L
s
.51356 .42988 m
.50534 .45602 L
s
0 .134 1 r
.61452 .37326 m
.61812 .37308 L
s
0 1 .919 r
.63914 .44634 m
.63857 .44571 L
s
.64443 .45024 m
.63914 .44634 L
s
.63914 .44634 m
.63758 .45326 L
s
.64387 .44962 m
.64443 .45024 L
s
.64443 .45024 m
.63758 .45326 L
s
0 1 .769 r
.59407 .68083 m
.59921 .68395 L
s
.59407 .68083 m
.59289 .68536 L
s
.325 0 1 r
.74984 .36982 m
.75227 .36951 L
s
.75227 .36951 m
.74159 .37377 L
s
0 .739 1 r
.73159 .68632 m
.72604 .68365 L
s
.72604 .68365 m
.72818 .67681 L
s
.72604 .68365 m
.7256 .68154 L
s
0 1 .496 r
.67333 .52759 m
.67088 .52781 L
s
.67088 .52781 m
.66782 .5231 L
s
.67088 .52781 m
.66638 .52861 L
s
0 .768 1 r
.83097 .50944 m
.79896 .52284 L
s
0 .07 1 r
.34898 .82767 m
.35852 .81107 L
s
0 1 .677 r
.70233 .60674 m
.69799 .60553 L
s
.69799 .60553 m
.69776 .59972 L
s
.69799 .60553 m
.69573 .60473 L
s
.325 0 1 r
.74159 .37377 m
.74984 .36982 L
s
.74159 .37377 m
.74279 .36361 L
s
.77146 .33756 m
.74159 .37377 L
s
0 1 .389 r
.50347 .44968 m
.50824 .45119 L
s
0 1 .058 r
.56777 .60507 m
.56725 .6094 L
s
.56312 .60818 m
.56725 .6094 L
s
.56352 .60366 m
.56777 .60507 L
s
.56352 .60366 m
.56312 .60818 L
s
0 .46 1 r
.77374 .43995 m
.77395 .43995 L
s
.77858 .4462 m
.77374 .43995 L
s
.77374 .43995 m
.77002 .44789 L
s
.7788 .44622 m
.77858 .4462 L
s
.77858 .4462 m
.77002 .44789 L
s
0 .595 1 r
.83689 .60217 m
.83274 .60076 L
s
.83274 .60076 m
.8328 .59331 L
s
.83274 .60076 m
.8284 .59854 L
s
0 1 .769 r
.59921 .68395 m
.59639 .68944 L
s
.59289 .68536 m
.59639 .68944 L
s
0 .375 1 r
.63088 .76308 m
.62631 .76973 L
s
.62319 .76318 m
.62631 .76973 L
s
0 .768 1 r
.80781 .52376 m
.80535 .5233 L
s
.80535 .5233 m
.80294 .51656 L
s
.80535 .5233 m
.79896 .52284 L
s
0 .375 1 r
.62319 .76318 m
.63088 .76308 L
s
0 1 .496 r
.66782 .5231 m
.67027 .52287 L
s
.66782 .5231 m
.66638 .52861 L
s
.164 1 0 r
.53528 .52655 m
.53862 .52921 L
s
.53393 .5317 m
.53862 .52921 L
s
0 .739 1 r
.72818 .67681 m
.73375 .67947 L
s
.72818 .67681 m
.7256 .68154 L
s
.164 1 0 r
.53393 .5317 m
.53528 .52655 L
s
0 1 .769 r
.59289 .68536 m
.59921 .68395 L
s
0 1 .697 r
.6618 .66723 m
.64614 .66764 L
s
.756 1 0 r
.34413 .58761 m
.34952 .591 L
s
0 .768 1 r
.80294 .51656 m
.8054 .517 L
s
.80294 .51656 m
.79896 .52284 L
s
0 1 .677 r
.69776 .59972 m
.7021 .60092 L
s
.69776 .59972 m
.69573 .60473 L
s
0 1 .919 r
.63758 .45326 m
.64387 .44962 L
s
.63758 .45326 m
.63857 .44571 L
s
.6572 .42684 m
.63758 .45326 L
s
0 .595 1 r
.8328 .59331 m
.83695 .59469 L
s
.8328 .59331 m
.8284 .59854 L
s
0 1 .058 r
.56312 .60818 m
.56777 .60507 L
s
0 .134 1 r
.60758 .3693 m
.61452 .37326 L
s
0 .46 1 r
.77002 .44789 m
.7788 .44622 L
s
.77002 .44789 m
.77395 .43995 L
s
.80131 .42379 m
.77002 .44789 L
s
0 .2 1 r
.49234 .82529 m
.4927 .81276 L
s
0 .613 1 r
.26256 .35204 m
.25661 .35604 L
s
.26636 .35353 m
.26256 .35204 L
s
.26256 .35204 m
.26443 .36105 L
s
0 .739 1 r
.73375 .67947 m
.73159 .68632 L
s
.7256 .68154 m
.73159 .68632 L
s
0 .613 1 r
.26443 .36105 m
.2604 .35755 L
s
.26443 .36105 m
.25661 .35604 L
s
.26636 .35353 m
.26443 .36105 L
s
.2496 .3295 m
.26443 .36105 L
s
0 1 .677 r
.7021 .60092 m
.70233 .60674 L
s
.69573 .60473 m
.70233 .60674 L
s
0 1 .496 r
.66638 .52861 m
.67333 .52759 L
s
.66638 .52861 m
.67027 .52287 L
s
0 1 .919 r
.63857 .44571 m
.64387 .44962 L
s
0 1 .496 r
.67027 .52287 m
.67333 .52759 L
s
0 .698 1 r
.8058 .66458 m
.78007 .66259 L
s
.512 1 0 r
.4876 .58483 m
.48248 .59186 L
s
0 .739 1 r
.7256 .68154 m
.73375 .67947 L
s
0 .768 1 r
.79896 .52284 m
.80781 .52376 L
s
.79896 .52284 m
.8054 .517 L
s
0 1 .677 r
.69573 .60473 m
.7021 .60092 L
s
.962 0 1 r
.47138 .90369 m
.47879 .9115 L
s
.46348 .91065 m
.47138 .90369 L
s
.47138 .90369 m
.47213 .90781 L
s
.325 0 1 r
.74279 .36361 m
.74984 .36982 L
s
0 .613 1 r
.25661 .35604 m
.2604 .35755 L
s
0 .595 1 r
.83695 .59469 m
.83689 .60217 L
s
.8284 .59854 m
.83689 .60217 L
s
0 .085 1 r
.63619 .8229 m
.62753 .8115 L
s
0 1 .979 r
.31772 .74308 m
.32736 .73072 L
s
0 1 .029 r
.29102 .43134 m
.28708 .43373 L
s
.29279 .43164 m
.29102 .43134 L
s
.29102 .43134 m
.29208 .43682 L
s
0 .768 1 r
.8054 .517 m
.80781 .52376 L
s
0 .595 1 r
.8284 .59854 m
.83695 .59469 L
s
0 .46 1 r
.77395 .43995 m
.7788 .44622 L
s
0 1 .029 r
.29208 .43682 m
.28884 .43404 L
s
.29208 .43682 m
.28708 .43373 L
s
.29279 .43164 m
.29208 .43682 L
s
.28132 .41611 m
.29208 .43682 L
s
.073 0 1 r
.44009 .82423 m
.44618 .83077 L
s
.43344 .82997 m
.44009 .82423 L
s
.44009 .82423 m
.44059 .82776 L
s
.962 0 1 r
.47879 .9115 m
.4709 .91849 L
s
.47213 .90781 m
.47879 .9115 L
s
0 1 .029 r
.28708 .43373 m
.28884 .43404 L
s
0 1 .078 r
.63155 .58204 m
.61606 .58996 L
s
.895 1 0 r
.31283 .50215 m
.32045 .51349 L
s
1 0 .68 r
.46629 .98149 m
.47493 .95991 L
s
0 .553 1 r
.3964 .35342 m
.39056 .35547 L
s
.40151 .35522 m
.3964 .35342 L
s
.3964 .35342 m
.39645 .36256 L
s
0 .613 1 r
.2604 .35755 m
.26636 .35353 L
s
.962 0 1 r
.4709 .91849 m
.46348 .91065 L
s
.46348 .91065 m
.47213 .90781 L
s
.895 1 0 r
.31813 .51235 m
.31737 .51177 L
s
.32048 .51067 m
.31813 .51235 L
s
.32045 .51349 m
.31813 .51235 L
s
.31972 .51009 m
.32048 .51067 L
s
.32048 .51067 m
.32045 .51349 L
s
.073 0 1 r
.44618 .83077 m
.43954 .83652 L
s
.44059 .82776 m
.44618 .83077 L
s
0 .887 1 r
.40922 .74513 m
.41387 .75038 L
s
.40394 .74955 m
.40922 .74513 L
s
.40922 .74513 m
.40962 .74822 L
s
0 1 .843 r
.46151 .74055 m
.46141 .73267 L
s
0 .553 1 r
.39645 .36256 m
.39567 .35728 L
s
.39645 .36256 m
.39056 .35547 L
s
.40151 .35522 m
.39645 .36256 L
s
.39436 .32626 m
.39645 .36256 L
s
.756 1 0 r
.35036 .59108 m
.34754 .59239 L
s
.34933 .58825 m
.35036 .59108 L
s
.34952 .591 m
.35036 .59108 L
s
0 1 .029 r
.28884 .43404 m
.29279 .43164 L
s
0 .887 1 r
.41387 .75038 m
.40859 .7548 L
s
.40962 .74822 m
.41387 .75038 L
s
.073 0 1 r
.43954 .83652 m
.43344 .82997 L
s
.43344 .82997 m
.44059 .82776 L
s
0 1 .119 r
.38191 .67042 m
.37801 .6734 L
s
.37886 .66645 m
.38191 .67042 L
s
.37925 .66927 m
.38191 .67042 L
s
.37497 .66943 m
.37886 .66645 L
s
.37886 .66645 m
.37925 .66927 L
s
.895 1 0 r
.32045 .51349 m
.31737 .51177 L
s
.31972 .51009 m
.32045 .51349 L
s
.756 1 0 r
.34754 .59239 m
.34651 .58956 L
s
.34952 .591 m
.34754 .59239 L
s
.34651 .58956 m
.34933 .58825 L
s
.34933 .58825 m
.34952 .591 L
s
.639 1 0 r
.45673 .49921 m
.45315 .51458 L
s
0 1 .798 r
.77599 .57924 m
.74992 .58532 L
s
.962 0 1 r
.47213 .90781 m
.4709 .91849 L
s
0 1 .167 r
.42468 .43261 m
.42109 .43294 L
s
.42832 .43329 m
.42468 .43261 L
s
.42468 .43261 m
.42447 .43813 L
s
0 .887 1 r
.40859 .7548 m
.40394 .74955 L
s
.40394 .74955 m
.40962 .74822 L
s
.895 1 0 r
.31737 .51177 m
.31972 .51009 L
s
0 1 .119 r
.37801 .6734 m
.37497 .66943 L
s
.37925 .66927 m
.37801 .6734 L
s
.37497 .66943 m
.37925 .66927 L
s
.756 1 0 r
.34651 .58956 m
.34952 .591 L
s
.073 0 1 r
.44059 .82776 m
.43954 .83652 L
s
.108 0 1 r
.57472 .8236 m
.58143 .82945 L
s
.5686 .83034 m
.57472 .8236 L
s
.57472 .8236 m
.574 .82776 L
s
0 .887 1 r
.40962 .74822 m
.40859 .7548 L
s
0 .277 1 r
.5305 .35192 m
.52568 .35275 L
s
.53699 .35501 m
.5305 .35192 L
s
.5305 .35192 m
.52928 .36154 L
s
0 .553 1 r
.39056 .35547 m
.39567 .35728 L
s
.39567 .35728 m
.40151 .35522 L
s
0 .972 1 r
.60578 .73801 m
.59616 .73174 L
s
0 1 .021 r
.28626 .65792 m
.29685 .65098 L
s
.108 0 1 r
.57531 .8362 m
.5686 .83034 L
s
.5686 .83034 m
.574 .82776 L
s
0 1 .167 r
.42447 .43813 m
.42473 .43362 L
s
.42447 .43813 m
.42109 .43294 L
s
.42832 .43329 m
.42447 .43813 L
s
.42565 .41303 m
.42447 .43813 L
s
.639 1 0 r
.45253 .512 m
.4519 .51059 L
s
.45583 .51242 m
.45253 .512 L
s
.45253 .512 m
.45315 .51458 L
s
0 .804 1 r
.54374 .74467 m
.54915 .7492 L
s
.53906 .75021 m
.54374 .74467 L
s
.54374 .74467 m
.54293 .74853 L
s
0 1 .167 r
.42473 .43362 m
.42832 .43329 L
s
0 .277 1 r
.52928 .36154 m
.53218 .35585 L
s
.52928 .36154 m
.52568 .35275 L
s
.53699 .35501 m
.52928 .36154 L
s
.53961 .32301 m
.52928 .36154 L
s
.639 1 0 r
.45521 .51101 m
.45583 .51242 L
s
.45583 .51242 m
.45315 .51458 L
s
0 .804 1 r
.54447 .75475 m
.53906 .75021 L
s
.53906 .75021 m
.54293 .74853 L
s
0 1 .167 r
.42109 .43294 m
.42473 .43362 L
s
0 .362 1 r
.92091 .57643 m
.8837 .57792 L
s
.02 1 0 r
.60111 .49627 m
.58654 .513 L
s
.502 0 1 r
.43529 .89705 m
.44227 .878 L
s
.108 0 1 r
.58143 .82945 m
.57531 .8362 L
s
.574 .82776 m
.58143 .82945 L
s
.12 0 1 r
.66531 .34761 m
.66175 .34807 L
s
.67245 .35268 m
.66531 .34761 L
s
.66531 .34761 m
.66258 .35798 L
s
.512 1 0 r
.48456 .59274 m
.48123 .59118 L
s
.48123 .59118 m
.48246 .58814 L
s
.48123 .59118 m
.48248 .59186 L
s
0 1 .602 r
.55862 .4304 m
.55666 .42994 L
s
.56368 .43299 m
.55862 .4304 L
s
.55862 .4304 m
.5576 .43684 L
s
0 1 .267 r
.51413 .67359 m
.50997 .67042 L
s
.50997 .67042 m
.51306 .66614 L
s
.50997 .67042 m
.51241 .66986 L
s
.512 1 0 r
.48579 .58971 m
.48456 .59274 L
s
.48248 .59186 m
.48456 .59274 L
s
0 1 .267 r
.51306 .66614 m
.51722 .66931 L
s
.51306 .66614 m
.51241 .66986 L
s
0 .277 1 r
.53218 .35585 m
.53699 .35501 L
s
0 .804 1 r
.54915 .7492 m
.54447 .75475 L
s
.54293 .74853 m
.54915 .7492 L
s
.108 0 1 r
.574 .82776 m
.57531 .8362 L
s
0 1 .267 r
.51722 .66931 m
.51413 .67359 L
s
.51241 .66986 m
.51413 .67359 L
s
0 .556 1 r
.75054 .73547 m
.73128 .7279 L
s
.149 1 0 r
.43047 .65524 m
.4307 .65318 L
s
0 .804 1 r
.54293 .74853 m
.54447 .75475 L
s
0 .497 1 r
.68082 .75249 m
.67475 .74856 L
s
.67475 .74856 m
.67878 .7418 L
s
.67475 .74856 m
.67674 .74595 L
s
.626 0 1 r
.80093 .34079 m
.79826 .34149 L
s
.80786 .34818 m
.80093 .34079 L
s
.80093 .34079 m
.796 .35188 L
s
.639 1 0 r
.45315 .51458 m
.45521 .51101 L
s
.45315 .51458 m
.4519 .51059 L
s
.4519 .51059 m
.45521 .51101 L
s
.512 1 0 r
.48246 .58814 m
.48579 .58971 L
s
.48246 .58814 m
.48248 .59186 L
s
0 1 .267 r
.51241 .66986 m
.51722 .66931 L
s
0 1 .602 r
.56173 .43254 m
.56368 .43299 L
s
.56368 .43299 m
.5576 .43684 L
s
0 .497 1 r
.67878 .7418 m
.68485 .74572 L
s
.67878 .7418 m
.67674 .74595 L
s
.512 1 0 r
.48248 .59186 m
.48579 .58971 L
s
.12 0 1 r
.66258 .35798 m
.66892 .35316 L
s
.66258 .35798 m
.66175 .34807 L
s
.67245 .35268 m
.66258 .35798 L
s
.68535 .31974 m
.66258 .35798 L
s
.02 1 0 r
.5919 .51092 m
.59042 .51161 L
s
.59042 .51161 m
.58702 .50838 L
s
.59042 .51161 m
.58654 .513 L
s
0 .308 1 r
.1818 .33987 m
.17618 .33815 L
s
.17809 .33037 m
.1818 .33987 L
s
.1818 .33987 m
.17232 .33615 L
s
.18196 .33235 m
.1818 .33987 L
s
.15826 .31153 m
.1818 .33987 L
s
0 1 .697 r
.65068 .67167 m
.64577 .66912 L
s
.64577 .66912 m
.64791 .66344 L
s
.64577 .66912 m
.64614 .66764 L
s
0 1 .078 r
.62124 .59112 m
.61745 .59019 L
s
.61745 .59019 m
.61711 .58562 L
s
.61745 .59019 m
.61606 .58996 L
s
.12 0 1 r
.66892 .35316 m
.67245 .35268 L
s
.02 1 0 r
.58702 .50838 m
.5885 .50768 L
s
.58702 .50838 m
.58654 .513 L
s
0 .83 1 r
.69382 .42534 m
.69309 .42515 L
s
.69902 .43028 m
.69382 .42534 L
s
.69382 .42534 m
.69114 .43294 L
s
0 1 .602 r
.5576 .43684 m
.56173 .43254 L
s
.5576 .43684 m
.55666 .42994 L
s
.57046 .40993 m
.5576 .43684 L
s
.626 0 1 r
.80522 .34892 m
.80786 .34818 L
s
.80786 .34818 m
.796 .35188 L
s
1 0 .36 r
.42063 .96953 m
.42881 .97867 L
s
.41166 .97682 m
.42063 .96953 L
s
.42063 .96953 m
.42264 .97329 L
s
.626 0 1 r
.796 .35188 m
.80522 .34892 L
s
.796 .35188 m
.79826 .34149 L
s
.83158 .31646 m
.796 .35188 L
s
0 .698 1 r
.78685 .6677 m
.78177 .66541 L
s
.78177 .66541 m
.78367 .65829 L
s
.78177 .66541 m
.78007 .66259 L
s
0 1 .703 r
.74598 .49332 m
.72026 .50874 L
s
.434 0 1 r
.57988 .89477 m
.57802 .87812 L
s
0 .83 1 r
.6983 .43011 m
.69902 .43028 L
s
.69902 .43028 m
.69114 .43294 L
s
0 .277 1 r
.52568 .35275 m
.53218 .35585 L
s
0 .308 1 r
.17809 .33037 m
.17232 .33615 L
s
.18196 .33235 m
.17809 .33037 L
s
0 .362 1 r
.89275 .58233 m
.8893 .58099 L
s
.8893 .58099 m
.88959 .57292 L
s
.8893 .58099 m
.8837 .57792 L
s
0 1 .697 r
.64791 .66344 m
.65283 .66599 L
s
.64791 .66344 m
.64614 .66764 L
s
0 .15 1 r
.83423 .42578 m
.83448 .42534 L
s
.83448 .42534 m
.82994 .41802 L
s
.83448 .42534 m
.82474 .42642 L
s
.82994 .41802 m
.82967 .41843 L
s
.82994 .41802 m
.82474 .42642 L
s
0 1 .703 r
.72783 .50838 m
.72597 .50833 L
s
.72597 .50833 m
.72301 .50292 L
s
.72597 .50833 m
.72026 .50874 L
s
0 1 .798 r
.75722 .58775 m
.75351 .58667 L
s
.75351 .58667 m
.7531 .58045 L
s
.75351 .58667 m
.74992 .58532 L
s
0 .479 1 r
.86339 .50364 m
.86162 .50295 L
s
.86162 .50295 m
.85952 .49538 L
s
.86162 .50295 m
.85398 .5018 L
s
0 1 .078 r
.61711 .58562 m
.62091 .58655 L
s
.61711 .58562 m
.61606 .58996 L
s
0 .698 1 r
.78367 .65829 m
.78876 .66057 L
s
.78367 .65829 m
.78007 .66259 L
s
0 1 .703 r
.72301 .50292 m
.72486 .50297 L
s
.72301 .50292 m
.72026 .50874 L
s
0 .362 1 r
.88959 .57292 m
.89304 .57424 L
s
.88959 .57292 m
.8837 .57792 L
s
0 .479 1 r
.85952 .49538 m
.86129 .49605 L
s
.85952 .49538 m
.85398 .5018 L
s
0 1 .145 r
.57518 .65255 m
.56533 .65256 L
s
.732 1 0 r
.25458 .5722 m
.267 .57195 L
s
1 0 0 r
.40894 1.05435 m
.42519 1.02733 L
s
0 .308 1 r
.17232 .33615 m
.17618 .33815 L
s
0 1 .798 r
.7531 .58045 m
.75681 .58151 L
s
.7531 .58045 m
.74992 .58532 L
s
0 .497 1 r
.68485 .74572 m
.68082 .75249 L
s
.67674 .74595 m
.68082 .75249 L
s
0 .83 1 r
.69114 .43294 m
.6983 .43011 L
s
.69114 .43294 m
.69309 .42515 L
s
.71577 .40682 m
.69114 .43294 L
s
0 1 .697 r
.65283 .66599 m
.65068 .67167 L
s
.64614 .66764 m
.65068 .67167 L
s
0 1 .602 r
.55666 .42994 m
.56173 .43254 L
s
0 1 .078 r
.62091 .58655 m
.62124 .59112 L
s
.61606 .58996 m
.62124 .59112 L
s
0 .497 1 r
.67674 .74595 m
.68485 .74572 L
s
1 0 .36 r
.42881 .97867 m
.41986 .98599 L
s
.42264 .97329 m
.42881 .97867 L
s
.823 0 1 r
.38862 .88898 m
.3956 .89687 L
s
.3808 .89506 m
.38862 .88898 L
s
.38862 .88898 m
.39029 .89196 L
s
.02 1 0 r
.58654 .513 m
.5919 .51092 L
s
.58654 .513 m
.5885 .50768 L
s
0 .15 1 r
.82474 .42642 m
.83423 .42578 L
s
.82474 .42642 m
.82967 .41843 L
s
.86156 .4037 m
.82474 .42642 L
s
.02 1 0 r
.5885 .50768 m
.5919 .51092 L
s
0 1 .697 r
.64614 .66764 m
.65283 .66599 L
s
0 1 .327 r
.20945 .41632 m
.20485 .4154 L
s
.20654 .41035 m
.20945 .41632 L
s
.20945 .41632 m
.203 .41447 L
s
.2084 .41127 m
.20945 .41632 L
s
.19058 .399 m
.20945 .41632 L
s
.20654 .41035 m
.203 .41447 L
s
.2084 .41127 m
.20654 .41035 L
s
0 .479 1 r
.89133 .49035 m
.85398 .5018 L
s
0 .397 1 r
.40409 .81206 m
.41017 .79654 L
s
0 1 .078 r
.61606 .58996 m
.62091 .58655 L
s
0 1 .327 r
.203 .41447 m
.20485 .4154 L
s
.12 0 1 r
.66175 .34807 m
.66892 .35316 L
s
.823 0 1 r
.3956 .89687 m
.38779 .90298 L
s
.39029 .89196 m
.3956 .89687 L
s
0 .07 1 r
.35703 .80872 m
.36267 .81534 L
s
.35051 .81353 m
.35703 .80872 L
s
.35703 .80872 m
.35852 .81107 L
s
0 1 .703 r
.72026 .50874 m
.72783 .50838 L
s
.72026 .50874 m
.72486 .50297 L
s
0 .479 1 r
.85398 .5018 m
.86339 .50364 L
s
.85398 .5018 m
.86129 .49605 L
s
0 .698 1 r
.78876 .66057 m
.78685 .6677 L
s
.78007 .66259 m
.78685 .6677 L
s
0 1 .701 r
.72036 .64986 m
.70038 .6491 L
s
.993 1 0 r
.39923 .56936 m
.40061 .57436 L
s
1 0 .36 r
.41986 .98599 m
.41166 .97682 L
s
.41166 .97682 m
.42264 .97329 L
s
0 1 .798 r
.75681 .58151 m
.75722 .58775 L
s
.74992 .58532 m
.75722 .58775 L
s
.657 1 0 r
.23415 .49354 m
.23395 .49377 L
s
.23571 .49051 m
.23415 .49354 L
s
.23786 .4937 m
.23415 .49354 L
s
0 .308 1 r
.17618 .33815 m
.18196 .33235 L
s
.657 1 0 r
.23552 .49075 m
.23571 .49051 L
s
.23571 .49051 m
.23786 .4937 L
s
0 .83 1 r
.69309 .42515 m
.6983 .43011 L
s
0 1 .703 r
.72486 .50297 m
.72783 .50838 L
s
0 .07 1 r
.36267 .81534 m
.35615 .82016 L
s
.35852 .81107 m
.36267 .81534 L
s
0 1 .979 r
.32588 .72882 m
.33004 .73416 L
s
.32079 .73227 m
.32588 .72882 L
s
.32588 .72882 m
.32736 .73072 L
s
0 .698 1 r
.78007 .66259 m
.78876 .66057 L
s
0 .479 1 r
.31318 .33323 m
.30693 .33677 L
s
.31776 .33511 m
.31318 .33323 L
s
.31318 .33323 m
.31435 .3428 L
s
0 1 .798 r
.74992 .58532 m
.75681 .58151 L
s
0 .362 1 r
.8837 .57792 m
.89275 .58233 L
s
.8837 .57792 m
.89304 .57424 L
s
0 .479 1 r
.31435 .3428 m
.3115 .33865 L
s
.31435 .3428 m
.30693 .33677 L
s
.31776 .33511 m
.31435 .3428 L
s
.30422 .30823 m
.31435 .3428 L
s
.732 1 0 r
.2658 .57321 m
.26375 .57397 L
s
.26527 .57004 m
.2658 .57321 L
s
.267 .57195 m
.2658 .57321 L
s
0 1 .979 r
.33004 .73416 m
.32495 .73762 L
s
.32736 .73072 m
.33004 .73416 L
s
.626 0 1 r
.79826 .34149 m
.80522 .34892 L
s
0 .44 1 r
.54911 .80962 m
.54587 .79697 L
s
.657 1 0 r
.23786 .4937 m
.23395 .49377 L
s
.23552 .49075 m
.23786 .4937 L
s
.22269 .48589 m
.23786 .4937 L
s
0 1 .021 r
.29775 .65342 m
.29417 .65549 L
s
.29526 .64928 m
.29775 .65342 L
s
.29685 .65098 m
.29775 .65342 L
s
.29168 .65134 m
.29526 .64928 L
s
.29526 .64928 m
.29685 .65098 L
s
.823 0 1 r
.38779 .90298 m
.3808 .89506 L
s
.3808 .89506 m
.39029 .89196 L
s
.732 1 0 r
.26322 .57079 m
.26527 .57004 L
s
.26527 .57004 m
.267 .57195 L
s
0 .362 1 r
.89304 .57424 m
.89275 .58233 L
s
0 1 .327 r
.20485 .4154 m
.2084 .41127 L
s
0 .479 1 r
.86129 .49605 m
.86339 .50364 L
s
.684 0 1 r
.52428 .8896 m
.53158 .89675 L
s
.51688 .89652 m
.52428 .8896 L
s
.52428 .8896 m
.52455 .89337 L
s
1 0 .36 r
.42264 .97329 m
.41986 .98599 L
s
0 .15 1 r
.82967 .41843 m
.83423 .42578 L
s
0 .07 1 r
.35615 .82016 m
.35051 .81353 L
s
.35051 .81353 m
.35852 .81107 L
s
0 .568 1 r
.86604 .64715 m
.8355 .64282 L
s
.532 1 0 r
.54436 .56652 m
.53506 .57403 L
s
1 0 .738 r
.37757 .96966 m
.3917 .94417 L
s
.657 1 0 r
.23395 .49377 m
.23552 .49075 L
s
.732 1 0 r
.26375 .57397 m
.26322 .57079 L
s
.267 .57195 m
.26375 .57397 L
s
0 1 .121 r
.34187 .41323 m
.33776 .41506 L
s
.34455 .41387 m
.34187 .41323 L
s
.34187 .41323 m
.34241 .4191 L
s
.823 0 1 r
.39029 .89196 m
.38779 .90298 L
s
0 1 .979 r
.32495 .73762 m
.32079 .73227 L
s
.32079 .73227 m
.32736 .73072 L
s
0 .479 1 r
.30693 .33677 m
.3115 .33865 L
s
.732 1 0 r
.26322 .57079 m
.267 .57195 L
s
0 1 .021 r
.29417 .65549 m
.29168 .65134 L
s
.29685 .65098 m
.29417 .65549 L
s
.29168 .65134 m
.29685 .65098 L
s
0 .07 1 r
.35852 .81107 m
.35615 .82016 L
s
0 1 .979 r
.32736 .73072 m
.32495 .73762 L
s
0 .2 1 r
.4927 .8095 m
.49869 .81537 L
s
.48657 .81523 m
.4927 .8095 L
s
.4927 .8095 m
.4927 .81276 L
s
0 .229 1 r
.69462 .80718 m
.68207 .79442 L
s
0 1 .633 r
.37267 .72649 m
.37866 .71561 L
s
0 1 .121 r
.34241 .4191 m
.34043 .4157 L
s
.34241 .4191 m
.33776 .41506 L
s
.34455 .41387 m
.34241 .4191 L
s
.3361 .39586 m
.34241 .4191 L
s
.684 0 1 r
.53158 .89675 m
.52419 .9037 L
s
.52455 .89337 m
.53158 .89675 L
s
.52419 .9037 m
.51688 .89652 L
s
.51688 .89652 m
.52455 .89337 L
s
0 .343 1 r
.44842 .33339 m
.44263 .33524 L
s
.45432 .33597 m
.44842 .33339 L
s
.44842 .33339 m
.44793 .34321 L
s
0 .479 1 r
.3115 .33865 m
.31776 .33511 L
s
0 1 .121 r
.33776 .41506 m
.34043 .4157 L
s
.939 1 0 r
.37143 .49373 m
.36878 .49422 L
s
.3722 .49303 m
.37143 .49373 L
s
.37143 .49373 m
.37117 .49631 L
s
0 1 .183 r
.68999 .56367 m
.67 .57094 L
s
.939 1 0 r
.36777 .4829 m
.37117 .49631 L
s
1 0 .977 r
.52291 .96749 m
.52829 .94574 L
s
0 .343 1 r
.44793 .34321 m
.44853 .33782 L
s
.44793 .34321 m
.44263 .33524 L
s
.45432 .33597 m
.44793 .34321 L
s
.45067 .30491 m
.44793 .34321 L
s
0 1 .843 r
.4615 .72976 m
.46607 .73433 L
s
.45678 .7342 m
.4615 .72976 L
s
.4615 .72976 m
.46141 .73267 L
s
0 .2 1 r
.49869 .81537 m
.49256 .82112 L
s
.4927 .81276 m
.49869 .81537 L
s
.49256 .82112 m
.48657 .81523 L
s
.48657 .81523 m
.4927 .81276 L
s
.939 1 0 r
.36878 .49422 m
.36955 .49352 L
s
.37117 .49631 m
.36878 .49422 L
s
0 1 .121 r
.34043 .4157 m
.34455 .41387 L
s
.993 1 0 r
.3999 .57512 m
.39846 .57303 L
s
.4022 .57369 m
.3999 .57512 L
s
.40061 .57436 m
.3999 .57512 L
s
0 1 .843 r
.46607 .73433 m
.46135 .73878 L
s
.46141 .73267 m
.46607 .73433 L
s
.993 1 0 r
.40076 .5716 m
.4022 .57369 L
s
.40061 .57436 m
.4022 .57369 L
s
0 1 .843 r
.46135 .73878 m
.45678 .7342 L
s
.45678 .7342 m
.46141 .73267 L
s
.684 0 1 r
.52455 .89337 m
.52419 .9037 L
s
.939 1 0 r
.37117 .49631 m
.36955 .49352 L
s
.3722 .49303 m
.37117 .49631 L
s
.149 1 0 r
.43076 .65043 m
.43383 .6537 L
s
.42747 .65349 m
.43076 .65043 L
s
.43076 .65043 m
.4307 .65318 L
s
0 1 .371 r
.47693 .41305 m
.47366 .41329 L
s
.48131 .41467 m
.47693 .41305 L
s
.47693 .41305 m
.47633 .41928 L
s
0 1 .615 r
.51813 .7239 m
.51425 .71633 L
s
.149 1 0 r
.43383 .6537 m
.43054 .65676 L
s
.4307 .65318 m
.43383 .6537 L
s
0 .085 1 r
.62879 .80782 m
.63538 .81302 L
s
.62319 .8146 m
.62879 .80782 L
s
.62879 .80782 m
.62753 .8115 L
s
.939 1 0 r
.36955 .49352 m
.3722 .49303 L
s
.149 1 0 r
.43054 .65676 m
.42747 .65349 L
s
.42747 .65349 m
.4307 .65318 L
s
.993 1 0 r
.39846 .57303 m
.40076 .5716 L
s
.39846 .57303 m
.40061 .57436 L
s
.149 1 0 r
.4307 .65318 m
.43054 .65676 L
s
0 .028 1 r
.58413 .33069 m
.57942 .33164 L
s
.59109 .33483 m
.58413 .33069 L
s
.58413 .33069 m
.58219 .34108 L
s
0 .2 1 r
.4927 .81276 m
.49256 .82112 L
s
.993 1 0 r
.40076 .5716 m
.40061 .57436 L
s
0 1 .843 r
.46141 .73267 m
.46135 .73878 L
s
0 .085 1 r
.62978 .81981 m
.62319 .8146 L
s
.62319 .8146 m
.62753 .8115 L
s
0 .343 1 r
.44853 .33782 m
.45432 .33597 L
s
.499 1 0 r
.51334 .47991 m
.50538 .49625 L
s
0 .994 1 r
.83611 .56081 m
.80507 .56509 L
s
.448 0 1 r
.34599 .88441 m
.35878 .86139 L
s
0 1 .371 r
.47633 .41928 m
.47804 .41491 L
s
.47633 .41928 m
.47366 .41329 L
s
.48131 .41467 m
.47633 .41928 L
s
.48211 .3927 m
.47633 .41928 L
s
0 .028 1 r
.58219 .34108 m
.5864 .33579 L
s
.58219 .34108 m
.57942 .33164 L
s
.59109 .33483 m
.58219 .34108 L
s
.59762 .30158 m
.58219 .34108 L
s
0 .343 1 r
.44263 .33524 m
.44853 .33782 L
s
0 .972 1 r
.5975 .72824 m
.6028 .73213 L
s
.59342 .73389 m
.5975 .72824 L
s
.5975 .72824 m
.59616 .73174 L
s
.499 1 0 r
.50533 .4927 m
.50521 .49172 L
s
.50873 .49423 m
.50533 .4927 L
s
.50533 .4927 m
.50538 .49625 L
s
0 .972 1 r
.59872 .73779 m
.59342 .73389 L
s
.59342 .73389 m
.59616 .73174 L
s
0 1 .371 r
.47804 .41491 m
.48131 .41467 L
s
.499 1 0 r
.50862 .49325 m
.50873 .49423 L
s
.50873 .49423 m
.50538 .49625 L
s
.407 0 1 r
.72058 .32528 m
.71695 .32609 L
s
.72784 .33155 m
.72058 .32528 L
s
.72058 .32528 m
.71678 .33639 L
s
.532 1 0 r
.5386 .57454 m
.53542 .5738 L
s
.53542 .5738 m
.53526 .57051 L
s
.53542 .5738 m
.53506 .57403 L
s
0 1 .145 r
.56821 .65604 m
.56411 .65353 L
s
.56411 .65353 m
.56641 .64907 L
s
.56411 .65353 m
.56533 .65256 L
s
0 1 .855 r
.61274 .40961 m
.61085 .40949 L
s
.61797 .4133 m
.61274 .40961 L
s
.61274 .40961 m
.61087 .41685 L
s
.361 1 0 r
.34105 .64034 m
.34778 .6353 L
s
0 1 .921 r
.66408 .72131 m
.65042 .71414 L
s
0 .085 1 r
.63538 .81302 m
.62978 .81981 L
s
.62753 .8115 m
.63538 .81302 L
s
0 .028 1 r
.5864 .33579 m
.59109 .33483 L
s
0 .556 1 r
.73624 .73459 m
.73046 .7312 L
s
.73046 .7312 m
.7341 .72428 L
s
.73046 .7312 m
.73128 .7279 L
s
0 1 .145 r
.56641 .64907 m
.57052 .65158 L
s
.56641 .64907 m
.56533 .65256 L
s
0 1 .371 r
.47366 .41329 m
.47804 .41491 L
s
.407 0 1 r
.71678 .33639 m
.72423 .33237 L
s
.71678 .33639 m
.71695 .32609 L
s
.72784 .33155 m
.71678 .33639 L
s
.74508 .29825 m
.71678 .33639 L
s
0 .556 1 r
.7341 .72428 m
.73989 .72765 L
s
.7341 .72428 m
.73128 .7279 L
s
0 .085 1 r
.62753 .8115 m
.62978 .81981 L
s
.532 1 0 r
.53526 .57051 m
.53844 .57125 L
s
.53526 .57051 m
.53506 .57403 L
s
0 1 .855 r
.61609 .41319 m
.61797 .4133 L
s
.61797 .4133 m
.61087 .41685 L
s
.532 1 0 r
.53844 .57125 m
.5386 .57454 L
s
.53506 .57403 m
.5386 .57454 L
s
0 1 .701 r
.70583 .65327 m
.7013 .65117 L
s
.7013 .65117 m
.70299 .64524 L
s
.7013 .65117 m
.70038 .6491 L
s
.407 0 1 r
.72423 .33237 m
.72784 .33155 L
s
0 .972 1 r
.6028 .73213 m
.59872 .73779 L
s
.59616 .73174 m
.6028 .73213 L
s
.499 1 0 r
.50538 .49625 m
.50862 .49325 L
s
.50538 .49625 m
.50521 .49172 L
s
0 1 .145 r
.57052 .65158 m
.56821 .65604 L
s
.56533 .65256 m
.56821 .65604 L
s
0 .972 1 r
.59616 .73174 m
.59872 .73779 L
s
0 1 .193 r
.64619 .49201 m
.64516 .49233 L
s
.64516 .49233 m
.64182 .48834 L
s
.64516 .49233 m
.64015 .4935 L
s
0 .568 1 r
.84297 .64845 m
.83845 .64645 L
s
.83845 .64645 m
.84034 .63894 L
s
.83845 .64645 m
.8355 .64282 L
s
0 1 .183 r
.67598 .57232 m
.67278 .57158 L
s
.67278 .57158 m
.67205 .56665 L
s
.67278 .57158 m
.67 .57094 L
s
0 .53 1 r
.74963 .40358 m
.74859 .40382 L
s
.75469 .40963 m
.74963 .40358 L
s
.74963 .40358 m
.74568 .4118 L
s
0 1 .193 r
.65941 .4769 m
.64015 .4935 L
s
.207 0 1 r
.49177 .88208 m
.49532 .86326 L
s
0 1 .193 r
.64182 .48834 m
.64285 .48801 L
s
.64182 .48834 m
.64015 .4935 L
s
0 1 .855 r
.61087 .41685 m
.61609 .41319 L
s
.61087 .41685 m
.61085 .40949 L
s
.62862 .38954 m
.61087 .41685 L
s
0 .53 1 r
.75367 .40988 m
.75469 .40963 L
s
.75469 .40963 m
.74568 .4118 L
s
0 1 .145 r
.56533 .65256 m
.57052 .65158 L
s
.499 1 0 r
.50521 .49172 m
.50862 .49325 L
s
0 .994 1 r
.81299 .56815 m
.80995 .56711 L
s
.80995 .56711 m
.80961 .56031 L
s
.80995 .56711 m
.80507 .56509 L
s
0 1 .701 r
.70299 .64524 m
.70752 .64733 L
s
.70299 .64524 m
.70038 .6491 L
s
0 1 .98 r
.78329 .48852 m
.78203 .48817 L
s
.78203 .48817 m
.77929 .48192 L
s
.78203 .48817 m
.77512 .48805 L
s
0 .568 1 r
.84034 .63894 m
.84487 .64092 L
s
.84034 .63894 m
.8355 .64282 L
s
.532 1 0 r
.53506 .57403 m
.53844 .57125 L
s
0 1 .183 r
.67205 .56665 m
.67525 .56737 L
s
.67205 .56665 m
.67 .57094 L
s
0 1 .98 r
.77929 .48192 m
.78054 .48225 L
s
.77929 .48192 m
.77512 .48805 L
s
0 .994 1 r
.80961 .56031 m
.81266 .56133 L
s
.80961 .56031 m
.80507 .56509 L
s
0 .535 1 r
.81053 .71871 m
.7868 .70903 L
s
.356 1 0 r
.48695 .6376 m
.4832 .63629 L
s
1 0 .68 r
.47339 .95647 m
.48142 .96495 L
s
.46491 .96365 m
.47339 .95647 L
s
.47339 .95647 m
.47493 .95991 L
s
0 .249 1 r
.23114 .3219 m
.22649 .31928 L
s
.22835 .31184 m
.23114 .3219 L
s
.23114 .3219 m
.22205 .31705 L
s
.23281 .31405 m
.23114 .3219 L
s
.21238 .28985 m
.23114 .3219 L
s
0 .53 1 r
.74568 .4118 m
.75367 .40988 L
s
.74568 .4118 m
.74859 .40382 L
s
.77563 .38636 m
.74568 .4118 L
s
0 .028 1 r
.57942 .33164 m
.5864 .33579 L
s
0 .249 1 r
.22835 .31184 m
.22205 .31705 L
s
.23281 .31405 m
.22835 .31184 L
s
0 1 .193 r
.64015 .4935 m
.64619 .49201 L
s
.64015 .4935 m
.64285 .48801 L
s
0 .556 1 r
.73989 .72765 m
.73624 .73459 L
s
.73128 .7279 m
.73624 .73459 L
s
.73128 .7279 m
.73989 .72765 L
s
0 1 .701 r
.70752 .64733 m
.70583 .65327 L
s
.70038 .6491 m
.70583 .65327 L
s
0 1 .98 r
.80597 .47388 m
.77512 .48805 L
s
.222 0 1 r
.63804 .87975 m
.63253 .86206 L
s
0 .433 1 r
.31419 .79858 m
.32645 .77908 L
s
0 1 .855 r
.61085 .40949 m
.61609 .41319 L
s
0 1 .183 r
.67525 .56737 m
.67598 .57232 L
s
.67 .57094 m
.67598 .57232 L
s
0 1 .98 r
.77512 .48805 m
.78329 .48852 L
s
.77512 .48805 m
.78054 .48225 L
s
0 1 .193 r
.64285 .48801 m
.64619 .49201 L
s
0 1 .701 r
.70038 .6491 m
.70752 .64733 L
s
.502 0 1 r
.44112 .87525 m
.44792 .88247 L
s
.43378 .88127 m
.44112 .87525 L
s
.44112 .87525 m
.44227 .878 L
s
1 0 .68 r
.48142 .96495 m
.47295 .97216 L
s
.47493 .95991 m
.48142 .96495 L
s
0 1 .183 r
.67 .57094 m
.67525 .56737 L
s
0 .249 1 r
.22205 .31705 m
.22649 .31928 L
s
0 1 .103 r
.63334 .63485 m
.61927 .63444 L
s
1 .863 0 r
.30921 .55361 m
.31756 .55569 L
s
1 0 .339 r
.46527 1.04107 m
.4784 1.01428 L
s
.407 0 1 r
.71695 .32609 m
.72423 .33237 L
s
0 .568 1 r
.84487 .64092 m
.84297 .64845 L
s
.8355 .64282 m
.84297 .64845 L
s
0 .994 1 r
.80507 .56509 m
.81299 .56815 L
s
.80507 .56509 m
.81266 .56133 L
s
0 1 .317 r
.25921 .39891 m
.25555 .39711 L
s
.25717 .39254 m
.25921 .39891 L
s
.25921 .39891 m
.25312 .39604 L
s
.25961 .3936 m
.25921 .39891 L
s
.24487 .37837 m
.25921 .39891 L
s
.25717 .39254 m
.25312 .39604 L
s
.25961 .3936 m
.25717 .39254 L
s
0 .994 1 r
.81266 .56133 m
.81299 .56815 L
s
1 0 .68 r
.47295 .97216 m
.46491 .96365 L
s
.46491 .96365 m
.47493 .95991 L
s
0 .568 1 r
.8355 .64282 m
.84487 .64092 L
s
0 1 .98 r
.78054 .48225 m
.78329 .48852 L
s
0 .53 1 r
.74859 .40382 m
.75367 .40988 L
s
0 .695 1 r
.46041 .7961 m
.4629 .78121 L
s
0 .397 1 r
.40923 .79433 m
.41468 .80027 L
s
.40319 .79909 m
.40923 .79433 L
s
.40923 .79433 m
.41017 .79654 L
s
.502 0 1 r
.44792 .88247 m
.44059 .88851 L
s
.44227 .878 m
.44792 .88247 L
s
0 1 .317 r
.25312 .39604 m
.25555 .39711 L
s
0 .249 1 r
.22649 .31928 m
.23281 .31405 L
s
0 .305 1 r
.36483 .31355 m
.3584 .31672 L
s
.3702 .31597 m
.36483 .31355 L
s
.36483 .31355 m
.36535 .32374 L
s
.845 1 0 r
.28676 .47361 m
.28463 .47581 L
s
.28708 .4737 m
.28676 .47361 L
s
.28676 .47361 m
.28803 .47687 L
s
0 .305 1 r
.36535 .32374 m
.36377 .31915 L
s
.36535 .32374 m
.3584 .31672 L
s
.3702 .31597 m
.36535 .32374 L
s
.36006 .28647 m
.36535 .32374 L
s
0 .397 1 r
.41468 .80027 m
.40864 .80505 L
s
.41017 .79654 m
.41468 .80027 L
s
1 .884 0 r
.45555 .55071 m
.45276 .55692 L
s
0 1 .795 r
.78023 .63209 m
.75562 .62975 L
s
.845 1 0 r
.28463 .47581 m
.28495 .47589 L
s
.28803 .47687 m
.28463 .47581 L
s
0 1 .633 r
.37779 .71377 m
.38173 .71842 L
s
.37318 .71719 m
.37779 .71377 L
s
.37779 .71377 m
.37866 .71561 L
s
.502 0 1 r
.44059 .88851 m
.43378 .88127 L
s
.43378 .88127 m
.44227 .878 L
s
.434 0 1 r
.57826 .87482 m
.58545 .8813 L
s
.57135 .8817 m
.57826 .87482 L
s
.57826 .87482 m
.57802 .87812 L
s
.845 1 0 r
.28803 .47687 m
.28495 .47589 L
s
.28708 .4737 m
.28803 .47687 L
s
.27715 .46629 m
.28803 .47687 L
s
1 .863 0 r
.31682 .55619 m
.31504 .55671 L
s
.31673 .55384 m
.31682 .55619 L
s
.31756 .55569 m
.31682 .55619 L
s
0 1 .633 r
.38173 .71842 m
.37712 .72185 L
s
.37866 .71561 m
.38173 .71842 L
s
1 0 .68 r
.47493 .95991 m
.47295 .97216 L
s
0 1 .317 r
.25555 .39711 m
.25961 .3936 L
s
.361 1 0 r
.34687 .63361 m
.34912 .63701 L
s
.34373 .63561 m
.34687 .63361 L
s
.34687 .63361 m
.34778 .6353 L
s
.34912 .63701 m
.34598 .63902 L
s
.34778 .6353 m
.34912 .63701 L
s
1 .863 0 r
.31495 .55436 m
.31673 .55384 L
s
.31673 .55384 m
.31756 .55569 L
s
0 .397 1 r
.40864 .80505 m
.40319 .79909 L
s
.40319 .79909 m
.41017 .79654 L
s
0 .635 1 r
.60713 .79361 m
.60009 .78036 L
s
0 1 .646 r
.28218 .71216 m
.29475 .69732 L
s
.502 0 1 r
.44227 .878 m
.44059 .88851 L
s
.845 1 0 r
.28495 .47589 m
.28708 .4737 L
s
1 .863 0 r
.31504 .55671 m
.31495 .55436 L
s
.31756 .55569 m
.31504 .55671 L
s
0 1 .633 r
.37712 .72185 m
.37318 .71719 L
s
.37318 .71719 m
.37866 .71561 L
s
0 1 .282 r
.39375 .39416 m
.38963 .39562 L
s
.3973 .3954 m
.39375 .39416 L
s
.39375 .39416 m
.3938 .40057 L
s
.361 1 0 r
.34598 .63902 m
.34373 .63561 L
s
.34373 .63561 m
.34778 .6353 L
s
.34778 .6353 m
.34598 .63902 L
s
1 .863 0 r
.31495 .55436 m
.31756 .55569 L
s
.434 0 1 r
.57854 .88821 m
.57135 .8817 L
s
.57135 .8817 m
.57802 .87812 L
s
0 .397 1 r
.41017 .79654 m
.40864 .80505 L
s
0 .44 1 r
.54639 .79406 m
.55226 .79926 L
s
.54079 .7998 m
.54639 .79406 L
s
.54639 .79406 m
.54587 .79697 L
s
0 .34 1 r
.92761 .62933 m
.89189 .62221 L
s
.447 1 0 r
.60238 .54781 m
.58867 .55539 L
s
.921 0 1 r
.43374 .95541 m
.4446 .93052 L
s
0 1 .633 r
.37866 .71561 m
.37712 .72185 L
s
0 .305 1 r
.3584 .31672 m
.36377 .31915 L
s
0 1 .282 r
.3938 .40057 m
.39318 .39685 L
s
.3938 .40057 m
.38963 .39562 L
s
.3973 .3954 m
.3938 .40057 L
s
.3921 .37516 m
.3938 .40057 L
s
.434 0 1 r
.58545 .8813 m
.57854 .88821 L
s
.57802 .87812 m
.58545 .8813 L
s
0 .106 1 r
.50158 .31249 m
.49585 .31426 L
s
.50816 .31596 m
.50158 .31249 L
s
.50158 .31249 m
.50046 .32304 L
s
0 .305 1 r
.36377 .31915 m
.3702 .31597 L
s
0 .106 1 r
.50046 .32304 m
.50243 .31774 L
s
.50046 .32304 m
.49585 .31426 L
s
.50816 .31596 m
.50046 .32304 L
s
.50824 .28308 m
.50046 .32304 L
s
.851 1 0 r
.42306 .47537 m
.42099 .47516 L
s
.4253 .47545 m
.42306 .47537 L
s
.42306 .47537 m
.42295 .47832 L
s
0 .44 1 r
.54666 .80502 m
.54079 .7998 L
s
.54079 .7998 m
.54587 .79697 L
s
0 .308 1 r
.75435 .79112 m
.73764 .77651 L
s
0 1 .324 r
.42884 .70953 m
.43105 .6997 L
s
1 0 0 r
.42214 1.02415 m
.43101 1.03399 L
s
.41274 1.03166 m
.42214 1.02415 L
s
.42214 1.02415 m
.42519 1.02733 L
s
0 1 .615 r
.51486 .71365 m
.51935 .71755 L
s
.51072 .71817 m
.51486 .71365 L
s
.51486 .71365 m
.51425 .71633 L
s
0 1 .282 r
.38963 .39562 m
.39318 .39685 L
s
0 .44 1 r
.55226 .79926 m
.54666 .80502 L
s
.54587 .79697 m
.55226 .79926 L
s
0 1 .282 r
.39318 .39685 m
.3973 .3954 L
s
0 .229 1 r
.684 .7913 m
.69041 .79586 L
s
.67883 .79814 m
.684 .7913 L
s
.684 .7913 m
.68207 .79442 L
s
0 1 .615 r
.5152 .72207 m
.51072 .71817 L
s
.51072 .71817 m
.51425 .71633 L
s
.434 0 1 r
.57802 .87812 m
.57854 .88821 L
s
0 1 .617 r
.53045 .3926 m
.52736 .39294 L
s
.53534 .39525 m
.53045 .3926 L
s
.53045 .3926 m
.52924 .39961 L
s
.851 1 0 r
.42324 .47524 m
.4253 .47545 L
s
.4253 .47545 m
.42295 .47832 L
s
1 .884 0 r
.4541 .55711 m
.45179 .55618 L
s
.45485 .55517 m
.4541 .55711 L
s
.45276 .55692 m
.4541 .55711 L
s
.45179 .55618 m
.45253 .55424 L
s
.45179 .55618 m
.45276 .55692 L
s
.851 1 0 r
.42295 .47832 m
.42324 .47524 L
s
.42295 .47832 m
.42099 .47516 L
s
.42393 .46323 m
.42295 .47832 L
s
.356 1 0 r
.48424 .63943 m
.48112 .63687 L
s
.48112 .63687 m
.48367 .63367 L
s
.48112 .63687 m
.4832 .63629 L
s
.248 0 1 r
.63893 .30862 m
.63425 .30977 L
s
.64624 .31388 m
.63893 .30862 L
s
.63893 .30862 m
.63612 .31979 L
s
0 .229 1 r
.68523 .80272 m
.67883 .79814 L
s
.67883 .79814 m
.68207 .79442 L
s
0 1 .378 r
.74972 .54489 m
.72493 .55109 L
s
.755 0 1 r
.58079 .95318 m
.58272 .93076 L
s
.156 0 1 r
.14687 .29987 m
.14065 .29908 L
s
.14198 .28931 m
.14687 .29987 L
s
.14687 .29987 m
.13589 .29639 L
s
.14676 .29198 m
.14687 .29987 L
s
.11879 .27113 m
.14687 .29987 L
s
.851 1 0 r
.42099 .47516 m
.42324 .47524 L
s
.356 1 0 r
.48367 .63367 m
.48679 .63623 L
s
.48367 .63367 m
.4832 .63629 L
s
0 1 .615 r
.51935 .71755 m
.5152 .72207 L
s
.51425 .71633 m
.51935 .71755 L
s
0 .44 1 r
.54587 .79697 m
.54666 .80502 L
s
.356 1 0 r
.48679 .63623 m
.48424 .63943 L
s
.4832 .63629 m
.48424 .63943 L
s
.4832 .63629 m
.48679 .63623 L
s
0 .106 1 r
.50243 .31774 m
.50816 .31596 L
s
.248 0 1 r
.63612 .31979 m
.64157 .31505 L
s
.63612 .31979 m
.63425 .30977 L
s
.64624 .31388 m
.63612 .31979 L
s
.65694 .27968 m
.63612 .31979 L
s
0 1 .615 r
.51425 .71633 m
.5152 .72207 L
s
1 .884 0 r
.45253 .55424 m
.45485 .55517 L
s
.45276 .55692 m
.45485 .55517 L
s
.45253 .55424 m
.45276 .55692 L
s
0 1 .617 r
.52924 .39961 m
.53225 .3956 L
s
.52924 .39961 m
.52736 .39294 L
s
.53534 .39525 m
.52924 .39961 L
s
.53984 .37193 m
.52924 .39961 L
s
0 1 .921 r
.65394 .72013 m
.64884 .71684 L
s
.64884 .71684 m
.65242 .71105 L
s
.64884 .71684 m
.65042 .71414 L
s
1 0 0 r
.43101 1.03399 m
.42163 1.04154 L
s
.42519 1.02733 m
.43101 1.03399 L
s
0 1 .921 r
.65242 .71105 m
.65752 .71434 L
s
.65242 .71105 m
.65042 .71414 L
s
1 0 .738 r
.38913 .94186 m
.39691 .95047 L
s
.38074 .94822 m
.38913 .94186 L
s
.38913 .94186 m
.3917 .94417 L
s
.73 0 1 r
.77701 .30216 m
.77317 .30333 L
s
.78429 .30967 m
.77701 .30216 L
s
.77701 .30216 m
.77196 .31398 L
s
0 1 .444 r
.57601 .70689 m
.56815 .69917 L
s
.227 1 0 r
.24995 .62516 m
.26372 .61621 L
s
0 1 .617 r
.53225 .3956 m
.53534 .39525 L
s
.28 1 0 r
.55952 .47272 m
.55938 .47218 L
s
.56294 .47523 m
.55952 .47272 L
s
.55952 .47272 m
.55865 .47709 L
s
.73 0 1 r
.77196 .31398 m
.78048 .31087 L
s
.77196 .31398 m
.77317 .30333 L
s
.78429 .30967 m
.77196 .31398 L
s
.80615 .27627 m
.77196 .31398 L
s
0 .535 1 r
.79256 .71603 m
.78717 .71312 L
s
.78717 .71312 m
.79062 .70596 L
s
.78717 .71312 m
.7868 .70903 L
s
0 1 .103 r
.62321 .63784 m
.61935 .63589 L
s
.61935 .63589 m
.621 .6312 L
s
.61935 .63589 m
.61927 .63444 L
s
.28 1 0 r
.56281 .47469 m
.56294 .47523 L
s
.56294 .47523 m
.55865 .47709 L
s
.447 1 0 r
.59318 .55586 m
.59057 .55547 L
s
.59057 .55547 m
.58966 .55189 L
s
.59057 .55547 m
.58867 .55539 L
s
.156 0 1 r
.14198 .28931 m
.13589 .29639 L
s
.14676 .29198 m
.14198 .28931 L
s
0 .852 1 r
.66806 .38805 m
.66606 .3883 L
s
.67337 .39287 m
.66806 .38805 L
s
.66806 .38805 m
.66515 .39603 L
s
0 .535 1 r
.79062 .70596 m
.79602 .70885 L
s
.79062 .70596 m
.7868 .70903 L
s
0 .106 1 r
.49585 .31426 m
.50243 .31774 L
s
.248 0 1 r
.64157 .31505 m
.64624 .31388 L
s
0 .34 1 r
.89997 .62857 m
.89606 .62679 L
s
.89606 .62679 m
.89818 .61873 L
s
.89606 .62679 m
.89189 .62221 L
s
0 1 .103 r
.621 .6312 m
.62487 .63315 L
s
.621 .6312 m
.61927 .63444 L
s
0 .229 1 r
.69041 .79586 m
.68523 .80272 L
s
.68207 .79442 m
.69041 .79586 L
s
.73 0 1 r
.78048 .31087 m
.78429 .30967 L
s
0 1 .795 r
.76184 .63425 m
.75782 .63248 L
s
.75782 .63248 m
.75931 .62619 L
s
.75782 .63248 m
.75562 .62975 L
s
.28 1 0 r
.57122 .46017 m
.55865 .47709 L
s
0 .695 1 r
.89756 .54197 m
.86119 .54402 L
s
.1 0 1 r
.402 .86916 m
.41134 .84713 L
s
.447 1 0 r
.58966 .55189 m
.59227 .55227 L
s
.58966 .55189 m
.58867 .55539 L
s
0 .852 1 r
.67139 .39313 m
.67337 .39287 L
s
.67337 .39287 m
.66515 .39603 L
s
.156 0 1 r
.13589 .29639 m
.14065 .29908 L
s
0 .18 1 r
.80657 .38104 m
.80511 .38168 L
s
.81144 .38826 m
.80657 .38104 L
s
.80657 .38104 m
.80119 .38983 L
s
0 .695 1 r
.86968 .54792 m
.86733 .54686 L
s
.86733 .54686 m
.86727 .53932 L
s
.86733 .54686 m
.86119 .54402 L
s
0 .34 1 r
.89818 .61873 m
.9021 .62048 L
s
.89818 .61873 m
.89189 .62221 L
s
0 1 .378 r
.7316 .55295 m
.72904 .55224 L
s
.72904 .55224 m
.72822 .54676 L
s
.72904 .55224 m
.72493 .55109 L
s
0 1 .471 r
.7015 .47242 m
.70094 .47237 L
s
.70094 .47237 m
.69773 .46748 L
s
.70094 .47237 m
.69477 .47316 L
s
0 .18 1 r
.81001 .38892 m
.81144 .38826 L
s
.81144 .38826 m
.80119 .38983 L
s
0 .229 1 r
.68207 .79442 m
.68523 .80272 L
s
0 .852 1 r
.66515 .39603 m
.67139 .39313 L
s
.66515 .39603 m
.66606 .3883 L
s
.68808 .36869 m
.66515 .39603 L
s
0 .672 1 r
.83974 .46797 m
.83912 .46734 L
s
.83912 .46734 m
.83667 .4601 L
s
.83912 .46734 m
.83094 .46653 L
s
.28 1 0 r
.55865 .47709 m
.56281 .47469 L
s
.55865 .47709 m
.55938 .47218 L
s
0 1 .471 r
.69773 .46748 m
.69829 .46752 L
s
.69773 .46748 m
.69477 .47316 L
s
1 0 .738 r
.39691 .95047 m
.38854 .95687 L
s
.3917 .94417 m
.39691 .95047 L
s
0 1 .795 r
.75931 .62619 m
.76334 .62795 L
s
.75931 .62619 m
.75562 .62975 L
s
.448 0 1 r
.3565 .85981 m
.36307 .86716 L
s
.34929 .86495 m
.3565 .85981 L
s
.3565 .85981 m
.35878 .86139 L
s
0 1 .767 r
.17493 .37757 m
.16994 .37765 L
s
.17078 .37074 m
.17493 .37757 L
s
.17493 .37757 m
.16708 .37606 L
s
.17365 .37232 m
.17493 .37757 L
s
.15192 .36055 m
.17493 .37757 L
s
0 1 .617 r
.52736 .39294 m
.53225 .3956 L
s
0 1 .921 r
.65752 .71434 m
.65394 .72013 L
s
.65042 .71414 m
.65394 .72013 L
s
.65042 .71414 m
.65752 .71434 L
s
0 1 .103 r
.62487 .63315 m
.62321 .63784 L
s
.61927 .63444 m
.62321 .63784 L
s
0 .672 1 r
.83667 .4601 m
.83729 .46071 L
s
.83667 .4601 m
.83094 .46653 L
s
0 .695 1 r
.86727 .53932 m
.86962 .54035 L
s
.86727 .53932 m
.86119 .54402 L
s
0 1 .378 r
.72822 .54676 m
.73078 .54745 L
s
.72822 .54676 m
.72493 .55109 L
s
0 .18 1 r
.80119 .38983 m
.81001 .38892 L
s
.80119 .38983 m
.80511 .38168 L
s
.83683 .36544 m
.80119 .38983 L
s
.447 1 0 r
.59227 .55227 m
.59318 .55586 L
s
.58867 .55539 m
.59318 .55586 L
s
.698 1 0 r
.39706 .62237 m
.39981 .61881 L
s
0 1 .89 r
.72368 .70424 m
.7057 .69571 L
s
1 0 0 r
.42163 1.04154 m
.41274 1.03166 L
s
.41274 1.03166 m
.42519 1.02733 L
s
0 1 .767 r
.17078 .37074 m
.16708 .37606 L
s
.17365 .37232 m
.17078 .37074 L
s
0 1 .103 r
.61927 .63444 m
.62487 .63315 L
s
.28 1 0 r
.55938 .47218 m
.56281 .47469 L
s
0 1 .767 r
.16708 .37606 m
.16994 .37765 L
s
.447 1 0 r
.58867 .55539 m
.59227 .55227 L
s
.448 0 1 r
.36307 .86716 m
.35587 .87233 L
s
.35878 .86139 m
.36307 .86716 L
s
0 .433 1 r
.32427 .77805 m
.32951 .78414 L
s
.31842 .7819 m
.32427 .77805 L
s
.32427 .77805 m
.32645 .77908 L
s
0 1 .471 r
.69477 .47316 m
.7015 .47242 L
s
.69477 .47316 m
.69829 .46752 L
s
.719 .45709 m
.69477 .47316 L
s
0 .054 1 r
.5495 .86678 m
.54946 .84769 L
s
.248 0 1 r
.63425 .30977 m
.64157 .31505 L
s
1 0 .977 r
.52725 .94273 m
.53515 .95052 L
s
.51924 .9498 m
.52725 .94273 L
s
.52725 .94273 m
.52829 .94574 L
s
0 .672 1 r
.83094 .46653 m
.83974 .46797 L
s
.83094 .46653 m
.83729 .46071 L
s
.8673 .45401 m
.83094 .46653 L
s
0 .535 1 r
.79602 .70885 m
.79256 .71603 L
s
.7868 .70903 m
.79256 .71603 L
s
.326 1 0 r
.19875 .45648 m
.19975 .45716 L
s
.20025 .45259 m
.19875 .45648 L
s
.20378 .45625 m
.19875 .45648 L
s
1 0 .738 r
.38854 .95687 m
.38074 .94822 L
s
.38074 .94822 m
.3917 .94417 L
s
0 .535 1 r
.7868 .70903 m
.79602 .70885 L
s
0 .134 1 r
.28158 .30313 m
.27803 .29977 L
s
.27964 .29246 m
.28158 .30313 L
s
.28158 .30313 m
.27291 .29719 L
s
.28476 .29503 m
.28158 .30313 L
s
.26771 .26769 m
.28158 .30313 L
s
.326 1 0 r
.20125 .45327 m
.20025 .45259 L
s
.20025 .45259 m
.20378 .45625 L
s
.20378 .45625 m
.19975 .45716 L
s
.20125 .45327 m
.20378 .45625 L
s
.18482 .44936 m
.20378 .45625 L
s
0 .433 1 r
.32951 .78414 m
.32366 .788 L
s
.32645 .77908 m
.32951 .78414 L
s
0 1 .795 r
.76334 .62795 m
.76184 .63425 L
s
.75562 .62975 m
.76184 .63425 L
s
0 1 .646 r
.29248 .69662 m
.29626 .70148 L
s
.28816 .69914 m
.29248 .69662 L
s
.29248 .69662 m
.29475 .69732 L
s
.156 0 1 r
.14065 .29908 m
.14676 .29198 L
s
1 0 0 r
.42519 1.02733 m
.42163 1.04154 L
s
0 1 .378 r
.72493 .55109 m
.7316 .55295 L
s
.72493 .55109 m
.73078 .54745 L
s
.73078 .54745 m
.7316 .55295 L
s
0 .852 1 r
.66606 .3883 m
.67139 .39313 L
s
0 .695 1 r
.86119 .54402 m
.86968 .54792 L
s
.86119 .54402 m
.86962 .54035 L
s
.732 1 0 r
.23085 .53758 m
.23002 .53804 L
s
.23038 .5343 m
.23085 .53758 L
s
.23338 .53582 m
.23085 .53758 L
s
0 .421 1 r
.87185 .70157 m
.84331 .68933 L
s
.476 1 0 r
.54467 .61957 m
.53678 .61857 L
s
.732 1 0 r
.21749 .53756 m
.23338 .53582 L
s
1 0 .319 r
.37502 1.02961 m
.39378 .99867 L
s
0 .134 1 r
.27964 .29246 m
.27291 .29719 L
s
.28476 .29503 m
.27964 .29246 L
s
0 1 .646 r
.29626 .70148 m
.29195 .70401 L
s
.29475 .69732 m
.29626 .70148 L
s
0 1 .795 r
.75562 .62975 m
.76334 .62795 L
s
.227 1 0 r
.26116 .61547 m
.26337 .61927 L
s
.25853 .61674 m
.26116 .61547 L
s
.26116 .61547 m
.26372 .61621 L
s
.26337 .61927 m
.26074 .62054 L
s
.26372 .61621 m
.26337 .61927 L
s
.732 1 0 r
.22955 .53476 m
.23038 .5343 L
s
.23038 .5343 m
.23338 .53582 L
s
0 1 .471 r
.69829 .46752 m
.7015 .47242 L
s
0 .34 1 r
.89189 .62221 m
.89997 .62857 L
s
.89189 .62221 m
.9021 .62048 L
s
.448 0 1 r
.35587 .87233 m
.34929 .86495 L
s
.34929 .86495 m
.35878 .86139 L
s
.73 0 1 r
.77317 .30333 m
.78048 .31087 L
s
0 .34 1 r
.9021 .62048 m
.89997 .62857 L
s
0 1 .767 r
.16994 .37765 m
.17365 .37232 L
s
.207 0 1 r
.49471 .86083 m
.50135 .86737 L
s
.48785 .86678 m
.49471 .86083 L
s
.49471 .86083 m
.49532 .86326 L
s
1 0 .738 r
.3917 .94417 m
.38854 .95687 L
s
1 0 .977 r
.53515 .95052 m
.52714 .95763 L
s
.52829 .94574 m
.53515 .95052 L
s
0 .695 1 r
.86962 .54035 m
.86968 .54792 L
s
.061 0 1 r
.6975 .8644 m
.6881 .84517 L
s
0 .798 1 r
.37004 .78232 m
.37867 .76421 L
s
.732 1 0 r
.23338 .53582 m
.23002 .53804 L
s
.22955 .53476 m
.23338 .53582 L
s
0 .672 1 r
.83729 .46071 m
.83974 .46797 L
s
0 .433 1 r
.32366 .788 m
.31842 .7819 L
s
.31842 .7819 m
.32645 .77908 L
s
.326 1 0 r
.19975 .45716 m
.20125 .45327 L
s
0 .18 1 r
.80511 .38168 m
.81001 .38892 L
s
1 0 .977 r
.52714 .95763 m
.51924 .9498 L
s
.51924 .9498 m
.52829 .94574 L
s
.732 1 0 r
.23002 .53804 m
.22955 .53476 L
s
0 .134 1 r
.27291 .29719 m
.27803 .29977 L
s
.448 0 1 r
.35878 .86139 m
.35587 .87233 L
s
0 1 .393 r
.31007 .3807 m
.30749 .37823 L
s
.30879 .37386 m
.31007 .3807 L
s
.31007 .3807 m
.30438 .37684 L
s
.31191 .37524 m
.31007 .3807 L
s
.30038 .35727 m
.31007 .3807 L
s
.30879 .37386 m
.30438 .37684 L
s
.31191 .37524 m
.30879 .37386 L
s
0 1 .646 r
.29195 .70401 m
.28816 .69914 L
s
.28816 .69914 m
.29475 .69732 L
s
0 1 .158 r
.69279 .61676 m
.67425 .61549 L
s
1 .528 0 r
.36505 .53461 m
.36921 .53862 L
s
1 0 .655 r
.52285 1.0275 m
.53271 1.00042 L
s
.227 1 0 r
.26074 .62054 m
.25853 .61674 L
s
.25853 .61674 m
.26372 .61621 L
s
.26372 .61621 m
.26074 .62054 L
s
0 .433 1 r
.32645 .77908 m
.32366 .788 L
s
0 .695 1 r
.46253 .77923 m
.4678 .78448 L
s
.45698 .78397 m
.46253 .77923 L
s
.46253 .77923 m
.4629 .78121 L
s
0 1 .646 r
.29475 .69732 m
.29195 .70401 L
s
.207 0 1 r
.50135 .86737 m
.49449 .87334 L
s
.49532 .86326 m
.50135 .86737 L
s
.49449 .87334 m
.48785 .86678 L
s
.48785 .86678 m
.49532 .86326 L
s
0 .095 1 r
.41757 .29299 m
.41103 .2959 L
s
.42371 .2961 m
.41757 .29299 L
s
.41757 .29299 m
.41743 .30386 L
s
.41743 .30386 m
.41717 .29904 L
s
.41743 .30386 m
.41103 .2959 L
s
.42371 .2961 m
.41743 .30386 L
s
.41715 .26423 m
.41743 .30386 L
s
0 1 .393 r
.30438 .37684 m
.30749 .37823 L
s
0 .952 1 r
.51799 .77979 m
.51672 .76506 L
s
0 .134 1 r
.27803 .29977 m
.28476 .29503 L
s
.222 0 1 r
.63336 .85931 m
.64042 .86512 L
s
.62689 .86618 m
.63336 .85931 L
s
.63336 .85931 m
.63253 .86206 L
s
.891 1 0 r
.33866 .45583 m
.33621 .45727 L
s
.33979 .45599 m
.33866 .45583 L
s
.33866 .45583 m
.33929 .45922 L
s
0 .695 1 r
.4678 .78448 m
.46225 .78922 L
s
.4629 .78121 m
.4678 .78448 L
s
0 1 .324 r
.43077 .698 m
.43454 .70195 L
s
.42667 .70142 m
.43077 .698 L
s
.43077 .698 m
.43105 .6997 L
s
1 0 .977 r
.52829 .94574 m
.52714 .95763 L
s
.891 1 0 r
.33929 .45922 m
.33733 .45744 L
s
.33929 .45922 m
.33621 .45727 L
s
.33979 .45599 m
.33929 .45922 L
s
.33283 .44625 m
.33929 .45922 L
s
.33621 .45727 m
.33733 .45744 L
s
0 .695 1 r
.46225 .78922 m
.45698 .78397 L
s
.45698 .78397 m
.4629 .78121 L
s
0 1 .393 r
.30749 .37823 m
.31191 .37524 L
s
0 1 .988 r
.84142 .61394 m
.81186 .60955 L
s
1 .916 0 r
.51312 .53165 m
.50598 .53866 L
s
.95 0 1 r
.34289 .94309 m
.35966 .91401 L
s
0 1 .324 r
.43454 .70195 m
.43044 .70537 L
s
.43105 .6997 m
.43454 .70195 L
s
1 .528 0 r
.36903 .53848 m
.3675 .5387 L
s
.36926 .53694 m
.36903 .53848 L
s
.36921 .53862 m
.36903 .53848 L
s
.698 1 0 r
.3995 .61719 m
.40162 .61985 L
s
.39689 .6192 m
.3995 .61719 L
s
.3995 .61719 m
.39981 .61881 L
s
.40162 .61985 m
.39901 .62185 L
s
.39981 .61881 m
.40162 .61985 L
s
.222 0 1 r
.63394 .872 m
.62689 .86618 L
s
.62689 .86618 m
.63253 .86206 L
s
.207 0 1 r
.49532 .86326 m
.49449 .87334 L
s
0 1 .324 r
.43044 .70537 m
.42667 .70142 L
s
.42667 .70142 m
.43105 .6997 L
s
1 .528 0 r
.36773 .53715 m
.36926 .53694 L
s
.36926 .53694 m
.36921 .53862 L
s
.3675 .5387 m
.36773 .53715 L
s
.36921 .53862 m
.3675 .5387 L
s
0 1 .497 r
.44678 .37415 m
.4427 .37543 L
s
.45108 .37617 m
.44678 .37415 L
s
.44678 .37415 m
.44628 .38122 L
s
.891 1 0 r
.33733 .45744 m
.33979 .45599 L
s
0 .635 1 r
.60122 .77788 m
.60694 .78242 L
s
.59609 .78366 m
.60122 .77788 L
s
.60122 .77788 m
.60009 .78036 L
s
.698 1 0 r
.39901 .62185 m
.39689 .6192 L
s
.39689 .6192 m
.39981 .61881 L
s
.39981 .61881 m
.39901 .62185 L
s
0 .695 1 r
.4629 .78121 m
.46225 .78922 L
s
1 .528 0 r
.36773 .53715 m
.36921 .53862 L
s
0 1 .246 r
.33786 .69488 m
.3466 .68184 L
s
0 .771 1 r
.66645 .77724 m
.65537 .76292 L
s
0 1 .497 r
.44628 .38122 m
.44701 .37746 L
s
.44628 .38122 m
.4427 .37543 L
s
.45108 .37617 m
.44628 .38122 L
s
.44936 .35399 m
.44628 .38122 L
s
.156 0 1 r
.55592 .29072 m
.5502 .29253 L
s
.56306 .29519 m
.55592 .29072 L
s
.55592 .29072 m
.55404 .30204 L
s
0 1 .324 r
.43105 .6997 m
.43044 .70537 L
s
.222 0 1 r
.64042 .86512 m
.63394 .872 L
s
.63253 .86206 m
.64042 .86512 L
s
.156 0 1 r
.55404 .30204 m
.55735 .29701 L
s
.55404 .30204 m
.5502 .29253 L
s
.56306 .29519 m
.55404 .30204 L
s
.56711 .26077 m
.55404 .30204 L
s
0 .635 1 r
.60181 .78821 m
.59609 .78366 L
s
.59609 .78366 m
.60009 .78036 L
s
0 .095 1 r
.41717 .29904 m
.42371 .2961 L
s
.41103 .2959 m
.41717 .29904 L
s
0 .308 1 r
.74039 .77401 m
.74654 .77796 L
s
.73552 .78096 m
.74039 .77401 L
s
.74039 .77401 m
.73764 .77651 L
s
.654 1 0 r
.47624 .45577 m
.47466 .45555 L
s
.47917 .45692 m
.47624 .45577 L
s
.47624 .45577 m
.4758 .45952 L
s
0 1 .444 r
.56936 .6968 m
.5737 .70004 L
s
.56578 .70141 m
.56936 .6968 L
s
.56936 .6968 m
.56815 .69917 L
s
.256 1 0 r
.6617 .52868 m
.64333 .53593 L
s
.607 0 1 r
.49117 .94083 m
.49861 .91605 L
s
0 1 .444 r
.57012 .70466 m
.56578 .70141 L
s
.56578 .70141 m
.56815 .69917 L
s
0 .308 1 r
.74166 .78494 m
.73552 .78096 L
s
.73552 .78096 m
.73764 .77651 L
s
0 1 .497 r
.44701 .37746 m
.45108 .37617 L
s
1 0 .339 r
.47584 1.01148 m
.48453 1.02063 L
s
.46691 1.01883 m
.47584 1.01148 L
s
.47584 1.01148 m
.4784 1.01428 L
s
0 .635 1 r
.60694 .78242 m
.60181 .78821 L
s
.60009 .78036 m
.60694 .78242 L
s
.553 0 1 r
.69493 .28572 m
.69015 .28714 L
s
.70248 .29217 m
.69493 .28572 L
s
.69493 .28572 m
.69107 .29766 L
s
.222 0 1 r
.63253 .86206 m
.63394 .872 L
s
1 .916 0 r
.50884 .53835 m
.5069 .53832 L
s
.5069 .53832 m
.50598 .53616 L
s
.5069 .53832 m
.50598 .53866 L
s
.654 1 0 r
.47758 .45671 m
.47917 .45692 L
s
.47917 .45692 m
.4758 .45952 L
s
0 1 .902 r
.58522 .3713 m
.58216 .37186 L
s
.59046 .37505 m
.58522 .3713 L
s
.58522 .3713 m
.58319 .37912 L
s
.476 1 0 r
.539 .62141 m
.53594 .61953 L
s
.53594 .61953 m
.53773 .61613 L
s
.53594 .61953 m
.53678 .61857 L
s
.553 0 1 r
.69107 .29766 m
.69772 .29362 L
s
.69107 .29766 m
.69015 .28714 L
s
.70248 .29217 m
.69107 .29766 L
s
.71759 .25729 m
.69107 .29766 L
s
0 1 .497 r
.4427 .37543 m
.44701 .37746 L
s
.654 1 0 r
.4758 .45952 m
.47758 .45671 L
s
.4758 .45952 m
.47466 .45555 L
s
.48135 .44312 m
.4758 .45952 L
s
.476 1 0 r
.53773 .61613 m
.54079 .61801 L
s
.53773 .61613 m
.53678 .61857 L
s
0 .306 1 r
.81542 .77469 m
.79424 .75776 L
s
0 1 .067 r
.48627 .69219 m
.48453 .68297 L
s
.156 0 1 r
.55735 .29701 m
.56306 .29519 L
s
0 1 .89 r
.71011 .70181 m
.70532 .69905 L
s
.70532 .69905 m
.70855 .69306 L
s
.70532 .69905 m
.7057 .69571 L
s
1 .916 0 r
.50598 .53616 m
.50792 .53619 L
s
.50598 .53616 m
.50598 .53866 L
s
0 .635 1 r
.60009 .78036 m
.60181 .78821 L
s
0 .421 1 r
.84979 .6968 m
.84487 .69431 L
s
.84487 .69431 m
.84834 .6868 L
s
.84487 .69431 m
.84331 .68933 L
s
0 1 .89 r
.70855 .69306 m
.71334 .69581 L
s
.70855 .69306 m
.7057 .69571 L
s
0 1 .444 r
.5737 .70004 m
.57012 .70466 L
s
.56815 .69917 m
.5737 .70004 L
s
0 1 .902 r
.58319 .37912 m
.58741 .37562 L
s
.58319 .37912 m
.58216 .37186 L
s
.59046 .37505 m
.58319 .37912 L
s
.59886 .35069 m
.58319 .37912 L
s
0 .421 1 r
.84834 .6868 m
.85328 .68927 L
s
.84834 .6868 m
.84331 .68933 L
s
.476 1 0 r
.54079 .61801 m
.539 .62141 L
s
.53678 .61857 m
.539 .62141 L
s
1 .916 0 r
.50792 .53619 m
.50884 .53835 L
s
.50598 .53866 m
.50884 .53835 L
s
0 1 .444 r
.56815 .69917 m
.57012 .70466 L
s
.654 1 0 r
.47466 .45555 m
.47758 .45671 L
s
0 1 .902 r
.58741 .37562 m
.59046 .37505 L
s
0 1 .158 r
.67908 .61902 m
.67563 .61748 L
s
.67563 .61748 m
.67688 .61247 L
s
.67563 .61748 m
.67425 .61549 L
s
.476 1 0 r
.53678 .61857 m
.54079 .61801 L
s
0 1 .005 r
.61491 .452 m
.61455 .45186 L
s
.61834 .45551 m
.61491 .452 L
s
.61491 .452 m
.61296 .45711 L
s
.189 0 1 r
.19668 .28136 m
.19137 .2796 L
s
.19286 .27017 m
.19668 .28136 L
s
.19668 .28136 m
.18613 .27666 L
s
.19812 .27308 m
.19668 .28136 L
s
.1736 .24854 m
.19668 .28136 L
s
0 .516 1 r
.72457 .36569 m
.72232 .36632 L
s
.72988 .37169 m
.72457 .36569 L
s
.72457 .36569 m
.72045 .37438 L
s
.553 0 1 r
.69772 .29362 m
.70248 .29217 L
s
.256 1 0 r
.64858 .5367 m
.6466 .53634 L
s
.6466 .53634 m
.64544 .53225 L
s
.6466 .53634 m
.64333 .53593 L
s
0 1 .005 r
.61798 .45538 m
.61834 .45551 L
s
.61834 .45551 m
.61296 .45711 L
s
0 1 .988 r
.81876 .6146 m
.81531 .61307 L
s
.81531 .61307 m
.81685 .60627 L
s
.81531 .61307 m
.81186 .60955 L
s
1 .916 0 r
.50598 .53866 m
.50792 .53619 L
s
0 1 .663 r
.81078 .5257 m
.78088 .53041 L
s
.526 0 1 r
.63997 .93856 m
.63824 .91494 L
s
.152 0 1 r
.31054 .85599 m
.32613 .82973 L
s
0 1 .158 r
.67688 .61247 m
.68034 .614 L
s
.67688 .61247 m
.67425 .61549 L
s
1 0 .339 r
.48453 1.02063 m
.47562 1.02801 L
s
.4784 1.01428 m
.48453 1.02063 L
s
0 .516 1 r
.72765 .37234 m
.72988 .37169 L
s
.72988 .37169 m
.72045 .37438 L
s
.921 0 1 r
.44257 .92849 m
.45014 .93641 L
s
.43464 .93473 m
.44257 .92849 L
s
.44257 .92849 m
.4446 .93052 L
s
0 1 .663 r
.78816 .53295 m
.78626 .53219 L
s
.78626 .53219 m
.78559 .52598 L
s
.78626 .53219 m
.78088 .53041 L
s
.256 1 0 r
.64544 .53225 m
.64742 .5326 L
s
.64544 .53225 m
.64333 .53593 L
s
0 1 .988 r
.81685 .60627 m
.8203 .60779 L
s
.81685 .60627 m
.81186 .60955 L
s
0 .516 1 r
.72045 .37438 m
.72765 .37234 L
s
.72045 .37438 m
.72232 .36632 L
s
.74887 .34738 m
.72045 .37438 L
s
0 1 .812 r
.75783 .45212 m
.75779 .45173 L
s
.75779 .45173 m
.75476 .44582 L
s
.75779 .45173 m
.7504 .45199 L
s
0 .308 1 r
.74654 .77796 m
.74166 .78494 L
s
.73764 .77651 m
.74654 .77796 L
s
.156 0 1 r
.5502 .29253 m
.55735 .29701 L
s
0 1 .812 r
.75476 .44582 m
.7548 .4462 L
s
.75476 .44582 m
.7504 .45199 L
s
0 1 .005 r
.61296 .45711 m
.61798 .45538 L
s
.61296 .45711 m
.61455 .45186 L
s
.63039 .43999 m
.61296 .45711 L
s
0 1 .663 r
.78559 .52598 m
.78748 .52673 L
s
.78559 .52598 m
.78088 .53041 L
s
0 .308 1 r
.73764 .77651 m
.74166 .78494 L
s
0 1 .351 r
.63518 .68949 m
.62313 .68117 L
s
.69 1 0 r
.30546 .60685 m
.31519 .60011 L
s
.189 0 1 r
.19286 .27017 m
.18613 .27666 L
s
.19812 .27308 m
.19286 .27017 L
s
0 1 .89 r
.71334 .69581 m
.71011 .70181 L
s
.7057 .69571 m
.71011 .70181 L
s
.7057 .69571 m
.71334 .69581 L
s
0 1 .902 r
.58216 .37186 m
.58741 .37562 L
s
0 1 .158 r
.68034 .614 m
.67908 .61902 L
s
.67425 .61549 m
.67908 .61902 L
s
0 1 .812 r
.7504 .45199 m
.75783 .45212 L
s
.7504 .45199 m
.7548 .4462 L
s
.77994 .43684 m
.7504 .45199 L
s
.256 1 0 r
.64742 .5326 m
.64858 .5367 L
s
.64333 .53593 m
.64858 .5367 L
s
.64333 .53593 m
.64742 .5326 L
s
.1 0 1 r
.40966 .84575 m
.41598 .85239 L
s
.40291 .85079 m
.40966 .84575 L
s
.40966 .84575 m
.41134 .84713 L
s
1 0 .339 r
.47562 1.02801 m
.46691 1.01883 L
s
.46691 1.01883 m
.4784 1.01428 L
s
.921 0 1 r
.45014 .93641 m
.44222 .94268 L
s
.4446 .93052 m
.45014 .93641 L
s
0 .218 1 r
.45927 .85356 m
.46503 .83205 L
s
0 1 .158 r
.67425 .61549 m
.68034 .614 L
s
0 1 .733 r
.22518 .35966 m
.22102 .35883 L
s
.22208 .35232 m
.22518 .35966 L
s
.22518 .35966 m
.21775 .35704 L
s
.22536 .3541 m
.22518 .35966 L
s
.20691 .33905 m
.22518 .35966 L
s
.189 0 1 r
.18613 .27666 m
.19137 .2796 L
s
0 1 .005 r
.61455 .45186 m
.61798 .45538 L
s
0 1 .663 r
.78088 .53041 m
.78816 .53295 L
s
.78088 .53041 m
.78748 .52673 L
s
0 .421 1 r
.85328 .68927 m
.84979 .6968 L
s
.84331 .68933 m
.84979 .6968 L
s
.553 0 1 r
.69015 .28714 m
.69772 .29362 L
s
0 1 .733 r
.22208 .35232 m
.21775 .35704 L
s
.22536 .3541 m
.22208 .35232 L
s
0 .421 1 r
.84331 .68933 m
.85328 .68927 L
s
.755 0 1 r
.58223 .92828 m
.58999 .93537 L
s
.57467 .93525 m
.58223 .92828 L
s
.58223 .92828 m
.58272 .93076 L
s
.96 1 0 r
.45432 .60399 m
.45294 .60149 L
s
0 1 .954 r
.78461 .68678 m
.76202 .67644 L
s
0 1 .988 r
.8203 .60779 m
.81876 .6146 L
s
.81186 .60955 m
.81876 .6146 L
s
.81186 .60955 m
.8203 .60779 L
s
.1 0 1 r
.41598 .85239 m
.40924 .85746 L
s
.41134 .84713 m
.41598 .85239 L
s
0 .798 1 r
.37715 .7633 m
.38209 .76866 L
s
.37175 .76707 m
.37715 .7633 L
s
.37715 .7633 m
.37867 .76421 L
s
.921 0 1 r
.44222 .94268 m
.43464 .93473 L
s
.43464 .93473 m
.4446 .93052 L
s
0 1 .733 r
.21775 .35704 m
.22102 .35883 L
s
0 1 .663 r
.78748 .52673 m
.78816 .53295 L
s
0 .516 1 r
.72232 .36632 m
.72765 .37234 L
s
.027 0 1 r
.33313 .28352 m
.33078 .27962 L
s
.33199 .2722 m
.33313 .28352 L
s
.33313 .28352 m
.32494 .27653 L
s
.33783 .27527 m
.33313 .28352 L
s
.32431 .24502 m
.33313 .28352 L
s
0 1 .812 r
.7548 .4462 m
.75783 .45212 L
s
1 0 .339 r
.4784 1.01428 m
.47562 1.02801 L
s
0 .271 1 r
.60853 .85113 m
.60469 .83129 L
s
0 .695 1 r
.27796 .76828 m
.29322 .74594 L
s
.514 1 0 r
.25445 .43894 m
.25118 .4389 L
s
.25195 .43499 m
.25445 .43894 L
s
.25445 .43894 m
.24983 .43816 L
s
.25331 .43572 m
.25445 .43894 L
s
.23999 .42893 m
.25445 .43894 L
s
0 .798 1 r
.38209 .76866 m
.3767 .77245 L
s
.37867 .76421 m
.38209 .76866 L
s
.514 1 0 r
.25195 .43499 m
.24983 .43816 L
s
.25331 .43572 m
.25195 .43499 L
s
.189 0 1 r
.19137 .2796 m
.19812 .27308 L
s
0 1 .246 r
.34506 .68119 m
.3485 .68529 L
s
.34118 .68364 m
.34506 .68119 L
s
.34506 .68119 m
.3466 .68184 L
s
.514 1 0 r
.24983 .43816 m
.25118 .4389 L
s
.027 0 1 r
.33199 .2722 m
.32494 .27653 L
s
.33783 .27527 m
.33199 .2722 L
s
.1 0 1 r
.40924 .85746 m
.40291 .85079 L
s
.40291 .85079 m
.41134 .84713 L
s
0 1 .246 r
.3485 .68529 m
.34462 .68774 L
s
.3466 .68184 m
.3485 .68529 L
s
1 .819 0 r
.28234 .51997 m
.28182 .52026 L
s
.28245 .5176 m
.28234 .51997 L
s
.28446 .51911 m
.28234 .51997 L
s
0 .054 1 r
.54943 .84569 m
.55591 .85153 L
s
.54302 .85159 m
.54943 .84569 L
s
.54943 .84569 m
.54946 .84769 L
s
.69 1 0 r
.31347 .59941 m
.31524 .60237 L
s
.31124 .60056 m
.31347 .59941 L
s
.31347 .59941 m
.31519 .60011 L
s
.31524 .60237 m
.31301 .60351 L
s
.31519 .60011 m
.31524 .60237 L
s
1 .819 0 r
.28193 .51789 m
.28245 .5176 L
s
.28245 .5176 m
.28446 .51911 L
s
.921 0 1 r
.4446 .93052 m
.44222 .94268 L
s
0 .205 1 r
.93455 .68406 m
.90082 .66876 L
s
.481 1 0 r
.6037 .60113 m
.59142 .60003 L
s
1 .819 0 r
.27284 .5182 m
.28446 .51911 L
s
1 0 .678 r
.43214 1.01578 m
.44761 .98536 L
s
.755 0 1 r
.58999 .93537 m
.58243 .94237 L
s
.58272 .93076 m
.58999 .93537 L
s
0 1 .733 r
.22102 .35883 m
.22536 .3541 L
s
.755 0 1 r
.58243 .94237 m
.57467 .93525 L
s
.57467 .93525 m
.58272 .93076 L
s
0 .798 1 r
.3767 .77245 m
.37175 .76707 L
s
.37175 .76707 m
.37867 .76421 L
s
1 .819 0 r
.28446 .51911 m
.28182 .52026 L
s
.28193 .51789 m
.28446 .51911 L
s
.514 1 0 r
.25118 .4389 m
.25331 .43572 L
s
.1 0 1 r
.41134 .84713 m
.40924 .85746 L
s
0 1 .541 r
.36204 .36166 m
.36066 .35875 L
s
.36147 .35425 m
.36204 .36166 L
s
.36204 .36166 m
.35681 .35686 L
s
.36532 .35614 m
.36204 .36166 L
s
.35715 .3357 m
.36204 .36166 L
s
0 1 .246 r
.34462 .68774 m
.34118 .68364 L
s
.34118 .68364 m
.3466 .68184 L
s
1 .819 0 r
.28182 .52026 m
.28193 .51789 L
s
0 .035 1 r
.7583 .8487 m
.74473 .82743 L
s
0 1 .872 r
.42715 .76569 m
.43201 .74851 L
s
0 1 .541 r
.36147 .35425 m
.35681 .35686 L
s
.36532 .35614 m
.36147 .35425 L
s
.69 1 0 r
.31301 .60351 m
.31124 .60056 L
s
.31124 .60056 m
.31519 .60011 L
s
.31519 .60011 m
.31301 .60351 L
s
0 .952 1 r
.51696 .76341 m
.52206 .76795 L
s
.51189 .76813 m
.51696 .76341 L
s
.51696 .76341 m
.51672 .76506 L
s
0 .798 1 r
.37867 .76421 m
.3767 .77245 L
s
.027 0 1 r
.32494 .27653 m
.33078 .27962 L
s
0 1 .246 r
.3466 .68184 m
.34462 .68774 L
s
0 .054 1 r
.54951 .85745 m
.54302 .85159 L
s
.54302 .85159 m
.54946 .84769 L
s
.061 0 1 r
.68963 .84307 m
.69651 .84819 L
s
.68351 .84994 m
.68963 .84307 L
s
.68963 .84307 m
.6881 .84517 L
s
0 .054 1 r
.55591 .85153 m
.54951 .85745 L
s
.54946 .84769 m
.55591 .85153 L
s
.143 0 1 r
.47059 .28314 m
.47168 .27827 L
s
.47146 .27153 m
.47059 .28314 L
s
.47059 .28314 m
.46484 .2743 L
s
.4783 .27547 m
.47059 .28314 L
s
.47555 .24148 m
.47059 .28314 L
s
.47146 .27153 m
.46484 .2743 L
s
.4783 .27547 m
.47146 .27153 L
s
0 1 .319 r
.75359 .59825 m
.73027 .59569 L
s
1 .364 0 r
.42216 .51518 m
.42197 .52073 L
s
1 0 .94 r
.58174 1.01362 m
.58814 .98573 L
s
.027 0 1 r
.33078 .27962 m
.33783 .27527 L
s
1 0 .319 r
.39006 .99698 m
.39867 1.00633 L
s
.38124 1.00358 m
.39006 .99698 L
s
.39006 .99698 m
.39378 .99867 L
s
.755 0 1 r
.58272 .93076 m
.58243 .94237 L
s
.794 1 0 r
.39153 .43695 m
.38902 .43792 L
s
.39354 .4376 m
.39153 .43695 L
s
.39153 .43695 m
.39166 .44075 L
s
0 .952 1 r
.51698 .77269 m
.51189 .76813 L
s
.51189 .76813 m
.51672 .76506 L
s
0 1 .067 r
.48487 .68148 m
.48847 .68472 L
s
.48129 .68494 m
.48487 .68148 L
s
.48487 .68148 m
.48453 .68297 L
s
0 1 .541 r
.35681 .35686 m
.36066 .35875 L
s
.061 0 1 r
.69038 .85508 m
.68351 .84994 L
s
.68351 .84994 m
.6881 .84517 L
s
0 .952 1 r
.52206 .76795 m
.51698 .77269 L
s
.51672 .76506 m
.52206 .76795 L
s
.794 1 0 r
.39166 .44075 m
.39104 .43857 L
s
.39166 .44075 m
.38902 .43792 L
s
.39354 .4376 m
.39166 .44075 L
s
.38977 .42575 m
.39166 .44075 L
s
0 1 .541 r
.36066 .35875 m
.36532 .35614 L
s
0 1 .845 r
.57687 .7631 m
.57164 .74808 L
s
0 1 .455 r
.24515 .67996 m
.26096 .66273 L
s
0 .771 1 r
.65722 .76094 m
.66273 .76483 L
s
.65249 .7668 m
.65722 .76094 L
s
.65722 .76094 m
.65537 .76292 L
s
0 1 .067 r
.48489 .68818 m
.48129 .68494 L
s
.48129 .68494 m
.48453 .68297 L
s
0 .054 1 r
.54946 .84769 m
.54951 .85745 L
s
.794 1 0 r
.38902 .43792 m
.39104 .43857 L
s
1 .364 0 r
.42252 .52016 m
.42114 .51991 L
s
.42287 .51932 m
.42252 .52016 L
s
.42197 .52073 m
.42252 .52016 L
s
0 1 .067 r
.48847 .68472 m
.48489 .68818 L
s
.48453 .68297 m
.48847 .68472 L
s
0 1 .757 r
.50102 .35321 m
.49695 .35448 L
s
.50593 .35618 m
.50102 .35321 L
s
.50102 .35321 m
.49984 .36104 L
s
.96 1 0 r
.45316 .6 m
.45524 .60191 L
s
.45119 .60208 m
.45316 .6 L
s
.45316 .6 m
.45294 .60149 L
s
.794 1 0 r
.39104 .43857 m
.39354 .4376 L
s
1 .364 0 r
.42114 .51991 m
.4215 .51907 L
s
.42114 .51991 m
.42197 .52073 L
s
.96 1 0 r
.45327 .604 m
.45119 .60208 L
s
.45119 .60208 m
.45294 .60149 L
s
.444 0 1 r
.60868 .28019 m
.61329 .27559 L
s
.61146 .26807 m
.60868 .28019 L
s
.60868 .28019 m
.60569 .27001 L
s
.61905 .27364 m
.60868 .28019 L
s
.62733 .23794 m
.60868 .28019 L
s
.61146 .26807 m
.60569 .27001 L
s
.61905 .27364 m
.61146 .26807 L
s
.96 1 0 r
.45524 .60191 m
.45327 .604 L
s
.45294 .60149 m
.45524 .60191 L
s
0 .771 1 r
.65799 .7707 m
.65249 .7668 L
s
.65249 .7668 m
.65537 .76292 L
s
0 1 .757 r
.49984 .36104 m
.50187 .35745 L
s
.49984 .36104 m
.49695 .35448 L
s
.50593 .35618 m
.49984 .36104 L
s
.50792 .33234 m
.49984 .36104 L
s
0 .952 1 r
.51672 .76506 m
.51698 .77269 L
s
.96 1 0 r
.45294 .60149 m
.45327 .604 L
s
0 .306 1 r
.79798 .75591 m
.80381 .7593 L
s
.79323 .76305 m
.79798 .75591 L
s
.79798 .75591 m
.79424 .75776 L
s
1 .364 0 r
.4215 .51907 m
.42287 .51932 L
s
.42197 .52073 m
.42287 .51932 L
s
1 0 .319 r
.39867 1.00633 m
.38987 1.01298 L
s
.39378 .99867 m
.39867 1.00633 L
s
.9 1 0 r
.57199 .51215 m
.56028 .51956 L
s
0 .72 1 r
.904 .59537 m
.86911 .5885 L
s
.585 0 1 r
.39984 .92824 m
.41317 .90005 L
s
0 1 .067 r
.48453 .68297 m
.48489 .68818 L
s
.95 0 1 r
.35639 .91313 m
.36391 .92125 L
s
.3486 .91856 m
.35639 .91313 L
s
.35639 .91313 m
.35966 .91401 L
s
.061 0 1 r
.69651 .84819 m
.69038 .85508 L
s
.6881 .84517 m
.69651 .84819 L
s
1 .364 0 r
.4215 .51907 m
.42197 .52073 L
s
0 .306 1 r
.79905 .76646 m
.79323 .76305 L
s
.79323 .76305 m
.79424 .75776 L
s
.143 0 1 r
.47168 .27827 m
.4783 .27547 L
s
0 1 .351 r
.62507 .67914 m
.62918 .68178 L
s
.62194 .68392 m
.62507 .67914 L
s
.62507 .67914 m
.62313 .68117 L
s
.892 0 1 r
.74704 .27468 m
.75486 .27146 L
s
.75212 .26198 m
.74704 .27468 L
s
.74704 .27468 m
.74714 .2637 L
s
.75982 .26969 m
.74704 .27468 L
s
.77963 .23438 m
.74704 .27468 L
s
0 1 .351 r
.62605 .68656 m
.62194 .68392 L
s
.62194 .68392 m
.62313 .68117 L
s
.375 1 0 r
.53092 .43527 m
.52943 .43531 L
s
.53418 .43752 m
.53092 .43527 L
s
.53092 .43527 m
.52974 .43987 L
s
.892 0 1 r
.75212 .26198 m
.74714 .2637 L
s
.75982 .26969 m
.75212 .26198 L
s
0 .205 1 r
.90794 .67691 m
.90355 .67479 L
s
.90355 .67479 m
.90729 .66679 L
s
.90355 .67479 m
.90082 .66876 L
s
0 1 .757 r
.50187 .35745 m
.50593 .35618 L
s
.143 0 1 r
.46484 .2743 m
.47168 .27827 L
s
0 .829 1 r
.7271 .7605 m
.71172 .74463 L
s
.115 1 0 r
.39481 .67721 m
.39959 .66553 L
s
0 .71 1 r
.13917 .33744 m
.1337 .33853 L
s
.13374 .32965 m
.13917 .33744 L
s
.13917 .33744 m
.12976 .33629 L
s
.13768 .33187 m
.13917 .33744 L
s
.11162 .32047 m
.13917 .33744 L
s
.481 1 0 r
.5947 .60276 m
.59191 .60141 L
s
.59191 .60141 m
.59308 .59774 L
s
.59191 .60141 m
.59142 .60003 L
s
0 .205 1 r
.90729 .66679 m
.91169 .66889 L
s
.90729 .66679 m
.90082 .66876 L
s
.061 0 1 r
.6881 .84517 m
.69038 .85508 L
s
0 .777 1 r
.64123 .34918 m
.63806 .35001 L
s
.64671 .35408 m
.64123 .34918 L
s
.64123 .34918 m
.63821 .35778 L
s
0 1 .954 r
.76721 .68282 m
.76284 .68052 L
s
.76284 .68052 m
.76593 .67423 L
s
.76284 .68052 m
.76202 .67644 L
s
.9 1 0 r
.56395 .51939 m
.56267 .51939 L
s
.56267 .51939 m
.56131 .51677 L
s
.56267 .51939 m
.56028 .51956 L
s
.375 1 0 r
.5327 .43756 m
.53418 .43752 L
s
.53418 .43752 m
.52974 .43987 L
s
0 .771 1 r
.66273 .76483 m
.65799 .7707 L
s
.65537 .76292 m
.66273 .76483 L
s
0 1 .954 r
.76593 .67423 m
.77031 .67652 L
s
.76593 .67423 m
.76202 .67644 L
s
.375 1 0 r
.52974 .43987 m
.5327 .43756 L
s
.52974 .43987 m
.52943 .43531 L
s
.54007 .42256 m
.52974 .43987 L
s
1 0 .655 r
.53067 .99812 m
.53921 1.00655 L
s
.5222 1.0053 m
.53067 .99812 L
s
.53067 .99812 m
.53271 1.00042 L
s
.481 1 0 r
.59308 .59774 m
.59587 .59909 L
s
.59308 .59774 m
.59142 .60003 L
s
.444 0 1 r
.61329 .27559 m
.61905 .27364 L
s
0 .777 1 r
.63821 .35778 m
.64354 .35493 L
s
.63821 .35778 m
.63806 .35001 L
s
.64671 .35408 m
.63821 .35778 L
s
.65922 .32896 m
.63821 .35778 L
s
.95 0 1 r
.36391 .92125 m
.35614 .92671 L
s
.35966 .91401 m
.36391 .92125 L
s
.9 1 0 r
.56131 .51677 m
.56259 .51677 L
s
.56131 .51677 m
.56028 .51956 L
s
.152 0 1 r
.32308 .82951 m
.32941 .83638 L
s
.31653 .8337 m
.32308 .82951 L
s
.32308 .82951 m
.32613 .82973 L
s
0 .72 1 r
.8766 .5943 m
.8738 .59294 L
s
.8738 .59294 m
.87561 .58547 L
s
.8738 .59294 m
.86911 .5885 L
s
0 1 .319 r
.73586 .59958 m
.73293 .59831 L
s
.73293 .59831 m
.73406 .59284 L
s
.73293 .59831 m
.73027 .59569 L
s
0 .771 1 r
.65537 .76292 m
.65799 .7707 L
s
.892 0 1 r
.75486 .27146 m
.75982 .26969 L
s
0 1 .757 r
.49695 .35448 m
.50187 .35745 L
s
0 .777 1 r
.64354 .35493 m
.64671 .35408 L
s
0 .137 1 r
.78227 .34252 m
.77964 .34352 L
s
.78751 .34977 m
.78227 .34252 L
s
.78227 .34252 m
.77677 .35187 L
s
0 1 .029 r
.72235 .50911 m
.69903 .51561 L
s
.327 0 1 r
.5499 .92592 m
.55374 .90075 L
s
0 1 .347 r
.6715 .43048 m
.67078 .43073 L
s
.67489 .43507 m
.6715 .43048 L
s
.6715 .43048 m
.66833 .43628 L
s
0 1 .351 r
.62918 .68178 m
.62605 .68656 L
s
.62313 .68117 m
.62918 .68178 L
s
0 1 .029 r
.70495 .51695 m
.7036 .51649 L
s
.7036 .51649 m
.70246 .51167 L
s
.7036 .51649 m
.69903 .51561 L
s
0 .72 1 r
.87561 .58547 m
.87843 .5868 L
s
.87561 .58547 m
.86911 .5885 L
s
0 1 .347 r
.67418 .43532 m
.67489 .43507 L
s
.67489 .43507 m
.66833 .43628 L
s
0 .969 1 r
.84572 .5123 m
.84451 .51144 L
s
.84451 .51144 m
.84412 .50433 L
s
.84451 .51144 m
.83784 .50887 L
s
0 1 .351 r
.62313 .68117 m
.62605 .68656 L
s
0 .137 1 r
.77677 .35187 m
.7849 .35079 L
s
.77677 .35187 m
.77964 .34352 L
s
.78751 .34977 m
.77677 .35187 L
s
.81105 .32558 m
.77677 .35187 L
s
0 1 .319 r
.73406 .59284 m
.73698 .5941 L
s
.73406 .59284 m
.73027 .59569 L
s
0 .137 1 r
.7849 .35079 m
.78751 .34977 L
s
.481 1 0 r
.59587 .59909 m
.5947 .60276 L
s
.59142 .60003 m
.5947 .60276 L
s
0 .787 1 r
.81518 .43108 m
.81574 .43037 L
s
.81574 .43037 m
.81295 .42334 L
s
.81574 .43037 m
.80705 .42996 L
s
1 0 .319 r
.38987 1.01298 m
.38124 1.00358 L
s
.38124 1.00358 m
.39378 .99867 L
s
0 .71 1 r
.13374 .32965 m
.12976 .33629 L
s
.13768 .33187 m
.13374 .32965 L
s
.12976 .33629 m
.1337 .33853 L
s
0 1 .029 r
.70246 .51167 m
.70381 .51212 L
s
.70246 .51167 m
.69903 .51561 L
s
.9 1 0 r
.56028 .51956 m
.56395 .51939 L
s
.56028 .51956 m
.56259 .51677 L
s
.56259 .51677 m
.56395 .51939 L
s
.375 1 0 r
.52943 .43531 m
.5327 .43756 L
s
.481 1 0 r
.59142 .60003 m
.59587 .59909 L
s
0 .787 1 r
.81295 .42334 m
.81239 .42403 L
s
.81295 .42334 m
.80705 .42996 L
s
0 .969 1 r
.84412 .50433 m
.84532 .50516 L
s
.84412 .50433 m
.83784 .50887 L
s
.152 0 1 r
.32941 .83638 m
.32287 .84059 L
s
.32613 .82973 m
.32941 .83638 L
s
0 .695 1 r
.29018 .74617 m
.29522 .75181 L
s
.28505 .74907 m
.29018 .74617 L
s
.29018 .74617 m
.29322 .74594 L
s
0 1 .347 r
.66833 .43628 m
.67418 .43532 L
s
.66833 .43628 m
.67078 .43073 L
s
.6909 .41935 m
.66833 .43628 L
s
0 .208 1 r
.87786 .75789 m
.85186 .73814 L
s
.115 1 0 r
.54499 .67446 m
.53912 .6654 L
s
.253 1 0 r
.21212 .59103 m
.2294 .58018 L
s
0 .306 1 r
.80381 .7593 m
.79905 .76646 L
s
.79424 .75776 m
.80381 .7593 L
s
0 1 .165 r
.16847 .41746 m
.16419 .41934 L
s
.16356 .41312 m
.16847 .41746 L
s
.16847 .41746 m
.16198 .41817 L
s
.16578 .41428 m
.16847 .41746 L
s
.14536 .41129 m
.16847 .41746 L
s
.281 0 1 r
.24763 .26202 m
.24335 .25944 L
s
.2448 .25016 m
.24763 .26202 L
s
.24763 .26202 m
.23753 .25615 L
s
.25063 .25343 m
.24763 .26202 L
s
.22966 .22543 m
.24763 .26202 L
s
0 .306 1 r
.79424 .75776 m
.79905 .76646 L
s
.607 0 1 r
.49714 .91443 m
.50453 .92162 L
s
.48967 .92054 m
.49714 .91443 L
s
.49714 .91443 m
.49861 .91605 L
s
1 0 .655 r
.53921 1.00655 m
.53074 1.01376 L
s
.53271 1.00042 m
.53921 1.00655 L
s
0 1 .165 r
.16198 .41817 m
.16419 .41934 L
s
.16356 .41312 m
.16198 .41817 L
s
0 .787 1 r
.80705 .42996 m
.81518 .43108 L
s
.80705 .42996 m
.81239 .42403 L
s
.84225 .41614 m
.80705 .42996 L
s
.444 0 1 r
.60569 .27001 m
.61329 .27559 L
s
0 .695 1 r
.29522 .75181 m
.2901 .75473 L
s
.29322 .74594 m
.29522 .75181 L
s
0 1 .455 r
.25767 .66311 m
.26136 .66764 L
s
.2542 .66475 m
.25767 .66311 L
s
.25767 .66311 m
.26096 .66273 L
s
0 1 .165 r
.16578 .41428 m
.16356 .41312 L
s
.95 0 1 r
.35614 .92671 m
.3486 .91856 L
s
.3486 .91856 m
.35966 .91401 L
s
0 1 .954 r
.77031 .67652 m
.76721 .68282 L
s
.76202 .67644 m
.76721 .68282 L
s
0 1 .029 r
.69903 .51561 m
.70495 .51695 L
s
.69903 .51561 m
.70381 .51212 L
s
0 .969 1 r
.87323 .50607 m
.83784 .50887 L
s
.349 0 1 r
.70048 .9236 m
.69486 .89827 L
s
0 .227 1 r
.36732 .84009 m
.37929 .81513 L
s
.445 1 0 r
.19469 .50076 m
.19515 .5012 L
s
.1941 .49683 m
.19469 .50076 L
s
.19856 .4984 m
.19469 .50076 L
s
0 1 .954 r
.76202 .67644 m
.77031 .67652 L
s
0 1 .455 r
.26136 .66764 m
.2579 .66929 L
s
.26096 .66273 m
.26136 .66764 L
s
1 0 .319 r
.39378 .99867 m
.38987 1.01298 L
s
0 1 .319 r
.73698 .5941 m
.73586 .59958 L
s
.73027 .59569 m
.73586 .59958 L
s
.253 1 0 r
.22785 .58393 m
.2263 .58457 L
s
.22557 .58015 m
.22785 .58393 L
s
.2294 .58018 m
.22785 .58393 L
s
.22401 .58078 m
.22557 .58015 L
s
.22557 .58015 m
.2294 .58018 L
s
0 .969 1 r
.83784 .50887 m
.84572 .5123 L
s
.83784 .50887 m
.84532 .50516 L
s
.445 1 0 r
.19455 .49726 m
.1941 .49683 L
s
.1941 .49683 m
.19856 .4984 L
s
0 .777 1 r
.63806 .35001 m
.64354 .35493 L
s
.281 0 1 r
.2448 .25016 m
.23753 .25615 L
s
.25063 .25343 m
.2448 .25016 L
s
0 1 .319 r
.73027 .59569 m
.73698 .5941 L
s
0 1 .029 r
.70381 .51212 m
.70495 .51695 L
s
1 0 .655 r
.53074 1.01376 m
.5222 1.0053 L
s
.5222 1.0053 m
.53271 1.00042 L
s
.445 1 0 r
.19856 .4984 m
.19515 .5012 L
s
.19455 .49726 m
.19856 .4984 L
s
.17885 .50147 m
.19856 .4984 L
s
0 .72 1 r
.86911 .5885 m
.8766 .5943 L
s
.86911 .5885 m
.87843 .5868 L
s
0 .205 1 r
.90082 .66876 m
.90794 .67691 L
s
.90082 .66876 m
.91169 .66889 L
s
0 1 .347 r
.67078 .43073 m
.67418 .43532 L
s
.152 0 1 r
.32287 .84059 m
.31653 .8337 L
s
.31653 .8337 m
.32613 .82973 L
s
0 .205 1 r
.91169 .66889 m
.90794 .67691 L
s
0 1 .355 r
.69569 .6717 m
.67918 .66233 L
s
1 .875 0 r
.36224 .58812 m
.3678 .58319 L
s
0 .218 1 r
.46397 .83097 m
.47006 .83689 L
s
.45767 .83592 m
.46397 .83097 L
s
.46397 .83097 m
.46503 .83205 L
s
0 .71 1 r
.1337 .33853 m
.13768 .33187 L
s
.607 0 1 r
.50453 .92162 m
.49706 .92776 L
s
.49861 .91605 m
.50453 .92162 L
s
.95 0 1 r
.35966 .91401 m
.35614 .92671 L
s
.892 0 1 r
.74714 .2637 m
.75486 .27146 L
s
0 .72 1 r
.87843 .5868 m
.8766 .5943 L
s
0 1 .785 r
.27656 .34091 m
.27339 .33935 L
s
.27442 .33302 m
.27656 .34091 L
s
.27656 .34091 m
.26958 .33723 L
s
.27823 .33513 m
.27656 .34091 L
s
.26316 .31706 m
.27656 .34091 L
s
0 1 .165 r
.16419 .41934 m
.16578 .41428 L
s
.526 0 1 r
.63838 .9131 m
.64599 .91947 L
s
.6312 .91999 m
.63838 .9131 L
s
.63838 .9131 m
.63824 .91494 L
s
0 .695 1 r
.2901 .75473 m
.28505 .74907 L
s
.28505 .74907 m
.29322 .74594 L
s
0 .969 1 r
.84532 .50516 m
.84572 .5123 L
s
.253 1 0 r
.2294 .58018 m
.2263 .58457 L
s
.22401 .58078 m
.2294 .58018 L
s
.445 1 0 r
.19515 .5012 m
.19455 .49726 L
s
.281 0 1 r
.23753 .25615 m
.24335 .25944 L
s
0 .496 1 r
.51785 .83762 m
.51985 .81614 L
s
0 .137 1 r
.77964 .34352 m
.7849 .35079 L
s
0 .787 1 r
.81239 .42403 m
.81518 .43108 L
s
.607 0 1 r
.49706 .92776 m
.48967 .92054 L
s
.48967 .92054 m
.49861 .91605 L
s
.152 0 1 r
.32613 .82973 m
.32287 .84059 L
s
0 1 .785 r
.27442 .33302 m
.26958 .33723 L
s
.27823 .33513 m
.27442 .33302 L
s
0 1 .455 r
.2579 .66929 m
.2542 .66475 L
s
.2542 .66475 m
.26096 .66273 L
s
.253 1 0 r
.2263 .58457 m
.22401 .58078 L
s
0 1 .872 r
.43116 .74782 m
.43584 .75244 L
s
.42622 .75152 m
.43116 .74782 L
s
.43116 .74782 m
.43201 .74851 L
s
0 .695 1 r
.29322 .74594 m
.2901 .75473 L
s
0 .218 1 r
.47006 .83689 m
.46376 .84186 L
s
.46503 .83205 m
.47006 .83689 L
s
1 0 .655 r
.53271 1.00042 m
.53074 1.01376 L
s
0 1 .455 r
.26096 .66273 m
.2579 .66929 L
s
.226 0 1 r
.3858 .26307 m
.38473 .25881 L
s
.38546 .25104 m
.3858 .26307 L
s
.3858 .26307 m
.37816 .25508 L
s
.39203 .25475 m
.3858 .26307 L
s
.38221 .22182 m
.3858 .26307 L
s
1 .909 0 r
.51289 .5852 m
.50718 .58334 L
s
0 .879 1 r
.84692 .66892 m
.81938 .6563 L
s
1 0 .57 r
.33969 1.00383 m
.36121 .96898 L
s
0 1 .785 r
.26958 .33723 m
.27339 .33935 L
s
0 .218 1 r
.46376 .84186 m
.45767 .83592 L
s
.45767 .83592 m
.46503 .83205 L
s
.57 1 0 r
.30625 .42079 m
.30391 .42001 L
s
.30467 .4165 m
.30625 .42079 L
s
.30625 .42079 m
.30207 .41907 L
s
.30653 .41743 m
.30625 .42079 L
s
.29642 .40804 m
.30625 .42079 L
s
.226 0 1 r
.38546 .25104 m
.37816 .25508 L
s
.39203 .25475 m
.38546 .25104 L
s
.281 0 1 r
.24335 .25944 m
.25063 .25343 L
s
0 .271 1 r
.60532 .82981 m
.61163 .83494 L
s
.59931 .83568 m
.60532 .82981 L
s
.60532 .82981 m
.60469 .83129 L
s
.57 1 0 r
.30467 .4165 m
.30207 .41907 L
s
.30653 .41743 m
.30467 .4165 L
s
.526 0 1 r
.63881 .92639 m
.6312 .91999 L
s
.6312 .91999 m
.63824 .91494 L
s
0 1 .872 r
.43584 .75244 m
.4309 .75616 L
s
.43201 .74851 m
.43584 .75244 L
s
.115 1 0 r
.39877 .66502 m
.4019 .66835 L
s
.39535 .66741 m
.39877 .66502 L
s
.39877 .66502 m
.39959 .66553 L
s
.607 0 1 r
.49861 .91605 m
.49706 .92776 L
s
.57 1 0 r
.30207 .41907 m
.30391 .42001 L
s
0 1 .898 r
.33457 .75133 m
.34601 .73069 L
s
0 .429 1 r
.6689 .83513 m
.66102 .81404 L
s
.526 0 1 r
.64599 .91947 m
.63881 .92639 L
s
.63824 .91494 m
.64599 .91947 L
s
.115 1 0 r
.4019 .66835 m
.39848 .67074 L
s
.39959 .66553 m
.4019 .66835 L
s
0 1 .872 r
.4309 .75616 m
.42622 .75152 L
s
.42622 .75152 m
.43201 .74851 L
s
0 1 .785 r
.27339 .33935 m
.27823 .33513 L
s
1 .437 0 r
.33498 .50161 m
.33485 .50173 L
s
.33561 .50016 m
.33498 .50161 L
s
.33668 .50158 m
.33498 .50161 L
s
1 .875 0 r
.36687 .58261 m
.36829 .58471 L
s
.36508 .58364 m
.36687 .58261 L
s
.36687 .58261 m
.3678 .58319 L
s
1 .437 0 r
.33548 .50027 m
.33561 .50016 L
s
.33561 .50016 m
.33668 .50158 L
s
1 .875 0 r
.36829 .58471 m
.3665 .58574 L
s
.3678 .58319 m
.36829 .58471 L
s
0 .035 1 r
.7471 .82604 m
.75375 .83051 L
s
.74121 .83296 m
.7471 .82604 L
s
.7471 .82604 m
.74473 .82743 L
s
0 .218 1 r
.46503 .83205 m
.46376 .84186 L
s
1 .437 0 r
.33668 .50158 m
.33485 .50173 L
s
.33548 .50027 m
.33668 .50158 L
s
.32944 .4984 m
.33668 .50158 L
s
0 1 .749 r
.41512 .34177 m
.41501 .33867 L
s
.41528 .3337 m
.41512 .34177 L
s
.41512 .34177 m
.41046 .33607 L
s
.41983 .33629 m
.41512 .34177 L
s
.41523 .31363 m
.41512 .34177 L
s
.115 1 0 r
.39848 .67074 m
.39535 .66741 L
s
.39535 .66741 m
.39959 .66553 L
s
0 .271 1 r
.60562 .84082 m
.59931 .83568 L
s
.59931 .83568 m
.60469 .83129 L
s
.356 1 0 r
.66406 .58227 m
.64715 .58063 L
s
.991 0 1 r
.49056 1.00163 m
.5026 .97122 L
s
.57 1 0 r
.30391 .42001 m
.30653 .41743 L
s
0 1 .749 r
.41528 .3337 m
.41046 .33607 L
s
.41983 .33629 m
.41528 .3337 L
s
0 1 .845 r
.57257 .74681 m
.57746 .75067 L
s
.56793 .75156 m
.57257 .74681 L
s
.57257 .74681 m
.57164 .74808 L
s
1 .437 0 r
.33485 .50173 m
.33548 .50027 L
s
1 .875 0 r
.3665 .58574 m
.36508 .58364 L
s
.36508 .58364 m
.3678 .58319 L
s
.3678 .58319 m
.3665 .58574 L
s
.408 0 1 r
.52485 .26156 m
.52729 .25683 L
s
.52654 .24916 m
.52485 .26156 L
s
.52485 .26156 m
.51983 .25191 L
s
.534 .25407 m
.52485 .26156 L
s
.5353 .21821 m
.52485 .26156 L
s
0 1 .872 r
.43201 .74851 m
.4309 .75616 L
s
.115 1 0 r
.39959 .66553 m
.39848 .67074 L
s
0 .271 1 r
.61163 .83494 m
.60562 .84082 L
s
.60469 .83129 m
.61163 .83494 L
s
.408 0 1 r
.52654 .24916 m
.51983 .25191 L
s
.534 .25407 m
.52654 .24916 L
s
0 .035 1 r
.74785 .83745 m
.74121 .83296 L
s
.74121 .83296 m
.74473 .82743 L
s
.226 0 1 r
.37816 .25508 m
.38473 .25881 L
s
.526 0 1 r
.63824 .91494 m
.63881 .92639 L
s
0 .049 1 r
.82048 .83264 m
.80242 .80883 L
s
0 1 .588 r
.48556 .74869 m
.48649 .73198 L
s
0 1 .845 r
.57282 .75543 m
.56793 .75156 L
s
.56793 .75156 m
.57164 .74808 L
s
.226 0 1 r
.38473 .25881 m
.39203 .25475 L
s
.578 1 0 r
.44559 .41699 m
.44311 .4178 L
s
.44833 .41844 m
.44559 .41699 L
s
.44559 .41699 m
.44515 .42144 L
s
.115 1 0 r
.54014 .66417 m
.54355 .66674 L
s
.53706 .66772 m
.54014 .66417 L
s
.54014 .66417 m
.53912 .6654 L
s
0 .829 1 r
.71446 .7432 m
.71969 .74648 L
s
.70997 .74919 m
.71446 .7432 L
s
.71446 .7432 m
.71172 .74463 L
s
1 0 .678 r
.44446 .98402 m
.45283 .99264 L
s
.43609 .99043 m
.44446 .98402 L
s
.44446 .98402 m
.44761 .98536 L
s
.578 1 0 r
.44515 .42144 m
.44584 .41926 L
s
.44515 .42144 m
.44311 .4178 L
s
.44833 .41844 m
.44515 .42144 L
s
.44801 .40479 m
.44515 .42144 L
s
0 1 .845 r
.57746 .75067 m
.57282 .75543 L
s
.57164 .74808 m
.57746 .75067 L
s
0 .208 1 r
.85682 .73698 m
.86226 .73985 L
s
.85198 .7444 m
.85682 .73698 L
s
.85682 .73698 m
.85186 .73814 L
s
.115 1 0 r
.54047 .67028 m
.53706 .66772 L
s
.53706 .66772 m
.53912 .6654 L
s
.76 0 1 r
.66439 .25748 m
.67028 .25346 L
s
.66822 .24456 m
.66439 .25748 L
s
.66439 .25748 m
.66232 .24668 L
s
.67616 .25131 m
.66439 .25748 L
s
.68893 .21458 m
.66439 .25748 L
s
0 1 .749 r
.41501 .33867 m
.41983 .33629 L
s
0 .829 1 r
.71519 .75248 m
.70997 .74919 L
s
.70997 .74919 m
.71172 .74463 L
s
0 .271 1 r
.60469 .83129 m
.60562 .84082 L
s
0 1 .749 r
.41046 .33607 m
.41501 .33867 L
s
0 1 .586 r
.81577 .57933 m
.78734 .57503 L
s
1 .485 0 r
.48056 .49531 m
.47584 .50199 L
s
.816 0 1 r
.64196 .99943 m
.64469 .97019 L
s
.716 0 1 r
.30675 .91541 m
.32645 .88274 L
s
0 .208 1 r
.8574 .74729 m
.85198 .7444 L
s
.85198 .7444 m
.85186 .73814 L
s
0 .945 1 r
.55651 .33138 m
.55238 .33275 L
s
.5619 .3354 m
.55651 .33138 L
s
.55651 .33138 m
.55449 .34 L
s
.76 0 1 r
.66822 .24456 m
.66232 .24668 L
s
.67616 .25131 m
.66822 .24456 L
s
1 .909 0 r
.50868 .58548 m
.5067 .58424 L
s
.5067 .58424 m
.50797 .58196 L
s
.5067 .58424 m
.50718 .58334 L
s
0 .945 1 r
.55449 .34 m
.55777 .33678 L
s
.55449 .34 m
.55238 .33275 L
s
.5619 .3354 m
.55449 .34 L
s
.56783 .31019 m
.55449 .34 L
s
.578 1 0 r
.44584 .41926 m
.44833 .41844 L
s
1 .485 0 r
.47759 .50098 m
.47738 .50131 L
s
.47738 .50131 m
.47599 .50033 L
s
.47738 .50131 m
.47584 .50199 L
s
.47599 .50033 m
.4762 .5 L
s
.47599 .50033 m
.47584 .50199 L
s
1 .909 0 r
.50797 .58196 m
.50995 .58319 L
s
.50797 .58196 m
.50718 .58334 L
s
.115 1 0 r
.54355 .66674 m
.54047 .67028 L
s
.53912 .6654 m
.54355 .66674 L
s
0 1 .845 r
.57164 .74808 m
.57282 .75543 L
s
.578 1 0 r
.44311 .4178 m
.44584 .41926 L
s
0 .035 1 r
.75375 .83051 m
.74785 .83745 L
s
.74473 .82743 m
.75375 .83051 L
s
1 .909 0 r
.50995 .58319 m
.50868 .58548 L
s
.50718 .58334 m
.50868 .58548 L
s
.408 0 1 r
.52729 .25683 m
.534 .25407 L
s
0 1 .355 r
.68297 .66779 m
.6792 .66567 L
s
.6792 .66567 m
.68204 .66065 L
s
.6792 .66567 m
.67918 .66233 L
s
.68204 .66065 m
.68581 .66276 L
s
.68204 .66065 m
.67918 .66233 L
s
1 .485 0 r
.47584 .50199 m
.47759 .50098 L
s
.47584 .50199 m
.4762 .5 L
s
.115 1 0 r
.53912 .6654 m
.54047 .67028 L
s
1 .909 0 r
.50718 .58334 m
.50995 .58319 L
s
0 1 .714 r
.63709 .74604 m
.62766 .73025 L
s
0 1 0 r
.30159 .66195 m
.31338 .64683 L
s
0 .879 1 r
.82526 .66317 m
.82139 .66125 L
s
.82139 .66125 m
.82458 .65453 L
s
.82139 .66125 m
.81938 .6563 L
s
1 .485 0 r
.4762 .5 m
.47759 .50098 L
s
0 .879 1 r
.82458 .65453 m
.82846 .65642 L
s
.82458 .65453 m
.81938 .6563 L
s
.037 1 0 r
.58692 .41396 m
.58529 .4143 L
s
.59039 .41732 m
.58692 .41396 L
s
.58692 .41396 m
.58478 .41937 L
s
1 0 .678 r
.45283 .99264 m
.44448 .99909 L
s
.44761 .98536 m
.45283 .99264 L
s
.356 1 0 r
.65129 .58351 m
.64895 .58249 L
s
.64895 .58249 m
.64981 .57841 L
s
.64895 .58249 m
.64715 .58063 L
s
.585 0 1 r
.41051 .89944 m
.41775 .90682 L
s
.40317 .90471 m
.41051 .89944 L
s
.41051 .89944 m
.41317 .90005 L
s
0 .945 1 r
.55777 .33678 m
.5619 .3354 L
s
0 .418 1 r
.69849 .32621 m
.69506 .32736 L
s
.70409 .33233 m
.69849 .32621 L
s
.69849 .32621 m
.69428 .33557 L
s
.69428 .33557 m
.70068 .3335 L
s
.69428 .33557 m
.69506 .32736 L
s
.70409 .33233 m
.69428 .33557 L
s
.72098 .30674 m
.69428 .33557 L
s
0 .035 1 r
.74473 .82743 m
.74785 .83745 L
s
.598 1 0 r
.62005 .49991 m
.61935 .49973 L
s
.61935 .49973 m
.61792 .49635 L
s
.61935 .49973 m
.61567 .49961 L
s
.037 1 0 r
.58876 .41767 m
.59039 .41732 L
s
.59039 .41732 m
.58478 .41937 L
s
.76 0 1 r
.67028 .25346 m
.67616 .25131 L
s
.356 1 0 r
.64981 .57841 m
.65215 .57942 L
s
.64981 .57841 m
.64715 .58063 L
s
.037 1 0 r
.58478 .41937 m
.58876 .41767 L
s
.58478 .41937 m
.58529 .4143 L
s
.60014 .40152 m
.58478 .41937 L
s
0 1 .586 r
.79358 .57952 m
.79127 .5784 L
s
.79127 .5784 m
.7925 .57228 L
s
.79127 .5784 m
.78734 .57503 L
s
.598 1 0 r
.61792 .49635 m
.61861 .49653 L
s
.61792 .49635 m
.61567 .49961 L
s
.63221 .49221 m
.61567 .49961 L
s
.25 0 1 r
.4581 .91305 m
.46783 .88527 L
s
0 .829 1 r
.71969 .74648 m
.71519 .75248 L
s
.71172 .74463 m
.71969 .74648 L
s
.408 0 1 r
.51983 .25191 m
.52729 .25683 L
s
0 .418 1 r
.70068 .3335 m
.70409 .33233 L
s
0 1 .586 r
.7925 .57228 m
.79482 .57338 L
s
.7925 .57228 m
.78734 .57503 L
s
0 1 .395 r
.76236 .49655 m
.76165 .49593 L
s
.76165 .49593 m
.76066 .49019 L
s
.76165 .49593 m
.75579 .49443 L
s
1 0 .94 r
.58667 .98405 m
.59506 .99173 L
s
.57861 .99106 m
.58667 .98405 L
s
.58667 .98405 m
.58814 .98573 L
s
0 1 .741 r
.73141 .4145 m
.73259 .41389 L
s
.73259 .41389 m
.72928 .40816 L
s
.73259 .41389 m
.72476 .41458 L
s
.72928 .40816 m
.7281 .40875 L
s
.72928 .40816 m
.72476 .41458 L
s
0 .829 1 r
.71172 .74463 m
.71519 .75248 L
s
0 1 .395 r
.76066 .49019 m
.76137 .49079 L
s
.76066 .49019 m
.75579 .49443 L
s
0 .768 1 r
.1899 .31898 m
.1852 .3191 L
s
.18566 .31058 m
.1899 .31898 L
s
.1899 .31898 m
.18096 .31662 L
s
.18992 .31305 m
.1899 .31898 L
s
.16732 .29805 m
.1899 .31898 L
s
.598 1 0 r
.61567 .49961 m
.62005 .49991 L
s
.61567 .49961 m
.61861 .49653 L
s
0 1 .355 r
.68581 .66276 m
.68297 .66779 L
s
.67918 .66233 m
.68297 .66779 L
s
.67918 .66233 m
.68581 .66276 L
s
0 1 .741 r
.72476 .41458 m
.73141 .4145 L
s
.72476 .41458 m
.7281 .40875 L
s
.7528 .39824 m
.72476 .41458 L
s
.418 1 0 r
.45306 .65914 m
.45372 .64838 L
s
0 .794 1 r
.78915 .74338 m
.76914 .72547 L
s
0 .945 1 r
.55238 .33275 m
.55777 .33678 L
s
.585 0 1 r
.41775 .90682 m
.41043 .91212 L
s
.41317 .90005 m
.41775 .90682 L
s
0 .227 1 r
.37693 .81509 m
.38292 .8212 L
s
.37081 .81915 m
.37693 .81509 L
s
.37693 .81509 m
.37929 .81513 L
s
.356 1 0 r
.65215 .57942 m
.65129 .58351 L
s
.64715 .58063 m
.65129 .58351 L
s
1 0 .678 r
.44448 .99909 m
.43609 .99043 L
s
.43609 .99043 m
.44761 .98536 L
s
0 .208 1 r
.86226 .73985 m
.8574 .74729 L
s
.85186 .73814 m
.86226 .73985 L
s
.598 1 0 r
.61861 .49653 m
.62005 .49991 L
s
.356 1 0 r
.64715 .58063 m
.65215 .57942 L
s
.037 1 0 r
.58529 .4143 m
.58876 .41767 L
s
0 .208 1 r
.85186 .73814 m
.8574 .74729 L
s
0 1 .395 r
.75579 .49443 m
.76236 .49655 L
s
.75579 .49443 m
.76137 .49079 L
s
.78439 .4891 m
.75579 .49443 L
s
.092 0 1 r
.60997 .91068 m
.61001 .8846 L
s
0 .048 1 r
.27359 .82636 m
.29229 .79691 L
s
0 .768 1 r
.18566 .31058 m
.18096 .31662 L
s
.18992 .31305 m
.18566 .31058 L
s
0 .227 1 r
.38292 .8212 m
.37681 .82528 L
s
.37929 .81513 m
.38292 .8212 L
s
0 .879 1 r
.82846 .65642 m
.82526 .66317 L
s
.81938 .6563 m
.82526 .66317 L
s
.327 0 1 r
.55289 .89963 m
.56009 .90609 L
s
.54583 .90562 m
.55289 .89963 L
s
.55289 .89963 m
.55374 .90075 L
s
.76 0 1 r
.66232 .24668 m
.67028 .25346 L
s
0 1 .898 r
.34373 .73104 m
.34838 .73589 L
s
.33903 .73382 m
.34373 .73104 L
s
.34373 .73104 m
.34601 .73069 L
s
0 1 .586 r
.78734 .57503 m
.79358 .57952 L
s
.78734 .57503 m
.79482 .57338 L
s
0 .879 1 r
.81938 .6563 m
.82846 .65642 L
s
0 .768 1 r
.18096 .31662 m
.1852 .3191 L
s
.423 0 1 r
.29973 .24183 m
.2966 .2386 L
s
.29785 .22927 m
.29973 .24183 L
s
.29973 .24183 m
.29013 .23483 L
s
.30432 .23302 m
.29973 .24183 L
s
.28703 .20178 m
.29973 .24183 L
s
1 0 .94 r
.59506 .99173 m
.58701 .99878 L
s
.58814 .98573 m
.59506 .99173 L
s
.022 1 0 r
.21965 .39963 m
.21605 .40059 L
s
.21592 .39484 m
.21965 .39963 L
s
.21965 .39963 m
.21359 .39923 L
s
.21838 .39619 m
.21965 .39963 L
s
.20125 .38999 m
.21965 .39963 L
s
0 1 .586 r
.79482 .57338 m
.79358 .57952 L
s
.585 0 1 r
.41043 .91212 m
.40317 .90471 L
s
.40317 .90471 m
.41317 .90005 L
s
0 .005 1 r
.94174 .74071 m
.91052 .71765 L
s
.766 1 0 r
.26838 .57193 m
.28141 .56364 L
s
.196 1 0 r
.60506 .65632 m
.59482 .64698 L
s
0 1 .395 r
.76137 .49079 m
.76236 .49655 L
s
0 .418 1 r
.69506 .32736 m
.70068 .3335 L
s
1 0 .94 r
.58701 .99878 m
.57861 .99106 L
s
.57861 .99106 m
.58814 .98573 L
s
1 0 .678 r
.44761 .98536 m
.44448 .99909 L
s
0 1 .898 r
.34838 .73589 m
.34369 .73868 L
s
.34601 .73069 m
.34838 .73589 L
s
0 1 0 r
.31092 .64728 m
.31415 .65095 L
s
.30786 .64879 m
.31092 .64728 L
s
.31092 .64728 m
.31338 .64683 L
s
.022 1 0 r
.21359 .39923 m
.21605 .40059 L
s
.21592 .39484 m
.21359 .39923 L
s
.21838 .39619 m
.21592 .39484 L
s
0 1 .741 r
.7281 .40875 m
.73141 .4145 L
s
.423 0 1 r
.29785 .22927 m
.29013 .23483 L
s
.30432 .23302 m
.29785 .22927 L
s
0 1 0 r
.31415 .65095 m
.31109 .65247 L
s
.31338 .64683 m
.31415 .65095 L
s
.859 1 0 r
.2467 .48256 m
.24747 .483 L
s
.24677 .47945 m
.2467 .48256 L
s
.25016 .48121 m
.2467 .48256 L
s
0 .227 1 r
.37681 .82528 m
.37081 .81915 L
s
.37081 .81915 m
.37929 .81513 L
s
.238 0 1 r
.76238 .9083 m
.75257 .88074 L
s
0 .573 1 r
.42541 .82384 m
.43362 .7997 L
s
.766 1 0 r
.28025 .56649 m
.27909 .56697 L
s
.27851 .56364 m
.28025 .56649 L
s
.28141 .56364 m
.28025 .56649 L
s
.27735 .56411 m
.27851 .56364 L
s
.27851 .56364 m
.28141 .56364 L
s
.349 0 1 r
.69572 .89717 m
.70316 .90282 L
s
.68884 .90399 m
.69572 .89717 L
s
.69572 .89717 m
.69486 .89827 L
s
0 .496 1 r
.51945 .81545 m
.52532 .82064 L
s
.51356 .82033 m
.51945 .81545 L
s
.51945 .81545 m
.51985 .81614 L
s
.859 1 0 r
.24754 .47989 m
.24677 .47945 L
s
.24677 .47945 m
.25016 .48121 L
s
.25016 .48121 m
.24747 .483 L
s
.24754 .47989 m
.25016 .48121 L
s
.23493 .48129 m
.25016 .48121 L
s
.327 0 1 r
.56009 .90609 m
.55303 .9121 L
s
.55374 .90075 m
.56009 .90609 L
s
.585 0 1 r
.41317 .90005 m
.41043 .91212 L
s
0 .768 1 r
.1852 .3191 m
.18992 .31305 L
s
0 1 .911 r
.3291 .32132 m
.32703 .31922 L
s
.32785 .31281 m
.3291 .32132 L
s
.3291 .32132 m
.32261 .31662 L
s
.33227 .3154 m
.3291 .32132 L
s
.32071 .29456 m
.3291 .32132 L
s
.327 0 1 r
.55303 .9121 m
.54583 .90562 L
s
.54583 .90562 m
.55374 .90075 L
s
0 1 .898 r
.34369 .73868 m
.33903 .73382 L
s
.33903 .73382 m
.34601 .73069 L
s
0 1 .47 r
.75759 .6535 m
.73631 .64262 L
s
1 .502 0 r
.42032 .56896 m
.42156 .56542 L
s
.022 1 0 r
.21605 .40059 m
.21838 .39619 L
s
0 .227 1 r
.37929 .81513 m
.37681 .82528 L
s
.766 1 0 r
.28141 .56364 m
.27909 .56697 L
s
.27735 .56411 m
.28141 .56364 L
s
.859 1 0 r
.24747 .483 m
.24754 .47989 L
s
0 1 0 r
.31109 .65247 m
.30786 .64879 L
s
.30786 .64879 m
.31338 .64683 L
s
1 0 .94 r
.58814 .98573 m
.58701 .99878 L
s
0 1 .911 r
.32785 .31281 m
.32261 .31662 L
s
.33227 .3154 m
.32785 .31281 L
s
.766 1 0 r
.27909 .56697 m
.27735 .56411 L
s
0 1 .588 r
.48635 .73158 m
.49077 .73546 L
s
.48184 .73525 m
.48635 .73158 L
s
.48635 .73158 m
.48649 .73198 L
s
.458 0 1 r
.43961 .24176 m
.43986 .23732 L
s
.44009 .22896 m
.43961 .24176 L
s
.43961 .24176 m
.43259 .2328 L
s
.44736 .23346 m
.43961 .24176 L
s
.44146 .19809 m
.43961 .24176 L
s
.423 0 1 r
.29013 .23483 m
.2966 .2386 L
s
0 1 .898 r
.34601 .73069 m
.34369 .73868 L
s
0 .496 1 r
.52532 .82064 m
.51944 .82553 L
s
.51985 .81614 m
.52532 .82064 L
s
0 1 0 r
.31338 .64683 m
.31109 .65247 L
s
.349 0 1 r
.69628 .90967 m
.68884 .90399 L
s
.68884 .90399 m
.69486 .89827 L
s
0 .723 1 r
.57776 .8213 m
.57581 .79937 L
s
0 .833 1 r
.24019 .73669 m
.25878 .71159 L
s
0 .496 1 r
.51944 .82553 m
.51356 .82033 L
s
.51356 .82033 m
.51985 .81614 L
s
0 .429 1 r
.66242 .81316 m
.66851 .81759 L
s
.65672 .81903 m
.66242 .81316 L
s
.66242 .81316 m
.66102 .81404 L
s
1 0 .57 r
.3567 .96875 m
.3652 .97766 L
s
.34848 .97442 m
.3567 .96875 L
s
.3567 .96875 m
.36121 .96898 L
s
.458 0 1 r
.44009 .22896 m
.43259 .2328 L
s
.44736 .23346 m
.44009 .22896 L
s
.491 1 0 r
.35922 .4018 m
.35795 .40055 L
s
.35847 .39703 m
.35922 .4018 L
s
.35922 .4018 m
.35551 .39918 L
s
.36091 .3984 m
.35922 .4018 L
s
.35415 .38667 m
.35922 .4018 L
s
.423 0 1 r
.2966 .2386 m
.30432 .23302 L
s
.327 0 1 r
.55374 .90075 m
.55303 .9121 L
s
.491 1 0 r
.35847 .39703 m
.35551 .39918 L
s
.36091 .3984 m
.35847 .39703 L
s
0 1 .911 r
.32261 .31662 m
.32703 .31922 L
s
.349 0 1 r
.70316 .90282 m
.69628 .90967 L
s
.69486 .89827 m
.70316 .90282 L
s
0 .049 1 r
.80581 .80821 m
.81219 .81203 L
s
.79997 .81524 m
.80581 .80821 L
s
.80581 .80821 m
.80242 .80883 L
s
.418 1 0 r
.45364 .64808 m
.4565 .65064 L
s
.45067 .65045 m
.45364 .64808 L
s
.45364 .64808 m
.45372 .64838 L
s
0 1 .588 r
.49077 .73546 m
.48626 .73914 L
s
.48649 .73198 m
.49077 .73546 L
s
1 .961 0 r
.5728 .56597 m
.56254 .56433 L
s
0 .604 1 r
.91067 .65066 m
.87777 .63529 L
s
1 0 .95 r
.39761 .98941 m
.41568 .95537 L
s
0 1 .588 r
.48626 .73914 m
.48184 .73525 L
s
.48184 .73525 m
.48649 .73198 L
s
0 .429 1 r
.66281 .82347 m
.65672 .81903 L
s
.65672 .81903 m
.66102 .81404 L
s
0 1 .911 r
.32703 .31922 m
.33227 .3154 L
s
.491 1 0 r
.35551 .39918 m
.35795 .40055 L
s
.418 1 0 r
.4565 .65064 m
.45353 .65302 L
s
.45372 .64838 m
.4565 .65064 L
s
0 .995 1 r
.46935 .32103 m
.4705 .31795 L
s
.47029 .31222 m
.46935 .32103 L
s
.46935 .32103 m
.46532 .31449 L
s
.47547 .31567 m
.46935 .32103 L
s
.47465 .29105 m
.46935 .32103 L
s
0 .496 1 r
.51985 .81614 m
.51944 .82553 L
s
0 .049 1 r
.80633 .81909 m
.79997 .81524 L
s
.79997 .81524 m
.80242 .80883 L
s
0 1 .714 r
.6294 .72942 m
.63404 .73261 L
s
.62509 .73425 m
.6294 .72942 L
s
.6294 .72942 m
.62766 .73025 L
s
1 .257 0 r
.38973 .4818 m
.38877 .48244 L
s
.39024 .48193 m
.38973 .4818 L
s
.38973 .4818 m
.39005 .4832 L
s
.418 1 0 r
.45353 .65302 m
.45067 .65045 L
s
.45067 .65045 m
.45372 .64838 L
s
.7 0 1 r
.58022 .23911 m
.58401 .23468 L
s
.58285 .2259 m
.58022 .23911 L
s
.58022 .23911 m
.57601 .22869 L
s
.59083 .23186 m
.58022 .23911 L
s
.59644 .19439 m
.58022 .23911 L
s
1 .502 0 r
.42138 .56501 m
.42253 .56627 L
s
.42008 .56599 m
.42138 .56501 L
s
.42138 .56501 m
.42156 .56542 L
s
1 .257 0 r
.39005 .4832 m
.38928 .48258 L
s
.39005 .4832 m
.38877 .48244 L
s
.39024 .48193 m
.39005 .4832 L
s
.38735 .47814 m
.39005 .4832 L
s
.38877 .48244 m
.38928 .48258 L
s
1 0 .57 r
.3652 .97766 m
.357 .98338 L
s
.36121 .96898 m
.3652 .97766 L
s
1 .502 0 r
.42253 .56627 m
.42124 .56725 L
s
.42156 .56542 m
.42253 .56627 L
s
0 .512 1 r
.73065 .81876 m
.71846 .79592 L
s
0 1 .529 r
.39248 .734 m
.39998 .71461 L
s
0 .995 1 r
.47029 .31222 m
.46532 .31449 L
s
.47547 .31567 m
.47029 .31222 L
s
.491 1 0 r
.35795 .40055 m
.36091 .3984 L
s
.716 0 1 r
.32231 .88327 m
.32975 .89095 L
s
.31516 .88774 m
.32231 .88327 L
s
.32231 .88327 m
.32645 .88274 L
s
1 .502 0 r
.42124 .56725 m
.42008 .56599 L
s
.42008 .56599 m
.42156 .56542 L
s
1 .257 0 r
.38928 .48258 m
.39024 .48193 L
s
0 1 .588 r
.48649 .73198 m
.48626 .73914 L
s
1 .502 0 r
.42156 .56542 m
.42124 .56725 L
s
.7 0 1 r
.58285 .2259 m
.57601 .22869 L
s
.59083 .23186 m
.58285 .2259 L
s
0 .429 1 r
.66851 .81759 m
.66281 .82347 L
s
.66102 .81404 m
.66851 .81759 L
s
0 1 .714 r
.62973 .73745 m
.62509 .73425 L
s
.62509 .73425 m
.62766 .73025 L
s
.418 1 0 r
.45372 .64838 m
.45353 .65302 L
s
0 .005 1 r
.91691 .71718 m
.92189 .71956 L
s
.91174 .72502 m
.91691 .71718 L
s
.91691 .71718 m
.91052 .71765 L
s
.349 0 1 r
.69486 .89827 m
.69628 .90967 L
s
0 .794 1 r
.77296 .72461 m
.77783 .72733 L
s
.76852 .73083 m
.77296 .72461 L
s
.77296 .72461 m
.76914 .72547 L
s
0 .005 1 r
.9167 .72743 m
.91174 .72502 L
s
.91174 .72502 m
.91052 .71765 L
s
1 0 .894 r
.72118 .23389 m
.7283 .23059 L
s
.72621 .22016 m
.72118 .23389 L
s
.72118 .23389 m
.72009 .22253 L
s
.73441 .22818 m
.72118 .23389 L
s
.75198 .19068 m
.72118 .23389 L
s
.458 0 1 r
.43986 .23732 m
.44736 .23346 L
s
.107 1 0 r
.72582 .56298 m
.70397 .56036 L
s
.694 0 1 r
.55032 .98716 m
.55874 .95623 L
s
0 .794 1 r
.77339 .73356 m
.76852 .73083 L
s
.76852 .73083 m
.76914 .72547 L
s
.196 1 0 r
.59667 .64602 m
.59979 .64798 L
s
.59398 .64974 m
.59667 .64602 L
s
.59667 .64602 m
.59482 .64698 L
s
.28 1 0 r
.50098 .39604 m
.49842 .39691 L
s
.50423 .39848 m
.50098 .39604 L
s
.50098 .39604 m
.49977 .40127 L
s
.196 1 0 r
.5971 .65171 m
.59398 .64974 L
s
.59398 .64974 m
.59482 .64698 L
s
.458 0 1 r
.43259 .2328 m
.43986 .23732 L
s
.28 1 0 r
.49977 .40127 m
.50167 .39936 L
s
.49977 .40127 m
.49842 .39691 L
s
.50423 .39848 m
.49977 .40127 L
s
.5076 .38334 m
.49977 .40127 L
s
.716 0 1 r
.32975 .89095 m
.32262 .89546 L
s
.32645 .88274 m
.32975 .89095 L
s
0 .995 1 r
.4705 .31795 m
.47547 .31567 L
s
1 0 .894 r
.72621 .22016 m
.72009 .22253 L
s
.73441 .22818 m
.72621 .22016 L
s
0 .611 1 r
.61025 .31808 m
.61472 .31539 L
s
.61327 .30866 m
.61025 .31808 L
s
.61025 .31808 m
.60897 .31022 L
s
.61902 .31382 m
.61025 .31808 L
s
.62913 .28753 m
.61025 .31808 L
s
0 .048 1 r
.28829 .79801 m
.29459 .80448 L
s
.28243 .80123 m
.28829 .79801 L
s
.28829 .79801 m
.29229 .79691 L
s
.991 0 1 r
.50003 .97035 m
.5082 .97821 L
s
.4921 .97657 m
.50003 .97035 L
s
.50003 .97035 m
.5026 .97122 L
s
0 .429 1 r
.66102 .81404 m
.66281 .82347 L
s
0 1 .714 r
.63404 .73261 m
.62973 .73745 L
s
.62766 .73025 m
.63404 .73261 L
s
1 .961 0 r
.56505 .56637 m
.56339 .56559 L
s
.56339 .56559 m
.56414 .56296 L
s
.56339 .56559 m
.56254 .56433 L
s
0 .611 1 r
.61327 .30866 m
.60897 .31022 L
s
.61902 .31382 m
.61327 .30866 L
s
0 .604 1 r
.88428 .64285 m
.88098 .64125 L
s
.88098 .64125 m
.88448 .63392 L
s
.88098 .64125 m
.87777 .63529 L
s
.28 1 0 r
.50167 .39936 m
.50423 .39848 L
s
.034 0 1 r
.88409 .81621 m
.86118 .78934 L
s
0 1 .37 r
.54532 .7313 m
.54212 .7146 L
s
0 1 .436 r
.20655 .64639 m
.22594 .62687 L
s
0 1 .47 r
.74086 .64836 m
.73754 .64666 L
s
.73754 .64666 m
.74032 .64125 L
s
.73754 .64666 m
.73631 .64262 L
s
1 .81 0 r
.53341 .48189 m
.53355 .48187 L
s
.53355 .48187 m
.53206 .47995 L
s
.53355 .48187 m
.53084 .4824 L
s
.53206 .47995 m
.53192 .47997 L
s
.53206 .47995 m
.53084 .4824 L
s
1 .961 0 r
.56414 .56296 m
.5658 .56373 L
s
.56414 .56296 m
.56254 .56433 L
s
0 .604 1 r
.88448 .63392 m
.88779 .63549 L
s
.88448 .63392 m
.87777 .63529 L
s
0 1 .47 r
.74032 .64125 m
.74364 .64294 L
s
.74032 .64125 m
.73631 .64262 L
s
0 .049 1 r
.81219 .81203 m
.80633 .81909 L
s
.80242 .80883 m
.81219 .81203 L
s
0 .995 1 r
.46532 .31449 m
.4705 .31795 L
s
.7 0 1 r
.58401 .23468 m
.59083 .23186 L
s
0 1 .714 r
.62766 .73025 m
.62973 .73745 L
s
1 .81 0 r
.53084 .4824 m
.53341 .48189 L
s
.53084 .4824 m
.53192 .47997 L
s
.54031 .47498 m
.53084 .4824 L
s
0 .021 1 r
.75143 .31249 m
.75886 .3113 L
s
.75698 .30239 m
.75143 .31249 L
s
.75143 .31249 m
.75318 .30386 L
s
.76264 .3098 m
.75143 .31249 L
s
.78417 .28399 m
.75143 .31249 L
s
.196 1 0 r
.59979 .64798 m
.5971 .65171 L
s
.59482 .64698 m
.59979 .64798 L
s
0 1 .739 r
.13188 .37725 m
.12723 .38017 L
s
.12555 .37209 m
.13188 .37725 L
s
.13188 .37725 m
.12377 .37848 L
s
.12902 .37376 m
.13188 .37725 L
s
.1042 .37159 m
.13188 .37725 L
s
.107 1 0 r
.70883 .56367 m
.70706 .56282 L
s
.70706 .56282 m
.70787 .55811 L
s
.70706 .56282 m
.70397 .56036 L
s
0 1 .951 r
.85231 .55878 m
.85066 .55777 L
s
.85066 .55777 m
.85219 .55082 L
s
.85066 .55777 m
.84546 .5535 L
s
.196 1 0 r
.59482 .64698 m
.5971 .65171 L
s
0 .048 1 r
.29459 .80448 m
.28874 .80772 L
s
.29229 .79691 m
.29459 .80448 L
s
1 0 .57 r
.357 .98338 m
.34848 .97442 L
s
.34848 .97442 m
.36121 .96898 L
s
0 1 .348 r
.64421 .39182 m
.64226 .39249 L
s
.64779 .39635 m
.64421 .39182 L
s
.64421 .39182 m
.64091 .39801 L
s
1 .961 0 r
.5658 .56373 m
.56505 .56637 L
s
.56254 .56433 m
.56505 .56637 L
s
0 .021 1 r
.75698 .30239 m
.75318 .30386 L
s
.76264 .3098 m
.75698 .30239 L
s
0 .611 1 r
.61472 .31539 m
.61902 .31382 L
s
0 .833 1 r
.25464 .71299 m
.25975 .71832 L
s
.25031 .71496 m
.25464 .71299 L
s
.25464 .71299 m
.25878 .71159 L
s
1 0 .894 r
.7283 .23059 m
.73441 .22818 L
s
.28 1 0 r
.49842 .39691 m
.50167 .39936 L
s
0 1 .951 r
.87938 .55997 m
.84546 .5535 L
s
.624 0 1 r
.70357 .98491 m
.70237 .95379 L
s
.324 0 1 r
.3645 .89992 m
.38057 .86846 L
s
.107 1 0 r
.70787 .55811 m
.70965 .55895 L
s
.70787 .55811 m
.70397 .56036 L
s
.215 1 0 r
.67724 .47977 m
.67713 .47937 L
s
.67713 .47937 m
.67573 .47503 L
s
.67713 .47937 m
.67216 .47879 L
s
1 .961 0 r
.56254 .56433 m
.5658 .56373 L
s
0 1 .348 r
.64091 .39801 m
.64585 .39702 L
s
.64091 .39801 m
.64226 .39249 L
s
.64779 .39635 m
.64091 .39801 L
s
.66159 .38 m
.64091 .39801 L
s
.64585 .39702 m
.64779 .39635 L
s
0 .049 1 r
.80242 .80883 m
.80633 .81909 L
s
0 1 .951 r
.85219 .55082 m
.85385 .55181 L
s
.85219 .55082 m
.84546 .5535 L
s
0 1 .833 r
.82082 .47542 m
.82079 .47465 L
s
.82079 .47465 m
.82007 .46784 L
s
.82079 .47465 m
.8136 .47238 L
s
1 .81 0 r
.53192 .47997 m
.53341 .48189 L
s
.215 1 0 r
.67573 .47503 m
.67585 .47542 L
s
.67573 .47503 m
.67216 .47879 L
s
0 .021 1 r
.75886 .3113 m
.76264 .3098 L
s
0 .818 1 r
.78971 .39291 m
.79144 .39198 L
s
.79144 .39198 m
.78828 .38501 L
s
.79144 .39198 m
.78225 .39201 L
s
0 1 .739 r
.12377 .37848 m
.12723 .38017 L
s
.12555 .37209 m
.12377 .37848 L
s
0 .818 1 r
.78828 .38501 m
.78653 .38591 L
s
.78828 .38501 m
.78225 .39201 L
s
0 .794 1 r
.77783 .72733 m
.77339 .73356 L
s
.76914 .72547 m
.77783 .72733 L
s
.991 0 1 r
.5082 .97821 m
.50028 .98447 L
s
.5026 .97122 m
.5082 .97821 L
s
0 .833 1 r
.25975 .71832 m
.25544 .72031 L
s
.25878 .71159 m
.25975 .71832 L
s
.25 0 1 r
.46582 .88502 m
.47281 .89164 L
s
.45891 .89014 m
.46582 .88502 L
s
.46582 .88502 m
.46783 .88527 L
s
0 1 .833 r
.82007 .46784 m
.8201 .4686 L
s
.82007 .46784 m
.8136 .47238 L
s
0 .818 1 r
.78225 .39201 m
.78971 .39291 L
s
.78225 .39201 m
.78653 .38591 L
s
.81613 .37664 m
.78225 .39201 L
s
0 1 .436 r
.22134 .62814 m
.22525 .6326 L
s
.21885 .62897 m
.22134 .62814 L
s
.22134 .62814 m
.22594 .62687 L
s
.816 0 1 r
.64386 .96924 m
.65211 .97616 L
s
.63616 .97609 m
.64386 .96924 L
s
.64386 .96924 m
.64469 .97019 L
s
0 .794 1 r
.76914 .72547 m
.77339 .73356 L
s
0 1 .677 r
.6987 .72859 m
.68481 .71154 L
s
.42 1 0 r
.35933 .64352 m
.36697 .6301 L
s
0 1 .739 r
.12902 .37376 m
.12555 .37209 L
s
0 1 .024 r
.15712 .46265 m
.15893 .46327 L
s
.15648 .45764 m
.15712 .46265 L
s
.16246 .45961 m
.15712 .46265 L
s
.215 1 0 r
.67216 .47879 m
.67724 .47977 L
s
.67216 .47879 m
.67585 .47542 L
s
.69382 .47181 m
.67216 .47879 L
s
.7 0 1 r
.57601 .22869 m
.58401 .23468 L
s
0 1 .436 r
.22525 .6326 m
.22277 .63344 L
s
.22594 .62687 m
.22525 .6326 L
s
.716 0 1 r
.32262 .89546 m
.31516 .88774 L
s
.31516 .88774 m
.32645 .88274 L
s
.051 1 0 r
.19104 .54738 m
.19074 .54759 L
s
.18846 .54314 m
.19104 .54738 L
s
.19383 .54285 m
.19104 .54738 L
s
0 1 .024 r
.16246 .45961 m
.15893 .46327 L
s
.15648 .45764 m
.16246 .45961 L
s
.15828 .45825 m
.16246 .45961 L
s
.13856 .46384 m
.16246 .45961 L
s
.051 1 0 r
.18815 .54334 m
.18846 .54314 L
s
.18846 .54314 m
.19383 .54285 L
s
1 0 .57 r
.36121 .96898 m
.357 .98338 L
s
0 1 .47 r
.74364 .64294 m
.74086 .64836 L
s
.73631 .64262 m
.74086 .64836 L
s
.73631 .64262 m
.74364 .64294 L
s
0 1 .024 r
.15828 .45825 m
.15648 .45764 L
s
0 1 .833 r
.8136 .47238 m
.82082 .47542 L
s
.8136 .47238 m
.8201 .4686 L
s
.84787 .46863 m
.8136 .47238 L
s
0 .005 1 r
.91052 .71765 m
.9167 .72743 L
s
.91052 .71765 m
.92189 .71956 L
s
.107 1 0 r
.70397 .56036 m
.70883 .56367 L
s
.70397 .56036 m
.70965 .55895 L
s
0 .005 1 r
.92189 .71956 m
.9167 .72743 L
s
.107 1 0 r
.70965 .55895 m
.70883 .56367 L
s
0 .611 1 r
.60897 .31022 m
.61472 .31539 L
s
0 .046 1 r
.51769 .8975 m
.52367 .86963 L
s
0 1 .951 r
.84546 .5535 m
.85231 .55878 L
s
.84546 .5535 m
.85385 .55181 L
s
0 .604 1 r
.87777 .63529 m
.88428 .64285 L
s
.87777 .63529 m
.88779 .63549 L
s
.991 0 1 r
.50028 .98447 m
.4921 .97657 L
s
.4921 .97657 m
.5026 .97122 L
s
0 .742 1 r
.24182 .29966 m
.23802 .29898 L
s
.23869 .29064 m
.24182 .29966 L
s
.24182 .29966 m
.23335 .29615 L
s
.24337 .29346 m
.24182 .29966 L
s
.22432 .2751 m
.24182 .29966 L
s
.215 1 0 r
.67585 .47542 m
.67724 .47977 L
s
0 .048 1 r
.28874 .80772 m
.28243 .80123 L
s
.28243 .80123 m
.29229 .79691 L
s
0 .573 1 r
.43196 .79994 m
.43765 .80527 L
s
.42626 .80387 m
.43196 .79994 L
s
.43196 .79994 m
.43362 .7997 L
s
.25 0 1 r
.47281 .89164 m
.46591 .89678 L
s
.46783 .88527 m
.47281 .89164 L
s
0 1 .348 r
.64226 .39249 m
.64585 .39702 L
s
.051 1 0 r
.19383 .54285 m
.19074 .54759 L
s
.18815 .54334 m
.19383 .54285 L
s
.17268 .55544 m
.19383 .54285 L
s
0 .604 1 r
.88779 .63549 m
.88428 .64285 L
s
.716 0 1 r
.32645 .88274 m
.32262 .89546 L
s
0 1 .739 r
.12723 .38017 m
.12902 .37376 L
s
.627 1 0 r
.51265 .64065 m
.509 .63037 L
s
0 .653 1 r
.85262 .72586 m
.82764 .70543 L
s
1 0 .894 r
.72009 .22253 m
.7283 .23059 L
s
.092 0 1 r
.60985 .88409 m
.61686 .8898 L
s
.60314 .88998 m
.60985 .88409 L
s
.60985 .88409 m
.61001 .8846 L
s
0 .833 1 r
.25544 .72031 m
.25031 .71496 L
s
.25031 .71496 m
.25878 .71159 L
s
0 1 .951 r
.85385 .55181 m
.85231 .55878 L
s
0 1 .024 r
.15893 .46327 m
.15828 .45825 L
s
0 1 .436 r
.22594 .62687 m
.22277 .63344 L
s
.21885 .62897 m
.22594 .62687 L
s
0 .048 1 r
.29229 .79691 m
.28874 .80772 L
s
.816 0 1 r
.65211 .97616 m
.64441 .98304 L
s
.64469 .97019 m
.65211 .97616 L
s
0 1 .833 r
.8201 .4686 m
.82082 .47542 L
s
.816 0 1 r
.64441 .98304 m
.63616 .97609 L
s
.63616 .97609 m
.64469 .97019 L
s
0 .742 1 r
.23869 .29064 m
.23335 .29615 L
s
.24337 .29346 m
.23869 .29064 L
s
0 .833 1 r
.25878 .71159 m
.25544 .72031 L
s
.25 0 1 r
.46591 .89678 m
.45891 .89014 L
s
.45891 .89014 m
.46783 .88527 L
s
0 1 .436 r
.22277 .63344 m
.21885 .62897 L
s
.051 1 0 r
.19074 .54759 m
.18815 .54334 L
s
.607 0 1 r
.35301 .22077 m
.35111 .21706 L
s
.35204 .20746 m
.35301 .22077 L
s
.35301 .22077 m
.34396 .21268 L
s
.3592 .21182 m
.35301 .22077 L
s
.34575 .17757 m
.35301 .22077 L
s
0 .021 1 r
.75318 .30386 m
.75886 .3113 L
s
0 .573 1 r
.43765 .80527 m
.43196 .80922 L
s
.43362 .7997 m
.43765 .80527 L
s
0 1 .529 r
.39847 .71515 m
.40276 .7192 L
s
.39418 .71783 m
.39847 .71515 L
s
.39847 .71515 m
.39998 .71461 L
s
0 .818 1 r
.78653 .38591 m
.78971 .39291 L
s
0 .461 1 r
.33116 .80979 m
.34605 .78195 L
s
0 .085 1 r
.67143 .89508 m
.66741 .86758 L
s
.091 1 0 r
.272 .38095 m
.26922 .38116 L
s
.26939 .37568 m
.272 .38095 L
s
.272 .38095 m
.26643 .3795 L
s
.27219 .37732 m
.272 .38095 L
s
.25844 .3682 m
.272 .38095 L
s
.991 0 1 r
.5026 .97122 m
.50028 .98447 L
s
0 .742 1 r
.23335 .29615 m
.23802 .29898 L
s
.238 0 1 r
.75429 .88045 m
.76154 .88538 L
s
.74758 .88725 m
.75429 .88045 L
s
.75429 .88045 m
.75257 .88074 L
s
0 1 .529 r
.40276 .7192 m
.39847 .72189 L
s
.39998 .71461 m
.40276 .7192 L
s
0 .573 1 r
.43196 .80922 m
.42626 .80387 L
s
.42626 .80387 m
.43362 .7997 L
s
.42 1 0 r
.36536 .6307 m
.36816 .6335 L
s
.3627 .63208 m
.36536 .6307 L
s
.36536 .6307 m
.36697 .6301 L
s
.091 1 0 r
.26939 .37568 m
.26643 .3795 L
s
.27219 .37732 m
.26939 .37568 L
s
.15 1 0 r
.66652 .63777 m
.65165 .62768 L
s
1 .737 0 r
.32594 .5524 m
.33461 .54625 L
s
.607 0 1 r
.35204 .20746 m
.34396 .21268 L
s
.3592 .21182 m
.35204 .20746 L
s
0 .723 1 r
.57615 .79917 m
.58179 .80361 L
s
.57062 .804 m
.57615 .79917 L
s
.57615 .79917 m
.57581 .79937 L
s
.091 1 0 r
.26643 .3795 m
.26922 .38116 L
s
.092 0 1 r
.61015 .8957 m
.60314 .88998 L
s
.60314 .88998 m
.61001 .8846 L
s
.25 0 1 r
.46783 .88527 m
.46591 .89678 L
s
.092 0 1 r
.61686 .8898 m
.61015 .8957 L
s
.61001 .8846 m
.61686 .8898 L
s
.42 1 0 r
.36816 .6335 m
.3655 .63489 L
s
.36697 .6301 m
.36816 .6335 L
s
1 .832 0 r
.30294 .46317 m
.30102 .46413 L
s
.30063 .4612 m
.30294 .46317 L
s
.30294 .46317 m
.29993 .46358 L
s
.30172 .46175 m
.30294 .46317 L
s
.29231 .46063 m
.30294 .46317 L
s
.29993 .46358 m
.30102 .46413 L
s
.30063 .4612 m
.29993 .46358 L
s
1 .737 0 r
.33261 .54639 m
.33388 .54829 L
s
.33186 .54668 m
.33261 .54639 L
s
.33261 .54639 m
.33461 .54625 L
s
.33388 .54829 m
.33313 .54858 L
s
.33461 .54625 m
.33388 .54829 L
s
0 .9 1 r
.38281 .30085 m
.38192 .29843 L
s
.38244 .29167 m
.38281 .30085 L
s
.38281 .30085 m
.37687 .29519 L
s
.38749 .2949 m
.38281 .30085 L
s
.37961 .27153 m
.38281 .30085 L
s
1 .832 0 r
.30172 .46175 m
.30063 .4612 L
s
0 1 .529 r
.39847 .72189 m
.39418 .71783 L
s
.39418 .71783 m
.39998 .71461 L
s
0 .742 1 r
.23802 .29898 m
.24337 .29346 L
s
.21 0 1 r
.82572 .89265 m
.81138 .86232 L
s
0 .874 1 r
.48484 .80721 m
.48912 .78341 L
s
.238 0 1 r
.75482 .89221 m
.74758 .88725 L
s
.74758 .88725 m
.75257 .88074 L
s
.816 0 1 r
.64469 .97019 m
.64441 .98304 L
s
0 .573 1 r
.43362 .7997 m
.43196 .80922 L
s
.719 0 1 r
.49457 .21956 m
.49617 .21513 L
s
.49594 .20596 m
.49457 .21956 L
s
.49457 .21956 m
.48825 .2097 L
s
.50385 .21137 m
.49457 .21956 L
s
.5021 .1738 m
.49457 .21956 L
s
.42 1 0 r
.3655 .63489 m
.3627 .63208 L
s
.3627 .63208 m
.36697 .6301 L
s
0 .512 1 r
.72078 .7957 m
.72661 .79945 L
s
.71524 .80163 m
.72078 .7957 L
s
.72078 .7957 m
.71846 .79592 L
s
.091 1 0 r
.26922 .38116 m
.27219 .37732 L
s
1 .737 0 r
.33461 .54625 m
.33313 .54858 L
s
.33186 .54668 m
.33461 .54625 L
s
0 1 .37 r
.54277 .71455 m
.54692 .7177 L
s
.53862 .71823 m
.54277 .71455 L
s
.54277 .71455 m
.54212 .7146 L
s
0 .723 1 r
.57626 .80845 m
.57062 .804 L
s
.57062 .804 m
.57581 .79937 L
s
0 .9 1 r
.38244 .29167 m
.37687 .29519 L
s
.38749 .2949 m
.38244 .29167 L
s
1 .832 0 r
.30102 .46413 m
.30172 .46175 L
s
1 .737 0 r
.33313 .54858 m
.33186 .54668 L
s
.034 0 1 r
.8658 .78953 m
.87184 .79274 L
s
.85979 .79678 m
.8658 .78953 L
s
.8658 .78953 m
.86118 .78934 L
s
0 1 .529 r
.39998 .71461 m
.39847 .72189 L
s
0 .723 1 r
.58179 .80361 m
.57626 .80845 L
s
.57581 .79937 m
.58179 .80361 L
s
.42 1 0 r
.36697 .6301 m
.3655 .63489 L
s
0 1 .701 r
.82093 .63488 m
.79453 .62202 L
s
1 .319 0 r
.47975 .54936 m
.47647 .5468 L
s
1 0 .743 r
.30284 .97695 m
.32744 .93818 L
s
.607 0 1 r
.34396 .21268 m
.35111 .21706 L
s
.719 0 1 r
.49594 .20596 m
.48825 .2097 L
s
.50385 .21137 m
.49594 .20596 L
s
.298 1 0 r
.41335 .38195 m
.41323 .38052 L
s
.41342 .37655 m
.41335 .38195 L
s
.41335 .38195 m
.41019 .37847 L
s
.41646 .3786 m
.41335 .38195 L
s
.41323 .3648 m
.41335 .38195 L
s
.092 0 1 r
.61001 .8846 m
.61015 .8957 L
s
0 .512 1 r
.72107 .80539 m
.71524 .80163 L
s
.71524 .80163 m
.71846 .79592 L
s
.238 0 1 r
.76154 .88538 m
.75482 .89221 L
s
.75257 .88074 m
.76154 .88538 L
s
.034 0 1 r
.86582 .80002 m
.85979 .79678 L
s
.85979 .79678 m
.86118 .78934 L
s
0 1 .37 r
.54277 .72139 m
.53862 .71823 L
s
.53862 .71823 m
.54212 .7146 L
s
1 0 .95 r
.41179 .95547 m
.42 .96361 L
s
.40402 .96093 m
.41179 .95547 L
s
.41179 .95547 m
.41568 .95537 L
s
.607 0 1 r
.35111 .21706 m
.3592 .21182 L
s
.298 1 0 r
.41342 .37655 m
.41019 .37847 L
s
.41646 .3786 m
.41342 .37655 L
s
.627 1 0 r
.50975 .6303 m
.5123 .63215 L
s
.50717 .63273 m
.50975 .6303 L
s
.50975 .6303 m
.509 .63037 L
s
0 .881 1 r
.63907 .80461 m
.63291 .78173 L
s
0 1 .719 r
.29758 .71902 m
.31215 .69594 L
s
1 0 .982 r
.63671 .21578 m
.64182 .2118 L
s
.6404 .20172 m
.63671 .21578 L
s
.63671 .21578 m
.63339 .20464 L
s
.64882 .20885 m
.63671 .21578 L
s
.65902 .17001 m
.63671 .21578 L
s
0 1 .37 r
.54692 .7177 m
.54277 .72139 L
s
.54212 .7146 m
.54692 .7177 L
s
0 1 .677 r
.68752 .71119 m
.69184 .71376 L
s
.68338 .71619 m
.68752 .71119 L
s
.68752 .71119 m
.68481 .71154 L
s
0 .698 1 r
.52471 .2994 m
.52713 .29654 L
s
.52656 .2898 m
.52471 .2994 L
s
.52471 .2994 m
.5214 .29209 L
s
.53227 .29424 m
.52471 .2994 L
s
.53546 .26793 m
.52471 .2994 L
s
0 .9 1 r
.37687 .29519 m
.38192 .29843 L
s
.627 1 0 r
.50972 .63458 m
.50717 .63273 L
s
.50717 .63273 m
.509 .63037 L
s
0 .9 1 r
.38192 .29843 m
.38749 .2949 L
s
0 .723 1 r
.57581 .79937 m
.57626 .80845 L
s
0 .653 1 r
.83276 .70514 m
.8372 .70735 L
s
.82816 .71173 m
.83276 .70514 L
s
.83276 .70514 m
.82764 .70543 L
s
0 1 .677 r
.68769 .71877 m
.68338 .71619 L
s
.68338 .71619 m
.68481 .71154 L
s
1 .437 0 r
.44492 .46201 m
.44387 .46244 L
s
.44609 .46286 m
.44492 .46201 L
s
.44492 .46201 m
.44458 .46396 L
s
.44458 .46396 m
.44505 .46329 L
s
.44458 .46396 m
.44387 .46244 L
s
.44609 .46286 m
.44458 .46396 L
s
.44661 .45741 m
.44458 .46396 L
s
.627 1 0 r
.5123 .63215 m
.50972 .63458 L
s
.509 .63037 m
.5123 .63215 L
s
0 .698 1 r
.52656 .2898 m
.5214 .29209 L
s
.53227 .29424 m
.52656 .2898 L
s
1 .319 0 r
.47706 .54646 m
.47797 .54703 L
s
.47629 .54759 m
.47706 .54646 L
s
.47706 .54646 m
.47647 .5468 L
s
.4772 .54816 m
.47629 .54759 L
s
.47629 .54759 m
.47647 .5468 L
s
0 .653 1 r
.83258 .71396 m
.82816 .71173 L
s
.82816 .71173 m
.82764 .70543 L
s
.298 1 0 r
.41323 .38052 m
.41646 .3786 L
s
.808 1 0 r
.6341 .5463 m
.61903 .54445 L
s
.7 0 1 r
.45688 .97466 m
.47135 .94092 L
s
1 0 .982 r
.6404 .20172 m
.63339 .20464 L
s
.64882 .20885 m
.6404 .20172 L
s
.298 1 0 r
.41019 .37847 m
.41323 .38052 L
s
1 .437 0 r
.44505 .46329 m
.44609 .46286 L
s
.238 0 1 r
.75257 .88074 m
.75482 .89221 L
s
0 1 .37 r
.54212 .7146 m
.54277 .72139 L
s
0 .512 1 r
.72661 .79945 m
.72107 .80539 L
s
.71846 .79592 m
.72661 .79945 L
s
1 .319 0 r
.47797 .54703 m
.4772 .54816 L
s
.47647 .5468 m
.47797 .54703 L
s
.47647 .5468 m
.4772 .54816 L
s
1 .437 0 r
.44387 .46244 m
.44505 .46329 L
s
.627 1 0 r
.509 .63037 m
.50972 .63458 L
s
1 0 .95 r
.42 .96361 m
.41224 .96911 L
s
.41568 .95537 m
.42 .96361 L
s
.15 1 0 r
.65453 .62696 m
.65726 .62842 L
s
.65203 .631 m
.65453 .62696 L
s
.65453 .62696 m
.65165 .62768 L
s
.324 0 1 r
.37713 .86923 m
.38422 .87612 L
s
.37041 .87352 m
.37713 .86923 L
s
.37713 .86923 m
.38057 .86846 L
s
.15 1 0 r
.65475 .63247 m
.65203 .631 L
s
.65203 .631 m
.65165 .62768 L
s
.719 0 1 r
.49617 .21513 m
.50385 .21137 L
s
0 .243 1 r
.66712 .29529 m
.67275 .29326 L
s
.6713 .28506 m
.66712 .29529 L
s
.66712 .29529 m
.66673 .28686 L
s
.67731 .29144 m
.66712 .29529 L
s
.69187 .26433 m
.66712 .29529 L
s
0 1 .075 r
.55552 .38022 m
.55855 .37877 L
s
.55769 .37418 m
.55552 .38022 L
s
.55552 .38022 m
.55492 .37523 L
s
.56132 .37771 m
.55552 .38022 L
s
.56858 .36139 m
.55552 .38022 L
s
.55769 .37418 m
.55492 .37523 L
s
.56132 .37771 m
.55769 .37418 L
s
0 1 .211 r
.45175 .71626 m
.45514 .69766 L
s
0 .501 1 r
.79385 .80201 m
.77701 .77692 L
s
0 1 .701 r
.79974 .62827 m
.79697 .62691 L
s
.79697 .62691 m
.79991 .62094 L
s
.79697 .62691 m
.79453 .62202 L
s
.79991 .62094 m
.80269 .62228 L
s
.79991 .62094 m
.79453 .62202 L
s
.808 1 0 r
.62235 .54673 m
.62119 .54615 L
s
.62119 .54615 m
.62175 .54292 L
s
.62119 .54615 m
.61903 .54445 L
s
0 .698 1 r
.52713 .29654 m
.53227 .29424 L
s
0 .512 1 r
.71846 .79592 m
.72107 .80539 L
s
0 .243 1 r
.6713 .28506 m
.66673 .28686 L
s
.67731 .29144 m
.6713 .28506 L
s
.808 1 0 r
.62175 .54292 m
.62291 .54349 L
s
.62175 .54292 m
.61903 .54445 L
s
0 1 .677 r
.69184 .71376 m
.68769 .71877 L
s
.68481 .71154 m
.69184 .71376 L
s
.776 1 0 r
.59037 .46203 m
.59096 .46172 L
s
.59096 .46172 m
.58937 .45873 L
s
.59096 .46172 m
.58697 .46193 L
s
0 1 .075 r
.55855 .37877 m
.56132 .37771 L
s
.719 0 1 r
.48825 .2097 m
.49617 .21513 L
s
.776 1 0 r
.58937 .45873 m
.58878 .45905 L
s
.58937 .45873 m
.58697 .46193 L
s
.694 0 1 r
.55681 .95594 m
.56479 .96303 L
s
.54928 .96197 m
.55681 .95594 L
s
.55681 .95594 m
.55874 .95623 L
s
.034 0 1 r
.87184 .79274 m
.86582 .80002 L
s
.86118 .78934 m
.87184 .79274 L
s
1 0 .982 r
.64182 .2118 m
.64882 .20885 L
s
0 1 .247 r
.7674 .54318 m
.76626 .5424 L
s
.76626 .5424 m
.76723 .53686 L
s
.76626 .5424 m
.76188 .53921 L
s
.776 1 0 r
.58697 .46193 m
.59037 .46203 L
s
.58697 .46193 m
.58878 .45905 L
s
.60146 .45418 m
.58697 .46193 L
s
0 1 .247 r
.78901 .54323 m
.76188 .53921 L
s
.573 0 1 r
.26906 .88653 m
.292 .85031 L
s
.443 0 1 r
.61147 .97236 m
.61607 .94037 L
s
0 1 .677 r
.68481 .71154 m
.68769 .71877 L
s
0 1 .247 r
.76723 .53686 m
.76837 .53762 L
s
.76723 .53686 m
.76188 .53921 L
s
0 .243 1 r
.67275 .29326 m
.67731 .29144 L
s
.324 0 1 r
.38422 .87612 m
.37751 .88044 L
s
.38057 .86846 m
.38422 .87612 L
s
0 1 .775 r
.69814 .37575 m
.70401 .3756 L
s
.70276 .36884 m
.69814 .37575 L
s
.69814 .37575 m
.70037 .36982 L
s
.70639 .3746 m
.69814 .37575 L
s
.72449 .35797 m
.69814 .37575 L
s
0 1 .229 r
.73554 .4589 m
.73604 .45827 L
s
.73604 .45827 m
.73477 .45283 L
s
.73604 .45827 m
.72974 .45709 L
s
0 1 .775 r
.70276 .36884 m
.70037 .36982 L
s
.70639 .3746 m
.70276 .36884 L
s
0 .461 1 r
.34282 .78321 m
.3487 .78885 L
s
.33738 .78627 m
.34282 .78321 L
s
.34282 .78321 m
.34605 .78195 L
s
0 1 .775 r
.70401 .3756 m
.70639 .3746 L
s
.15 1 0 r
.65726 .62842 m
.65475 .63247 L
s
.65165 .62768 m
.65726 .62842 L
s
.034 0 1 r
.86118 .78934 m
.86582 .80002 L
s
0 .698 1 r
.5214 .29209 m
.52713 .29654 L
s
.15 1 0 r
.65165 .62768 m
.65475 .63247 L
s
0 1 .229 r
.73477 .45283 m
.73426 .45344 L
s
.73477 .45283 m
.72974 .45709 L
s
.808 1 0 r
.61903 .54445 m
.62235 .54673 L
s
.61903 .54445 m
.62291 .54349 L
s
.62291 .54349 m
.62235 .54673 L
s
1 0 .95 r
.41224 .96911 m
.40402 .96093 L
s
.40402 .96093 m
.41568 .95537 L
s
.223 0 1 r
.94918 .7994 m
.92102 .76896 L
s
0 1 .241 r
.60647 .7135 m
.59891 .69634 L
s
.059 1 0 r
.26376 .6276 m
.27892 .61053 L
s
0 1 .075 r
.55492 .37523 m
.55855 .37877 L
s
0 .653 1 r
.8372 .70735 m
.83258 .71396 L
s
.82764 .70543 m
.8372 .70735 L
s
0 1 .229 r
.72974 .45709 m
.73554 .4589 L
s
.72974 .45709 m
.73426 .45344 L
s
.75687 .45093 m
.72974 .45709 L
s
.776 1 0 r
.58878 .45905 m
.59037 .46203 L
s
0 1 .548 r
.18356 .35887 m
.17954 .36084 L
s
.17856 .35312 m
.18356 .35887 L
s
.18356 .35887 m
.17591 .35887 L
s
.1822 .35509 m
.18356 .35887 L
s
.16082 .34936 m
.18356 .35887 L
s
0 .653 1 r
.82764 .70543 m
.83258 .71396 L
s
.624 0 1 r
.70228 .95366 m
.71038 .95982 L
s
.69484 .96037 m
.70228 .95366 L
s
.70228 .95366 m
.70237 .95379 L
s
0 .461 1 r
.3487 .78885 m
.34327 .79194 L
s
.34605 .78195 m
.3487 .78885 L
s
0 1 .719 r
.30886 .69744 m
.31349 .70191 L
s
.30494 .69925 m
.30886 .69744 L
s
.30886 .69744 m
.31215 .69594 L
s
0 1 .247 r
.76188 .53921 m
.7674 .54318 L
s
.76188 .53921 m
.76837 .53762 L
s
0 1 .701 r
.79453 .62202 m
.79974 .62827 L
s
.79453 .62202 m
.80269 .62228 L
s
0 .046 1 r
.52235 .86987 m
.52911 .8757 L
s
.51582 .87484 m
.52235 .86987 L
s
.52235 .86987 m
.52367 .86963 L
s
.694 0 1 r
.56479 .96303 m
.55726 .96909 L
s
.55874 .95623 m
.56479 .96303 L
s
.5 0 1 r
.76662 .97005 m
.76119 .9365 L
s
0 .034 1 r
.4236 .88407 m
.4359 .85332 L
s
1 0 .982 r
.63339 .20464 m
.64182 .2118 L
s
0 1 .701 r
.80269 .62228 m
.79974 .62827 L
s
.324 0 1 r
.37751 .88044 m
.37041 .87352 L
s
.37041 .87352 m
.38057 .86846 L
s
0 1 .719 r
.31349 .70191 m
.30958 .70373 L
s
.31215 .69594 m
.31349 .70191 L
s
0 1 .247 r
.76837 .53762 m
.7674 .54318 L
s
0 1 .548 r
.17591 .35887 m
.17954 .36084 L
s
.17856 .35312 m
.17591 .35887 L
s
1 0 .95 r
.41568 .95537 m
.41224 .96911 L
s
.059 1 0 r
.27523 .61186 m
.27861 .61539 L
s
.27314 .61252 m
.27523 .61186 L
s
.27523 .61186 m
.27892 .61053 L
s
.694 0 1 r
.55726 .96909 m
.54928 .96197 L
s
.54928 .96197 m
.55874 .95623 L
s
0 .243 1 r
.66673 .28686 m
.67275 .29326 L
s
0 1 .548 r
.1822 .35509 m
.17856 .35312 L
s
.343 1 0 r
.21459 .4419 m
.21171 .44462 L
s
.20982 .43954 m
.21459 .4419 L
s
.21459 .4419 m
.20963 .44382 L
s
.2119 .44033 m
.21459 .4419 L
s
.19538 .44277 m
.21459 .4419 L
s
0 1 .229 r
.73426 .45344 m
.73554 .4589 L
s
.059 1 0 r
.27861 .61539 m
.27652 .61606 L
s
.27892 .61053 m
.27861 .61539 L
s
0 1 .749 r
.76174 .71072 m
.74308 .69195 L
s
.781 1 0 r
.41842 .62467 m
.42175 .6125 L
s
.343 1 0 r
.20963 .44382 m
.21171 .44462 L
s
.20982 .43954 m
.20963 .44382 L
s
.555 1 0 r
.24397 .52939 m
.2441 .52948 L
s
.24199 .52604 m
.24397 .52939 L
s
.24638 .52582 m
.24397 .52939 L
s
0 1 .775 r
.70037 .36982 m
.70401 .3756 L
s
.555 1 0 r
.24212 .52613 m
.24199 .52604 L
s
.24199 .52604 m
.24638 .52582 L
s
0 .461 1 r
.34327 .79194 m
.33738 .78627 L
s
.33738 .78627 m
.34605 .78195 L
s
.343 1 0 r
.2119 .44033 m
.20982 .43954 L
s
0 .642 1 r
.29494 .27947 m
.29216 .27816 L
s
.29286 .26977 m
.29494 .27947 L
s
.29494 .27947 m
.28699 .27485 L
s
.29804 .27307 m
.29494 .27947 L
s
.28267 .25161 m
.29494 .27947 L
s
0 .874 1 r
.48822 .78403 m
.49362 .78857 L
s
.48289 .78785 m
.48822 .78403 L
s
.48822 .78403 m
.48912 .78341 L
s
0 .046 1 r
.52911 .8757 m
.52258 .88069 L
s
.52367 .86963 m
.52911 .8757 L
s
0 .085 1 r
.66806 .86777 m
.67486 .87272 L
s
.66159 .87358 m
.66806 .86777 L
s
.66806 .86777 m
.66741 .86758 L
s
.324 0 1 r
.38057 .86846 m
.37751 .88044 L
s
.624 0 1 r
.70295 .96656 m
.69484 .96037 L
s
.69484 .96037 m
.70237 .95379 L
s
.555 1 0 r
.24638 .52582 m
.2441 .52948 L
s
.24212 .52613 m
.24638 .52582 L
s
.22969 .53552 m
.24638 .52582 L
s
0 .291 1 r
.57868 .8816 m
.58069 .85312 L
s
0 .138 1 r
.23505 .79546 m
.25719 .76287 L
s
0 1 .719 r
.30958 .70373 m
.30494 .69925 L
s
.30494 .69925 m
.31215 .69594 L
s
.624 0 1 r
.71038 .95982 m
.70295 .96656 L
s
.70237 .95379 m
.71038 .95982 L
s
0 .046 1 r
.52258 .88069 m
.51582 .87484 L
s
.51582 .87484 m
.52367 .86963 L
s
0 1 .548 r
.17954 .36084 m
.1822 .35509 L
s
.21 0 1 r
.81414 .86292 m
.82116 .86714 L
s
.80741 .86976 m
.81414 .86292 L
s
.81414 .86292 m
.81138 .86232 L
s
.343 1 0 r
.21171 .44462 m
.2119 .44033 L
s
.826 0 1 r
.40747 .19882 m
.40687 .1948 L
s
.40743 .18472 m
.40747 .19882 L
s
.40747 .19882 m
.39904 .18968 L
s
.41526 .18981 m
.40747 .19882 L
s
.40587 .15279 m
.40747 .19882 L
s
0 .461 1 r
.34605 .78195 m
.34327 .79194 L
s
.059 1 0 r
.27892 .61053 m
.27652 .61606 L
s
.27314 .61252 m
.27892 .61053 L
s
.27652 .61606 m
.27314 .61252 L
s
.694 0 1 r
.55874 .95623 m
.55726 .96909 L
s
0 1 .719 r
.31215 .69594 m
.30958 .70373 L
s
0 .642 1 r
.29286 .26977 m
.28699 .27485 L
s
.29804 .27307 m
.29286 .26977 L
s
.696 1 0 r
.57364 .62173 m
.56545 .61149 L
s
0 .401 1 r
.91758 .70794 m
.88722 .68449 L
s
.555 1 0 r
.2441 .52948 m
.24212 .52613 L
s
0 1 .211 r
.45445 .6985 m
.45839 .70173 L
s
.45052 .70109 m
.45445 .6985 L
s
.45445 .6985 m
.45514 .69766 L
s
0 .874 1 r
.49362 .78857 m
.48829 .79241 L
s
.48912 .78341 m
.49362 .78857 L
s
.041 1 0 r
.32556 .3614 m
.32371 .36107 L
s
.324 .35557 m
.32556 .3614 L
s
.32556 .3614 m
.3205 .35897 L
s
.32722 .35767 m
.32556 .3614 L
s
.31698 .34589 m
.32556 .3614 L
s
1 0 .743 r
.32196 .93938 m
.33051 .94792 L
s
.31438 .94411 m
.32196 .93938 L
s
.32196 .93938 m
.32744 .93818 L
s
0 .085 1 r
.6684 .87855 m
.66159 .87358 L
s
.66159 .87358 m
.66741 .86758 L
s
0 .874 1 r
.48829 .79241 m
.48289 .78785 L
s
.48289 .78785 m
.48912 .78341 L
s
0 .881 1 r
.63411 .78209 m
.63949 .78579 L
s
.62882 .78691 m
.63411 .78209 L
s
.63411 .78209 m
.63291 .78173 L
s
0 .187 1 r
.73433 .87912 m
.72597 .84967 L
s
0 .836 1 r
.39008 .79283 m
.40102 .76612 L
s
.21 0 1 r
.81442 .874 m
.80741 .86976 L
s
.80741 .86976 m
.81138 .86232 L
s
.826 0 1 r
.40743 .18472 m
.39904 .18968 L
s
.41526 .18981 m
.40743 .18472 L
s
0 .642 1 r
.28699 .27485 m
.29216 .27816 L
s
0 1 .211 r
.45839 .70173 m
.45446 .70433 L
s
.45514 .69766 m
.45839 .70173 L
s
0 .046 1 r
.52367 .86963 m
.52258 .88069 L
s
.781 1 0 r
.42104 .61333 m
.42343 .61526 L
s
.41873 .61461 m
.42104 .61333 L
s
.42104 .61333 m
.42175 .6125 L
s
.041 1 0 r
.324 .35557 m
.3205 .35897 L
s
.32722 .35767 m
.324 .35557 L
s
0 .085 1 r
.67486 .87272 m
.6684 .87855 L
s
.66741 .86758 m
.67486 .87272 L
s
.223 0 1 r
.92707 .76998 m
.93272 .7726 L
s
.92068 .77758 m
.92707 .76998 L
s
.92707 .76998 m
.92102 .76896 L
s
0 1 .211 r
.45446 .70433 m
.45052 .70109 L
s
.45052 .70109 m
.45514 .69766 L
s
0 .501 1 r
.78044 .77739 m
.78596 .78049 L
s
.77488 .78347 m
.78044 .77739 L
s
.78044 .77739 m
.77701 .77692 L
s
0 .66 1 r
.4377 .2795 m
.43804 .27697 L
s
.43824 .26956 m
.4377 .2795 L
s
.4377 .2795 m
.43238 .27292 L
s
.4439 .27359 m
.4377 .2795 L
s
.43991 .24795 m
.4377 .2795 L
s
1 .707 0 r
.35693 .44427 m
.35582 .44467 L
s
.35568 .44196 m
.35693 .44427 L
s
.35693 .44427 m
.3544 .4438 L
s
.3571 .44283 m
.35693 .44427 L
s
.35104 .43949 m
.35693 .44427 L
s
.624 0 1 r
.70237 .95379 m
.70295 .96656 L
s
.041 1 0 r
.3205 .35897 m
.32371 .36107 L
s
.781 1 0 r
.42343 .61526 m
.42112 .61655 L
s
.42175 .6125 m
.42343 .61526 L
s
1 0 .993 r
.55068 .19647 m
.55365 .19221 L
s
.55303 .18202 m
.55068 .19647 L
s
.55068 .19647 m
.54515 .18574 L
s
.56152 .18846 m
.55068 .19647 L
s
.56419 .14893 m
.55068 .19647 L
s
1 .268 0 r
.38485 .53241 m
.389 .528 L
s
0 1 .031 r
.72941 .61878 m
.70961 .6075 L
s
1 0 .743 r
.33051 .94792 m
.32296 .9527 L
s
.32744 .93818 m
.33051 .94792 L
s
0 .881 1 r
.6342 .79063 m
.62882 .78691 L
s
.62882 .78691 m
.63291 .78173 L
s
0 .642 1 r
.29216 .27816 m
.29804 .27307 L
s
1 .268 0 r
.38792 .5284 m
.38879 .52929 L
s
.38755 .52847 m
.38792 .5284 L
s
.38792 .5284 m
.389 .528 L
s
1 .707 0 r
.35568 .44196 m
.3544 .4438 L
s
.3571 .44283 m
.35568 .44196 L
s
0 .874 1 r
.48912 .78341 m
.48829 .79241 L
s
.573 0 1 r
.28682 .85219 m
.29436 .85954 L
s
.28036 .8557 m
.28682 .85219 L
s
.28682 .85219 m
.292 .85031 L
s
1 .268 0 r
.38879 .52929 m
.38842 .52936 L
s
.389 .528 m
.38879 .52929 L
s
1 .707 0 r
.3544 .4438 m
.35582 .44467 L
s
.223 0 1 r
.92631 .78023 m
.92068 .77758 L
s
.92068 .77758 m
.92102 .76896 L
s
0 1 .241 r
.60047 .69669 m
.60431 .69914 L
s
.59657 .70044 m
.60047 .69669 L
s
.60047 .69669 m
.59891 .69634 L
s
.781 1 0 r
.42112 .61655 m
.41873 .61461 L
s
.41873 .61461 m
.42175 .6125 L
s
0 .501 1 r
.78038 .78658 m
.77488 .78347 L
s
.77488 .78347 m
.77701 .77692 L
s
.041 1 0 r
.32371 .36107 m
.32722 .35767 L
s
1 .268 0 r
.389 .528 m
.38842 .52936 L
s
.38755 .52847 m
.389 .528 L
s
0 .66 1 r
.43824 .26956 m
.43238 .27292 L
s
.4439 .27359 m
.43824 .26956 L
s
1 .268 0 r
.38842 .52936 m
.38755 .52847 L
s
0 1 .211 r
.45514 .69766 m
.45446 .70433 L
s
1 .707 0 r
.35582 .44467 m
.3571 .44283 L
s
0 .881 1 r
.63949 .78579 m
.6342 .79063 L
s
.63291 .78173 m
.63949 .78579 L
s
.279 0 1 r
.89054 .87663 m
.87131 .84299 L
s
0 1 .885 r
.54566 .79018 m
.54582 .76624 L
s
0 .833 1 r
.20079 .70374 m
.22305 .67596 L
s
.781 1 0 r
.42175 .6125 m
.42112 .61655 L
s
.21 0 1 r
.82116 .86714 m
.81442 .874 L
s
.81138 .86232 m
.82116 .86714 L
s
1 0 .993 r
.55303 .18202 m
.54515 .18574 L
s
.56152 .18846 m
.55303 .18202 L
s
1 0 .634 r
.69432 .19154 m
.70075 .18816 L
s
.69923 .17663 m
.69432 .19154 L
s
.69432 .19154 m
.69196 .17973 L
s
.70799 .18503 m
.69432 .19154 L
s
.7231 .14505 m
.69432 .19154 L
s
0 .085 1 r
.66741 .86758 m
.6684 .87855 L
s
0 1 .241 r
.60039 .70291 m
.59657 .70044 L
s
.59657 .70044 m
.59891 .69634 L
s
.02 1 0 r
.46865 .3612 m
.46969 .35987 L
s
.46962 .35508 m
.46865 .3612 L
s
.46865 .3612 m
.46612 .35694 L
s
.47319 .358 m
.46865 .3612 L
s
.47371 .34241 m
.46865 .3612 L
s
0 1 .749 r
.74697 .69207 m
.75088 .69409 L
s
.7428 .69736 m
.74697 .69207 L
s
.74697 .69207 m
.74308 .69195 L
s
0 .401 1 r
.89386 .68477 m
.89779 .68651 L
s
.88887 .69188 m
.89386 .68477 L
s
.89386 .68477 m
.88722 .68449 L
s
.573 0 1 r
.29436 .85954 m
.28793 .86308 L
s
.292 .85031 m
.29436 .85954 L
s
.826 0 1 r
.40687 .1948 m
.41526 .18981 L
s
0 .401 1 r
.89279 .69365 m
.88887 .69188 L
s
.88887 .69188 m
.88722 .68449 L
s
.696 1 0 r
.56717 .6116 m
.56934 .61284 L
s
.56485 .61425 m
.56717 .6116 L
s
.56717 .6116 m
.56545 .61149 L
s
.826 0 1 r
.39904 .18968 m
.40687 .1948 L
s
0 .138 1 r
.25202 .7652 m
.25852 .7714 L
s
.24694 .76746 m
.25202 .7652 L
s
.25202 .7652 m
.25719 .76287 L
s
0 .366 1 r
.58123 .27688 m
.58488 .27441 L
s
.5841 .26646 m
.58123 .27688 L
s
.58123 .27688 m
.57872 .26884 L
s
.59026 .272 m
.58123 .27688 L
s
.59772 .24427 m
.58123 .27688 L
s
.02 1 0 r
.46962 .35508 m
.46612 .35694 L
s
.47319 .358 m
.46962 .35508 L
s
0 1 .749 r
.7467 .69939 m
.7428 .69736 L
s
.7428 .69736 m
.74308 .69195 L
s
.7 0 1 r
.46812 .94146 m
.47606 .9488 L
s
.46076 .9467 m
.46812 .94146 L
s
.46812 .94146 m
.47135 .94092 L
s
0 .959 1 r
.88575 .61582 m
.85383 .60052 L
s
1 .485 0 r
.54057 .5293 m
.53256 .52729 L
s
.853 0 1 r
.36158 .9619 m
.38254 .92425 L
s
.696 1 0 r
.56702 .61549 m
.56485 .61425 L
s
.56485 .61425 m
.56545 .61149 L
s
0 1 .241 r
.60431 .69914 m
.60039 .70291 L
s
.59891 .69634 m
.60431 .69914 L
s
0 .881 1 r
.63291 .78173 m
.6342 .79063 L
s
0 .66 1 r
.43804 .27697 m
.4439 .27359 L
s
1 0 .634 r
.69923 .17663 m
.69196 .17973 L
s
.70799 .18503 m
.69923 .17663 L
s
1 .819 0 r
.50028 .44383 m
.50179 .44354 L
s
.50156 .44107 m
.50028 .44383 L
s
.50028 .44383 m
.50022 .44166 L
s
.50313 .44296 m
.50028 .44383 L
s
.50726 .43619 m
.50028 .44383 L
s
.21 0 1 r
.81138 .86232 m
.81442 .874 L
s
1 .485 0 r
.53416 .52867 m
.53369 .52839 L
s
.53369 .52839 m
.53416 .52671 L
s
.53369 .52839 m
.53256 .52729 L
s
0 .366 1 r
.5841 .26646 m
.57872 .26884 L
s
.59026 .272 m
.5841 .26646 L
s
1 .819 0 r
.50156 .44107 m
.50022 .44166 L
s
.50313 .44296 m
.50156 .44107 L
s
1 .485 0 r
.53416 .52671 m
.53463 .52699 L
s
.53416 .52671 m
.53256 .52729 L
s
.02 1 0 r
.46969 .35987 m
.47319 .358 L
s
0 .66 1 r
.43238 .27292 m
.43804 .27697 L
s
1 .819 0 r
.50179 .44354 m
.50313 .44296 L
s
0 .959 1 r
.85966 .60751 m
.8575 .60641 L
s
.8575 .60641 m
.86081 .59968 L
s
.8575 .60641 m
.85383 .60052 L
s
0 .501 1 r
.78596 .78049 m
.78038 .78658 L
s
.77701 .77692 m
.78596 .78049 L
s
0 .138 1 r
.25852 .7714 m
.25345 .77369 L
s
.25719 .76287 m
.25852 .7714 L
s
.16 0 1 r
.72511 .27158 m
.73186 .27035 L
s
.73062 .26057 m
.72511 .27158 L
s
.72511 .27158 m
.72568 .26263 L
s
.73679 .26826 m
.72511 .27158 L
s
.75611 .24058 m
.72511 .27158 L
s
0 1 .031 r
.71343 .6126 m
.71121 .6115 L
s
.71121 .6115 m
.71374 .60693 L
s
.71121 .6115 m
.70961 .6075 L
s
.71374 .60693 m
.71597 .60803 L
s
.71374 .60693 m
.70961 .6075 L
s
0 1 .241 r
.59891 .69634 m
.60039 .70291 L
s
.696 1 0 r
.56934 .61284 m
.56702 .61549 L
s
.56545 .61149 m
.56934 .61284 L
s
0 .95 1 r
.70181 .78753 m
.69118 .7632 L
s
0 1 .311 r
.35631 .70093 m
.36675 .67943 L
s
0 .833 1 r
.21756 .67837 m
.223 .68363 L
s
.21416 .67944 m
.21756 .67837 L
s
.21756 .67837 m
.22305 .67596 L
s
0 .959 1 r
.86081 .59968 m
.86297 .60076 L
s
.86081 .59968 m
.85383 .60052 L
s
1 0 .993 r
.55365 .19221 m
.56152 .18846 L
s
1 0 .743 r
.32296 .9527 m
.31438 .94411 L
s
.31438 .94411 m
.32744 .93818 L
s
0 1 .474 r
.61243 .35827 m
.61652 .35743 L
s
.61573 .35143 m
.61243 .35827 L
s
.61243 .35827 m
.61262 .35271 L
s
.61962 .35614 m
.61243 .35827 L
s
.631 .33892 m
.61243 .35827 L
s
1 .485 0 r
.53256 .52729 m
.53416 .52867 L
s
.53256 .52729 m
.53463 .52699 L
s
.696 1 0 r
.56545 .61149 m
.56702 .61549 L
s
.02 1 0 r
.46612 .35694 m
.46969 .35987 L
s
1 .485 0 r
.53463 .52699 m
.53416 .52867 L
s
.447 1 0 r
.68069 .52648 m
.68013 .52595 L
s
.68013 .52595 m
.68071 .52187 L
s
.68013 .52595 m
.67666 .52368 L
s
0 1 .474 r
.61573 .35143 m
.61262 .35271 L
s
.61962 .35614 m
.61573 .35143 L
s
1 .819 0 r
.50022 .44166 m
.50179 .44354 L
s
0 1 .688 r
.82704 .52199 m
.82659 .52123 L
s
.82659 .52123 m
.82786 .51468 L
s
.82659 .52123 m
.82089 .51716 L
s
0 .833 1 r
.223 .68363 m
.21961 .68472 L
s
.22305 .67596 m
.223 .68363 L
s
.16 0 1 r
.73062 .26057 m
.72568 .26263 L
s
.73679 .26826 m
.73062 .26057 L
s
0 .366 1 r
.58488 .27441 m
.59026 .272 L
s
0 .501 1 r
.77701 .77692 m
.78038 .78658 L
s
0 1 .588 r
.12503 .41938 m
.12123 .42405 L
s
.11749 .41677 m
.12503 .41938 L
s
.12503 .41938 m
.11805 .42311 L
s
.12068 .4177 m
.12503 .41938 L
s
.09651 .42456 m
.12503 .41938 L
s
.447 1 0 r
.68071 .52187 m
.68127 .52239 L
s
.68071 .52187 m
.67666 .52368 L
s
.7 0 1 r
.47606 .9488 m
.46872 .95407 L
s
.47135 .94092 m
.47606 .9488 L
s
.314 1 0 r
.64846 .4414 m
.64958 .44081 L
s
.64958 .44081 m
.64795 .43668 L
s
.64958 .44081 m
.64425 .44057 L
s
1 0 .634 r
.70075 .18816 m
.70799 .18503 L
s
0 .034 1 r
.43319 .85444 m
.43995 .86052 L
s
.42687 .85855 m
.43319 .85444 L
s
.43319 .85444 m
.4359 .85332 L
s
.223 0 1 r
.93272 .7726 m
.92631 .78023 L
s
.92102 .76896 m
.93272 .7726 L
s
0 1 .474 r
.61652 .35743 m
.61962 .35614 L
s
.447 1 0 r
.69685 .52617 m
.67666 .52368 L
s
.389 0 1 r
.51754 .95956 m
.52823 .9256 L
s
0 1 .588 r
.11805 .42311 m
.12123 .42405 L
s
.11749 .41677 m
.11805 .42311 L
s
0 1 .59 r
.18342 .59155 m
.18778 .59632 L
s
.18211 .5917 m
.18342 .59155 L
s
.18342 .59155 m
.18962 .58968 L
s
.314 1 0 r
.64795 .43668 m
.64682 .43726 L
s
.64795 .43668 m
.64425 .44057 L
s
0 1 .59 r
.18778 .59632 m
.18648 .59649 L
s
.18962 .58968 m
.18778 .59632 L
s
0 .76 1 r
.7565 .35259 m
.76327 .35338 L
s
.76258 .345 m
.7565 .35259 L
s
.7565 .35259 m
.75966 .34628 L
s
.76618 .35208 m
.7565 .35259 L
s
.78887 .33542 m
.7565 .35259 L
s
0 1 .688 r
.82786 .51468 m
.82831 .51542 L
s
.82786 .51468 m
.82089 .51716 L
s
.223 0 1 r
.92102 .76896 m
.92631 .78023 L
s
0 1 .329 r
.15274 .50951 m
.15386 .50954 L
s
.14987 .50436 m
.15274 .50951 L
s
.15693 .50412 m
.15274 .50951 L
s
0 1 .749 r
.75088 .69409 m
.7467 .69939 L
s
.74308 .69195 m
.75088 .69409 L
s
0 1 .723 r
.79495 .43726 m
.79613 .43642 L
s
.79613 .43642 m
.79506 .42975 L
s
.79613 .43642 m
.78843 .43448 L
s
.314 1 0 r
.64425 .44057 m
.64846 .4414 L
s
.64425 .44057 m
.64682 .43726 L
s
.66404 .43288 m
.64425 .44057 L
s
.16 0 1 r
.73186 .27035 m
.73679 .26826 L
s
0 .76 1 r
.76327 .35338 m
.76618 .35208 L
s
.76618 .35208 m
.76258 .345 L
s
.443 0 1 r
.61484 .94078 m
.62264 .94706 L
s
.60763 .94663 m
.61484 .94078 L
s
.61484 .94078 m
.61607 .94037 L
s
0 .76 1 r
.76258 .345 m
.75966 .34628 L
s
0 1 .749 r
.74308 .69195 m
.7467 .69939 L
s
.573 0 1 r
.28793 .86308 m
.28036 .8557 L
s
.28036 .8557 m
.292 .85031 L
s
0 1 .723 r
.79506 .42975 m
.79387 .43057 L
s
.79506 .42975 m
.78843 .43448 L
s
1 0 .993 r
.54515 .18574 m
.55365 .19221 L
s
0 1 .329 r
.15099 .50437 m
.14987 .50436 L
s
.14987 .50436 m
.15693 .50412 L
s
1 0 .743 r
.32744 .93818 m
.32296 .9527 L
s
.447 1 0 r
.67666 .52368 m
.68069 .52648 L
s
.67666 .52368 m
.68127 .52239 L
s
0 1 .588 r
.12068 .4177 m
.11749 .41677 L
s
0 1 .723 r
.78843 .43448 m
.79495 .43726 L
s
.78843 .43448 m
.79387 .43057 L
s
.8214 .42956 m
.78843 .43448 L
s
0 .401 1 r
.88722 .68449 m
.89279 .69365 L
s
.88722 .68449 m
.89779 .68651 L
s
.029 1 0 r
.5124 .69811 m
.51149 .67984 L
s
0 .384 1 r
.85852 .78487 m
.83669 .75701 L
s
0 1 .59 r
.16628 .61135 m
.18962 .58968 L
s
0 1 .329 r
.15693 .50412 m
.15386 .50954 L
s
.15099 .50437 m
.15693 .50412 L
s
.13152 .5183 m
.15693 .50412 L
s
0 1 .031 r
.70961 .6075 m
.71343 .6126 L
s
.70961 .6075 m
.71597 .60803 L
s
.71597 .60803 m
.71343 .6126 L
s
0 1 .688 r
.82089 .51716 m
.82704 .52199 L
s
.82089 .51716 m
.82831 .51542 L
s
.85369 .52303 m
.82089 .51716 L
s
0 .959 1 r
.85383 .60052 m
.85966 .60751 L
s
.85383 .60052 m
.86297 .60076 L
s
0 .401 1 r
.89779 .68651 m
.89279 .69365 L
s
0 .366 1 r
.57872 .26884 m
.58488 .27441 L
s
.447 1 0 r
.68127 .52239 m
.68069 .52648 L
s
0 .034 1 r
.43995 .86052 m
.43365 .86465 L
s
.4359 .85332 m
.43995 .86052 L
s
.7 0 1 r
.46872 .95407 m
.46076 .9467 L
s
.46076 .9467 m
.47135 .94092 L
s
.573 0 1 r
.292 .85031 m
.28793 .86308 L
s
0 .836 1 r
.39859 .76765 m
.40409 .77246 L
s
.39353 .77055 m
.39859 .76765 L
s
.39859 .76765 m
.40102 .76612 L
s
0 .138 1 r
.25345 .77369 m
.24694 .76746 L
s
.24694 .76746 m
.25719 .76287 L
s
.5 0 1 r
.76198 .9373 m
.76992 .94267 L
s
.75466 .9439 m
.76198 .9373 L
s
.76198 .9373 m
.76119 .9365 L
s
0 1 .59 r
.18962 .58968 m
.18648 .59649 L
s
.18211 .5917 m
.18962 .58968 L
s
.314 1 0 r
.64682 .43726 m
.64846 .4414 L
s
0 1 .474 r
.61262 .35271 m
.61652 .35743 L
s
.154 0 1 r
.32762 .87037 m
.34674 .83567 L
s
.25 0 1 r
.67406 .9572 m
.67457 .92362 L
s
0 .138 1 r
.25719 .76287 m
.25345 .77369 L
s
0 .833 1 r
.22305 .67596 m
.21961 .68472 L
s
.21416 .67944 m
.22305 .67596 L
s
0 1 .588 r
.12123 .42405 m
.12068 .4177 L
s
0 .959 1 r
.86297 .60076 m
.85966 .60751 L
s
0 .291 1 r
.58015 .85394 m
.58666 .85897 L
s
.57391 .85878 m
.58015 .85394 L
s
.58015 .85394 m
.58069 .85312 L
s
0 .833 1 r
.21961 .68472 m
.21416 .67944 L
s
1 0 .634 r
.69196 .17973 m
.70075 .18816 L
s
0 1 .464 r
.23647 .33961 m
.23318 .34079 L
s
.23274 .33327 m
.23647 .33961 L
s
.23647 .33961 m
.22931 .33845 L
s
.23662 .3356 m
.23647 .33961 L
s
.21879 .3266 m
.23647 .33961 L
s
0 1 .329 r
.15386 .50954 m
.15099 .50437 L
s
.443 0 1 r
.62264 .94706 m
.61543 .95294 L
s
.61607 .94037 m
.62264 .94706 L
s
0 1 .688 r
.82831 .51542 m
.82704 .52199 L
s
0 1 .226 r
.66906 .69528 m
.65687 .67718 L
s
.518 1 0 r
.32231 .60837 m
.33312 .59333 L
s
0 .836 1 r
.40409 .77246 m
.39904 .77537 L
s
.40102 .76612 m
.40409 .77246 L
s
0 1 .311 r
.36433 .68114 m
.36852 .68471 L
s
.36077 .68278 m
.36433 .68114 L
s
.36433 .68114 m
.36675 .67943 L
s
0 1 .59 r
.18648 .59649 m
.18211 .5917 L
s
0 .034 1 r
.43365 .86465 m
.42687 .85855 L
s
.42687 .85855 m
.4359 .85332 L
s
.443 0 1 r
.61543 .95294 m
.60763 .94663 L
s
.60763 .94663 m
.61607 .94037 L
s
0 1 .723 r
.79387 .43057 m
.79495 .43726 L
s
.16 0 1 r
.72568 .26263 m
.73186 .27035 L
s
.7 0 1 r
.47135 .94092 m
.46872 .95407 L
s
0 .76 1 r
.75966 .34628 m
.76327 .35338 L
s
.5 0 1 r
.7626 .9493 m
.75466 .9439 L
s
.75466 .9439 m
.76119 .9365 L
s
.459 0 1 r
.83115 .95484 m
.82115 .9183 L
s
0 .349 1 r
.48408 .86784 m
.49246 .83731 L
s
0 1 .311 r
.36852 .68471 m
.36497 .68637 L
s
.36675 .67943 m
.36852 .68471 L
s
0 .187 1 r
.72756 .85064 m
.73413 .85483 L
s
.72119 .85642 m
.72756 .85064 L
s
.72756 .85064 m
.72597 .84967 L
s
.518 1 0 r
.33037 .59483 m
.33326 .5974 L
s
.32863 .59529 m
.33037 .59483 L
s
.33037 .59483 m
.33312 .59333 L
s
.598 1 0 r
.26794 .42332 m
.26574 .42528 L
s
.26441 .42053 m
.26794 .42332 L
s
.26794 .42332 m
.26341 .42418 L
s
.26674 .42162 m
.26794 .42332 L
s
.25355 .42121 m
.26794 .42332 L
s
0 1 .464 r
.23274 .33327 m
.22931 .33845 L
s
.23662 .3356 m
.23274 .33327 L
s
0 .836 1 r
.39904 .77537 m
.39353 .77055 L
s
.39353 .77055 m
.40102 .76612 L
s
0 1 .464 r
.22931 .33845 m
.23318 .34079 L
s
0 1 .885 r
.54576 .76732 m
.55086 .77107 L
s
.54071 .77107 m
.54576 .76732 L
s
.54576 .76732 m
.54582 .76624 L
s
.279 0 1 r
.8753 .84453 m
.88205 .84805 L
s
.86835 .85151 m
.8753 .84453 L
s
.8753 .84453 m
.87131 .84299 L
s
.518 1 0 r
.33326 .5974 m
.33153 .59785 L
s
.33312 .59333 m
.33326 .5974 L
s
0 .478 1 r
.34927 .25839 m
.34762 .25663 L
s
.34822 .24797 m
.34927 .25839 L
s
.34927 .25839 m
.34189 .25271 L
s
.35396 .25187 m
.34927 .25839 L
s
.34242 .22756 m
.34927 .25839 L
s
0 .291 1 r
.58666 .85897 m
.58043 .86383 L
s
.58069 .85312 m
.58666 .85897 L
s
.598 1 0 r
.26341 .42418 m
.26574 .42528 L
s
.26441 .42053 m
.26341 .42418 L
s
0 .034 1 r
.4359 .85332 m
.43365 .86465 L
s
1 .984 0 r
.29817 .51062 m
.29877 .51061 L
s
.29673 .50812 m
.29817 .51062 L
s
.30017 .50793 m
.29817 .51062 L
s
0 .291 1 r
.58043 .86383 m
.57391 .85878 L
s
.57391 .85878 m
.58069 .85312 L
s
0 1 .939 r
.82628 .69244 m
.80247 .67144 L
s
1 .969 0 r
.4789 .60537 m
.47773 .59401 L
s
.5 0 1 r
.76992 .94267 m
.7626 .9493 L
s
.76119 .9365 m
.76992 .94267 L
s
1 .984 0 r
.29733 .50811 m
.29673 .50812 L
s
.29673 .50812 m
.30017 .50793 L
s
.598 1 0 r
.26674 .42162 m
.26441 .42053 L
s
1 .984 0 r
.30017 .50793 m
.29877 .51061 L
s
.29733 .50811 m
.30017 .50793 L
s
.28805 .51513 m
.30017 .50793 L
s
0 1 .311 r
.36497 .68637 m
.36077 .68278 L
s
.36077 .68278 m
.36675 .67943 L
s
1 0 .923 r
.46312 .17596 m
.46389 .17182 L
s
.46405 .16102 m
.46312 .17596 L
s
.46312 .17596 m
.45538 .16582 L
s
.47255 .16698 m
.46312 .17596 L
s
.46743 .12742 m
.46312 .17596 L
s
.443 0 1 r
.61607 .94037 m
.61543 .95294 L
s
0 .836 1 r
.40102 .76612 m
.39904 .77537 L
s
0 .187 1 r
.72776 .86064 m
.72119 .85642 L
s
.72119 .85642 m
.72597 .84967 L
s
.279 0 1 r
.87508 .85506 m
.86835 .85151 L
s
.86835 .85151 m
.87131 .84299 L
s
.518 1 0 r
.33312 .59333 m
.33153 .59785 L
s
.32863 .59529 m
.33312 .59333 L
s
0 .47 1 r
.64111 .86531 m
.63891 .83571 L
s
0 .582 1 r
.29342 .77816 m
.31155 .74751 L
s
.518 1 0 r
.33153 .59785 m
.32863 .59529 L
s
.598 1 0 r
.26574 .42528 m
.26674 .42162 L
s
0 1 .464 r
.23318 .34079 m
.23662 .3356 L
s
.029 1 0 r
.51172 .68102 m
.51529 .68345 L
s
.50805 .68358 m
.51172 .68102 L
s
.51172 .68102 m
.51149 .67984 L
s
0 1 .311 r
.36675 .67943 m
.36497 .68637 L
s
0 .95 1 r
.6934 .76416 m
.69847 .76716 L
s
.68819 .76906 m
.6934 .76416 L
s
.6934 .76416 m
.69118 .7632 L
s
1 .984 0 r
.29877 .51061 m
.29733 .50811 L
s
0 .478 1 r
.34822 .24797 m
.34189 .25271 L
s
.35396 .25187 m
.34822 .24797 L
s
0 1 .885 r
.54582 .77483 m
.54071 .77107 L
s
.54071 .77107 m
.54582 .76624 L
s
.55086 .77107 m
.54582 .77483 L
s
.54582 .76624 m
.55086 .77107 L
s
0 1 .115 r
.38034 .34095 m
.37952 .34032 L
s
.37979 .33448 m
.38034 .34095 L
s
.38034 .34095 m
.37583 .33759 L
s
.38349 .33721 m
.38034 .34095 L
s
.37692 .32305 m
.38034 .34095 L
s
0 .384 1 r
.84143 .7582 m
.84656 .76067 L
s
.83562 .76456 m
.84143 .7582 L
s
.84143 .7582 m
.83669 .75701 L
s
.853 0 1 r
.37776 .92576 m
.38596 .93348 L
s
.37063 .93025 m
.37776 .92576 L
s
.37776 .92576 m
.38254 .92425 L
s
.595 1 0 r
.63606 .60236 m
.62307 .59171 L
s
1 0 .923 r
.46405 .16102 m
.45538 .16582 L
s
.47255 .16698 m
.46405 .16102 L
s
0 .187 1 r
.73413 .85483 m
.72776 .86064 L
s
.72597 .84967 m
.73413 .85483 L
s
0 .291 1 r
.58069 .85312 m
.58043 .86383 L
s
.5 0 1 r
.76119 .9365 m
.7626 .9493 L
s
1 0 .678 r
.60795 .17246 m
.6123 .16853 L
s
.61141 .15714 m
.60795 .17246 L
s
.60795 .17246 m
.60329 .16092 L
s
.6204 .16472 m
.60795 .17246 L
s
.62778 .12346 m
.60795 .17246 L
s
0 .95 1 r
.69325 .77207 m
.68819 .76906 L
s
.68819 .76906 m
.69118 .7632 L
s
.029 1 0 r
.51163 .68602 m
.50805 .68358 L
s
.50805 .68358 m
.51149 .67984 L
s
1 .969 0 r
.47805 .59509 m
.47998 .5962 L
s
.47595 .59638 m
.47805 .59509 L
s
.47805 .59509 m
.47773 .59401 L
s
0 .376 1 r
.49379 .25725 m
.49539 .25478 L
s
.4953 .24651 m
.49379 .25725 L
s
.49379 .25725 m
.48916 .2498 L
s
.50152 .25147 m
.49379 .25725 L
s
.50165 .22381 m
.49379 .25725 L
s
.029 1 0 r
.51529 .68345 m
.51163 .68602 L
s
.51149 .67984 m
.51529 .68345 L
s
0 1 .115 r
.37979 .33448 m
.37583 .33759 L
s
.38349 .33721 m
.37979 .33448 L
s
0 .384 1 r
.84074 .76705 m
.83562 .76456 L
s
.83562 .76456 m
.83669 .75701 L
s
1 .822 0 r
.41212 .42447 m
.4119 .42468 L
s
.41196 .42163 m
.41212 .42447 L
s
.41212 .42447 m
.41015 .42319 L
s
.41372 .42311 m
.41212 .42447 L
s
.41116 .41785 m
.41212 .42447 L
s
0 .478 1 r
.34189 .25271 m
.34762 .25663 L
s
0 1 .226 r
.65953 .67792 m
.66296 .67975 L
s
.65568 .68189 m
.65953 .67792 L
s
.65953 .67792 m
.65687 .67718 L
s
0 1 .837 r
.45039 .77547 m
.45723 .74942 L
s
0 .197 1 r
.79872 .86278 m
.78568 .83086 L
s
0 1 .885 r
.54582 .76624 m
.54582 .77483 L
s
1 .969 0 r
.47789 .59749 m
.47595 .59638 L
s
.47595 .59638 m
.47773 .59401 L
s
0 .478 1 r
.34762 .25663 m
.35396 .25187 L
s
1 .969 0 r
.47998 .5962 m
.47789 .59749 L
s
.47773 .59401 m
.47998 .5962 L
s
1 .822 0 r
.41196 .42163 m
.41015 .42319 L
s
.41372 .42311 m
.41196 .42163 L
s
0 1 .115 r
.37583 .33759 m
.37952 .34032 L
s
1 0 0 r
.44494 .50958 m
.44512 .50934 L
s
.4443 .50962 m
.44494 .50958 L
s
.44494 .50958 m
.4446 .50886 L
s
0 1 .226 r
.65911 .68373 m
.65568 .68189 L
s
.65568 .68189 m
.65687 .67718 L
s
.279 0 1 r
.88205 .84805 m
.87508 .85506 L
s
.87131 .84299 m
.88205 .84805 L
s
1 0 0 r
.4446 .50886 m
.44449 .50938 L
s
.4446 .50886 m
.44512 .50934 L
s
.4443 .50962 m
.4446 .50886 L
s
.44515 .51195 m
.4446 .50886 L
s
.44449 .50938 m
.4443 .50962 L
s
0 1 .939 r
.80777 .67201 m
.81118 .67355 L
s
.80335 .67777 m
.80777 .67201 L
s
.80777 .67201 m
.80247 .67144 L
s
0 .376 1 r
.4953 .24651 m
.48916 .2498 L
s
.50152 .25147 m
.4953 .24651 L
s
.853 0 1 r
.38596 .93348 m
.37885 .93801 L
s
.38254 .92425 m
.38596 .93348 L
s
0 1 .115 r
.37952 .34032 m
.38349 .33721 L
s
.029 1 0 r
.51149 .67984 m
.51163 .68602 L
s
1 0 0 r
.44512 .50934 m
.44449 .50938 L
s
1 .822 0 r
.41015 .42319 m
.4119 .42468 L
s
0 .95 1 r
.69847 .76716 m
.69325 .77207 L
s
.69118 .7632 m
.69847 .76716 L
s
0 .187 1 r
.72597 .84967 m
.72776 .86064 L
s
1 .822 0 r
.4119 .42468 m
.41372 .42311 L
s
1 0 .678 r
.61141 .15714 m
.60329 .16092 L
s
.6204 .16472 m
.61141 .15714 L
s
.154 0 1 r
.34233 .83777 m
.34946 .84427 L
s
.33629 .84107 m
.34233 .83777 L
s
.34233 .83777 m
.34674 .83567 L
s
0 1 .939 r
.80675 .67932 m
.80335 .67777 L
s
.80335 .67777 m
.80247 .67144 L
s
0 1 .32 r
.52515 .33956 m
.52732 .33852 L
s
.52713 .33264 m
.52515 .33956 L
s
.52515 .33956 m
.52331 .33456 L
s
.53115 .33659 m
.52515 .33956 L
s
.53563 .31949 m
.52515 .33956 L
s
1 .969 0 r
.47773 .59401 m
.47789 .59749 L
s
0 1 .336 r
.7938 .59934 m
.76871 .58641 L
s
1 0 .832 r
.26437 .94889 m
.29238 .90621 L
s
0 0 1 r
.63891 .25344 m
.64378 .25151 L
s
.64296 .24218 m
.63891 .25344 L
s
.63891 .25344 m
.63726 .24473 L
s
.64947 .24894 m
.63891 .25344 L
s
.66148 .22004 m
.63891 .25344 L
s
.595 1 0 r
.62597 .5919 m
.62765 .5927 L
s
.62371 .59499 m
.62597 .5919 L
s
.62597 .5919 m
.62307 .59171 L
s
.62538 .59579 m
.62371 .59499 L
s
.62371 .59499 m
.62307 .59171 L
s
1 0 .923 r
.46389 .17182 m
.47255 .16698 L
s
0 1 .32 r
.52713 .33264 m
.52331 .33456 L
s
.53115 .33659 m
.52713 .33264 L
s
.279 0 1 r
.87131 .84299 m
.87508 .85506 L
s
0 .95 1 r
.69118 .7632 m
.69325 .77207 L
s
0 1 .336 r
.77317 .59207 m
.77155 .59123 L
s
.77155 .59123 m
.77431 .58594 L
s
.77155 .59123 m
.76871 .58641 L
s
.455 0 1 r
.95689 .86023 m
.93234 .82275 L
s
0 1 .724 r
.60793 .77276 m
.60372 .74818 L
s
0 1 .689 r
.25896 .68529 m
.27701 .65987 L
s
.389 0 1 r
.52571 .92671 m
.53341 .93321 L
s
.51871 .93173 m
.52571 .92671 L
s
.52571 .92671 m
.52823 .9256 L
s
0 1 .226 r
.66296 .67975 m
.65911 .68373 L
s
.65687 .67718 m
.66296 .67975 L
s
.732 1 0 r
.55717 .4228 m
.55962 .42306 L
s
.55958 .41923 m
.55717 .4228 L
s
.55717 .4228 m
.55779 .42003 L
s
.56141 .42225 m
.55717 .4228 L
s
.56935 .41447 m
.55717 .4228 L
s
0 1 .336 r
.77431 .58594 m
.77593 .58676 L
s
.77431 .58594 m
.76871 .58641 L
s
1 .875 0 r
.59219 .50871 m
.59229 .50842 L
s
.59229 .50842 m
.59266 .50581 L
s
.59229 .50842 m
.58983 .50688 L
s
0 .376 1 r
.49539 .25478 m
.50152 .25147 L
s
1 0 .923 r
.45538 .16582 m
.46389 .17182 L
s
0 0 1 r
.64296 .24218 m
.63726 .24473 L
s
.64947 .24894 m
.64296 .24218 L
s
1 .875 0 r
.59266 .50581 m
.59257 .5061 L
s
.59266 .50581 m
.58983 .50688 L
s
.154 0 1 r
.34946 .84427 m
.34344 .84759 L
s
.34674 .83567 m
.34946 .84427 L
s
.732 1 0 r
.55958 .41923 m
.55779 .42003 L
s
.56141 .42225 m
.55958 .41923 L
s
0 .384 1 r
.84656 .76067 m
.84074 .76705 L
s
.83669 .75701 m
.84656 .76067 L
s
.732 1 0 r
.55962 .42306 m
.56141 .42225 L
s
0 1 .32 r
.52732 .33852 m
.53115 .33659 L
s
0 1 .909 r
.6705 .33541 m
.6756 .33531 L
s
.67509 .32778 m
.6705 .33541 L
s
.6705 .33541 m
.67154 .32932 L
s
.67914 .33376 m
.6705 .33541 L
s
.69492 .31591 m
.6705 .33541 L
s
0 .582 1 r
.30723 .74998 m
.31325 .7553 L
s
.30255 .75205 m
.30723 .74998 L
s
.30723 .74998 m
.31155 .74751 L
s
1 0 .678 r
.6123 .16853 m
.6204 .16472 L
s
0 1 .226 r
.65687 .67718 m
.65911 .68373 L
s
0 1 0 r
.74014 .50555 m
.74024 .50498 L
s
.74024 .50498 m
.74098 .49986 L
s
.74024 .50498 m
.73543 .50199 L
s
1 .875 0 r
.58983 .50688 m
.59219 .50871 L
s
.58983 .50688 m
.59257 .5061 L
s
.60283 .50876 m
.58983 .50688 L
s
0 .384 1 r
.83669 .75701 m
.84074 .76705 L
s
.595 1 0 r
.62765 .5927 m
.62538 .59579 L
s
.62307 .59171 m
.62765 .5927 L
s
0 .376 1 r
.48916 .2498 m
.49539 .25478 L
s
.483 0 1 r
.42172 .9465 m
.4389 .90946 L
s
.595 1 0 r
.62307 .59171 m
.62538 .59579 L
s
0 1 .909 r
.67509 .32778 m
.67154 .32932 L
s
.67914 .33376 m
.67509 .32778 L
s
0 1 0 r
.74098 .49986 m
.74088 .50042 L
s
.74098 .49986 m
.73543 .50199 L
s
0 0 1 r
.64378 .25151 m
.64947 .24894 L
s
0 1 .183 r
.7077 .41997 m
.70942 .41913 L
s
.70942 .41913 m
.70781 .41375 L
s
.70942 .41913 m
.70268 .4183 L
s
.853 0 1 r
.37885 .93801 m
.37063 .93025 L
s
.37063 .93025 m
.38254 .92425 L
s
0 1 .909 r
.6756 .33531 m
.67914 .33376 L
s
1 .875 0 r
.59257 .5061 m
.59219 .50871 L
s
0 1 .183 r
.70268 .4183 m
.7077 .41997 L
s
.70781 .41375 m
.70268 .4183 L
s
.70268 .4183 m
.70608 .41458 L
s
.72812 .41108 m
.70268 .4183 L
s
.70781 .41375 m
.70608 .41458 L
s
0 1 .32 r
.52331 .33456 m
.52732 .33852 L
s
0 .582 1 r
.31325 .7553 m
.30858 .75739 L
s
.31155 .74751 m
.31325 .7553 L
s
0 1 .939 r
.80247 .67144 m
.80675 .67932 L
s
.80247 .67144 m
.81118 .67355 L
s
.732 1 0 r
.55779 .42003 m
.55962 .42306 L
s
0 1 .939 r
.81118 .67355 m
.80675 .67932 L
s
0 1 .689 r
.27243 .66237 m
.27734 .66669 L
s
.26942 .66324 m
.27243 .66237 L
s
.27243 .66237 m
.27701 .65987 L
s
0 1 0 r
.73543 .50199 m
.74014 .50555 L
s
.73543 .50199 m
.74088 .50042 L
s
.76108 .50555 m
.73543 .50199 L
s
0 1 .336 r
.76871 .58641 m
.77317 .59207 L
s
.76871 .58641 m
.77593 .58676 L
s
0 .914 1 r
.76605 .77004 m
.75061 .74376 L
s
.041 1 0 r
.41644 .68241 m
.42258 .66203 L
s
.25 0 1 r
.67417 .92484 m
.68179 .9303 L
s
.66715 .93052 m
.67417 .92484 L
s
.67417 .92484 m
.67457 .92362 L
s
0 .349 1 r
.49052 .8389 m
.49699 .84413 L
s
.48454 .84282 m
.49052 .8389 L
s
.49052 .8389 m
.49246 .83731 L
s
.389 0 1 r
.53341 .93321 m
.52643 .93826 L
s
.52823 .9256 m
.53341 .93321 L
s
0 1 .252 r
.17767 .40111 m
.17447 .40486 L
s
.1715 .39794 m
.17767 .40111 L
s
.17767 .40111 m
.17106 .4036 L
s
.17492 .3992 m
.17767 .40111 L
s
.15408 .40256 m
.17767 .40111 L
s
0 1 .689 r
.27734 .66669 m
.27434 .66758 L
s
.27701 .65987 m
.27734 .66669 L
s
1 0 .678 r
.60329 .16092 m
.6123 .16853 L
s
0 1 .336 r
.77593 .58676 m
.77317 .59207 L
s
.154 0 1 r
.34344 .84759 m
.33629 .84107 L
s
.33629 .84107 m
.34674 .83567 L
s
.459 0 1 r
.82299 .92011 m
.83076 .9247 L
s
.8156 .92667 m
.82299 .92011 L
s
.82299 .92011 m
.82115 .9183 L
s
0 1 .085 r
.23792 .57474 m
.24171 .57857 L
s
.23704 .5747 m
.23792 .57474 L
s
.23792 .57474 m
.24316 .57286 L
s
.853 0 1 r
.38254 .92425 m
.37885 .93801 L
s
0 1 .085 r
.24171 .57857 m
.24083 .57854 L
s
.24316 .57286 m
.24171 .57857 L
s
.128 0 1 r
.57964 .9441 m
.58634 .90939 L
s
.528 0 1 r
.22972 .85639 m
.25625 .81666 L
s
0 1 .252 r
.17106 .4036 m
.17447 .40486 L
s
.1715 .39794 m
.17106 .4036 L
s
0 1 0 r
.74088 .50042 m
.74014 .50555 L
s
.141 1 0 r
.20616 .49091 m
.20775 .49097 L
s
.20404 .48653 m
.20616 .49091 L
s
.21003 .48657 m
.20616 .49091 L
s
.389 0 1 r
.52643 .93826 m
.51871 .93173 L
s
.51871 .93173 m
.52823 .9256 L
s
0 0 1 r
.63726 .24473 m
.64378 .25151 L
s
0 1 .183 r
.70608 .41458 m
.7077 .41997 L
s
.141 1 0 r
.21003 .48657 m
.20775 .49097 L
s
.20404 .48653 m
.21003 .48657 L
s
.20564 .48658 m
.21003 .48657 L
s
.1893 .4975 m
.21003 .48657 L
s
.20564 .48658 m
.20404 .48653 L
s
0 1 .909 r
.67154 .32932 m
.6756 .33531 L
s
0 1 .252 r
.17492 .3992 m
.1715 .39794 L
s
.154 0 1 r
.34674 .83567 m
.34344 .84759 L
s
0 1 .837 r
.45565 .75132 m
.46079 .75526 L
s
.4509 .75407 m
.45565 .75132 L
s
.45565 .75132 m
.45723 .74942 L
s
0 .349 1 r
.49699 .84413 m
.49102 .84808 L
s
.49246 .83731 m
.49699 .84413 L
s
0 .582 1 r
.30858 .75739 m
.30255 .75205 L
s
.30255 .75205 m
.31155 .74751 L
s
.161 1 0 r
.5745 .67953 m
.56905 .66112 L
s
0 .155 1 r
.92474 .76731 m
.89748 .73617 L
s
0 1 .085 r
.22426 .59174 m
.24316 .57286 L
s
0 .47 1 r
.63925 .8372 m
.64552 .84143 L
s
.6332 .84195 m
.63925 .8372 L
s
.63925 .8372 m
.63891 .83571 L
s
0 1 .085 r
.24316 .57286 m
.24083 .57854 L
s
.23704 .5747 m
.24316 .57286 L
s
0 .582 1 r
.31155 .74751 m
.30858 .75739 L
s
.25 0 1 r
.67478 .93601 m
.66715 .93052 L
s
.66715 .93052 m
.67457 .92362 L
s
0 1 .689 r
.27701 .65987 m
.27434 .66758 L
s
.26942 .66324 m
.27701 .65987 L
s
.25 0 1 r
.68179 .9303 m
.67478 .93601 L
s
.67457 .92362 m
.68179 .9303 L
s
0 1 .689 r
.27434 .66758 m
.26942 .66324 L
s
0 1 .252 r
.17447 .40486 m
.17492 .3992 L
s
0 .349 1 r
.49102 .84808 m
.48454 .84282 L
s
.48454 .84282 m
.49246 .83731 L
s
.459 0 1 r
.82336 .93129 m
.8156 .92667 L
s
.8156 .92667 m
.82115 .9183 L
s
0 .228 1 r
.38758 .85382 m
.40275 .82015 L
s
.131 0 1 r
.73814 .94168 m
.73427 .90596 L
s
0 1 .487 r
.29062 .31945 m
.28819 .32002 L
s
.28811 .31248 m
.29062 .31945 L
s
.29062 .31945 m
.28401 .3172 L
s
.2923 .31529 m
.29062 .31945 L
s
.27815 .3033 m
.29062 .31945 L
s
.141 1 0 r
.20775 .49097 m
.20564 .48658 L
s
.455 0 1 r
.93779 .82526 m
.94422 .82809 L
s
.93038 .83251 m
.93779 .82526 L
s
.93779 .82526 m
.93234 .82275 L
s
0 .197 1 r
.78839 .83265 m
.7947 .8361 L
s
.78193 .8385 m
.78839 .83265 L
s
.78839 .83265 m
.78568 .83086 L
s
0 1 .837 r
.46079 .75526 m
.45605 .75802 L
s
.45723 .74942 m
.46079 .75526 L
s
.041 1 0 r
.42111 .66405 m
.42487 .66671 L
s
.41783 .66554 m
.42111 .66405 L
s
.42111 .66405 m
.42258 .66203 L
s
.389 0 1 r
.52823 .9256 m
.52643 .93826 L
s
0 1 .085 r
.24083 .57854 m
.23704 .5747 L
s
1 0 .832 r
.28575 .90879 m
.29455 .91707 L
s
.27888 .91257 m
.28575 .90879 L
s
.28575 .90879 m
.29238 .90621 L
s
0 1 .341 r
.73314 .67663 m
.716 .65711 L
s
.919 1 0 r
.38225 .58868 m
.38856 .57524 L
s
0 1 .724 r
.60463 .74978 m
.60941 .75274 L
s
.59973 .75352 m
.60463 .74978 L
s
.60463 .74978 m
.60372 .74818 L
s
0 1 .837 r
.45605 .75802 m
.4509 .75407 L
s
.4509 .75407 m
.45723 .74942 L
s
0 .47 1 r
.63946 .8462 m
.6332 .84195 L
s
.6332 .84195 m
.63891 .83571 L
s
.041 1 0 r
.42487 .66671 m
.42159 .66821 L
s
.42258 .66203 m
.42487 .66671 L
s
.704 1 0 r
.32254 .40385 m
.32104 .40526 L
s
.32029 .40056 m
.32254 .40385 L
s
.32254 .40385 m
.3185 .40371 L
s
.32284 .40211 m
.32254 .40385 L
s
.31311 .39913 m
.32254 .40385 L
s
.455 0 1 r
.93678 .83537 m
.93038 .83251 L
s
.93038 .83251 m
.93234 .82275 L
s
.459 0 1 r
.83076 .9247 m
.82336 .93129 L
s
.82115 .9183 m
.83076 .9247 L
s
.919 1 0 r
.38681 .57704 m
.38927 .57859 L
s
.38532 .57727 m
.38681 .57704 L
s
.38681 .57704 m
.38856 .57524 L
s
0 .26 1 r
.40484 .23638 m
.40439 .23438 L
s
.40481 .22519 m
.40484 .23638 L
s
.40484 .23638 m
.39807 .2297 L
s
.41113 .22985 m
.40484 .23638 L
s
.40362 .20292 m
.40484 .23638 L
s
0 .47 1 r
.64552 .84143 m
.63946 .8462 L
s
.63891 .83571 m
.64552 .84143 L
s
0 1 .487 r
.28811 .31248 m
.28401 .3172 L
s
.2923 .31529 m
.28811 .31248 L
s
0 .349 1 r
.49246 .83731 m
.49102 .84808 L
s
0 .197 1 r
.78823 .84197 m
.78193 .8385 L
s
.78193 .8385 m
.78568 .83086 L
s
.516 0 1 r
.89722 .93926 m
.88227 .89918 L
s
0 .607 1 r
.54602 .85123 m
.55025 .82041 L
s
0 .112 1 r
.19481 .7632 m
.22076 .72754 L
s
1 0 .832 r
.29455 .91707 m
.28771 .9209 L
s
.29238 .90621 m
.29455 .91707 L
s
1 0 .643 r
.51998 .15217 m
.52214 .14807 L
s
.52196 .13635 m
.51998 .15217 L
s
.51998 .15217 m
.51302 .14107 L
s
.53107 .14331 m
.51998 .15217 L
s
.53049 .10142 m
.51998 .15217 L
s
.919 1 0 r
.38927 .57859 m
.38778 .57882 L
s
.38856 .57524 m
.38927 .57859 L
s
0 1 .487 r
.28401 .3172 m
.28819 .32002 L
s
.041 1 0 r
.42159 .66821 m
.41783 .66554 L
s
.41783 .66554 m
.42258 .66203 L
s
.25 0 1 r
.67457 .92362 m
.67478 .93601 L
s
.528 0 1 r
.2498 .81981 m
.25767 .82695 L
s
.24411 .82235 m
.2498 .81981 L
s
.2498 .81981 m
.25625 .81666 L
s
1 .614 0 r
.35357 .49107 m
.35474 .49106 L
s
.35271 .48926 m
.35357 .49107 L
s
.3552 .48914 m
.35357 .49107 L
s
0 .914 1 r
.75404 .74534 m
.75874 .74767 L
s
.74872 .75044 m
.75404 .74534 L
s
.75404 .74534 m
.75061 .74376 L
s
1 .614 0 r
.3552 .48914 m
.35474 .49106 L
s
.35271 .48926 m
.3552 .48914 L
s
.35388 .48926 m
.3552 .48914 L
s
.34781 .49425 m
.3552 .48914 L
s
.704 1 0 r
.3185 .40371 m
.32104 .40526 L
s
.32029 .40056 m
.3185 .40371 L
s
0 .155 1 r
.90377 .73809 m
.90846 .73998 L
s
.89749 .74489 m
.90377 .73809 L
s
.90377 .73809 m
.89748 .73617 L
s
.704 1 0 r
.32284 .40211 m
.32029 .40056 L
s
0 1 .837 r
.45723 .74942 m
.45605 .75802 L
s
1 .614 0 r
.35388 .48926 m
.35271 .48926 L
s
0 1 .724 r
.60451 .75649 m
.59973 .75352 L
s
.59973 .75352 m
.60372 .74818 L
s
.161 1 0 r
.57035 .66265 m
.5735 .66433 L
s
.56679 .6653 m
.57035 .66265 L
s
.57035 .66265 m
.56905 .66112 L
s
.919 1 0 r
.38856 .57524 m
.38778 .57882 L
s
.38532 .57727 m
.38856 .57524 L
s
0 .755 1 r
.89236 .67372 m
.86301 .65002 L
s
1 .909 0 r
.54083 .58561 m
.53494 .57463 L
s
.919 1 0 r
.38778 .57882 m
.38532 .57727 L
s
.041 1 0 r
.42258 .66203 m
.42159 .66821 L
s
1 .614 0 r
.35474 .49106 m
.35388 .48926 L
s
0 .155 1 r
.90216 .74681 m
.89749 .74489 L
s
.89749 .74489 m
.89748 .73617 L
s
0 1 .487 r
.28819 .32002 m
.2923 .31529 L
s
0 .26 1 r
.40481 .22519 m
.39807 .2297 L
s
.41113 .22985 m
.40481 .22519 L
s
0 1 .358 r
.43634 .3196 m
.43662 .3189 L
s
.43684 .3124 m
.43634 .3196 L
s
.43634 .3196 m
.43245 .31536 L
s
.44101 .31593 m
.43634 .3196 L
s
.4383 .29966 m
.43634 .3196 L
s
0 1 .724 r
.60941 .75274 m
.60451 .75649 L
s
.60372 .74818 m
.60941 .75274 L
s
.704 1 0 r
.32104 .40526 m
.32284 .40211 L
s
0 .914 1 r
.7534 .75278 m
.74872 .75044 L
s
.74872 .75044 m
.75061 .74376 L
s
1 0 .334 r
.6664 .14752 m
.67213 .14407 L
s
.6711 .1313 m
.6664 .14752 L
s
.6664 .14752 m
.66269 .1352 L
s
.68052 .14013 m
.6664 .14752 L
s
.69292 .09736 m
.6664 .14752 L
s
.528 0 1 r
.25767 .82695 m
.25201 .82953 L
s
.25625 .81666 m
.25767 .82695 L
s
.459 0 1 r
.82115 .9183 m
.82336 .93129 L
s
0 .197 1 r
.7947 .8361 m
.78823 .84197 L
s
.78568 .83086 m
.7947 .8361 L
s
0 .47 1 r
.63891 .83571 m
.63946 .8462 L
s
1 0 .643 r
.52196 .13635 m
.51302 .14107 L
s
.53107 .14331 m
.52196 .13635 L
s
.161 1 0 r
.56994 .66699 m
.56679 .6653 L
s
.56679 .6653 m
.56905 .66112 L
s
0 .112 1 r
.21417 .73096 m
.2211 .73712 L
s
.20998 .73229 m
.21417 .73096 L
s
.21417 .73096 m
.22076 .72754 L
s
0 .055 1 r
.55108 .23407 m
.55394 .23185 L
s
.55367 .22248 m
.55108 .23407 L
s
.55108 .23407 m
.54722 .2258 L
s
.56038 .22852 m
.55108 .23407 L
s
.5649 .19908 m
.55108 .23407 L
s
0 .565 1 r
.70504 .84864 m
.69833 .8174 L
s
0 .987 1 r
.35318 .76045 m
.36718 .73126 L
s
.483 0 1 r
.43485 .91139 m
.44274 .91825 L
s
.42811 .91563 m
.43485 .91139 L
s
.43485 .91139 m
.4389 .90946 L
s
0 1 .341 r
.71997 .65821 m
.72291 .65949 L
s
.71598 .66257 m
.71997 .65821 L
s
.71997 .65821 m
.716 .65711 L
s
1 .909 0 r
.53649 .57582 m
.53783 .57628 L
s
.5344 .57738 m
.53649 .57582 L
s
.53649 .57582 m
.53494 .57463 L
s
0 1 .358 r
.43684 .3124 m
.43245 .31536 L
s
.44101 .31593 m
.43684 .3124 L
s
.88 1 0 r
.46854 .40377 m
.46925 .4041 L
s
.46951 .40022 m
.46854 .40377 L
s
.46854 .40377 m
.46717 .40173 L
s
.47159 .40259 m
.46854 .40377 L
s
.47273 .39568 m
.46854 .40377 L
s
0 .755 1 r
.86992 .651 m
.87275 .65211 L
s
.86505 .65743 m
.86992 .651 L
s
.86992 .651 m
.86301 .65002 L
s
.161 1 0 r
.5735 .66433 m
.56994 .66699 L
s
.56905 .66112 m
.5735 .66433 L
s
0 .755 1 r
.86787 .65856 m
.86505 .65743 L
s
.86505 .65743 m
.86301 .65002 L
s
0 1 .341 r
.71891 .66387 m
.71598 .66257 L
s
.71598 .66257 m
.716 .65711 L
s
1 .909 0 r
.53574 .57784 m
.5344 .57738 L
s
.5344 .57738 m
.53494 .57463 L
s
0 .112 1 r
.2211 .73712 m
.21693 .73847 L
s
.22076 .72754 m
.2211 .73712 L
s
0 1 .724 r
.60372 .74818 m
.60451 .75649 L
s
.455 0 1 r
.94422 .82809 m
.93678 .83537 L
s
.93234 .82275 m
.94422 .82809 L
s
.333 1 0 r
.69999 .58252 m
.68188 .57101 L
s
0 .26 1 r
.40439 .23438 m
.41113 .22985 L
s
.39807 .2297 m
.40439 .23438 L
s
.4 0 1 r
.69776 .22907 m
.70384 .22783 L
s
.70314 .21697 m
.69776 .22907 L
s
.69776 .22907 m
.69705 .21974 L
s
.70991 .22504 m
.69776 .22907 L
s
.72678 .19522 m
.69776 .22907 L
s
0 .197 1 r
.78568 .83086 m
.78823 .84197 L
s
.455 0 1 r
.93234 .82275 m
.93678 .83537 L
s
1 .324 0 r
.50196 .48999 m
.5028 .48985 L
s
.5028 .48985 m
.50308 .48851 L
s
.5028 .48985 m
.50142 .48881 L
s
.50142 .48881 m
.50196 .48999 L
s
.50308 .48851 m
.50142 .48881 L
s
.50142 .48881 m
.50223 .48865 L
s
.5069 .49099 m
.50142 .48881 L
s
0 .695 1 r
.17885 .64218 m
.18484 .64768 L
s
.17655 .64244 m
.17885 .64218 L
s
.17885 .64218 m
.18598 .63899 L
s
.88 1 0 r
.46951 .40022 m
.46717 .40173 L
s
.47159 .40259 m
.46951 .40022 L
s
0 .055 1 r
.55367 .22248 m
.54722 .2258 L
s
.56038 .22852 m
.55367 .22248 L
s
1 0 .334 r
.6711 .1313 m
.66269 .1352 L
s
.68052 .14013 m
.6711 .1313 L
s
0 1 .707 r
.58285 .31699 m
.58614 .31642 L
s
.58599 .30925 m
.58285 .31699 L
s
.58285 .31699 m
.58177 .31131 L
s
.59034 .31435 m
.58285 .31699 L
s
.59905 .29601 m
.58285 .31699 L
s
1 .324 0 r
.50308 .48851 m
.50223 .48865 L
s
0 .914 1 r
.75874 .74767 m
.7534 .75278 L
s
.75061 .74376 m
.75874 .74767 L
s
1 .909 0 r
.53783 .57628 m
.53574 .57784 L
s
.53494 .57463 m
.53783 .57628 L
s
0 1 .358 r
.43662 .3189 m
.44101 .31593 L
s
.88 1 0 r
.46925 .4041 m
.47159 .40259 L
s
.161 1 0 r
.56905 .66112 m
.56994 .66699 L
s
1 .909 0 r
.53494 .57463 m
.53574 .57784 L
s
0 .695 1 r
.18484 .64768 m
.18256 .64795 L
s
.18598 .63899 m
.18484 .64768 L
s
1 0 .832 r
.28771 .9209 m
.27888 .91257 L
s
.27888 .91257 m
.29238 .90621 L
s
.333 1 0 r
.68484 .57549 m
.68378 .57496 L
s
.68378 .57496 m
.68616 .57116 L
s
.68378 .57496 m
.68188 .57101 L
s
.68616 .57116 m
.68724 .57168 L
s
.68616 .57116 m
.68188 .57101 L
s
1 .324 0 r
.50223 .48865 m
.50196 .48999 L
s
0 1 .358 r
.43245 .31536 m
.43662 .3189 L
s
0 1 .746 r
.83401 .57084 m
.83307 .57019 L
s
.83307 .57019 m
.83621 .56396 L
s
.83307 .57019 m
.82895 .56439 L
s
0 1 .578 r
.51214 .75769 m
.51467 .73182 L
s
0 .101 1 r
.86465 .84604 m
.84655 .81112 L
s
0 .695 1 r
.15964 .66933 m
.18598 .63899 L
s
0 1 .895 r
.14877 .55873 m
.14887 .5584 L
s
.14392 .55322 m
.14877 .55873 L
s
.15192 .55108 m
.14877 .55873 L
s
.88 1 0 r
.46717 .40173 m
.46925 .4041 L
s
.483 0 1 r
.44274 .91825 m
.43602 .92253 L
s
.4389 .90946 m
.44274 .91825 L
s
0 1 .746 r
.83621 .56396 m
.83716 .5646 L
s
.83621 .56396 m
.82895 .56439 L
s
1 0 .643 r
.52214 .14807 m
.53107 .14331 L
s
0 1 .821 r
.11283 .47019 m
.11548 .47028 L
s
.10984 .46377 m
.11283 .47019 L
s
.11864 .46393 m
.11283 .47019 L
s
0 .228 1 r
.39914 .8226 m
.40589 .82821 L
s
.39347 .82567 m
.39914 .8226 L
s
.39914 .8226 m
.40275 .82015 L
s
0 .914 1 r
.75061 .74376 m
.7534 .75278 L
s
1 0 .832 r
.29238 .90621 m
.28771 .9209 L
s
0 1 .895 r
.144 .55287 m
.14392 .55322 L
s
.14392 .55322 m
.15192 .55108 L
s
0 1 .707 r
.58599 .30925 m
.58177 .31131 L
s
.59034 .31435 m
.58599 .30925 L
s
.648 1 0 r
.6514 .48806 m
.65211 .48765 L
s
.65211 .48765 m
.65248 .48392 L
s
.65211 .48765 m
.64828 .48556 L
s
.247 1 0 r
.61526 .40085 m
.61862 .40178 L
s
.61894 .39649 m
.61526 .40085 L
s
.61526 .40085 m
.61662 .39753 L
s
.62094 .40074 m
.61526 .40085 L
s
.63294 .39222 m
.61526 .40085 L
s
0 .62 1 r
.72973 .31163 m
.73584 .31239 L
s
.73577 .30324 m
.72973 .31163 L
s
.72973 .31163 m
.73169 .30504 L
s
.73991 .31057 m
.72973 .31163 L
s
.76039 .29235 m
.72973 .31163 L
s
0 .155 1 r
.89748 .73617 m
.90216 .74681 L
s
.89748 .73617 m
.90846 .73998 L
s
0 1 .821 r
.11864 .46393 m
.11548 .47028 L
s
.10984 .46377 m
.11864 .46393 L
s
.11248 .46384 m
.11864 .46393 L
s
.08853 .4795 m
.11864 .46393 L
s
.4 0 1 r
.70314 .21697 m
.69705 .21974 L
s
.70991 .22504 m
.70314 .21697 L
s
0 .055 1 r
.55394 .23185 m
.56038 .22852 L
s
0 1 .51 r
.80075 .48387 m
.80156 .48323 L
s
.80156 .48323 m
.80254 .47691 L
s
.80156 .48323 m
.79536 .47938 L
s
.648 1 0 r
.65248 .48392 m
.65177 .48433 L
s
.65248 .48392 m
.64828 .48556 L
s
0 .155 1 r
.90846 .73998 m
.90216 .74681 L
s
.247 1 0 r
.61862 .40178 m
.62094 .40074 L
s
.62094 .40074 m
.61894 .39649 L
s
0 1 .341 r
.72291 .65949 m
.71891 .66387 L
s
.716 .65711 m
.72291 .65949 L
s
0 1 .707 r
.58614 .31642 m
.59034 .31435 L
s
.247 1 0 r
.61894 .39649 m
.61662 .39753 L
s
.128 0 1 r
.5846 .91118 m
.59209 .91682 L
s
.57788 .91598 m
.5846 .91118 L
s
.5846 .91118 m
.58634 .90939 L
s
1 0 .334 r
.67213 .14407 m
.68052 .14013 L
s
0 1 .341 r
.716 .65711 m
.71891 .66387 L
s
0 1 .746 r
.85973 .57943 m
.82895 .56439 L
s
.741 0 1 r
.32396 .93318 m
.34813 .89194 L
s
.648 1 0 r
.64828 .48556 m
.6514 .48806 L
s
.64828 .48556 m
.65177 .48433 L
s
.66659 .48773 m
.64828 .48556 L
s
0 1 .821 r
.11248 .46384 m
.10984 .46377 L
s
.528 0 1 r
.25201 .82953 m
.24411 .82235 L
s
.24411 .82235 m
.25625 .81666 L
s
0 1 .51 r
.80254 .47691 m
.80173 .47754 L
s
.80254 .47691 m
.79536 .47938 L
s
.333 1 0 r
.68188 .57101 m
.68484 .57549 L
s
.68188 .57101 m
.68724 .57168 L
s
0 1 .713 r
.7681 .39773 m
.77049 .39665 L
s
.77049 .39665 m
.76897 .38994 L
s
.77049 .39665 m
.76228 .39509 L
s
.528 0 1 r
.25625 .81666 m
.25201 .82953 L
s
1 0 .643 r
.51302 .14107 m
.52214 .14807 L
s
0 1 .713 r
.76228 .39509 m
.7681 .39773 L
s
.76897 .38994 m
.76228 .39509 L
s
.76228 .39509 m
.76657 .391 L
s
.79375 .38875 m
.76228 .39509 L
s
0 .755 1 r
.86301 .65002 m
.86787 .65856 L
s
.86301 .65002 m
.87275 .65211 L
s
.4 0 1 r
.70384 .22783 m
.70991 .22504 L
s
0 1 .895 r
.15192 .55108 m
.14887 .5584 L
s
.144 .55287 m
.15192 .55108 L
s
.12422 .57477 m
.15192 .55108 L
s
0 .62 1 r
.73577 .30324 m
.73169 .30504 L
s
.73991 .31057 m
.73577 .30324 L
s
.73584 .31239 m
.73991 .31057 L
s
0 1 .713 r
.76897 .38994 m
.76657 .391 L
s
0 .112 1 r
.22076 .72754 m
.21693 .73847 L
s
.20998 .73229 m
.22076 .72754 L
s
0 1 .51 r
.79536 .47938 m
.80075 .48387 L
s
.79536 .47938 m
.80173 .47754 L
s
.82686 .48445 m
.79536 .47938 L
s
0 .695 1 r
.18598 .63899 m
.18256 .64795 L
s
.17655 .64244 m
.18598 .63899 L
s
0 1 .746 r
.82895 .56439 m
.83401 .57084 L
s
.82895 .56439 m
.83716 .5646 L
s
.333 1 0 r
.68724 .57168 m
.68484 .57549 L
s
0 .228 1 r
.40589 .82821 m
.40024 .8313 L
s
.40275 .82015 m
.40589 .82821 L
s
0 .987 1 r
.36374 .734 m
.36932 .7384 L
s
.3594 .73586 m
.36374 .734 L
s
.36374 .734 m
.36718 .73126 L
s
0 1 .666 r
.67169 .75492 m
.66283 .7292 L
s
0 1 .252 r
.31854 .6664 m
.33224 .64289 L
s
0 .055 1 r
.54722 .2258 m
.55394 .23185 L
s
.648 1 0 r
.65177 .48433 m
.6514 .48806 L
s
.483 0 1 r
.43602 .92253 m
.42811 .91563 L
s
.42811 .91563 m
.4389 .90946 L
s
0 .755 1 r
.87275 .65211 m
.86787 .65856 L
s
0 .112 1 r
.21693 .73847 m
.20998 .73229 L
s
.131 0 1 r
.73482 .90808 m
.74225 .91271 L
s
.72786 .91365 m
.73482 .90808 L
s
.73482 .90808 m
.73427 .90596 L
s
0 1 .707 r
.58177 .31131 m
.58614 .31642 L
s
.247 1 0 r
.61662 .39753 m
.61862 .40178 L
s
.516 0 1 r
.88535 .90207 m
.89292 .90586 L
s
.87767 .90867 m
.88535 .90207 L
s
.88535 .90207 m
.88227 .89918 L
s
.156 0 1 r
.4833 .93072 m
.49653 .89378 L
s
0 1 .821 r
.11548 .47028 m
.11248 .46384 L
s
0 1 .746 r
.83716 .5646 m
.83401 .57084 L
s
0 .607 1 r
.54917 .82256 m
.55535 .82693 L
s
.54343 .82632 m
.54917 .82256 L
s
.54917 .82256 m
.55025 .82041 L
s
0 .695 1 r
.18256 .64795 m
.17655 .64244 L
s
0 .987 1 r
.36932 .7384 m
.36499 .74027 L
s
.36718 .73126 m
.36932 .7384 L
s
.128 0 1 r
.59209 .91682 m
.58537 .92165 L
s
.58634 .90939 m
.59209 .91682 L
s
0 1 .252 r
.32861 .64561 m
.33304 .64896 L
s
.32593 .64625 m
.32861 .64561 L
s
.32861 .64561 m
.33224 .64289 L
s
0 1 .895 r
.14887 .5584 m
.144 .55287 L
s
1 0 .334 r
.66269 .1352 m
.67213 .14407 L
s
0 1 .51 r
.80173 .47754 m
.80075 .48387 L
s
0 .228 1 r
.40024 .8313 m
.39347 .82567 L
s
.39347 .82567 m
.40275 .82015 L
s
.128 0 1 r
.58537 .92165 m
.57788 .91598 L
s
.57788 .91598 m
.58634 .90939 L
s
.483 0 1 r
.4389 .90946 m
.43602 .92253 L
s
0 1 .021 r
.2316 .38194 m
.229 .38494 L
s
.22682 .37819 m
.2316 .38194 L
s
.2316 .38194 m
.2254 .38325 L
s
.23043 .37988 m
.2316 .38194 L
s
.21305 .38002 m
.2316 .38194 L
s
0 .76 1 r
.83183 .75213 m
.81122 .72339 L
s
.307 1 0 r
.47802 .66345 m
.47966 .64373 L
s
0 1 .713 r
.76657 .391 m
.7681 .39773 L
s
.4 0 1 r
.69705 .21974 m
.70384 .22783 L
s
0 1 .252 r
.33304 .64896 m
.33037 .64961 L
s
.33224 .64289 m
.33304 .64896 L
s
0 .62 1 r
.73169 .30504 m
.73584 .31239 L
s
.379 1 0 r
.29368 .55715 m
.297 .56002 L
s
.2932 .55687 m
.29368 .55715 L
s
.29368 .55715 m
.29797 .55515 L
s
.297 .56002 m
.29653 .55975 L
s
.29797 .55515 m
.297 .56002 L
s
0 .565 1 r
.69971 .81962 m
.7057 .82305 L
s
.69367 .82435 m
.69971 .81962 L
s
.69971 .81962 m
.69833 .8174 L
s
.131 0 1 r
.73529 .9183 m
.72786 .91365 L
s
.72786 .91365 m
.73427 .90596 L
s
.516 0 1 r
.88522 .9125 m
.87767 .90867 L
s
.87767 .90867 m
.88227 .89918 L
s
.54 1 0 r
.26084 .47149 m
.26295 .47168 L
s
.25951 .4678 m
.26084 .47149 L
s
.26441 .46813 m
.26084 .47149 L
s
0 1 .578 r
.51405 .73418 m
.51883 .73724 L
s
.5095 .73681 m
.51405 .73418 L
s
.51405 .73418 m
.51467 .73182 L
s
0 .228 1 r
.40275 .82015 m
.40024 .8313 L
s
0 .987 1 r
.36499 .74027 m
.3594 .73586 L
s
.3594 .73586 m
.36718 .73126 L
s
0 .069 1 r
.64324 .92826 m
.64569 .89226 L
s
.084 0 1 r
.28911 .8395 m
.31161 .80162 L
s
0 1 .021 r
.2254 .38325 m
.229 .38494 L
s
.22682 .37819 m
.2254 .38325 L
s
.54 1 0 r
.26441 .46813 m
.26295 .47168 L
s
.25951 .4678 m
.26441 .46813 L
s
.26162 .46798 m
.26441 .46813 L
s
.24847 .47619 m
.26441 .46813 L
s
0 .607 1 r
.55535 .82693 m
.54962 .83071 L
s
.55025 .82041 m
.55535 .82693 L
s
0 .101 1 r
.85061 .81377 m
.85659 .8165 L
s
.84382 .81981 m
.85061 .81377 L
s
.85061 .81377 m
.84655 .81112 L
s
.131 0 1 r
.74225 .91271 m
.73529 .9183 L
s
.73427 .90596 m
.74225 .91271 L
s
0 1 .021 r
.23043 .37988 m
.22682 .37819 L
s
.54 1 0 r
.26162 .46798 m
.25951 .4678 L
s
0 .607 1 r
.54962 .83071 m
.54343 .82632 L
s
.54343 .82632 m
.55025 .82041 L
s
0 .987 1 r
.36718 .73126 m
.36499 .74027 L
s
.379 1 0 r
.29797 .55515 m
.29653 .55975 L
s
.2932 .55687 m
.29797 .55515 L
s
.28363 .57165 m
.29797 .55515 L
s
0 1 .252 r
.33224 .64289 m
.33037 .64961 L
s
.32593 .64625 m
.33224 .64289 L
s
.33037 .64961 m
.32593 .64625 L
s
.152 1 0 r
.6381 .66049 m
.62783 .64148 L
s
.128 0 1 r
.58634 .90939 m
.58537 .92165 L
s
0 1 .607 r
.34605 .29837 m
.34458 .29854 L
s
.34472 .29071 m
.34605 .29837 L
s
.34605 .29837 m
.34001 .29509 L
s
.34929 .29415 m
.34605 .29837 L
s
.33897 .27942 m
.34605 .29837 L
s
0 1 .021 r
.229 .38494 m
.23043 .37988 L
s
.54 1 0 r
.26295 .47168 m
.26162 .46798 L
s
.307 1 0 r
.47926 .64611 m
.48256 .64786 L
s
.4761 .64752 m
.47926 .64611 L
s
.47926 .64611 m
.47966 .64373 L
s
0 .565 1 r
.69965 .82779 m
.69367 .82435 L
s
.69367 .82435 m
.69833 .8174 L
s
0 1 .578 r
.51883 .73724 m
.51428 .73989 L
s
.51467 .73182 m
.51883 .73724 L
s
.379 1 0 r
.29653 .55975 m
.2932 .55687 L
s
0 .101 1 r
.84979 .82255 m
.84382 .81981 L
s
.84382 .81981 m
.84655 .81112 L
s
0 1 .666 r
.66488 .73136 m
.66928 .73356 L
s
.65996 .73519 m
.66488 .73136 L
s
.66488 .73136 m
.66283 .7292 L
s
0 1 .578 r
.51428 .73989 m
.5095 .73681 L
s
.5095 .73681 m
.51467 .73182 L
s
0 .564 1 r
.44898 .83687 m
.46003 .80374 L
s
.104 0 1 r
.80377 .92579 m
.79517 .88737 L
s
.516 0 1 r
.89292 .90586 m
.88522 .9125 L
s
.88227 .89918 m
.89292 .90586 L
s
.741 0 1 r
.34227 .8948 m
.35066 .9022 L
s
.33583 .89831 m
.34227 .8948 L
s
.34227 .8948 m
.34813 .89194 L
s
.004 0 1 r
.46166 .21345 m
.46246 .21138 L
s
.46269 .20142 m
.46166 .21345 L
s
.46166 .21345 m
.45558 .2058 L
s
.46957 .20698 m
.46166 .21345 L
s
.46632 .17768 m
.46166 .21345 L
s
1 0 .335 r
.57806 .12744 m
.58164 .12354 L
s
.58118 .1107 m
.57806 .12744 L
s
.57806 .12744 m
.57195 .11542 L
s
.59085 .11878 m
.57806 .12744 L
s
.59512 .07478 m
.57806 .12744 L
s
.638 1 0 r
.37841 .38346 m
.37766 .38459 L
s
.37745 .37957 m
.37841 .38346 L
s
.37841 .38346 m
.37492 .38239 L
s
.3802 .38177 m
.37841 .38346 L
s
.37412 .37651 m
.37841 .38346 L
s
0 .76 1 r
.81609 .72559 m
.82033 .72729 L
s
.81041 .73105 m
.81609 .72559 L
s
.81609 .72559 m
.81122 .72339 L
s
0 .565 1 r
.7057 .82305 m
.69965 .82779 L
s
.69833 .8174 m
.7057 .82305 L
s
0 .607 1 r
.55025 .82041 m
.54962 .83071 L
s
.307 1 0 r
.48256 .64786 m
.47941 .64927 L
s
.47966 .64373 m
.48256 .64786 L
s
1 .801 0 r
.44476 .55842 m
.4467 .5589 L
s
.44317 .55849 m
.44476 .55842 L
s
.44476 .55842 m
.44526 .55624 L
s
.131 0 1 r
.73427 .90596 m
.73529 .9183 L
s
0 1 .586 r
.79876 .65752 m
.77631 .63611 L
s
1 .801 0 r
.44365 .56851 m
.44526 .55624 L
s
0 1 .607 r
.34472 .29071 m
.34001 .29509 L
s
.34929 .29415 m
.34472 .29071 L
s
.307 1 0 r
.47941 .64927 m
.4761 .64752 L
s
.4761 .64752 m
.47966 .64373 L
s
0 1 .666 r
.66435 .73741 m
.65996 .73519 L
s
.65996 .73519 m
.66283 .7292 L
s
0 .76 1 r
.81464 .73277 m
.81041 .73105 L
s
.81041 .73105 m
.81122 .72339 L
s
.516 0 1 r
.88227 .89918 m
.88522 .9125 L
s
1 .468 0 r
.41149 .46945 m
.41153 .47122 L
s
.41046 .46905 m
.41149 .46945 L
s
.41149 .46945 m
.40993 .47051 L
s
.41207 .46976 m
.41149 .46945 L
s
.40901 .47287 m
.41149 .46945 L
s
0 1 .578 r
.51467 .73182 m
.51428 .73989 L
s
1 .801 0 r
.4467 .5589 m
.44511 .55898 L
s
.44526 .55624 m
.4467 .5589 L
s
.152 1 0 r
.6304 .64331 m
.63303 .64434 L
s
.62676 .64624 m
.6304 .64331 L
s
.6304 .64331 m
.62783 .64148 L
s
.741 0 1 r
.35066 .9022 m
.34425 .90575 L
s
.34813 .89194 m
.35066 .9022 L
s
0 1 .607 r
.34001 .29509 m
.34458 .29854 L
s
1 .801 0 r
.44511 .55898 m
.44317 .55849 L
s
.44317 .55849 m
.44526 .55624 L
s
.44526 .55624 m
.44511 .55898 L
s
.638 1 0 r
.37745 .37957 m
.37492 .38239 L
s
.3802 .38177 m
.37745 .37957 L
s
.307 1 0 r
.47966 .64373 m
.47941 .64927 L
s
1 .468 0 r
.40993 .47051 m
.41153 .47122 L
s
.41046 .46905 m
.40993 .47051 L
s
.41153 .47122 m
.41207 .46976 L
s
.681 0 1 r
.96489 .92332 m
.94454 .87912 L
s
0 .791 1 r
.60944 .83422 m
.60928 .80259 L
s
0 .582 1 r
.254 .74513 m
.27572 .71174 L
s
0 1 .666 r
.49359 .29731 m
.49499 .29675 L
s
.49519 .28932 m
.49359 .29731 L
s
.49359 .29731 m
.49037 .29224 L
s
.49981 .29381 m
.49359 .29731 L
s
.50119 .2757 m
.49359 .29731 L
s
.084 0 1 r
.30601 .80497 m
.31341 .81121 L
s
.30074 .80727 m
.30601 .80497 L
s
.30601 .80497 m
.31161 .80162 L
s
.638 1 0 r
.37492 .38239 m
.37766 .38459 L
s
0 .101 1 r
.85659 .8165 m
.84979 .82255 L
s
.84655 .81112 m
.85659 .8165 L
s
.004 0 1 r
.46269 .20142 m
.45558 .2058 L
s
.46957 .20698 m
.46269 .20142 L
s
0 1 .666 r
.66928 .73356 m
.66435 .73741 L
s
.66283 .7292 m
.66928 .73356 L
s
0 1 .607 r
.34458 .29854 m
.34929 .29415 L
s
.152 1 0 r
.62938 .64728 m
.62676 .64624 L
s
.62676 .64624 m
.62783 .64148 L
s
.301 0 1 r
.60958 .20994 m
.61372 .20814 L
s
.61338 .19749 m
.60958 .20994 L
s
.60958 .20994 m
.60657 .2009 L
s
.62051 .20471 m
.60958 .20994 L
s
.6297 .17374 m
.60958 .20994 L
s
1 .468 0 r
.41207 .46976 m
.41046 .46905 L
s
0 .565 1 r
.69833 .8174 m
.69965 .82779 L
s
.638 1 0 r
.37766 .38459 m
.3802 .38177 L
s
0 1 .586 r
.78181 .6375 m
.78416 .63834 L
s
.77749 .64247 m
.78181 .6375 L
s
.78181 .6375 m
.77631 .63611 L
s
1 0 .335 r
.58118 .1107 m
.57195 .11542 L
s
.59085 .11878 m
.58118 .1107 L
s
0 1 .586 r
.77982 .64333 m
.77749 .64247 L
s
.77749 .64247 m
.77631 .63611 L
s
0 .101 1 r
.84655 .81112 m
.84979 .82255 L
s
.922 1 0 r
.60425 .56537 m
.59337 .55432 L
s
.59635 .55535 m
.59695 .55546 L
s
.59414 .5576 m
.59635 .55535 L
s
.59635 .55535 m
.59337 .55432 L
s
.482 1 0 r
.52621 .38214 m
.52786 .38283 L
s
.52836 .3778 m
.52621 .38214 L
s
.52621 .38214 m
.52549 .3794 L
s
.53073 .38124 m
.52621 .38214 L
s
.5358 .37298 m
.52621 .38214 L
s
.922 1 0 r
.59474 .55772 m
.59414 .5576 L
s
.59414 .5576 m
.59337 .55432 L
s
0 1 .666 r
.66283 .7292 m
.66435 .73741 L
s
.49519 .28932 m
.49037 .29224 L
s
.49981 .29381 m
.49519 .28932 L
s
.084 0 1 r
.31341 .81121 m
.30816 .81354 L
s
.31161 .80162 m
.31341 .81121 L
s
.156 0 1 r
.49325 .89626 m
.50086 .90223 L
s
.48684 .90024 m
.49325 .89626 L
s
.49325 .89626 m
.49653 .89378 L
s
.152 1 0 r
.63303 .64434 m
.62938 .64728 L
s
.62783 .64148 m
.63303 .64434 L
s
0 .867 1 r
.64176 .29348 m
.64614 .29353 L
s
.6462 .28492 m
.64176 .29348 L
s
.64176 .29348 m
.64151 .28717 L
s
.65081 .29127 m
.64176 .29348 L
s
.66402 .27196 m
.64176 .29348 L
s
0 .582 1 r
.27005 .71529 m
.27645 .7205 L
s
.26626 .71638 m
.27005 .71529 L
s
.27005 .71529 m
.27572 .71174 L
s
0 1 .053 r
.74547 .55452 m
.74508 .55414 L
s
.74508 .55414 m
.74771 .54939 L
s
.74508 .55414 m
.74187 .54938 L
s
1 .816 0 r
.55948 .46784 m
.56087 .46964 L
s
.56235 .46672 m
.55948 .46784 L
s
.55948 .46784 m
.56095 .46712 L
s
.56227 .46924 m
.55948 .46784 L
s
.57015 .46953 m
.55948 .46784 L
s
.56087 .46964 m
.56227 .46924 L
s
.56227 .46924 m
.56235 .46672 L
s
.004 0 1 r
.46246 .21138 m
.46957 .20698 L
s
.152 1 0 r
.62783 .64148 m
.62938 .64728 L
s
.301 0 1 r
.61338 .19749 m
.60657 .2009 L
s
.62051 .20471 m
.61338 .19749 L
s
0 .557 1 r
.77051 .83157 m
.75895 .79815 L
s
0 1 .662 r
.4144 .74231 m
.42409 .71411 L
s
0 1 .053 r
.74771 .54939 m
.7481 .54975 L
s
.74771 .54939 m
.74187 .54938 L
s
0 .76 1 r
.82033 .72729 m
.81464 .73277 L
s
.81122 .72339 m
.82033 .72729 L
s
.482 1 0 r
.52836 .3778 m
.52549 .3794 L
s
.53073 .38124 m
.52836 .3778 L
s
.922 1 0 r
.59337 .55432 m
.59474 .55772 L
s
.59337 .55432 m
.59695 .55546 L
s
1 .816 0 r
.56235 .46672 m
.56095 .46712 L
s
0 .76 1 r
.81122 .72339 m
.81464 .73277 L
s
.482 1 0 r
.52786 .38283 m
.53073 .38124 L
s
0 1 .666 r
.49499 .29675 m
.49981 .29381 L
s
.004 0 1 r
.45558 .2058 m
.46246 .21138 L
s
.922 1 0 r
.59695 .55546 m
.59474 .55772 L
s
.124 1 0 r
.71181 .46664 m
.71319 .46608 L
s
.71319 .46608 m
.71363 .46112 L
s
.71319 .46608 m
.70794 .4633 L
s
1 0 .335 r
.58164 .12354 m
.59085 .11878 L
s
0 1 .264 r
.67456 .37797 m
.67882 .37969 L
s
.67965 .37286 m
.67456 .37797 L
s
.67456 .37797 m
.67672 .37413 L
s
.68174 .37841 m
.67456 .37797 L
s
.69809 .36944 m
.67456 .37797 L
s
0 .582 1 r
.27645 .7205 m
.27268 .72161 L
s
.27572 .71174 m
.27645 .7205 L
s
1 .816 0 r
.56095 .46712 m
.56087 .46964 L
s
.741 0 1 r
.34425 .90575 m
.33583 .89831 L
s
.33583 .89831 m
.34813 .89194 L
s
0 1 .586 r
.77631 .63611 m
.77982 .64333 L
s
.77631 .63611 m
.78416 .63834 L
s
0 .867 1 r
.6462 .28492 m
.64151 .28717 L
s
.65081 .29127 m
.6462 .28492 L
s
0 1 .053 r
.76546 .56221 m
.74187 .54938 L
s
1 0 .832 r
.22419 .91958 m
.25597 .87301 L
s
0 1 .666 r
.49037 .29224 m
.49499 .29675 L
s
.124 1 0 r
.71363 .46112 m
.71224 .46167 L
s
.71363 .46112 m
.70794 .4633 L
s
.301 0 1 r
.61372 .20814 m
.62051 .20471 L
s
0 1 .264 r
.67882 .37969 m
.68174 .37841 L
s
.68174 .37841 m
.67965 .37286 L
s
0 1 .811 r
.23435 .62566 m
.23978 .63019 L
s
.23247 .62569 m
.23435 .62566 L
s
.23435 .62566 m
.24051 .62241 L
s
.124 1 0 r
.70794 .4633 m
.71181 .46664 L
s
.70794 .4633 m
.71224 .46167 L
s
.7319 .46618 m
.70794 .4633 L
s
0 1 .053 r
.74187 .54938 m
.74547 .55452 L
s
.74187 .54938 m
.7481 .54975 L
s
.482 1 0 r
.52549 .3794 m
.52786 .38283 L
s
0 .867 1 r
.64614 .29353 m
.65081 .29127 L
s
0 1 .264 r
.67965 .37286 m
.67672 .37413 L
s
.156 0 1 r
.50086 .90223 m
.49447 .90624 L
s
.49653 .89378 m
.50086 .90223 L
s
0 1 .586 r
.78416 .63834 m
.77982 .64333 L
s
0 .564 1 r
.45727 .80664 m
.46369 .81134 L
s
.45191 .80949 m
.45727 .80664 L
s
.45727 .80664 m
.46003 .80374 L
s
0 1 .811 r
.23978 .63019 m
.23791 .63023 L
s
.24051 .62241 m
.23978 .63019 L
s
.741 0 1 r
.34813 .89194 m
.34425 .90575 L
s
0 .069 1 r
.64484 .89484 m
.65212 .89961 L
s
.63827 .89945 m
.64484 .89484 L
s
.64484 .89484 m
.64569 .89226 L
s
0 1 .397 r
.20323 .54039 m
.20384 .53993 L
s
.19901 .53574 m
.20323 .54039 L
s
.20602 .53373 m
.20323 .54039 L
s
.107 0 1 r
.93217 .8289 m
.90859 .79043 L
s
0 1 .411 r
.5754 .73948 m
.57338 .7133 L
s
0 1 .811 r
.21862 .65005 m
.24051 .62241 L
s
0 1 .384 r
.16672 .45091 m
.16985 .45121 L
s
.16469 .44518 m
.16672 .45091 L
s
.17228 .44581 m
.16672 .45091 L
s
.17228 .44581 m
.16985 .45121 L
s
.16469 .44518 m
.17228 .44581 L
s
.16782 .44546 m
.17228 .44581 L
s
.14708 .45776 m
.17228 .44581 L
s
1 0 .335 r
.57195 .11542 m
.58164 .12354 L
s
.084 0 1 r
.30816 .81354 m
.30074 .80727 L
s
.30074 .80727 m
.31161 .80162 L
s
0 1 .397 r
.19961 .53527 m
.19901 .53574 L
s
.19901 .53574 m
.20602 .53373 L
s
0 1 .053 r
.7481 .54975 m
.74547 .55452 L
s
.084 0 1 r
.31161 .80162 m
.30816 .81354 L
s
.104 0 1 r
.79686 .89046 m
.80408 .89426 L
s
.78974 .89599 m
.79686 .89046 L
s
.79686 .89046 m
.79517 .88737 L
s
.681 0 1 r
.9491 .88312 m
.95642 .88614 L
s
.94088 .88991 m
.9491 .88312 L
s
.9491 .88312 m
.94454 .87912 L
s
.124 1 0 r
.71224 .46167 m
.71181 .46664 L
s
0 1 .397 r
.20602 .53373 m
.20384 .53993 L
s
.19961 .53527 m
.20602 .53373 L
s
.18299 .55426 m
.20602 .53373 L
s
.156 0 1 r
.49447 .90624 m
.48684 .90024 L
s
.48684 .90024 m
.49653 .89378 L
s
.351 0 1 r
.38499 .91708 m
.40519 .87677 L
s
.301 0 1 r
.60657 .2009 m
.61372 .20814 L
s
0 .582 1 r
.27572 .71174 m
.27268 .72161 L
s
.26626 .71638 m
.27572 .71174 L
s
0 1 .384 r
.16782 .44546 m
.16469 .44518 L
s
0 .564 1 r
.46369 .81134 m
.45833 .8142 L
s
.46003 .80374 m
.46369 .81134 L
s
0 1 .811 r
.24051 .62241 m
.23791 .63023 L
s
.23247 .62569 m
.24051 .62241 L
s
0 1 .264 r
.67672 .37413 m
.67882 .37969 L
s
0 1 .662 r
.42159 .71723 m
.42676 .72068 L
s
.41751 .71888 m
.42159 .71723 L
s
.42159 .71723 m
.42409 .71411 L
s
0 .867 1 r
.64151 .28717 m
.64614 .29353 L
s
0 .582 1 r
.27268 .72161 m
.26626 .71638 L
s
0 .791 1 r
.60919 .80539 m
.61508 .80889 L
s
.60356 .80904 m
.60919 .80539 L
s
.60919 .80539 m
.60928 .80259 L
s
0 1 .729 r
.737 .73664 m
.72316 .70929 L
s
.126 1 0 r
.37956 .64704 m
.38875 .62501 L
s
0 .069 1 r
.65212 .89961 m
.64554 .90425 L
s
.64569 .89226 m
.65212 .89961 L
s
.64554 .90425 m
.63827 .89945 L
s
.63827 .89945 m
.64569 .89226 L
s
0 1 .384 r
.16985 .45121 m
.16782 .44546 L
s
.681 0 1 r
.94817 .89295 m
.94088 .88991 L
s
.94088 .88991 m
.94454 .87912 L
s
0 1 .811 r
.23791 .63023 m
.23247 .62569 L
s
0 .564 1 r
.45833 .8142 m
.45191 .80949 L
s
.45191 .80949 m
.46003 .80374 L
s
0 1 .662 r
.42676 .72068 m
.42269 .72234 L
s
.42409 .71411 m
.42676 .72068 L
s
1 0 .832 r
.24799 .87689 m
.25722 .88505 L
s
.2419 .87972 m
.24799 .87689 L
s
.24799 .87689 m
.25597 .87301 L
s
.156 0 1 r
.49653 .89378 m
.49447 .90624 L
s
0 1 .397 r
.20384 .53993 m
.19961 .53527 L
s
.104 0 1 r
.79695 .89982 m
.78974 .89599 L
s
.78974 .89599 m
.79517 .88737 L
s
.126 1 0 r
.38616 .62806 m
.39014 .63038 L
s
.38367 .62846 m
.38616 .62806 L
s
.38616 .62806 m
.38875 .62501 L
s
0 .117 1 r
.54638 .91457 m
.55544 .87718 L
s
.585 0 1 r
.18861 .82489 m
.21911 .7817 L
s
0 .557 1 r
.76158 .80115 m
.76723 .80379 L
s
.75534 .80597 m
.76158 .80115 L
s
.76158 .80115 m
.75895 .79815 L
s
.107 0 1 r
.91422 .79396 m
.91981 .79599 L
s
.90688 .80034 m
.91422 .79396 L
s
.91422 .79396 m
.90859 .79043 L
s
.084 1 0 r
.28682 .36186 m
.28486 .36428 L
s
.28348 .35748 m
.28682 .36186 L
s
.28682 .36186 m
.28112 .36204 L
s
.28722 .35972 m
.28682 .36186 L
s
.27346 .35693 m
.28682 .36186 L
s
.126 1 0 r
.39014 .63038 m
.38767 .63079 L
s
.38875 .62501 m
.39014 .63038 L
s
0 1 .411 r
.57386 .71617 m
.57823 .71837 L
s
.56934 .71877 m
.57386 .71617 L
s
.57386 .71617 m
.57338 .7133 L
s
0 .564 1 r
.46003 .80374 m
.45833 .8142 L
s
0 1 .662 r
.42269 .72234 m
.41751 .71888 L
s
.41751 .71888 m
.42409 .71411 L
s
0 .489 1 r
.89921 .73379 m
.87301 .70208 L
s
.445 1 0 r
.5411 .64403 m
.53801 .62451 L
s
1 0 .832 r
.25722 .88505 m
.25118 .88792 L
s
.25597 .87301 m
.25722 .88505 L
s
0 .791 1 r
.60944 .81255 m
.60356 .80904 L
s
.60356 .80904 m
.60928 .80259 L
s
.772 1 0 r
.35073 .53879 m
.35371 .54068 L
s
.35059 .53818 m
.35073 .53879 L
s
.35073 .53879 m
.35407 .53653 L
s
0 .791 1 r
.61508 .80889 m
.60944 .81255 L
s
.60928 .80259 m
.61508 .80889 L
s
.104 0 1 r
.80408 .89426 m
.79695 .89982 L
s
.79517 .88737 m
.80408 .89426 L
s
.772 1 0 r
.35371 .54068 m
.35357 .54008 L
s
.35407 .53653 m
.35371 .54068 L
s
.824 1 0 r
.32008 .44878 m
.31937 .45177 L
s
.31642 .44801 m
.32008 .44878 L
s
.32008 .44878 m
.31676 .4512 L
s
.31903 .44858 m
.32008 .44878 L
s
.30909 .45436 m
.32008 .44878 L
s
.107 0 1 r
.91244 .8024 m
.90688 .80034 L
s
.90688 .80034 m
.90859 .79043 L
s
.585 0 1 r
.21118 .786 m
.21957 .79314 L
s
.20637 .78759 m
.21118 .786 L
s
.21118 .786 m
.21911 .7817 L
s
0 1 .662 r
.42409 .71411 m
.42269 .72234 L
s
.824 1 0 r
.31676 .4512 m
.31937 .45177 L
s
.31642 .44801 m
.31676 .4512 L
s
0 .557 1 r
.76098 .80863 m
.75534 .80597 L
s
.75534 .80597 m
.75895 .79815 L
s
.772 1 0 r
.35407 .53653 m
.35357 .54008 L
s
.35059 .53818 m
.35407 .53653 L
s
.34446 .55107 m
.35407 .53653 L
s
.084 1 0 r
.28112 .36204 m
.28486 .36428 L
s
.28348 .35748 m
.28112 .36204 L
s
0 .069 1 r
.64569 .89226 m
.64554 .90425 L
s
.126 1 0 r
.38875 .62501 m
.38767 .63079 L
s
.38367 .62846 m
.38875 .62501 L
s
.38767 .63079 m
.38367 .62846 L
s
0 .184 1 r
.70839 .91205 m
.70628 .8742 L
s
0 .321 1 r
.34994 .8222 m
.36829 .78569 L
s
.084 1 0 r
.28722 .35972 m
.28348 .35748 L
s
0 1 .729 r
.72657 .71199 m
.7305 .71349 L
s
.7214 .71608 m
.72657 .71199 L
s
.72657 .71199 m
.72316 .70929 L
s
0 1 .81 r
.40276 .27635 m
.40233 .27631 L
s
.4026 .26793 m
.40276 .27635 L
s
.40276 .27635 m
.39734 .27209 L
s
.40759 .27215 m
.40276 .27635 L
s
.40128 .25496 m
.40276 .27635 L
s
.824 1 0 r
.31903 .44858 m
.31642 .44801 L
s
.681 0 1 r
.95642 .88614 m
.94817 .89295 L
s
.94454 .87912 m
.95642 .88614 L
s
0 1 .411 r
.57371 .72097 m
.56934 .71877 L
s
.56934 .71877 m
.57338 .7133 L
s
.445 1 0 r
.5389 .62724 m
.54163 .62812 L
s
.53562 .62873 m
.5389 .62724 L
s
.5389 .62724 m
.53801 .62451 L
s
.824 1 0 r
.31937 .45177 m
.31903 .44858 L
s
0 .489 1 r
.87954 .70486 m
.88323 .70599 L
s
.87331 .71089 m
.87954 .70486 L
s
.87954 .70486 m
.87301 .70208 L
s
.585 0 1 r
.21957 .79314 m
.2148 .79477 L
s
.21911 .7817 m
.21957 .79314 L
s
0 1 .411 r
.57823 .71837 m
.57371 .72097 L
s
.57338 .7133 m
.57823 .71837 L
s
.084 1 0 r
.28486 .36428 m
.28722 .35972 L
s
.772 1 0 r
.35357 .54008 m
.35059 .53818 L
s
1 0 0 r
.63737 .10175 m
.64239 .0982 L
s
.64176 .08406 m
.63737 .10175 L
s
.63737 .10175 m
.6322 .08884 L
s
.65192 .09338 m
.63737 .10175 L
s
.66135 .04748 m
.63737 .10175 L
s
.104 0 1 r
.79517 .88737 m
.79695 .89982 L
s
.681 0 1 r
.94454 .87912 m
.94817 .89295 L
s
0 1 .008 r
.70324 .641 m
.68784 .6209 L
s
.308 0 1 r
.51973 .18956 m
.52182 .18761 L
s
.52191 .17666 m
.51973 .18956 L
s
.51973 .18956 m
.51441 .18099 L
s
.52931 .18325 m
.51973 .18956 L
s
.53057 .15181 m
.51973 .18956 L
s
0 .791 1 r
.60928 .80259 m
.60944 .81255 L
s
.028 0 1 r
.17466 .69518 m
.18222 .70155 L
s
.17153 .69562 m
.17466 .69518 L
s
.17466 .69518 m
.18293 .69085 L
s
0 .489 1 r
.87699 .71204 m
.87331 .71089 L
s
.87331 .71089 m
.87301 .70208 L
s
0 1 .729 r
.72531 .7176 m
.7214 .71608 L
s
.7214 .71608 m
.72316 .70929 L
s
0 .557 1 r
.76723 .80379 m
.76098 .80863 L
s
.75895 .79815 m
.76723 .80379 L
s
.421 1 0 r
.43556 .36213 m
.43565 .36322 L
s
.4359 .35755 m
.43556 .36213 L
s
.43556 .36213 m
.43268 .3602 L
s
.43886 .36057 m
.43556 .36213 L
s
.43663 .35333 m
.43556 .36213 L
s
.351 0 1 r
.40012 .88004 m
.40815 .88653 L
s
.39406 .88326 m
.40012 .88004 L
s
.40012 .88004 m
.40519 .87677 L
s
.445 1 0 r
.53836 .62961 m
.53562 .62873 L
s
.53562 .62873 m
.53801 .62451 L
s
.028 0 1 r
.18222 .70155 m
.17911 .70202 L
s
.18293 .69085 m
.18222 .70155 L
s
1 .749 0 r
.50457 .53858 m
.50539 .53812 L
s
.50238 .53912 m
.50457 .53858 L
s
.50457 .53858 m
.50322 .53631 L
s
0 .837 1 r
.51188 .8195 m
.5186 .78641 L
s
.181 0 1 r
.871 .90952 m
.85727 .86784 L
s
.028 0 1 r
.15276 .72949 m
.18293 .69085 L
s
.445 1 0 r
.54163 .62812 m
.53836 .62961 L
s
.53801 .62451 m
.54163 .62812 L
s
0 1 .411 r
.57338 .7133 m
.57371 .72097 L
s
0 1 .008 r
.6919 .62293 m
.69389 .62344 L
s
.68798 .62641 m
.6919 .62293 L
s
.6919 .62293 m
.68784 .6209 L
s
0 1 .81 r
.4026 .26793 m
.39734 .27209 L
s
.40759 .27215 m
.4026 .26793 L
s
1 .654 0 r
.46906 .44882 m
.46912 .45073 L
s
.47006 .44776 m
.46906 .44882 L
s
.46906 .44882 m
.46814 .44885 L
s
.47104 .44965 m
.46906 .44882 L
s
.47172 .45096 m
.46906 .44882 L
s
1 .749 0 r
.5032 .53866 m
.50238 .53912 L
s
.50238 .53912 m
.50322 .53631 L
s
0 .557 1 r
.75895 .79815 m
.76098 .80863 L
s
0 .433 1 r
.1451 .61039 m
.14415 .60998 L
s
.13847 .60429 m
.1451 .61039 L
s
.14746 .60058 m
.1451 .61039 L
s
.69 0 1 r
.66931 .18486 m
.67472 .18362 L
s
.67446 .17152 m
.66931 .18486 L
s
.66931 .18486 m
.66723 .17507 L
s
.68193 .18004 m
.66931 .18486 L
s
.69611 .14778 m
.66931 .18486 L
s
0 1 .008 r
.68995 .62693 m
.68798 .62641 L
s
.68798 .62641 m
.68784 .6209 L
s
.445 1 0 r
.53801 .62451 m
.53836 .62961 L
s
0 .433 1 r
.1375 .60385 m
.13847 .60429 L
s
.13847 .60429 m
.14746 .60058 L
s
0 1 .948 r
.84504 .61577 m
.84671 .61626 L
s
.84022 .62159 m
.84504 .61577 L
s
.84504 .61577 m
.83782 .61417 L
s
0 .973 1 r
.55209 .27407 m
.55463 .27384 L
s
.5549 .26524 m
.55209 .27407 L
s
.55209 .27407 m
.54962 .26822 L
s
.55991 .27085 m
.55209 .27407 L
s
.56563 .25114 m
.55209 .27407 L
s
.107 0 1 r
.90859 .79043 m
.91244 .8024 L
s
.90859 .79043 m
.91981 .79599 L
s
0 1 .948 r
.84188 .6221 m
.84022 .62159 L
s
.84022 .62159 m
.83782 .61417 L
s
1 .749 0 r
.50322 .53631 m
.5032 .53866 L
s
.50322 .53631 m
.50539 .53812 L
s
.50654 .54786 m
.50322 .53631 L
s
.107 0 1 r
.91981 .79599 m
.91244 .8024 L
s
1 0 .832 r
.25597 .87301 m
.25118 .88792 L
s
.2419 .87972 m
.25597 .87301 L
s
0 .689 1 r
.10808 .51969 m
.10977 .51911 L
s
.10282 .51304 m
.10808 .51969 L
s
.11277 .51099 m
.10808 .51969 L
s
.421 1 0 r
.4359 .35755 m
.43268 .3602 L
s
.43886 .36057 m
.4359 .35755 L
s
1 .654 0 r
.46912 .45073 m
.47104 .44965 L
s
.47104 .44965 m
.47006 .44776 L
s
1 .749 0 r
.50539 .53812 m
.5032 .53866 L
s
0 1 .948 r
.86599 .63795 m
.83782 .61417 L
s
0 1 .729 r
.7305 .71349 m
.72531 .7176 L
s
.72316 .70929 m
.7305 .71349 L
s
.308 0 1 r
.52191 .17666 m
.51441 .18099 L
s
.52931 .18325 m
.52191 .17666 L
s
1 .654 0 r
.46814 .44885 m
.46912 .45073 L
s
1 0 .832 r
.25118 .88792 m
.2419 .87972 L
s
0 1 .81 r
.40233 .27631 m
.40759 .27215 L
s
1 0 0 r
.64176 .08406 m
.6322 .08884 L
s
.65192 .09338 m
.64176 .08406 L
s
0 1 .81 r
.39734 .27209 m
.40233 .27631 L
s
.351 0 1 r
.40815 .88653 m
.40212 .88978 L
s
.40519 .87677 m
.40815 .88653 L
s
.421 1 0 r
.43565 .36322 m
.43886 .36057 L
s
1 .654 0 r
.47006 .44776 m
.46814 .44885 L
s
0 1 .729 r
.72316 .70929 m
.72531 .7176 L
s
.575 1 0 r
.65501 .53703 m
.6552 .53701 L
s
.6552 .53701 m
.65754 .53374 L
s
.6552 .53701 m
.65304 .53307 L
s
.421 1 0 r
.43268 .3602 m
.43565 .36322 L
s
0 .321 1 r
.36356 .78937 m
.37055 .79466 L
s
.35864 .7914 m
.36356 .78937 L
s
.36356 .78937 m
.36829 .78569 L
s
.029 1 0 r
.58512 .35956 m
.58773 .36079 L
s
.58858 .35442 m
.58512 .35956 L
s
.58512 .35956 m
.58513 .35616 L
s
.59118 .35905 m
.58512 .35956 L
s
.60043 .34971 m
.58512 .35956 L
s
.575 1 0 r
.65754 .53374 m
.65735 .53375 L
s
.65754 .53374 m
.65304 .53307 L
s
0 .689 1 r
.1045 .51244 m
.10282 .51304 L
s
.10282 .51304 m
.11277 .51099 L
s
0 1 .53 r
.80729 .53282 m
.80765 .53252 L
s
.80765 .53252 m
.81062 .52662 L
s
.80765 .53252 m
.80307 .5268 L
s
.585 0 1 r
.21911 .7817 m
.2148 .79477 L
s
.20637 .78759 m
.21911 .7817 L
s
0 .405 1 r
.70189 .26902 m
.70735 .26982 L
s
.70778 .25964 m
.70189 .26902 L
s
.70189 .26902 m
.70255 .2621 L
s
.71257 .26734 m
.70189 .26902 L
s
.73061 .24731 m
.70189 .26902 L
s
0 .489 1 r
.87301 .70208 m
.87699 .71204 L
s
.87301 .70208 m
.88323 .70599 L
s
0 .689 1 r
.11277 .51099 m
.10977 .51911 L
s
.1045 .51244 m
.11277 .51099 L
s
.08024 .53652 m
.11277 .51099 L
s
0 .88 1 r
.67442 .81679 m
.66958 .78383 L
s
0 1 .992 r
.31463 .72661 m
.33201 .69503 L
s
0 .973 1 r
.5549 .26524 m
.54962 .26822 L
s
.55991 .27085 m
.5549 .26524 L
s
0 1 .008 r
.68784 .6209 m
.68995 .62693 L
s
.68784 .6209 m
.69389 .62344 L
s
0 1 .53 r
.81062 .52662 m
.81026 .52691 L
s
.81062 .52662 m
.80307 .5268 L
s
.657 1 0 r
.61878 .44593 m
.62101 .44844 L
s
.62299 .44406 m
.61878 .44593 L
s
.61878 .44593 m
.62098 .44467 L
s
.62303 .44783 m
.61878 .44593 L
s
.63496 .44754 m
.61878 .44593 L
s
.62101 .44844 m
.62303 .44783 L
s
.62303 .44783 m
.62299 .44406 L
s
.028 0 1 r
.18293 .69085 m
.17911 .70202 L
s
.17153 .69562 m
.18293 .69085 L
s
0 .433 1 r
.14746 .60058 m
.14415 .60998 L
s
.1375 .60385 m
.14746 .60058 L
s
.11664 .63337 m
.14746 .60058 L
s
.575 1 0 r
.65304 .53307 m
.65501 .53703 L
s
.65304 .53307 m
.65735 .53375 L
s
.66923 .54463 m
.65304 .53307 L
s
0 .117 1 r
.55302 .88033 m
.56038 .88538 L
s
.54684 .88406 m
.55302 .88033 L
s
.55302 .88033 m
.55544 .87718 L
s
0 1 .008 r
.69389 .62344 m
.68995 .62693 L
s
.69 0 1 r
.67446 .17152 m
.66723 .17507 L
s
.68193 .18004 m
.67446 .17152 L
s
.308 0 1 r
.52182 .18761 m
.52931 .18325 L
s
0 .489 1 r
.88323 .70599 m
.87699 .71204 L
s
0 1 .436 r
.77343 .4444 m
.77554 .44369 L
s
.77554 .44369 m
.77613 .43738 L
s
.77554 .44369 m
.76881 .44009 L
s
.585 0 1 r
.2148 .79477 m
.20637 .78759 L
s
0 1 .803 r
.73507 .35412 m
.74022 .35676 L
s
.74172 .34831 m
.73507 .35412 L
s
.73507 .35412 m
.73813 .3498 L
s
.74381 .35525 m
.73507 .35412 L
s
.76484 .34608 m
.73507 .35412 L
s
.657 1 0 r
.62299 .44406 m
.62098 .44467 L
s
0 1 .948 r
.83782 .61417 m
.84188 .6221 L
s
.83782 .61417 m
.84671 .61626 L
s
.029 1 0 r
.58773 .36079 m
.59118 .35905 L
s
.59118 .35905 m
.58858 .35442 L
s
.58858 .35442 m
.58513 .35616 L
s
0 .973 1 r
.55463 .27384 m
.55991 .27085 L
s
1 0 0 r
.64239 .0982 m
.65192 .09338 L
s
0 .321 1 r
.37055 .79466 m
.36564 .79671 L
s
.36829 .78569 m
.37055 .79466 L
s
0 1 .436 r
.76881 .44009 m
.77343 .4444 L
s
.77613 .43738 m
.76881 .44009 L
s
.76881 .44009 m
.77402 .43808 L
s
.79881 .44411 m
.76881 .44009 L
s
0 1 .53 r
.80307 .5268 m
.80729 .53282 L
s
.80307 .5268 m
.81026 .52691 L
s
.83253 .5414 m
.80307 .5268 L
s
0 1 .803 r
.74022 .35676 m
.74381 .35525 L
s
.74381 .35525 m
.74172 .34831 L
s
0 1 .436 r
.77613 .43738 m
.77402 .43808 L
s
0 1 .992 r
.32728 .69885 m
.33322 .70306 L
s
.32381 .69967 m
.32728 .69885 L
s
.32728 .69885 m
.33201 .69503 L
s
0 .405 1 r
.70778 .25964 m
.70255 .2621 L
s
.71257 .26734 m
.70778 .25964 L
s
.575 1 0 r
.65735 .53375 m
.65501 .53703 L
s
.69 0 1 r
.67472 .18362 m
.68193 .18004 L
s
0 .405 1 r
.70735 .26982 m
.71257 .26734 L
s
0 1 .803 r
.74172 .34831 m
.73813 .3498 L
s
.657 1 0 r
.62098 .44467 m
.62101 .44844 L
s
.308 0 1 r
.51441 .18099 m
.52182 .18761 L
s
.351 0 1 r
.40212 .88978 m
.39406 .88326 L
s
.39406 .88326 m
.40519 .87677 L
s
.028 0 1 r
.17911 .70202 m
.17153 .69562 L
s
0 .436 1 r
.83758 .81407 m
.8208 .77795 L
s
0 1 .384 r
.47711 .72372 m
.48229 .69604 L
s
0 1 .948 r
.84671 .61626 m
.84188 .6221 L
s
0 .184 1 r
.70649 .87765 m
.71354 .88153 L
s
.69988 .88214 m
.70649 .87765 L
s
.70649 .87765 m
.70628 .8742 L
s
0 .973 1 r
.54962 .26822 m
.55463 .27384 L
s
.029 1 0 r
.58513 .35616 m
.58773 .36079 L
s
0 1 .992 r
.33322 .70306 m
.32977 .7039 L
s
.33201 .69503 m
.33322 .70306 L
s
0 .689 1 r
.10977 .51911 m
.1045 .51244 L
s
0 .837 1 r
.5168 .78987 m
.52288 .79363 L
s
.5116 .79251 m
.5168 .78987 L
s
.5168 .78987 m
.5186 .78641 L
s
0 .117 1 r
.56038 .88538 m
.5542 .88913 L
s
.55544 .87718 m
.56038 .88538 L
s
.351 0 1 r
.40519 .87677 m
.40212 .88978 L
s
0 .433 1 r
.14415 .60998 m
.1375 .60385 L
s
.181 0 1 r
.86032 .87194 m
.86728 .87492 L
s
.85281 .87755 m
.86032 .87194 L
s
.86032 .87194 m
.85727 .86784 L
s
0 1 .53 r
.81026 .52691 m
.80729 .53282 L
s
0 1 .362 r
.29119 .60837 m
.29615 .61189 L
s
.28966 .60811 m
.29119 .60837 L
s
.29119 .60837 m
.29638 .60493 L
s
.72 0 1 r
.28463 .90315 m
.31237 .85836 L
s
1 0 0 r
.6322 .08884 m
.64239 .0982 L
s
0 1 .362 r
.29615 .61189 m
.29463 .61165 L
s
.29638 .60493 m
.29615 .61189 L
s
0 1 .436 r
.77402 .43808 m
.77343 .4444 L
s
0 .321 1 r
.36564 .79671 m
.35864 .7914 L
s
.35864 .7914 m
.36829 .78569 L
s
0 .117 1 r
.5542 .88913 m
.54684 .88406 L
s
.54684 .88406 m
.55544 .87718 L
s
0 .321 1 r
.36829 .78569 m
.36564 .79671 L
s
.045 1 0 r
.25904 .52125 m
.26022 .52063 L
s
.25539 .51742 m
.25904 .52125 L
s
.26144 .51548 m
.25904 .52125 L
s
0 1 .029 r
.22725 .42678 m
.22552 .43141 L
s
.22096 .42561 m
.22725 .42678 L
s
.22725 .42678 m
.22193 .43075 L
s
.22455 .42626 m
.22725 .42678 L
s
.20708 .43548 m
.22725 .42678 L
s
0 1 .803 r
.73813 .3498 m
.74022 .35676 L
s
.69 0 1 r
.66723 .17507 m
.67472 .18362 L
s
0 1 .362 r
.64021 .72082 m
.63335 .69384 L
s
.27905 .6303 m
.29638 .60493 L
s
0 1 .029 r
.22193 .43075 m
.22552 .43141 L
s
.22096 .42561 m
.22193 .43075 L
s
.045 1 0 r
.25656 .51679 m
.25539 .51742 L
s
.25539 .51742 m
.26144 .51548 L
s
0 .405 1 r
.70255 .2621 m
.70735 .26982 L
s
0 1 .992 r
.33201 .69503 m
.32977 .7039 L
s
.32381 .69967 m
.33201 .69503 L
s
.045 1 0 r
.26144 .51548 m
.26022 .52063 L
s
.25656 .51679 m
.26144 .51548 L
s
.2432 .53326 m
.26144 .51548 L
s
0 .88 1 r
.67066 .78734 m
.6762 .78997 L
s
.66492 .79096 m
.67066 .78734 L
s
.67066 .78734 m
.66958 .78383 L
s
0 1 .384 r
.48087 .69963 m
.48562 .7021 L
s
.47688 .7011 m
.48087 .69963 L
s
.48087 .69963 m
.48229 .69604 L
s
0 .837 1 r
.52288 .79363 m
.51769 .79628 L
s
.5186 .78641 m
.52288 .79363 L
s
0 1 .362 r
.29638 .60493 m
.29463 .61165 L
s
.28966 .60811 m
.29638 .60493 L
s
0 .184 1 r
.70692 .88604 m
.69988 .88214 L
s
.69988 .88214 m
.70628 .8742 L
s
0 1 .992 r
.32977 .7039 m
.32381 .69967 L
s
.181 0 1 r
.85975 .88055 m
.85281 .87755 L
s
.85281 .87755 m
.85727 .86784 L
s
.008 0 1 r
.44752 .90059 m
.46357 .86069 L
s
0 .184 1 r
.71354 .88153 m
.70692 .88604 L
s
.70628 .8742 m
.71354 .88153 L
s
0 1 .029 r
.22455 .42626 m
.22096 .42561 L
s
0 .436 1 r
.8249 .78174 m
.83015 .78363 L
s
.81822 .78681 m
.8249 .78174 L
s
.8249 .78174 m
.8208 .77795 L
s
0 .837 1 r
.51769 .79628 m
.5116 .79251 L
s
.5116 .79251 m
.5186 .78641 L
s
0 .117 1 r
.55544 .87718 m
.5542 .88913 L
s
0 1 .362 r
.29463 .61165 m
.28966 .60811 L
s
0 1 .029 r
.22552 .43141 m
.22455 .42626 L
s
0 1 .384 r
.48562 .7021 m
.48164 .70357 L
s
.48229 .69604 m
.48562 .7021 L
s
0 1 .919 r
.80392 .71791 m
.78473 .68843 L
s
.41 1 0 r
.44208 .62722 m
.44658 .60619 L
s
.045 1 0 r
.26022 .52063 m
.25656 .51679 L
s
.41 1 0 r
.44518 .60969 m
.44871 .61092 L
s
.44265 .60988 m
.44518 .60969 L
s
.44518 .60969 m
.44658 .60619 L
s
.72 0 1 r
.3052 .86249 m
.31399 .86972 L
s
.29956 .86501 m
.3052 .86249 L
s
.3052 .86249 m
.31237 .85836 L
s
0 .88 1 r
.67045 .79361 m
.66492 .79096 L
s
.66492 .79096 m
.66958 .78383 L
s
.053 1 0 r
.34337 .34082 m
.34211 .34287 L
s
.34146 .33578 m
.34337 .34082 L
s
.34337 .34082 m
.33823 .33996 L
s
.34534 .3387 m
.34337 .34082 L
s
.33538 .33327 m
.34337 .34082 L
s
0 1 .362 r
.63514 .69722 m
.63902 .69859 L
s
.63043 .69993 m
.63514 .69722 L
s
.63514 .69722 m
.63335 .69384 L
s
0 .837 1 r
.5186 .78641 m
.51769 .79628 L
s
0 .436 1 r
.82345 .78871 m
.81822 .78681 L
s
.81822 .78681 m
.8208 .77795 L
s
0 1 .384 r
.48164 .70357 m
.47688 .7011 L
s
.47688 .7011 m
.48229 .69604 L
s
.181 0 1 r
.86728 .87492 m
.85975 .88055 L
s
.85727 .86784 m
.86728 .87492 L
s
.119 0 1 r
.24884 .80723 m
.2751 .76623 L
s
0 .319 1 r
.61102 .89801 m
.61564 .85965 L
s
0 .184 1 r
.70628 .8742 m
.70692 .88604 L
s
0 .88 1 r
.6762 .78997 m
.67045 .79361 L
s
.66958 .78383 m
.6762 .78997 L
s
.41 1 0 r
.44871 .61092 m
.44617 .61112 L
s
.44658 .60619 m
.44871 .61092 L
s
.931 1 0 r
.37707 .42848 m
.37676 .43129 L
s
.37506 .42707 m
.37707 .42848 L
s
.37707 .42848 m
.37397 .42988 L
s
.37785 .42848 m
.37707 .42848 L
s
.37122 .432 m
.37707 .42848 L
s
0 1 .384 r
.48229 .69604 m
.48164 .70357 L
s
0 1 .919 r
.78973 .69161 m
.79307 .69249 L
s
.78409 .69619 m
.78973 .69161 L
s
.78973 .69161 m
.78473 .68843 L
s
1 .965 0 r
.40918 .51968 m
.41199 .52054 L
s
.40911 .5186 m
.40918 .51968 L
s
.40918 .51968 m
.41149 .51697 L
s
.41199 .52054 m
.41192 .51946 L
s
.41149 .51697 m
.41199 .52054 L
s
.181 0 1 r
.85727 .86784 m
.85975 .88055 L
s
.41 1 0 r
.44617 .61112 m
.44265 .60988 L
s
.44265 .60988 m
.44658 .60619 L
s
1 .965 0 r
.41149 .51697 m
.41192 .51946 L
s
.40911 .5186 m
.41149 .51697 L
s
.40678 .52998 m
.41149 .51697 L
s
.72 0 1 r
.31399 .86972 m
.30838 .87228 L
s
.31237 .85836 m
.31399 .86972 L
s
.41 1 0 r
.44658 .60619 m
.44617 .61112 L
s
0 1 .362 r
.63431 .70131 m
.63043 .69993 L
s
.63043 .69993 m
.63335 .69384 L
s
.416 1 0 r
.60573 .62412 m
.59763 .60434 L
s
0 .918 1 r
.46076 .25337 m
.46144 .25333 L
s
.46182 .24414 m
.46076 .25337 L
s
.46076 .25337 m
.45603 .24818 L
s
.46723 .24928 m
.46076 .25337 L
s
.46516 .22988 m
.46076 .25337 L
s
.931 1 0 r
.37397 .42988 m
.37676 .43129 L
s
.37506 .42707 m
.37397 .42988 L
s
0 1 .919 r
.78743 .69708 m
.78409 .69619 L
s
.78409 .69619 m
.78473 .68843 L
s
.416 1 0 r
.60008 .60728 m
.60205 .60743 L
s
.59646 .60917 m
.60008 .60728 L
s
.60008 .60728 m
.59763 .60434 L
s
.119 0 1 r
.26806 .77071 m
.27595 .7769 L
s
.26369 .77202 m
.26806 .77071 L
s
.26806 .77071 m
.2751 .76623 L
s
.053 1 0 r
.34146 .33578 m
.33823 .33996 L
s
.34534 .3387 m
.34146 .33578 L
s
.33823 .33996 m
.34211 .34287 L
s
0 .88 1 r
.66958 .78383 m
.67045 .79361 L
s
.931 1 0 r
.37676 .43129 m
.37785 .42848 L
s
.648 0 1 r
.57907 .1647 m
.58247 .16302 L
s
.58251 .15089 m
.57907 .1647 L
s
.57907 .1647 m
.57459 .15524 L
s
.59037 .15864 m
.57907 .1647 L
s
.59645 .12529 m
.57907 .1647 L
s
0 1 .362 r
.63902 .69859 m
.63431 .70131 L
s
.63335 .69384 m
.63902 .69859 L
s
1 .965 0 r
.41192 .51946 m
.40911 .5186 L
s
.931 1 0 r
.37785 .42848 m
.37506 .42707 L
s
0 .436 1 r
.83015 .78363 m
.82345 .78871 L
s
.8208 .77795 m
.83015 .78363 L
s
0 .2 1 r
.77514 .89543 m
.76813 .85519 L
s
0 .676 1 r
.41227 .80448 m
.42631 .76883 L
s
.416 1 0 r
.59843 .60933 m
.59646 .60917 L
s
.59646 .60917 m
.59763 .60434 L
s
.053 1 0 r
.34211 .34287 m
.34534 .3387 L
s
.096 1 0 r
.494 .33985 m
.495 .34113 L
s
.49566 .3345 m
.494 .33985 L
s
.494 .33985 m
.4918 .3371 L
s
.49886 .33852 m
.494 .33985 L
s
.50071 .32958 m
.494 .33985 L
s
0 .436 1 r
.8208 .77795 m
.82345 .78871 L
s
.119 0 1 r
.27595 .7769 m
.2716 .77824 L
s
.2751 .76623 m
.27595 .7769 L
s
0 1 .308 r
.75483 .60147 m
.75606 .60161 L
s
.75051 .60577 m
.75483 .60147 L
s
.75483 .60147 m
.7491 .59936 L
s
0 1 .362 r
.63335 .69384 m
.63431 .70131 L
s
0 1 .308 r
.75172 .60592 m
.75051 .60577 L
s
.75051 .60577 m
.7491 .59936 L
s
.008 0 1 r
.45934 .86451 m
.46707 .87004 L
s
.45359 .86742 m
.45934 .86451 L
s
.45934 .86451 m
.46357 .86069 L
s
1 .965 0 r
.56267 .51833 m
.56335 .51888 L
s
.56335 .51888 m
.56568 .51704 L
s
.56335 .51888 m
.56247 .51544 L
s
.952 1 0 r
.52792 .42724 m
.52863 .42953 L
s
.53041 .42546 m
.52792 .42724 L
s
.52792 .42724 m
.52781 .42655 L
s
.53123 .42843 m
.52792 .42724 L
s
.53598 .42851 m
.52792 .42724 L
s
0 .569 1 r
.61186 .24986 m
.61555 .25012 L
s
.61601 .24018 m
.61186 .24986 L
s
.61186 .24986 m
.61021 .24327 L
s
.62133 .24701 m
.61186 .24986 L
s
.63169 .22597 m
.61186 .24986 L
s
1 .965 0 r
.56568 .51704 m
.565 .51649 L
s
.56568 .51704 m
.56247 .51544 L
s
.416 1 0 r
.59763 .60434 m
.59843 .60933 L
s
.59763 .60434 m
.60205 .60743 L
s
0 1 .308 r
.77 .62102 m
.7491 .59936 L
s
0 .458 1 r
.23118 .67899 m
.23819 .68439 L
s
.22848 .67917 m
.23118 .67899 L
s
.23118 .67899 m
.23849 .67457 L
s
0 .918 1 r
.46182 .24414 m
.45603 .24818 L
s
.46723 .24928 m
.46182 .24414 L
s
1 .965 0 r
.56247 .51544 m
.56267 .51833 L
s
.56247 .51544 m
.565 .51649 L
s
.57099 .52669 m
.56247 .51544 L
s
.416 1 0 r
.60205 .60743 m
.59843 .60933 L
s
0 1 .919 r
.78473 .68843 m
.78743 .69708 L
s
.78473 .68843 m
.79307 .69249 L
s
.952 1 0 r
.52863 .42953 m
.53123 .42843 L
s
.53123 .42843 m
.53041 .42546 L
s
.118 1 0 r
.71658 .51563 m
.71756 .51558 L
s
.71756 .51558 m
.72005 .5111 L
s
.71756 .51558 m
.71395 .51086 L
s
0 .458 1 r
.23819 .68439 m
.23551 .68458 L
s
.23849 .67457 m
.23819 .68439 L
s
0 1 .919 r
.79307 .69249 m
.78743 .69708 L
s
.648 0 1 r
.58251 .15089 m
.57459 .15524 L
s
.59037 .15864 m
.58251 .15089 L
s
.096 1 0 r
.49566 .3345 m
.4918 .3371 L
s
.49886 .33852 m
.49566 .3345 L
s
0 1 .462 r
.64529 .33601 m
.64887 .33793 L
s
.65019 .33008 m
.64529 .33601 L
s
.64529 .33601 m
.64611 .332 L
s
.65294 .336 m
.64529 .33601 L
s
.66667 .32587 m
.64529 .33601 L
s
.096 1 0 r
.495 .34113 m
.49886 .33852 L
s
0 .918 1 r
.46144 .25333 m
.46723 .24928 L
s
0 1 .972 r
.57633 .80171 m
.57847 .76813 L
s
.371 0 1 r
.93989 .89284 m
.92059 .84734 L
s
0 .458 1 r
.21277 .71059 m
.23849 .67457 L
s
.952 1 0 r
.53041 .42546 m
.52781 .42655 L
s
.118 1 0 r
.72005 .5111 m
.71907 .51114 L
s
.72005 .5111 m
.71395 .51086 L
s
1 .965 0 r
.565 .51649 m
.56267 .51833 L
s
0 1 .308 r
.7491 .59936 m
.75172 .60592 L
s
.7491 .59936 m
.75606 .60161 L
s
.952 1 0 r
.52781 .42655 m
.52863 .42953 L
s
.72 0 1 r
.31237 .85836 m
.30838 .87228 L
s
.29956 .86501 m
.31237 .85836 L
s
.30838 .87228 m
.29956 .86501 L
s
.105 1 0 r
.67934 .42305 m
.68241 .4264 L
s
.68504 .42047 m
.67934 .42305 L
s
.67934 .42305 m
.68234 .42129 L
s
.6851 .42558 m
.67934 .42305 L
s
.70137 .425 m
.67934 .42305 L
s
0 .931 1 r
.20061 .59233 m
.20016 .59169 L
s
.19458 .58715 m
.20061 .59233 L
s
.20258 .58348 m
.20061 .59233 L
s
.118 1 0 r
.71395 .51086 m
.71658 .51563 L
s
.71395 .51086 m
.71907 .51114 L
s
.73581 .52338 m
.71395 .51086 L
s
.105 1 0 r
.68241 .4264 m
.6851 .42558 L
s
.6851 .42558 m
.68504 .42047 L
s
0 .931 1 r
.1941 .5865 m
.19458 .58715 L
s
.19458 .58715 m
.20258 .58348 L
s
0 .918 1 r
.45603 .24818 m
.46144 .25333 L
s
.008 0 1 r
.46707 .87004 m
.46133 .87298 L
s
.46357 .86069 m
.46707 .87004 L
s
.096 1 0 r
.4918 .3371 m
.495 .34113 L
s
0 .569 1 r
.61601 .24018 m
.61021 .24327 L
s
.62133 .24701 m
.61601 .24018 L
s
0 .676 1 r
.42251 .77297 m
.42912 .77727 L
s
.41784 .77472 m
.42251 .77297 L
s
.42251 .77297 m
.42631 .76883 L
s
0 1 .829 r
.163 .50069 m
.16531 .50011 L
s
.15855 .4948 m
.163 .50069 L
s
.16742 .49307 m
.163 .50069 L
s
0 1 .462 r
.64887 .33793 m
.65294 .336 L
s
.65294 .336 m
.65019 .33008 L
s
.648 0 1 r
.58247 .16302 m
.59037 .15864 L
s
.105 1 0 r
.68504 .42047 m
.68234 .42129 L
s
0 .319 1 r
.61421 .86358 m
.62132 .86768 L
s
.6081 .86708 m
.61421 .86358 L
s
.61421 .86358 m
.61564 .85965 L
s
0 .569 1 r
.61555 .25012 m
.62133 .24701 L
s
.119 0 1 r
.2751 .76623 m
.2716 .77824 L
s
.26369 .77202 m
.2751 .76623 L
s
0 1 .462 r
.65019 .33008 m
.64611 .332 L
s
0 1 .308 r
.75606 .60161 m
.75172 .60592 L
s
0 1 .829 r
.16742 .49307 m
.16531 .50011 L
s
.15855 .4948 m
.16742 .49307 L
s
.16085 .49421 m
.16742 .49307 L
s
.13982 .51507 m
.16742 .49307 L
s
0 .458 1 r
.23849 .67457 m
.23551 .68458 L
s
.22848 .67917 m
.23849 .67457 L
s
0 1 .829 r
.16085 .49421 m
.15855 .4948 L
s
0 .931 1 r
.20258 .58348 m
.20016 .59169 L
s
.1941 .5865 m
.20258 .58348 L
s
.17644 .6132 m
.20258 .58348 L
s
.119 0 1 r
.2716 .77824 m
.26369 .77202 L
s
.118 1 0 r
.71907 .51114 m
.71658 .51563 L
s
0 .857 1 r
.74101 .79893 m
.73115 .76412 L
s
0 1 .621 r
.37676 .70764 m
.38963 .6774 L
s
.105 1 0 r
.68234 .42129 m
.68241 .4264 L
s
0 .2 1 r
.7696 .85958 m
.77638 .86256 L
s
.76272 .86403 m
.7696 .85958 L
s
.7696 .85958 m
.76813 .85519 L
s
0 .676 1 r
.42912 .77727 m
.42447 .77904 L
s
.42631 .76883 m
.42912 .77727 L
s
.008 0 1 r
.46133 .87298 m
.45359 .86742 L
s
.45359 .86742 m
.46357 .86069 L
s
.371 0 1 r
.92525 .85249 m
.93188 .85464 L
s
.91707 .85833 m
.92525 .85249 L
s
.92525 .85249 m
.92059 .84734 L
s
.648 0 1 r
.57459 .15524 m
.58247 .16302 L
s
0 1 .621 r
.38591 .6816 m
.39144 .68478 L
s
.38265 .68214 m
.38591 .6816 L
s
.38591 .6816 m
.38963 .6774 L
s
0 1 .462 r
.64611 .332 m
.64887 .33793 L
s
1 0 .743 r
.18217 .88893 m
.21813 .83851 L
s
0 .569 1 r
.61021 .24327 m
.61555 .25012 L
s
0 .458 1 r
.23551 .68458 m
.22848 .67917 L
s
0 1 .972 r
.57778 .77224 m
.58351 .77504 L
s
.57257 .77473 m
.57778 .77224 L
s
.57778 .77224 m
.57847 .76813 L
s
.008 0 1 r
.46357 .86069 m
.46133 .87298 L
s
0 .319 1 r
.62132 .86768 m
.61521 .8712 L
s
.61564 .85965 m
.62132 .86768 L
s
0 1 .621 r
.39144 .68478 m
.38819 .68533 L
s
.38963 .6774 m
.39144 .68478 L
s
1 0 .743 r
.20856 .84357 m
.21841 .8518 L
s
.20338 .84545 m
.20856 .84357 L
s
.20856 .84357 m
.21813 .83851 L
s
0 1 .829 r
.16531 .50011 m
.16085 .49421 L
s
0 .196 1 r
.90632 .79615 m
.88387 .75679 L
s
0 1 .209 r
.54138 .70467 m
.54182 .67702 L
s
0 .319 1 r
.61521 .8712 m
.6081 .86708 L
s
.6081 .86708 m
.61564 .85965 L
s
0 .931 1 r
.20016 .59169 m
.1941 .5865 L
s
0 .676 1 r
.42447 .77904 m
.41784 .77472 L
s
.41784 .77472 m
.42631 .76883 L
s
.023 1 0 r
.34942 .59029 m
.354 .59275 L
s
.34812 .58968 m
.34942 .59029 L
s
.34942 .59029 m
.35358 .58651 L
s
.371 0 1 r
.92369 .86051 m
.91707 .85833 L
s
.91707 .85833 m
.92059 .84734 L
s
0 .676 1 r
.42631 .76883 m
.42447 .77904 L
s
0 .2 1 r
.76949 .86704 m
.76272 .86403 L
s
.76272 .86403 m
.76813 .85519 L
s
.023 1 0 r
.354 .59275 m
.35271 .59215 L
s
.35358 .58651 m
.354 .59275 L
s
0 .857 1 r
.73361 .76835 m
.73873 .77014 L
s
.72753 .77209 m
.73361 .76835 L
s
.73361 .76835 m
.73115 .76412 L
s
1 0 .743 r
.21841 .8518 m
.21328 .85373 L
s
.21813 .83851 m
.21841 .8518 L
s
.312 0 1 r
.34657 .88631 m
.37013 .84278 L
s
.214 1 0 r
.28357 .4068 m
.28244 .41091 L
s
.27875 .40501 m
.28357 .4068 L
s
.28357 .4068 m
.27849 .40966 L
s
.2827 .40626 m
.28357 .4068 L
s
.26859 .41263 m
.28357 .4068 L
s
0 .196 1 r
.88969 .76134 m
.89444 .76251 L
s
.88234 .76686 m
.88969 .76134 L
s
.88969 .76134 m
.88387 .75679 L
s
.404 1 0 r
.3162 .50131 m
.31806 .50055 L
s
.31308 .49816 m
.3162 .50131 L
s
.31822 .49628 m
.3162 .50131 L
s
0 1 .209 r
.54166 .68114 m
.54593 .68261 L
s
.53752 .68253 m
.54166 .68114 L
s
.54166 .68114 m
.54182 .67702 L
s
0 1 .621 r
.38963 .6774 m
.38819 .68533 L
s
.38265 .68214 m
.38963 .6774 L
s
0 1 .972 r
.58351 .77504 m
.5783 .77754 L
s
.57847 .76813 m
.58351 .77504 L
s
0 1 .621 r
.38819 .68533 m
.38265 .68214 L
s
.404 1 0 r
.31822 .49628 m
.31806 .50055 L
s
.31308 .49816 m
.31822 .49628 L
s
.31494 .4974 m
.31822 .49628 L
s
.30493 .51172 m
.31822 .49628 L
s
.023 1 0 r
.35358 .58651 m
.35271 .59215 L
s
.34812 .58968 m
.35358 .58651 L
s
.34098 .61005 m
.35358 .58651 L
s
.738 0 1 r
.17084 .75066 m
.17993 .75805 L
s
.16708 .75133 m
.17084 .75066 L
s
.17084 .75066 m
.18051 .74536 L
s
0 .2 1 r
.77638 .86256 m
.76949 .86704 L
s
.76813 .85519 m
.77638 .86256 L
s
0 .319 1 r
.61564 .85965 m
.61521 .8712 L
s
0 1 .972 r
.5783 .77754 m
.57257 .77473 L
s
.57257 .77473 m
.57847 .76813 L
s
.404 1 0 r
.31494 .4974 m
.31308 .49816 L
s
.214 1 0 r
.27849 .40966 m
.28244 .41091 L
s
.27875 .40501 m
.27849 .40966 L
s
0 1 .448 r
.70662 .7017 m
.6946 .67342 L
s
0 .196 1 r
.88707 .76805 m
.88234 .76686 L
s
.88234 .76686 m
.88387 .75679 L
s
.738 0 1 r
.17993 .75805 m
.17622 .75876 L
s
.18051 .74536 m
.17993 .75805 L
s
0 .857 1 r
.73264 .7739 m
.72753 .77209 L
s
.72753 .77209 m
.73115 .76412 L
s
.023 1 0 r
.35271 .59215 m
.34812 .58968 L
s
.214 1 0 r
.2827 .40626 m
.27875 .40501 L
s
.28244 .41091 m
.2827 .40626 L
s
0 .277 1 r
.5116 .88368 m
.52329 .84368 L
s
.738 0 1 r
.14561 .79195 m
.18051 .74536 L
s
0 1 .448 r
.69796 .67724 m
.70121 .67787 L
s
.69282 .68032 m
.69796 .67724 L
s
.69796 .67724 m
.6946 .67342 L
s
0 .2 1 r
.76813 .85519 m
.76949 .86704 L
s
.553 1 0 r
.50591 .59035 m
.50874 .59047 L
s
.50288 .59058 m
.50591 .59035 L
s
.50591 .59035 m
.50572 .58643 L
s
.404 1 0 r
.31806 .50055 m
.31494 .4974 L
s
0 1 .972 r
.57847 .76813 m
.5783 .77754 L
s
.371 0 1 r
.93188 .85464 m
.92369 .86051 L
s
.92059 .84734 m
.93188 .85464 L
s
0 1 .209 r
.54593 .68261 m
.54179 .68401 L
s
.54182 .67702 m
.54593 .68261 L
s
.371 0 1 r
.92059 .84734 m
.92369 .86051 L
s
0 1 .209 r
.54179 .68401 m
.53752 .68253 L
s
.53752 .68253 m
.54182 .67702 L
s
.273 0 1 r
.13342 .65771 m
.1417 .66464 L
s
.13155 .65735 m
.13342 .65771 L
s
.13342 .65771 m
.1436 .65271 L
s
0 1 .105 r
.40125 .31882 m
.40077 .32071 L
s
.40077 .31306 m
.40125 .31882 L
s
.40125 .31882 m
.39674 .31697 L
s
.40481 .31679 m
.40125 .31882 L
s
.39886 .30901 m
.40125 .31882 L
s
0 .768 1 r
.85434 .67019 m
.857 .67054 L
s
.84807 .6755 m
.85434 .67019 L
s
.85434 .67019 m
.84753 .66658 L
s
.273 0 1 r
.1417 .66464 m
.13987 .66431 L
s
.1436 .65271 m
.1417 .66464 L
s
.312 0 1 r
.36382 .84731 m
.37222 .85357 L
s
.35855 .8495 m
.36382 .84731 L
s
.36382 .84731 m
.37013 .84278 L
s
0 .857 1 r
.73873 .77014 m
.73264 .7739 L
s
.73115 .76412 m
.73873 .77014 L
s
0 .768 1 r
.8725 .69872 m
.84753 .66658 L
s
.553 1 0 r
.50616 .60689 m
.50572 .58643 L
s
0 1 .209 r
.54182 .67702 m
.54179 .68401 L
s
0 1 .448 r
.69606 .68095 m
.69282 .68032 L
s
.69282 .68032 m
.6946 .67342 L
s
0 .768 1 r
.85071 .67586 m
.84807 .6755 L
s
.84807 .6755 m
.84753 .66658 L
s
.824 1 0 r
.43539 .40722 m
.43529 .41006 L
s
.43531 .40512 m
.43539 .40722 L
s
.43539 .40722 m
.43282 .40756 L
s
.43778 .40762 m
.43539 .40722 L
s
.4349 .40907 m
.43539 .40722 L
s
0 .07 1 r
.10363 .57166 m
.10424 .57075 L
s
.09639 .56455 m
.10363 .57166 L
s
.10744 .56066 m
.10363 .57166 L
s
.553 1 0 r
.50571 .59069 m
.50288 .59058 L
s
.50288 .59058 m
.50572 .58643 L
s
1 0 .743 r
.21813 .83851 m
.21328 .85373 L
s
.20338 .84545 m
.21813 .83851 L
s
.553 1 0 r
.50874 .59047 m
.50571 .59069 L
s
.50572 .58643 m
.50874 .59047 L
s
.50572 .58643 m
.50571 .59069 L
s
0 .857 1 r
.73115 .76412 m
.73264 .7739 L
s
1 .918 0 r
.47133 .4998 m
.4721 .49823 L
s
.46854 .49944 m
.47133 .4998 L
s
.47133 .4998 m
.47023 .49646 L
s
.47023 .49646 m
.46931 .49787 L
s
.47023 .49646 m
.4721 .49823 L
s
.46854 .49944 m
.47023 .49646 L
s
.47067 .50836 m
.47023 .49646 L
s
0 .59 1 r
.52008 .22941 m
.52191 .22955 L
s
.52242 .21932 m
.52008 .22941 L
s
.52008 .22941 m
.5161 .22333 L
s
.52823 .22552 m
.52008 .22941 L
s
.53065 .20417 m
.52008 .22941 L
s
1 0 .978 r
.6397 .13884 m
.64443 .13761 L
s
.64452 .12409 m
.6397 .13884 L
s
.6397 .13884 m
.63615 .12853 L
s
.65278 .13313 m
.6397 .13884 L
s
.664 .0981 m
.6397 .13884 L
s
0 .07 1 r
.09697 .56361 m
.09639 .56455 L
s
.09639 .56455 m
.10744 .56066 L
s
0 .196 1 r
.88387 .75679 m
.88707 .76805 L
s
.88387 .75679 m
.89444 .76251 L
s
1 .918 0 r
.46931 .49787 m
.46854 .49944 L
s
.214 1 0 r
.66275 .58612 m
.66375 .5858 L
s
.65871 .58882 m
.66275 .58612 L
s
.66275 .58612 m
.65855 .58321 L
s
0 .433 1 r
.67726 .88105 m
.67715 .84116 L
s
0 .305 1 r
.31057 .78913 m
.33246 .74984 L
s
.214 1 0 r
.65971 .58851 m
.65871 .58882 L
s
.65871 .58882 m
.65855 .58321 L
s
.738 0 1 r
.18051 .74536 m
.17622 .75876 L
s
.16708 .75133 m
.18051 .74536 L
s
.312 0 1 r
.37222 .85357 m
.36698 .85579 L
s
.37013 .84278 m
.37222 .85357 L
s
0 .196 1 r
.89444 .76251 m
.88707 .76805 L
s
0 1 .723 r
.81474 .58422 m
.81436 .58431 L
s
.81436 .58431 m
.81917 .57895 L
s
.81436 .58431 m
.8116 .57684 L
s
0 1 .105 r
.40077 .31306 m
.39674 .31697 L
s
.40481 .31679 m
.40077 .31306 L
s
.824 1 0 r
.43529 .41006 m
.43778 .40762 L
s
.43282 .40756 m
.43529 .41006 L
s
0 1 .723 r
.81917 .57895 m
.81956 .57884 L
s
.81917 .57895 m
.8116 .57684 L
s
0 1 .448 r
.6946 .67342 m
.69606 .68095 L
s
.6946 .67342 m
.70121 .67787 L
s
1 .918 0 r
.4721 .49823 m
.46931 .49787 L
s
1 0 .743 r
.21328 .85373 m
.20338 .84545 L
s
0 1 .448 r
.70121 .67787 m
.69606 .68095 L
s
0 1 .303 r
.55375 .31659 m
.55571 .31825 L
s
.5568 .31043 m
.55375 .31659 L
s
.55375 .31659 m
.55229 .31308 L
s
.56022 .31559 m
.55375 .31659 L
s
.56639 .30522 m
.55375 .31659 L
s
.824 1 0 r
.43778 .40762 m
.43531 .40512 L
s
.273 0 1 r
.1436 .65271 m
.13987 .66431 L
s
.13155 .65735 m
.1436 .65271 L
s
.10877 .69422 m
.1436 .65271 L
s
.824 1 0 r
.43531 .40512 m
.43282 .40756 L
s
0 .07 1 r
.10744 .56066 m
.10424 .57075 L
s
.09697 .56361 m
.10744 .56066 L
s
.07164 .59574 m
.10744 .56066 L
s
0 .305 1 r
.32635 .75464 m
.3338 .75982 L
s
.32233 .75563 m
.32635 .75464 L
s
.32635 .75464 m
.33246 .74984 L
s
0 1 .105 r
.39674 .31697 m
.40077 .32071 L
s
.214 1 0 r
.67197 .60372 m
.65855 .58321 L
s
0 1 .105 r
.40077 .32071 m
.40481 .31679 L
s
0 .128 1 r
.67291 .22466 m
.67774 .22556 L
s
.67854 .21411 m
.67291 .22466 L
s
.67291 .22466 m
.67216 .21736 L
s
.6841 .22229 m
.67291 .22466 L
s
.69943 .20016 m
.67291 .22466 L
s
0 .768 1 r
.84753 .66658 m
.85071 .67586 L
s
.84753 .66658 m
.857 .67054 L
s
.64 1 0 r
.62388 .49734 m
.62558 .4976 L
s
.62558 .4976 m
.62776 .4944 L
s
.62558 .4976 m
.62302 .49359 L
s
.214 1 0 r
.65855 .58321 m
.65971 .58851 L
s
.65855 .58321 m
.66375 .5858 L
s
.471 1 0 r
.58808 .40469 m
.58961 .40756 L
s
.59202 .40214 m
.58808 .40469 L
s
.58808 .40469 m
.58877 .40337 L
s
.59286 .40632 m
.58808 .40469 L
s
.60186 .40549 m
.58808 .40469 L
s
.64 1 0 r
.62302 .49359 m
.62388 .49734 L
s
.62776 .4944 m
.62302 .49359 L
s
.62302 .49359 m
.62606 .49413 L
s
.63705 .50499 m
.62302 .49359 L
s
0 1 .411 r
.77945 .49342 m
.78124 .4933 L
s
.78124 .4933 m
.78395 .48748 L
s
.78124 .4933 m
.77613 .48767 L
s
.64 1 0 r
.62776 .4944 m
.62606 .49413 L
s
0 .277 1 r
.52 .84816 m
.52745 .85269 L
s
.51442 .85077 m
.52 .84816 L
s
.52 .84816 m
.52329 .84368 L
s
0 .59 1 r
.52242 .21932 m
.5161 .22333 L
s
.52823 .22552 m
.52242 .21932 L
s
0 1 .985 r
.70674 .31148 m
.71129 .31422 L
s
.71322 .30476 m
.70674 .31148 L
s
.70674 .31148 m
.70845 .30687 L
s
.71605 .31209 m
.70674 .31148 L
s
.73458 .30142 m
.70674 .31148 L
s
0 1 .723 r
.8116 .57684 m
.81474 .58422 L
s
.8116 .57684 m
.81956 .57884 L
s
.83842 .60054 m
.8116 .57684 L
s
0 .105 1 r
.84356 .8784 m
.83125 .83521 L
s
0 .963 1 r
.47616 .78631 m
.48567 .75103 L
s
.471 1 0 r
.58961 .40756 m
.59286 .40632 L
s
.59286 .40632 m
.59202 .40214 L
s
0 .305 1 r
.3338 .75982 m
.3298 .76084 L
s
.33246 .74984 m
.3338 .75982 L
s
.214 1 0 r
.66375 .5858 m
.65971 .58851 L
s
.738 0 1 r
.17622 .75876 m
.16708 .75133 L
s
0 1 .411 r
.78395 .48748 m
.78216 .48759 L
s
.78395 .48748 m
.77613 .48767 L
s
0 .768 1 r
.857 .67054 m
.85071 .67586 L
s
1 0 .978 r
.64452 .12409 m
.63615 .12853 L
s
.65278 .13313 m
.64452 .12409 L
s
0 1 .471 r
.74116 .39918 m
.74507 .4035 L
s
.7485 .39595 m
.74116 .39918 L
s
.74116 .39918 m
.74507 .39696 L
s
.7485 .40248 m
.74116 .39918 L
s
.76946 .4019 m
.74116 .39918 L
s
0 1 .411 r
.77613 .48767 m
.77945 .49342 L
s
.77613 .48767 m
.78216 .48759 L
s
.80407 .5016 m
.77613 .48767 L
s
0 1 .303 r
.5568 .31043 m
.55229 .31308 L
s
.56022 .31559 m
.5568 .31043 L
s
.55571 .31825 m
.56022 .31559 L
s
0 1 .471 r
.74507 .4035 m
.7485 .40248 L
s
.7485 .40248 m
.7485 .39595 L
s
.471 1 0 r
.59202 .40214 m
.58877 .40337 L
s
0 .59 1 r
.52191 .22955 m
.52823 .22552 L
s
0 .899 1 r
.2891 .66202 m
.29564 .66639 L
s
.28675 .66188 m
.2891 .66202 L
s
.2891 .66202 m
.29543 .65736 L
s
.64 1 0 r
.62606 .49413 m
.62388 .49734 L
s
.471 1 0 r
.58877 .40337 m
.58961 .40756 L
s
0 1 .985 r
.71129 .31422 m
.71605 .31209 L
s
.71605 .31209 m
.71322 .30476 L
s
0 .128 1 r
.67854 .21411 m
.67216 .21736 L
s
.6841 .22229 m
.67854 .21411 L
s
0 1 .471 r
.7485 .39595 m
.74507 .39696 L
s
1 0 .978 r
.64443 .13761 m
.65278 .13313 L
s
.312 0 1 r
.37013 .84278 m
.36698 .85579 L
s
.35855 .8495 m
.37013 .84278 L
s
0 .899 1 r
.29564 .66639 m
.29331 .66626 L
s
.29543 .65736 m
.29564 .66639 L
s
.273 0 1 r
.13987 .66431 m
.13155 .65735 L
s
.312 0 1 r
.36698 .85579 m
.35855 .8495 L
s
0 .128 1 r
.67774 .22556 m
.6841 .22229 L
s
0 1 .985 r
.71322 .30476 m
.70845 .30687 L
s
0 .59 1 r
.5161 .22333 m
.52191 .22955 L
s
0 .433 1 r
.67689 .84594 m
.68372 .84908 L
s
.67063 .84929 m
.67689 .84594 L
s
.67689 .84594 m
.67715 .84116 L
s
0 1 .723 r
.81956 .57884 m
.81474 .58422 L
s
0 .07 1 r
.10424 .57075 m
.09697 .56361 L
s
0 1 .303 r
.55229 .31308 m
.55571 .31825 L
s
0 .277 1 r
.52745 .85269 m
.52188 .85532 L
s
.52329 .84368 m
.52745 .85269 L
s
0 1 .885 r
.6424 .78347 m
.63966 .7489 L
s
0 .899 1 r
.27429 .69121 m
.29543 .65736 L
s
0 .963 1 r
.48291 .75575 m
.48916 .75901 L
s
.47835 .75723 m
.48291 .75575 L
s
.48291 .75575 m
.48567 .75103 L
s
0 1 .621 r
.25758 .57344 m
.25761 .57251 L
s
.25204 .5692 m
.25758 .57344 L
s
.25908 .56545 m
.25758 .57344 L
s
.25205 .56826 m
.25204 .5692 L
s
.25204 .5692 m
.25908 .56545 L
s
0 1 .411 r
.78216 .48759 m
.77945 .49342 L
s
0 .305 1 r
.33246 .74984 m
.3298 .76084 L
s
.32233 .75563 m
.33246 .74984 L
s
0 .105 1 r
.83421 .84056 m
.84066 .84266 L
s
.82681 .84512 m
.83421 .84056 L
s
.83421 .84056 m
.83125 .83521 L
s
0 1 .413 r
.21929 .48085 m
.22229 .48033 L
s
.21566 .47561 m
.21929 .48085 L
s
.22346 .47422 m
.21929 .48085 L
s
0 1 .471 r
.74507 .39696 m
.74507 .4035 L
s
0 .305 1 r
.3298 .76084 m
.32233 .75563 L
s
0 .899 1 r
.29543 .65736 m
.29331 .66626 L
s
.28675 .66188 m
.29543 .65736 L
s
0 1 .413 r
.22346 .47422 m
.22229 .48033 L
s
.21566 .47561 m
.22346 .47422 L
s
.21865 .47509 m
.22346 .47422 L
s
.20089 .49308 m
.22346 .47422 L
s
0 1 .621 r
.25908 .56545 m
.25761 .57251 L
s
.25205 .56826 m
.25908 .56545 L
s
.23773 .59253 m
.25908 .56545 L
s
0 .277 1 r
.52188 .85532 m
.51442 .85077 L
s
.51442 .85077 m
.52329 .84368 L
s
0 1 .985 r
.70845 .30687 m
.71129 .31422 L
s
1 0 .978 r
.63615 .12853 m
.64443 .13761 L
s
0 1 .413 r
.21865 .47509 m
.21566 .47561 L
s
0 .963 1 r
.48916 .75901 m
.48461 .7605 L
s
.48567 .75103 m
.48916 .75901 L
s
0 1 .33 r
.44605 .66353 m
.45117 .6656 L
s
.44277 .6638 m
.44605 .66353 L
s
.44605 .66353 m
.44861 .65882 L
s
0 .128 1 r
.67216 .21736 m
.67774 .22556 L
s
0 .712 1 r
.80927 .78063 m
.79399 .74343 L
s
0 1 .33 r
.44046 .68818 m
.44861 .65882 L
s
0 1 .885 r
.64029 .7537 m
.6456 .75553 L
s
.63483 .75615 m
.64029 .7537 L
s
.64029 .7537 m
.63966 .7489 L
s
0 .277 1 r
.52329 .84368 m
.52188 .85532 L
s
0 .899 1 r
.29331 .66626 m
.28675 .66188 L
s
0 .433 1 r
.67746 .85244 m
.67063 .84929 L
s
.67063 .84929 m
.67715 .84116 L
s
.68372 .84908 m
.67746 .85244 L
s
.67715 .84116 m
.68372 .84908 L
s
0 .105 1 r
.83324 .84725 m
.82681 .84512 L
s
.82681 .84512 m
.83125 .83521 L
s
.791 0 1 r
.24348 .87173 m
.27518 .82343 L
s
0 .963 1 r
.48461 .7605 m
.47835 .75723 L
s
.47835 .75723 m
.48567 .75103 L
s
0 .712 1 r
.7981 .74836 m
.80269 .74935 L
s
.79143 .75243 m
.7981 .74836 L
s
.7981 .74836 m
.79399 .74343 L
s
0 1 .413 r
.22229 .48033 m
.21865 .47509 L
s
0 1 .33 r
.45117 .6656 m
.4479 .66587 L
s
.44861 .65882 m
.45117 .6656 L
s
0 1 .621 r
.25761 .57251 m
.25205 .56826 L
s
0 .963 1 r
.48567 .75103 m
.48461 .7605 L
s
.31 1 0 r
.40917 .57143 m
.41346 .57272 L
s
.40778 .57042 m
.40917 .57143 L
s
.40917 .57143 m
.41216 .56714 L
s
.791 0 1 r
.26648 .82871 m
.27585 .83598 L
s
.26176 .83026 m
.26648 .82871 L
s
.26648 .82871 m
.27518 .82343 L
s
0 1 .165 r
.60726 .68515 m
.60266 .65704 L
s
0 .433 1 r
.67715 .84116 m
.67746 .85244 L
s
0 1 .165 r
.60407 .66165 m
.60769 .66215 L
s
.59948 .66319 m
.60407 .66165 L
s
.60407 .66165 m
.60266 .65704 L
s
0 1 .885 r
.64013 .758 m
.63483 .75615 L
s
.63483 .75615 m
.63966 .7489 L
s
.314 1 0 r
.34126 .38586 m
.34054 .3897 L
s
.33817 .38335 m
.34126 .38586 L
s
.34126 .38586 m
.3365 .38758 L
s
.34221 .38546 m
.34126 .38586 L
s
.33166 .38922 m
.34126 .38586 L
s
.31 1 0 r
.41346 .57272 m
.41208 .57171 L
s
.41216 .56714 m
.41346 .57272 L
s
0 1 .33 r
.44861 .65882 m
.4479 .66587 L
s
.44277 .6638 m
.44861 .65882 L
s
0 .105 1 r
.84066 .84266 m
.83324 .84725 L
s
.83125 .83521 m
.84066 .84266 L
s
0 1 .33 r
.4479 .66587 m
.44277 .6638 L
s
0 .712 1 r
.79601 .75344 m
.79143 .75243 L
s
.79143 .75243 m
.79399 .74343 L
s
0 1 .885 r
.6456 .75553 m
.64013 .758 L
s
.63966 .7489 m
.6456 .75553 L
s
.634 1 0 r
.37636 .47612 m
.3773 .47991 L
s
.37218 .47771 m
.37636 .47612 L
s
.37636 .47612 m
.37442 .48056 L
s
.37505 .47706 m
.37636 .47612 L
s
.3682 .48965 m
.37636 .47612 L
s
.31 1 0 r
.41216 .56714 m
.41208 .57171 L
s
.40778 .57042 m
.41216 .56714 L
s
.40447 .5893 m
.41216 .56714 L
s
.634 1 0 r
.37442 .48056 m
.3773 .47991 L
s
.37218 .47771 m
.37442 .48056 L
s
.791 0 1 r
.27585 .83598 m
.27117 .83757 L
s
.27518 .82343 m
.27585 .83598 L
s
0 .105 1 r
.83125 .83521 m
.83324 .84725 L
s
0 .047 1 r
.41007 .86905 m
.42928 .82627 L
s
0 1 .673 r
.7623 .65616 m
.76476 .65617 L
s
.75657 .6599 m
.7623 .65616 L
s
.7623 .65616 m
.75714 .65202 L
s
0 1 .885 r
.63966 .7489 m
.64013 .758 L
s
.314 1 0 r
.3365 .38758 m
.34054 .3897 L
s
.33817 .38335 m
.3365 .38758 L
s
.634 1 0 r
.37505 .47706 m
.37218 .47771 L
s
.256 0 1 r
.22839 .73485 m
.23695 .74126 L
s
.2251 .73523 m
.22839 .73485 L
s
.22839 .73485 m
.23713 .72943 L
s
0 1 .165 r
.6031 .6637 m
.59948 .66319 L
s
.59948 .66319 m
.60266 .65704 L
s
.31 1 0 r
.41208 .57171 m
.40778 .57042 L
s
.634 1 0 r
.3773 .47991 m
.37505 .47706 L
s
.512 1 0 r
.56848 .56974 m
.57002 .5689 L
s
.56464 .57062 m
.56848 .56974 L
s
.56848 .56974 m
.5662 .56569 L
s
0 1 .673 r
.77471 .6821 m
.75714 .65202 L
s
.314 1 0 r
.34054 .3897 m
.34221 .38546 L
s
0 1 .673 r
.75902 .65992 m
.75657 .6599 L
s
.75657 .6599 m
.75714 .65202 L
s
0 1 .368 r
.46048 .29584 m
.46089 .29776 L
s
.46145 .28929 m
.46048 .29584 L
s
.46048 .29584 m
.45666 .29306 L
s
.46567 .29398 m
.46048 .29584 L
s
.46396 .28413 m
.46048 .29584 L
s
0 1 .165 r
.60769 .66215 m
.6031 .6637 L
s
.60266 .65704 m
.60769 .66215 L
s
.314 1 0 r
.34221 .38546 m
.33817 .38335 L
s
.256 0 1 r
.23695 .74126 m
.23369 .74166 L
s
.23713 .72943 m
.23695 .74126 L
s
0 .712 1 r
.79399 .74343 m
.79601 .75344 L
s
.79399 .74343 m
.80269 .74935 L
s
0 1 .165 r
.60266 .65704 m
.6031 .6637 L
s
0 .712 1 r
.80269 .74935 m
.79601 .75344 L
s
.512 1 0 r
.56618 .56979 m
.56464 .57062 L
s
.56464 .57062 m
.5662 .56569 L
s
.54 1 0 r
.49507 .38498 m
.49542 .38802 L
s
.49675 .38217 m
.49507 .38498 L
s
.49507 .38498 m
.49326 .38442 L
s
.49891 .38577 m
.49507 .38498 L
s
.5002 .38556 m
.49507 .38498 L
s
0 .487 1 r
.5773 .86635 m
.58437 .8257 L
s
.256 0 1 r
.2067 .77346 m
.23713 .72943 L
s
.512 1 0 r
.5662 .56569 m
.56618 .56979 L
s
.5662 .56569 m
.57002 .5689 L
s
.57185 .58606 m
.5662 .56569 L
s
0 .215 1 r
.58073 .20444 m
.58374 .20494 L
s
.58446 .19346 m
.58073 .20444 L
s
.58073 .20444 m
.57757 .19751 L
s
.59062 .20087 m
.58073 .20444 L
s
.59783 .1778 m
.58073 .20444 L
s
0 .047 1 r
.42386 .83133 m
.43193 .83657 L
s
.41888 .83317 m
.42386 .83133 L
s
.42386 .83133 m
.42928 .82627 L
s
.883 1 0 r
.53032 .47497 m
.52933 .47827 L
s
.53365 .47615 m
.53032 .47497 L
s
.53032 .47497 m
.53083 .47575 L
s
.53214 .47866 m
.53032 .47497 L
s
.53617 .4862 m
.53032 .47497 L
s
.52933 .47827 m
.53214 .47866 L
s
.53214 .47866 m
.53365 .47615 L
s
0 1 .133 r
.72234 .56708 m
.72239 .56761 L
s
.72239 .56761 m
.72681 .56378 L
s
.72239 .56761 m
.72076 .56109 L
s
0 .223 1 r
.19056 .64093 m
.19827 .64689 L
s
.1892 .64031 m
.19056 .64093 L
s
.19056 .64093 m
.19977 .63591 L
s
0 1 .133 r
.72681 .56378 m
.72677 .56324 L
s
.72681 .56378 m
.72076 .56109 L
s
0 .223 1 r
.19827 .64689 m
.19694 .64629 L
s
.19977 .63591 m
.19827 .64689 L
s
0 1 .673 r
.75714 .65202 m
.75902 .65992 L
s
.75714 .65202 m
.76476 .65617 L
s
.512 1 0 r
.57002 .5689 m
.56618 .56979 L
s
.791 0 1 r
.27518 .82343 m
.27117 .83757 L
s
.26176 .83026 m
.27518 .82343 L
s
0 1 .753 r
.61483 .29233 m
.61778 .29455 L
s
.61936 .28534 m
.61483 .29233 L
s
.61483 .29233 m
.61417 .28809 L
s
.62296 .29178 m
.61483 .29233 L
s
.63376 .28025 m
.61483 .29233 L
s
.883 1 0 r
.53365 .47615 m
.53083 .47575 L
s
.53083 .47575 m
.52933 .47827 L
s
0 1 .133 r
.72076 .56109 m
.72234 .56708 L
s
.72076 .56109 m
.72677 .56324 L
s
.73988 .58281 m
.72076 .56109 L
s
.54 1 0 r
.49542 .38802 m
.49891 .38577 L
s
.49891 .38577 m
.49675 .38217 L
s
0 .566 1 r
.15965 .55295 m
.16088 .55189 L
s
.1531 .5467 m
.15965 .55295 L
s
.16313 .54299 m
.15965 .55295 L
s
.149 1 0 r
.68652 .47544 m
.68904 .47544 L
s
.68904 .47544 m
.69117 .47085 L
s
.68904 .47544 m
.68488 .47076 L
s
0 1 .368 r
.46145 .28929 m
.45666 .29306 L
s
.46567 .29398 m
.46145 .28929 L
s
0 1 .673 r
.76476 .65617 m
.75902 .65992 L
s
0 1 .055 r
.64956 .38114 m
.65196 .38475 L
s
.65504 .37782 m
.64956 .38114 L
s
.64956 .38114 m
.65109 .37923 L
s
.6559 .38334 m
.64956 .38114 L
s
.66941 .38189 m
.64956 .38114 L
s
.54 1 0 r
.49326 .38442 m
.49542 .38802 L
s
.149 1 0 r
.68488 .47076 m
.68652 .47544 L
s
.69117 .47085 m
.68488 .47076 L
s
.68488 .47076 m
.68865 .47085 L
s
.70479 .48274 m
.68488 .47076 L
s
0 1 .368 r
.46089 .29776 m
.46567 .29398 L
s
.256 0 1 r
.23713 .72943 m
.23369 .74166 L
s
.2251 .73523 m
.23713 .72943 L
s
.54 1 0 r
.49675 .38217 m
.49326 .38442 L
s
0 .047 1 r
.43193 .83657 m
.42698 .83843 L
s
.42928 .82627 m
.43193 .83657 L
s
.791 0 1 r
.27117 .83757 m
.26176 .83026 L
s
0 .566 1 r
.15431 .54561 m
.1531 .5467 L
s
.1531 .5467 m
.16313 .54299 L
s
0 .675 1 r
.37386 .77058 m
.39122 .73251 L
s
0 .44 1 r
.74518 .86365 m
.73998 .82169 L
s
.149 1 0 r
.69117 .47085 m
.68865 .47085 L
s
0 1 .368 r
.45666 .29306 m
.46089 .29776 L
s
0 .675 1 r
.38609 .73776 m
.39316 .74188 L
s
.3823 .73841 m
.38609 .73776 L
s
.38609 .73776 m
.39122 .73251 L
s
0 .223 1 r
.19977 .63591 m
.19694 .64629 L
s
.1892 .64031 m
.19977 .63591 L
s
.16963 .67443 m
.19977 .63591 L
s
0 1 .055 r
.65196 .38475 m
.6559 .38334 L
s
.6559 .38334 m
.65504 .37782 L
s
0 .566 1 r
.16313 .54299 m
.16088 .55189 L
s
.15431 .54561 m
.16313 .54299 L
s
.13227 .57462 m
.16313 .54299 L
s
0 .215 1 r
.58446 .19346 m
.57757 .19751 L
s
.59062 .20087 m
.58446 .19346 L
s
0 .487 1 r
.58216 .83096 m
.58933 .83445 L
s
.57656 .83329 m
.58216 .83096 L
s
.58216 .83096 m
.58437 .8257 L
s
0 1 .753 r
.61778 .29455 m
.62296 .29178 L
s
.62296 .29178 m
.61936 .28534 L
s
0 1 .133 r
.72677 .56324 m
.72234 .56708 L
s
0 1 .055 r
.65504 .37782 m
.65109 .37923 L
s
0 .215 1 r
.58374 .20494 m
.59062 .20087 L
s
0 1 .753 r
.61936 .28534 m
.61417 .28809 L
s
.149 1 0 r
.68865 .47085 m
.68652 .47544 L
s
.256 0 1 r
.23369 .74166 m
.2251 .73523 L
s
0 .675 1 r
.39316 .74188 m
.3894 .74254 L
s
.39122 .73251 m
.39316 .74188 L
s
0 1 .055 r
.65109 .37923 m
.65196 .38475 L
s
.108 0 1 r
.91371 .86093 m
.89564 .81423 L
s
0 1 .837 r
.54167 .76768 m
.54639 .73227 L
s
0 .44 1 r
.74111 .82738 m
.74761 .82954 L
s
.73444 .8307 m
.74111 .82738 L
s
.74111 .82738 m
.73998 .82169 L
s
0 1 .721 r
.34846 .64424 m
.35463 .64753 L
s
.34634 .64372 m
.34846 .64424 L
s
.34846 .64424 m
.35377 .6392 L
s
0 .047 1 r
.42698 .83843 m
.41888 .83317 L
s
.41888 .83317 m
.42928 .82627 L
s
.42928 .82627 m
.42698 .83843 L
s
.108 0 1 r
.90038 .82054 m
.90638 .82178 L
s
.89217 .82542 m
.90038 .82054 L
s
.90038 .82054 m
.89564 .81423 L
s
0 1 .753 r
.61417 .28809 m
.61778 .29455 L
s
0 .215 1 r
.57757 .19751 m
.58374 .20494 L
s
0 .223 1 r
.19694 .64629 m
.1892 .64031 L
s
0 1 .721 r
.35463 .64753 m
.35253 .64702 L
s
.35377 .6392 m
.35463 .64753 L
s
0 1 .837 r
.54486 .73765 m
.55073 .73983 L
s
.54015 .73891 m
.54486 .73765 L
s
.54486 .73765 m
.54639 .73227 L
s
0 .487 1 r
.58933 .83445 m
.58374 .83681 L
s
.58437 .8257 m
.58933 .83445 L
s
1 0 .57 r
.16738 .80871 m
.17799 .81725 L
s
.16326 .80968 m
.16738 .80871 L
s
.16738 .80871 m
.17878 .80261 L
s
0 .566 1 r
.16088 .55189 m
.15431 .54561 L
s
0 .675 1 r
.39122 .73251 m
.3894 .74254 L
s
.3823 .73841 m
.39122 .73251 L
s
0 1 .244 r
.31607 .55372 m
.31656 .55243 L
s
.31088 .5504 m
.31607 .55372 L
s
.31699 .54646 m
.31607 .55372 L
s
0 .487 1 r
.58374 .83681 m
.57656 .83329 L
s
.57656 .83329 m
.58437 .8257 L
s
1 0 .57 r
.17799 .81725 m
.17393 .81828 L
s
.17878 .80261 m
.17799 .81725 L
s
0 1 .244 r
.31136 .54911 m
.31088 .5504 L
s
.31088 .5504 m
.31699 .54646 L
s
0 .675 1 r
.3894 .74254 m
.3823 .73841 L
s
0 1 .92 r
.71013 .76477 m
.70219 .72868 L
s
0 1 .721 r
.33737 .67134 m
.35377 .6392 L
s
.35377 .6392 m
.35253 .64702 L
s
.34634 .64372 m
.35377 .6392 L
s
.108 0 1 r
.89816 .82669 m
.89217 .82542 L
s
.89217 .82542 m
.89564 .81423 L
s
0 1 .085 r
.28091 .4544 m
.28068 .45985 L
s
.27423 .45536 m
.28091 .4544 L
s
.28091 .4544 m
.27687 .46012 L
s
.27803 .45507 m
.28091 .4544 L
s
.26353 .47053 m
.28091 .4544 L
s
.27687 .46012 m
.28068 .45985 L
s
.27423 .45536 m
.27687 .46012 L
s
0 1 .244 r
.31699 .54646 m
.31656 .55243 L
s
.31136 .54911 m
.31699 .54646 L
s
.30059 .57133 m
.31699 .54646 L
s
0 .44 1 r
.74094 .83287 m
.73444 .8307 L
s
.73444 .8307 m
.73998 .82169 L
s
0 1 .92 r
.7044 .73416 m
.70916 .73506 L
s
.69841 .73678 m
.7044 .73416 L
s
.7044 .73416 m
.70219 .72868 L
s
0 .487 1 r
.58437 .8257 m
.58374 .83681 L
s
0 1 .147 r
.50783 .64457 m
.51245 .64546 L
s
.50418 .64466 m
.50783 .64457 L
s
.50783 .64457 m
.50896 .63926 L
s
0 1 .837 r
.55073 .73983 m
.54603 .74111 L
s
.54639 .73227 m
.55073 .73983 L
s
1 0 .57 r
.13818 .85684 m
.17878 .80261 L
s
.981 0 1 r
.12871 .71365 m
.1386 .72158 L
s
.1262 .71348 m
.12871 .71365 L
s
.12871 .71365 m
.14036 .70757 L
s
0 .443 1 r
.86413 .7273 m
.86805 .72757 L
s
.85667 .73197 m
.86413 .7273 L
s
.86413 .7273 m
.85812 .72174 L
s
0 .44 1 r
.74761 .82954 m
.74094 .83287 L
s
.73998 .82169 m
.74761 .82954 L
s
0 1 .721 r
.35253 .64702 m
.34634 .64372 L
s
.981 0 1 r
.1386 .72158 m
.13614 .72145 L
s
.14036 .70757 m
.1386 .72158 L
s
0 1 .837 r
.54603 .74111 m
.54015 .73891 L
s
.54015 .73891 m
.54639 .73227 L
s
0 1 .085 r
.27803 .45507 m
.27423 .45536 L
s
0 .443 1 r
.87926 .76186 m
.85812 .72174 L
s
0 1 .147 r
.50576 .66824 m
.50896 .63926 L
s
0 1 .837 r
.54639 .73227 m
.54603 .74111 L
s
0 .44 1 r
.73998 .82169 m
.74094 .83287 L
s
0 1 .085 r
.28068 .45985 m
.27803 .45507 L
s
0 .443 1 r
.86057 .73226 m
.85667 .73197 L
s
.85667 .73197 m
.85812 .72174 L
s
0 1 .92 r
.70316 .73768 m
.69841 .73678 L
s
.69841 .73678 m
.70219 .72868 L
s
.606 0 1 r
.09941 .62626 m
.09909 .62529 L
s
.09037 .61844 m
.09941 .62626 L
s
.10269 .61304 m
.09941 .62626 L
s
0 1 .244 r
.31656 .55243 m
.31136 .54911 L
s
.108 0 1 r
.89564 .81423 m
.89816 .82669 L
s
.89564 .81423 m
.90638 .82178 L
s
0 1 .147 r
.51245 .64546 m
.50881 .64555 L
s
.50896 .63926 m
.51245 .64546 L
s
.454 1 0 r
.47084 .55176 m
.47465 .55157 L
s
.46855 .55048 m
.47084 .55176 L
s
.47084 .55176 m
.47211 .54679 L
s
.606 0 1 r
.09001 .61742 m
.09037 .61844 L
s
.09037 .61844 m
.10269 .61304 L
s
0 1 .27 r
.66813 .64101 m
.67083 .64068 L
s
.66287 .64308 m
.66813 .64101 L
s
.66813 .64101 m
.66485 .63606 L
s
.108 0 1 r
.90638 .82178 m
.89816 .82669 L
s
1 0 .57 r
.17878 .80261 m
.17393 .81828 L
s
.16326 .80968 m
.17878 .80261 L
s
.367 0 1 r
.30635 .8541 m
.33365 .80741 L
s
0 1 .147 r
.50896 .63926 m
.50881 .64555 L
s
.50418 .64466 m
.50896 .63926 L
s
.50881 .64555 m
.50418 .64466 L
s
.253 1 0 r
.40035 .36392 m
.39995 .36768 L
s
.39916 .36066 m
.40035 .36392 L
s
.40035 .36392 m
.39611 .36452 L
s
.403 .36382 m
.40035 .36392 L
s
.39634 .36519 m
.40035 .36392 L
s
.367 0 1 r
.32584 .81306 m
.3348 .81931 L
s
.32152 .81424 m
.32584 .81306 L
s
.32584 .81306 m
.33365 .80741 L
s
.454 1 0 r
.47211 .54679 m
.47237 .55029 L
s
.47211 .54679 m
.47465 .55157 L
s
.46855 .55048 m
.47211 .54679 L
s
.46958 .56802 m
.47211 .54679 L
s
0 1 .92 r
.70916 .73506 m
.70316 .73768 L
s
.70219 .72868 m
.70916 .73506 L
s
.683 1 0 r
.43589 .45497 m
.43668 .45938 L
s
.43399 .45535 m
.43589 .45497 L
s
.43589 .45497 m
.43294 .4582 L
s
.43773 .45653 m
.43589 .45497 L
s
.4331 .467 m
.43589 .45497 L
s
0 .978 1 r
.82813 .63396 m
.82968 .6335 L
s
.82172 .63866 m
.82813 .63396 L
s
.82813 .63396 m
.82098 .62961 L
s
.454 1 0 r
.47465 .55157 m
.47237 .55029 L
s
0 1 .92 r
.70219 .72868 m
.70316 .73768 L
s
.981 0 1 r
.14036 .70757 m
.13614 .72145 L
s
.1262 .71348 m
.14036 .70757 L
s
.10059 .75746 m
.14036 .70757 L
s
0 1 .27 r
.66557 .64275 m
.66287 .64308 L
s
.66287 .64308 m
.66485 .63606 L
s
0 .978 1 r
.82324 .63821 m
.82172 .63866 L
s
.82172 .63866 m
.82098 .62961 L
s
0 1 .27 r
.67482 .66513 m
.66485 .63606 L
s
.683 1 0 r
.43668 .45938 m
.43773 .45653 L
s
.43294 .4582 m
.43668 .45938 L
s
0 .443 1 r
.85812 .72174 m
.86057 .73226 L
s
.85812 .72174 m
.86805 .72757 L
s
.606 0 1 r
.10269 .61304 m
.09909 .62529 L
s
.09001 .61742 m
.10269 .61304 L
s
.0627 .65729 m
.10269 .61304 L
s
.454 1 0 r
.47237 .55029 m
.46855 .55048 L
s
.683 1 0 r
.43399 .45535 m
.43294 .4582 L
s
.367 0 1 r
.3348 .81931 m
.33052 .82052 L
s
.33365 .80741 m
.3348 .81931 L
s
0 1 .27 r
.66485 .63606 m
.66557 .64275 L
s
.66485 .63606 m
.67083 .64068 L
s
.288 1 0 r
.63251 .54758 m
.63235 .54639 L
s
.62818 .54981 m
.63251 .54758 L
s
.63251 .54758 m
.62803 .54396 L
s
0 1 .71 r
.52108 .27184 m
.52245 .274 L
s
.52353 .26445 m
.52108 .27184 L
s
.52108 .27184 m
.51802 .26819 L
s
.52796 .27026 m
.52108 .27184 L
s
.53074 .25861 m
.52108 .27184 L
s
.288 1 0 r
.62801 .54862 m
.62818 .54981 L
s
.62818 .54981 m
.62803 .54396 L
s
0 .344 1 r
.47518 .85135 m
.48982 .8088 L
s
.253 1 0 r
.39995 .36768 m
.403 .36382 L
s
.39611 .36452 m
.39995 .36768 L
s
.39916 .36066 m
.39611 .36452 L
s
1 0 .57 r
.17393 .81828 m
.16326 .80968 L
s
0 .443 1 r
.86805 .72757 m
.86057 .73226 L
s
0 .181 1 r
.28739 .71825 m
.2955 .72362 L
s
.28449 .71826 m
.28739 .71825 L
s
.28739 .71825 m
.29518 .71254 L
s
.683 1 0 r
.43773 .45653 m
.43399 .45535 L
s
0 1 .588 r
.78638 .54492 m
.78746 .54551 L
s
.78746 .54551 m
.79224 .54034 L
s
.78746 .54551 m
.78428 .53796 L
s
0 1 .27 r
.67083 .64068 m
.66557 .64275 L
s
.288 1 0 r
.62803 .54396 m
.62801 .54862 L
s
.62803 .54396 m
.63235 .54639 L
s
.63922 .56469 m
.62803 .54396 L
s
.201 0 1 r
.64272 .17845 m
.64693 .17946 L
s
.64796 .16656 m
.64272 .17845 L
s
.64272 .17845 m
.64046 .1707 L
s
.65442 .17529 m
.64272 .17845 L
s
.66675 .15074 m
.64272 .17845 L
s
0 .978 1 r
.82098 .62961 m
.82324 .63821 L
s
.82098 .62961 m
.82968 .6335 L
s
.84453 .662 m
.82098 .62961 L
s
.141 1 0 r
.5561 .36173 m
.55716 .36518 L
s
.55944 .35817 m
.5561 .36173 L
s
.5561 .36173 m
.55514 .3604 L
s
.56146 .36295 m
.5561 .36173 L
s
.56719 .36144 m
.5561 .36173 L
s
.253 1 0 r
.403 .36382 m
.39916 .36066 L
s
.509 1 0 r
.59177 .45248 m
.59171 .4566 L
s
.59643 .45273 m
.59177 .45248 L
s
.59177 .45248 m
.59298 .45285 L
s
.59516 .45648 m
.59177 .45248 L
s
.60335 .46347 m
.59177 .45248 L
s
0 1 .588 r
.79224 .54034 m
.79118 .53974 L
s
.79224 .54034 m
.78428 .53796 L
s
.509 1 0 r
.59171 .4566 m
.59516 .45648 L
s
.59516 .45648 m
.59643 .45273 L
s
0 .181 1 r
.2955 .72362 m
.29264 .72366 L
s
.29518 .71254 m
.2955 .72362 L
s
0 .755 1 r
.67723 .26705 m
.68121 .26997 L
s
.68339 .25922 m
.67723 .26705 L
s
.67723 .26705 m
.67748 .26212 L
s
.68711 .26706 m
.67723 .26705 L
s
.70287 .25462 m
.67723 .26705 L
s
0 1 .588 r
.78428 .53796 m
.78638 .54492 L
s
.78428 .53796 m
.79118 .53974 L
s
.80954 .56136 m
.78428 .53796 L
s
0 .344 1 r
.48541 .81452 m
.49319 .81869 L
s
.48056 .81599 m
.48541 .81452 L
s
.48541 .81452 m
.48982 .8088 L
s
0 1 .402 r
.75051 .45263 m
.75383 .4524 L
s
.75383 .4524 m
.75603 .44637 L
s
.75383 .4524 m
.74806 .44691 L
s
0 1 .614 r
.71236 .35657 m
.71566 .36106 L
s
.71951 .35252 m
.71236 .35657 L
s
.71236 .35657 m
.71481 .3541 L
s
.72035 .35947 m
.71236 .35657 L
s
.73871 .35768 m
.71236 .35657 L
s
0 1 .402 r
.74806 .44691 m
.75051 .45263 L
s
.75603 .44637 m
.74806 .44691 L
s
.74806 .44691 m
.75271 .44658 L
s
.77426 .45992 m
.74806 .44691 L
s
.981 0 1 r
.13614 .72145 m
.1262 .71348 L
s
.509 1 0 r
.59643 .45273 m
.59298 .45285 L
s
.141 1 0 r
.55716 .36518 m
.56146 .36295 L
s
.56146 .36295 m
.55944 .35817 L
s
.288 1 0 r
.63235 .54639 m
.62801 .54862 L
s
0 .602 1 r
.64467 .84858 m
.64681 .80674 L
s
0 .181 1 r
.26935 .75451 m
.29518 .71254 L
s
.509 1 0 r
.59298 .45285 m
.59171 .4566 L
s
.367 0 1 r
.33365 .80741 m
.33052 .82052 L
s
.32152 .81424 m
.33365 .80741 L
s
0 .669 1 r
.24914 .62333 m
.25637 .6283 L
s
.24824 .62237 m
.24914 .62333 L
s
.24914 .62333 m
.25737 .61816 L
s
0 .978 1 r
.82968 .6335 m
.82324 .63821 L
s
0 1 .71 r
.52353 .26445 m
.51802 .26819 L
s
.52796 .27026 m
.52353 .26445 L
s
.52245 .274 m
.52796 .27026 L
s
0 .669 1 r
.25637 .6283 m
.2555 .62735 L
s
.25737 .61816 m
.25637 .6283 L
s
0 1 .402 r
.75603 .44637 m
.75271 .44658 L
s
.141 1 0 r
.55944 .35817 m
.55514 .3604 L
s
0 1 .614 r
.71566 .36106 m
.72035 .35947 L
s
.72035 .35947 m
.71951 .35252 L
s
.141 1 0 r
.55514 .3604 m
.55716 .36518 L
s
.606 0 1 r
.09909 .62529 m
.09001 .61742 L
s
.367 0 1 r
.33052 .82052 m
.32152 .81424 L
s
.201 0 1 r
.64796 .16656 m
.64046 .1707 L
s
.65442 .17529 m
.64796 .16656 L
s
0 .181 1 r
.29518 .71254 m
.29264 .72366 L
s
.28449 .71826 m
.29518 .71254 L
s
0 .344 1 r
.49319 .81869 m
.48836 .82017 L
s
.48982 .8088 m
.49319 .81869 L
s
0 .755 1 r
.68121 .26997 m
.68711 .26706 L
s
.68711 .26706 m
.68339 .25922 L
s
0 1 .995 r
.21715 .53341 m
.21905 .53217 L
s
.21122 .52794 m
.21715 .53341 L
s
.22027 .52436 m
.21715 .53341 L
s
0 1 .588 r
.79118 .53974 m
.78638 .54492 L
s
0 .602 1 r
.64588 .81286 m
.65275 .81528 L
s
.64001 .815 m
.64588 .81286 L
s
.64588 .81286 m
.64681 .80674 L
s
0 1 .614 r
.71951 .35252 m
.71481 .3541 L
s
.201 0 1 r
.64693 .17946 m
.65442 .17529 L
s
0 1 .71 r
.51802 .26819 m
.52245 .274 L
s
0 .974 1 r
.44735 .72004 m
.45409 .72304 L
s
.44361 .72033 m
.44735 .72004 L
s
.44735 .72004 m
.45138 .7142 L
s
0 .755 1 r
.68339 .25922 m
.67748 .26212 L
s
0 .669 1 r
.25737 .61816 m
.2555 .62735 L
s
.24824 .62237 m
.25737 .61816 L
s
.23205 .65413 m
.25737 .61816 L
s
0 1 .995 r
.21311 .52669 m
.21122 .52794 L
s
.21122 .52794 m
.22027 .52436 L
s
0 1 .402 r
.75271 .44658 m
.75051 .45263 L
s
0 1 .995 r
.22027 .52436 m
.21905 .53217 L
s
.21311 .52669 m
.22027 .52436 L
s
.19446 .55296 m
.22027 .52436 L
s
0 .974 1 r
.43877 .75155 m
.45138 .7142 L
s
0 .33 1 r
.81483 .84581 m
.80414 .80121 L
s
.80694 .80783 m
.813 .80902 L
s
.79958 .8113 m
.80694 .80783 L
s
.80694 .80783 m
.80414 .80121 L
s
0 1 .614 r
.71481 .3541 m
.71566 .36106 L
s
0 .181 1 r
.29264 .72366 m
.28449 .71826 L
s
0 .974 1 r
.45409 .72304 m
.45037 .72334 L
s
.45138 .7142 m
.45409 .72304 L
s
0 .344 1 r
.48836 .82017 m
.48056 .81599 L
s
.48056 .81599 m
.48982 .8088 L
s
.48982 .8088 m
.48836 .82017 L
s
0 .755 1 r
.67748 .26212 m
.68121 .26997 L
s
0 1 .422 r
.40937 .62564 m
.41524 .62776 L
s
.40723 .62471 m
.40937 .62564 L
s
.40937 .62564 m
.41353 .62006 L
s
.201 0 1 r
.64046 .1707 m
.64693 .17946 L
s
0 1 .749 r
.60846 .71861 m
.61385 .71968 L
s
.60329 .7198 m
.60846 .71861 L
s
.60846 .71861 m
.6085 .71251 L
s
.60885 .74858 m
.6085 .71251 L
s
0 .602 1 r
.65275 .81528 m
.64688 .81743 L
s
.64681 .80674 m
.65275 .81528 L
s
0 .669 1 r
.2555 .62735 m
.24824 .62237 L
s
0 .602 1 r
.64688 .81743 m
.64001 .815 L
s
.64001 .815 m
.64681 .80674 L
s
0 .974 1 r
.45138 .7142 m
.45037 .72334 L
s
.44361 .72033 m
.45138 .7142 L
s
0 1 .422 r
.41524 .62776 m
.41311 .62683 L
s
.41353 .62006 m
.41524 .62776 L
s
0 .33 1 r
.80562 .81251 m
.79958 .8113 L
s
.79958 .8113 m
.80414 .80121 L
s
0 1 .995 r
.21905 .53217 m
.21311 .52669 L
s
0 .974 1 r
.45037 .72334 m
.44361 .72033 L
s
.949 0 1 r
.22599 .79335 m
.23608 .8009 L
s
.22238 .79397 m
.22599 .79335 L
s
.22599 .79335 m
.23647 .78708 L
s
0 .915 1 r
.77015 .71353 m
.77417 .71357 L
s
.76338 .71661 m
.77015 .71353 L
s
.77015 .71353 m
.76605 .70745 L
s
0 .602 1 r
.64681 .80674 m
.64688 .81743 L
s
0 1 .422 r
.41353 .62006 m
.41311 .62683 L
s
.40723 .62471 m
.41353 .62006 L
s
.40206 .65096 m
.41353 .62006 L
s
.035 1 0 r
.37612 .53318 m
.37702 .53142 L
s
.37114 .53075 m
.37612 .53318 L
s
.37632 .52648 m
.37612 .53318 L
s
.37202 .52898 m
.37114 .53075 L
s
.37114 .53075 m
.37632 .52648 L
s
.124 1 0 r
.33978 .43358 m
.34025 .43881 L
s
.33454 .43383 m
.33978 .43358 L
s
.33978 .43358 m
.33561 .43837 L
s
.3392 .43427 m
.33978 .43358 L
s
.32778 .44739 m
.33978 .43358 L
s
.035 1 0 r
.37632 .52648 m
.37702 .53142 L
s
.37202 .52898 m
.37632 .52648 L
s
.36507 .54958 m
.37632 .52648 L
s
.949 0 1 r
.23608 .8009 m
.23253 .80156 L
s
.23647 .78708 m
.23608 .8009 L
s
0 1 .104 r
.57145 .62456 m
.57525 .62422 L
s
.56697 .62481 m
.57145 .62456 L
s
.57145 .62456 m
.5707 .6187 L
s
0 .915 1 r
.77961 .7456 m
.76605 .70745 L
s
0 1 .749 r
.60868 .72088 m
.60329 .7198 L
s
.60329 .7198 m
.6085 .71251 L
s
.61385 .71968 m
.60868 .72088 L
s
.6085 .71251 m
.61385 .71968 L
s
0 .33 1 r
.813 .80902 m
.80562 .81251 L
s
.80414 .80121 m
.813 .80902 L
s
.124 1 0 r
.33561 .43837 m
.34025 .43881 L
s
.33454 .43383 m
.33561 .43837 L
s
0 .33 1 r
.80414 .80121 m
.80562 .81251 L
s
0 1 .422 r
.41311 .62683 m
.40723 .62471 L
s
0 .915 1 r
.76738 .71665 m
.76338 .71661 L
s
.76338 .71661 m
.76605 .70745 L
s
0 1 .749 r
.6085 .71251 m
.60868 .72088 L
s
.487 0 1 r
.18692 .69726 m
.19624 .70421 L
s
.18494 .69678 m
.18692 .69726 L
s
.18692 .69726 m
.19761 .69112 L
s
.949 0 1 r
.20038 .83883 m
.23647 .78708 L
s
.124 1 0 r
.34025 .43881 m
.3392 .43427 L
s
0 1 .521 r
.73377 .61913 m
.7353 .6182 L
s
.72779 .62214 m
.73377 .61913 L
s
.73377 .61913 m
.7284 .61408 L
s
.487 0 1 r
.19624 .70421 m
.19431 .70376 L
s
.19761 .69112 m
.19624 .70421 L
s
.124 1 0 r
.3392 .43427 m
.33454 .43383 L
s
0 1 .104 r
.57077 .62448 m
.56697 .62481 L
s
.56697 .62481 m
.5707 .6187 L
s
.035 1 0 r
.37702 .53142 m
.37202 .52898 L
s
0 1 .104 r
.5707 .6187 m
.57077 .62448 L
s
.5707 .6187 m
.57525 .62422 L
s
.57275 .64778 m
.5707 .6187 L
s
.416 1 0 r
.53553 .53058 m
.53692 .52862 L
s
.53117 .53052 m
.53553 .53058 L
s
.53553 .53058 m
.53346 .52543 L
s
0 .915 1 r
.76605 .70745 m
.76738 .71665 L
s
.76605 .70745 m
.77417 .71357 L
s
0 1 .104 r
.57525 .62422 m
.57077 .62448 L
s
0 1 .521 r
.7293 .62122 m
.72779 .62214 L
s
.72779 .62214 m
.7284 .61408 L
s
.045 1 0 r
.46085 .34096 m
.4609 .3448 L
s
.46154 .33696 m
.46085 .34096 L
s
.46085 .34096 m
.45732 .34054 L
s
.46511 .34122 m
.46085 .34096 L
s
.46271 .34055 m
.46085 .34096 L
s
.416 1 0 r
.53346 .52543 m
.53255 .52856 L
s
.53346 .52543 m
.53692 .52862 L
s
.53117 .53052 m
.53346 .52543 L
s
.53636 .54618 m
.53346 .52543 L
s
.532 1 0 r
.49683 .43281 m
.49626 .43752 L
s
.49853 .43246 m
.49683 .43281 L
s
.49683 .43281 m
.49457 .4342 L
s
.50022 .43579 m
.49683 .43281 L
s
.49968 .44378 m
.49683 .43281 L
s
.416 1 0 r
.53255 .52856 m
.53117 .53052 L
s
0 .915 1 r
.77417 .71357 m
.76738 .71665 L
s
.949 0 1 r
.23647 .78708 m
.23253 .80156 L
s
.22238 .79397 m
.23647 .78708 L
s
.105 0 1 r
.15653 .60789 m
.15683 .60667 L
s
.14815 .60097 m
.15653 .60789 L
s
.15946 .59567 m
.15653 .60789 L
s
0 .005 1 r
.38669 .79659 m
.39533 .80177 L
s
.38267 .79736 m
.38669 .79659 L
s
.38669 .79659 m
.39357 .79043 L
s
.105 0 1 r
.1484 .59972 m
.14815 .60097 L
s
.14815 .60097 m
.15946 .59567 L
s
0 1 .521 r
.7284 .61408 m
.7293 .62122 L
s
.7284 .61408 m
.7353 .6182 L
s
.74412 .64459 m
.7284 .61408 L
s
0 .005 1 r
.37084 .83601 m
.39357 .79043 L
s
0 1 .083 r
.69159 .52685 m
.69322 .52793 L
s
.69322 .52793 m
.69768 .52417 L
s
.69322 .52793 m
.69123 .52121 L
s
.532 1 0 r
.49626 .43752 m
.50022 .43579 L
s
.49457 .4342 m
.49626 .43752 L
s
0 .886 1 r
.58307 .24681 m
.58546 .24938 L
s
.58708 .23856 m
.58307 .24681 L
s
.58307 .24681 m
.58084 .24232 L
s
.59169 .24561 m
.58307 .24681 L
s
.59927 .23242 m
.58307 .24681 L
s
.532 1 0 r
.50022 .43579 m
.49853 .43246 L
s
.487 0 1 r
.19761 .69112 m
.19431 .70376 L
s
.18494 .69678 m
.19761 .69112 L
s
.16255 .73809 m
.19761 .69112 L
s
.416 1 0 r
.53692 .52862 m
.53255 .52856 L
s
0 1 .083 r
.69768 .52417 m
.69605 .52308 L
s
.69768 .52417 m
.69123 .52121 L
s
.69123 .52121 m
.69159 .52685 L
s
.69123 .52121 m
.69605 .52308 L
s
.70834 .54277 m
.69123 .52121 L
s
0 1 .329 r
.61852 .33746 m
.62041 .3415 L
s
.62352 .33312 m
.61852 .33746 L
s
.61852 .33746 m
.61843 .33541 L
s
.62549 .3392 m
.61852 .33746 L
s
.63592 .3367 m
.61852 .33746 L
s
.034 1 0 r
.65459 .42896 m
.65543 .43396 L
s
.66077 .42842 m
.65459 .42896 L
s
.65459 .42896 m
.65665 .42887 L
s
.65955 .4335 m
.65459 .42896 L
s
.67227 .44015 m
.65459 .42896 L
s
.105 0 1 r
.15946 .59567 m
.15683 .60667 L
s
.1484 .59972 m
.15946 .59567 L
s
.12442 .63655 m
.15946 .59567 L
s
0 .005 1 r
.39533 .80177 m
.39134 .80256 L
s
.39357 .79043 m
.39533 .80177 L
s
.045 1 0 r
.4609 .3448 m
.46511 .34122 L
s
.46511 .34122 m
.46154 .33696 L
s
.532 1 0 r
.49853 .43246 m
.49457 .4342 L
s
.045 1 0 r
.45732 .34054 m
.4609 .3448 L
s
.034 1 0 r
.65543 .43396 m
.65955 .4335 L
s
.65955 .4335 m
.66077 .42842 L
s
0 1 .521 r
.7353 .6182 m
.7293 .62122 L
s
.045 1 0 r
.46154 .33696 m
.45732 .34054 L
s
.949 0 1 r
.23253 .80156 m
.22238 .79397 L
s
0 .561 1 r
.34789 .70082 m
.35565 .7051 L
s
.34527 .70042 m
.34789 .70082 L
s
.34789 .70082 m
.35468 .69469 L
s
.54197 .83319 m
.55178 .79033 L
s
.54853 .79686 m
.55605 .79989 L
s
.54358 .79797 m
.54853 .79686 L
s
.54853 .79686 m
.55178 .79033 L
s
0 1 .329 r
.62041 .3415 m
.62549 .3392 L
s
.62549 .3392 m
.62352 .33312 L
s
.034 1 0 r
.66077 .42842 m
.65665 .42887 L
s
0 1 .083 r
.69605 .52308 m
.69159 .52685 L
s
0 .561 1 r
.35565 .7051 m
.35306 .70472 L
s
.35468 .69469 m
.35565 .7051 L
s
.034 1 0 r
.65665 .42887 m
.65543 .43396 L
s
0 .886 1 r
.58546 .24938 m
.59169 .24561 L
s
.59169 .24561 m
.58708 .23856 L
s
.58708 .23856 m
.58084 .24232 L
s
0 1 .329 r
.62352 .33312 m
.61843 .33541 L
s
0 .005 1 r
.39357 .79043 m
.39134 .80256 L
s
.38267 .79736 m
.39357 .79043 L
s
.487 0 1 r
.19431 .70376 m
.18494 .69678 L
s
0 1 .329 r
.61843 .33541 m
.62041 .3415 L
s
0 1 .948 r
.30918 .60489 m
.31607 .60884 L
s
.30867 .60351 m
.30918 .60489 L
s
.30918 .60489 m
.31643 .59942 L
s
0 .604 1 r
.71128 .79379 m
.71773 .79512 L
s
.70481 .79589 m
.71128 .79379 L
s
.71128 .79379 m
.71064 .78677 L
s
0 1 .948 r
.31607 .60884 m
.31558 .60747 L
s
.31643 .59942 m
.31607 .60884 L
s
0 .604 1 r
.71379 .83035 m
.71064 .78677 L
s
0 .561 1 r
.33361 .73506 m
.35468 .69469 L
s
0 .005 1 r
.39134 .80256 m
.38267 .79736 L
s
.105 0 1 r
.15683 .60667 m
.1484 .59972 L
s
0 .561 1 r
.35468 .69469 m
.35306 .70472 L
s
.34527 .70042 m
.35468 .69469 L
s
.55605 .79989 m
.55111 .80101 L
s
.55178 .79033 m
.55605 .79989 L
s
1 0 .319 r
.12436 .7722 m
.13582 .78131 L
s
.12147 .77232 m
.12436 .7722 L
s
.12436 .7722 m
.1378 .76525 L
s
0 .886 1 r
.58084 .24232 m
.58546 .24938 L
s
0 .099 1 r
.87442 .7872 m
.87987 .78747 L
s
.86609 .7911 m
.87442 .7872 L
s
.87442 .7872 m
.86964 .77972 L
s
0 1 .819 r
.51025 .70146 m
.51665 .70324 L
s
.50625 .70143 m
.51025 .70146 L
s
.51025 .70146 m
.51297 .6949 L
s
1 0 .319 r
.13582 .78131 m
.13301 .78149 L
s
.1378 .76525 m
.13582 .78131 L
s
0 1 .63 r
.27611 .51302 m
.27879 .5116 L
s
.27076 .50823 m
.27611 .51302 L
s
.27888 .50474 m
.27611 .51302 L
s
0 1 .948 r
.31643 .59942 m
.31558 .60747 L
s
.30867 .60351 m
.31643 .59942 L
s
.29609 .63331 m
.31643 .59942 L
s
0 1 .63 r
.27888 .50474 m
.27879 .5116 L
s
.27076 .50823 m
.27888 .50474 L
s
.27344 .5068 m
.27888 .50474 L
s
.25826 .53074 m
.27888 .50474 L
s
0 .561 1 r
.55111 .80101 m
.54358 .79797 L
s
.54358 .79797 m
.55178 .79033 L
s
0 1 .63 r
.27344 .5068 m
.27076 .50823 L
s
0 .561 1 r
.35306 .70472 m
.34527 .70042 L
s
.55178 .79033 m
.55111 .80101 L
s
0 .099 1 r
.88628 .82751 m
.86964 .77972 L
s
0 1 .819 r
.50535 .73203 m
.51297 .6949 L
s
1 0 .699 r
.09544 .68364 m
.09445 .68278 L
s
.08472 .67484 m
.09544 .68364 L
s
.09857 .66822 m
.09544 .68364 L
s
0 .099 1 r
.87152 .79139 m
.86609 .7911 L
s
.86609 .7911 m
.86964 .77972 L
s
0 1 .819 r
.51665 .70324 m
.51266 .70321 L
s
.51297 .6949 m
.51665 .70324 L
s
0 1 .791 r
.67382 .6985 m
.67848 .69847 L
s
.66785 .69991 m
.67382 .6985 L
s
.67382 .6985 m
.672 .69174 L
s
1 0 .699 r
.08366 .67394 m
.08472 .67484 L
s
.08472 .67484 m
.09857 .66822 L
s
0 .604 1 r
.71127 .79723 m
.70481 .79589 L
s
.70481 .79589 m
.71064 .78677 L
s
0 1 .235 r
.47202 .60621 m
.47756 .60697 L
s
.46938 .60489 m
.47202 .60621 L
s
.47202 .60621 m
.47473 .59991 L
s
0 .604 1 r
.71773 .79512 m
.71127 .79723 L
s
.71064 .78677 m
.71773 .79512 L
s
0 1 .819 r
.51297 .6949 m
.51266 .70321 L
s
.50625 .70143 m
.51297 .6949 L
s
0 1 .948 r
.31558 .60747 m
.30867 .60351 L
s
0 .622 1 r
.83751 .69175 m
.84059 .69104 L
s
.82982 .69562 m
.83751 .69175 L
s
.83751 .69175 m
.83127 .68519 L
s
0 .604 1 r
.71064 .78677 m
.71127 .79723 L
s
0 1 .819 r
.51266 .70321 m
.50625 .70143 L
s
1 0 .319 r
.1378 .76525 m
.13301 .78149 L
s
.12147 .77232 m
.1378 .76525 L
s
.09209 .82322 m
.1378 .76525 L
s
0 1 .63 r
.27879 .5116 m
.27344 .5068 L
s
0 1 .235 r
.47756 .60697 m
.47493 .60566 L
s
.47473 .59991 m
.47756 .60697 L
s
0 .099 1 r
.86964 .77972 m
.87152 .79139 L
s
.86964 .77972 m
.87987 .78747 L
s
0 1 .235 r
.47473 .59991 m
.47493 .60566 L
s
.46938 .60489 m
.47473 .59991 L
s
.46844 .63006 m
.47473 .59991 L
s
0 1 .791 r
.67778 .72898 m
.672 .69174 L
s
0 .622 1 r
.83287 .69493 m
.82982 .69562 L
s
.82982 .69562 m
.83127 .68519 L
s
0 1 .791 r
.67249 .69989 m
.66785 .69991 L
s
.66785 .69991 m
.672 .69174 L
s
1 0 .699 r
.09857 .66822 m
.09445 .68278 L
s
.08366 .67394 m
.09857 .66822 L
s
.0534 .7213 m
.09857 .66822 L
s
.176 1 0 r
.4378 .51184 m
.43903 .50944 L
s
.43282 .5102 m
.4378 .51184 L
s
.43709 .50549 m
.4378 .51184 L
s
.43709 .50549 m
.43903 .50944 L
s
.43282 .5102 m
.43709 .50549 L
s
.43405 .5078 m
.43709 .50549 L
s
.43123 .52727 m
.43709 .50549 L
s
.181 1 0 r
.40011 .41174 m
.40053 .41721 L
s
.39715 .41099 m
.40011 .41174 L
s
.40011 .41174 m
.39566 .41526 L
s
.40203 .41295 m
.40011 .41174 L
s
.39372 .42365 m
.40011 .41174 L
s
0 1 .216 r
.63699 .60321 m
.63934 .60182 L
s
.63142 .60428 m
.63699 .60321 L
s
.63699 .60321 m
.63385 .59713 L
s
.513 0 1 r
.28608 .77716 m
.29577 .78368 L
s
.28293 .77737 m
.28608 .77716 L
s
.28608 .77716 m
.29566 .77057 L
s
0 .099 1 r
.87987 .78747 m
.87152 .79139 L
s
.176 1 0 r
.43405 .5078 m
.43282 .5102 L
s
0 1 .791 r
.672 .69174 m
.67249 .69989 L
s
.672 .69174 m
.67848 .69847 L
s
0 1 .235 r
.47493 .60566 m
.46938 .60489 L
s
0 1 .791 r
.67848 .69847 m
.67249 .69989 L
s
.513 0 1 r
.29577 .78368 m
.29266 .78392 L
s
.29566 .77057 m
.29577 .78368 L
s
0 .622 1 r
.83127 .68519 m
.83287 .69493 L
s
.83127 .68519 m
.84059 .69104 L
s
.8509 .72592 m
.83127 .68519 L
s
0 1 .216 r
.63375 .60289 m
.63142 .60428 L
s
.63142 .60428 m
.63385 .59713 L
s
0 1 .896 r
.80088 .59602 m
.80113 .59474 L
s
.79424 .60031 m
.80088 .59602 L
s
.80088 .59602 m
.79331 .59105 L
s
.79447 .59905 m
.79424 .60031 L
s
.79424 .60031 m
.79331 .59105 L
s
.181 1 0 r
.40053 .41721 m
.40203 .41295 L
s
.39566 .41526 m
.40053 .41721 L
s
.39715 .41099 m
.39566 .41526 L
s
0 1 .216 r
.63385 .59713 m
.63375 .60289 L
s
.63385 .59713 m
.63934 .60182 L
s
.64148 .62679 m
.63385 .59713 L
s
.176 1 0 r
.43903 .50944 m
.43405 .5078 L
s
.197 1 0 r
.59467 .50753 m
.59682 .50936 L
s
.59682 .50936 m
.60124 .50682 L
s
.59682 .50936 m
.59623 .50305 L
s
.59623 .50305 m
.59467 .50753 L
s
.60124 .50682 m
.59623 .50305 L
s
.59623 .50305 m
.5991 .50499 L
s
.6049 .52378 m
.59623 .50305 L
s
0 1 .279 r
.52278 .31697 m
.52347 .32107 L
s
.52527 .31218 m
.52278 .31697 L
s
.52278 .31697 m
.52007 .31563 L
s
.52866 .31763 m
.52278 .31697 L
s
.53083 .31525 m
.52278 .31697 L
s
.042 0 1 r
.24661 .68004 m
.25548 .68598 L
s
.24513 .67918 m
.24661 .68004 L
s
.24661 .68004 m
.25635 .67369 L
s
0 1 .896 r
.79331 .59105 m
.79447 .59905 L
s
.79331 .59105 m
.80113 .59474 L
s
.81522 .62351 m
.79331 .59105 L
s
.218 1 0 r
.55919 .40962 m
.5589 .41465 L
s
.56299 .40868 m
.55919 .40962 L
s
.55919 .40962 m
.55818 .41013 L
s
.5637 .41321 m
.55919 .40962 L
s
.56801 .41994 m
.55919 .40962 L
s
1 0 .319 r
.13301 .78149 m
.12147 .77232 L
s
.197 1 0 r
.60124 .50682 m
.5991 .50499 L
s
.513 0 1 r
.2642 .82034 m
.29566 .77057 L
s
.181 1 0 r
.40203 .41295 m
.39715 .41099 L
s
0 1 .216 r
.63934 .60182 m
.63375 .60289 L
s
0 .622 1 r
.84059 .69104 m
.83287 .69493 L
s
.042 0 1 r
.25548 .68598 m
.25404 .68514 L
s
.25635 .67369 m
.25548 .68598 L
s
0 1 .556 r
.75678 .50421 m
.7596 .50506 L
s
.7596 .50506 m
.76415 .49973 L
s
.7596 .50506 m
.7558 .49742 L
s
0 .433 1 r
.64647 .22072 m
.6499 .22388 L
s
.65215 .21159 m
.64647 .22072 L
s
.64647 .22072 m
.64514 .21543 L
s
.65691 .22002 m
.64647 .22072 L
s
.66961 .20553 m
.64647 .22072 L
s
0 1 .556 r
.7558 .49742 m
.75678 .50421 L
s
.76415 .49973 m
.7558 .49742 L
s
.7558 .49742 m
.76134 .49886 L
s
.77926 .52028 m
.7558 .49742 L
s
.513 0 1 r
.29566 .77057 m
.29266 .78392 L
s
.28293 .77737 m
.29566 .77057 L
s
.218 1 0 r
.5589 .41465 m
.5637 .41321 L
s
.5637 .41321 m
.56299 .40868 L
s
0 .312 1 r
.4491 .77929 m
.45749 .78333 L
s
.44521 .7796 m
.4491 .77929 L
s
.4491 .77929 m
.45495 .77245 L
s
0 1 .556 r
.76415 .49973 m
.76134 .49886 L
s
0 1 .849 r
.68233 .31213 m
.68512 .31694 L
s
.68908 .307 m
.68233 .31213 L
s
.68233 .31213 m
.68319 .30942 L
s
.69101 .31451 m
.68233 .31213 L
s
.70646 .3113 m
.68233 .31213 L
s
0 1 .504 r
.71879 .4044 m
.72052 .41038 L
s
.72667 .40312 m
.71879 .4044 L
s
.71879 .4044 m
.7218 .40383 L
s
.72539 .40966 m
.71879 .4044 L
s
.74301 .41621 m
.71879 .4044 L
s
1 0 .699 r
.09445 .68278 m
.08366 .67394 L
s
.218 1 0 r
.55818 .41013 m
.5589 .41465 L
s
.197 1 0 r
.5991 .50499 m
.59467 .50753 L
s
0 .341 1 r
.21523 .58865 m
.21615 .58714 L
s
.20738 .58262 m
.21523 .58865 L
s
.21772 .57732 m
.21523 .58865 L
s
0 1 .504 r
.72052 .41038 m
.72539 .40966 L
s
.72539 .40966 m
.72667 .40312 L
s
0 .341 1 r
.20828 .58108 m
.20738 .58262 L
s
.20738 .58262 m
.21772 .57732 L
s
0 1 .279 r
.52347 .32107 m
.52866 .31763 L
s
.52866 .31763 m
.52527 .31218 L
s
.042 0 1 r
.25635 .67369 m
.25404 .68514 L
s
.24513 .67918 m
.25635 .67369 L
s
.22613 .71821 m
.25635 .67369 L
s
0 .312 1 r
.43701 .81746 m
.45495 .77245 L
s
.218 1 0 r
.56299 .40868 m
.55818 .41013 L
s
0 1 .896 r
.80113 .59474 m
.79447 .59905 L
s
0 1 .279 r
.52007 .31563 m
.52347 .32107 L
s
.52527 .31218 m
.52007 .31563 L
s
0 .312 1 r
.45749 .78333 m
.45362 .78366 L
s
.45495 .77245 m
.45749 .78333 L
s
0 .341 1 r
.21772 .57732 m
.21615 .58714 L
s
.20828 .58108 m
.21772 .57732 L
s
.18776 .61526 m
.21772 .57732 L
s
0 1 .849 r
.68512 .31694 m
.69101 .31451 L
s
.69101 .31451 m
.68908 .307 L
s
0 1 .504 r
.72667 .40312 m
.7218 .40383 L
s
.513 0 1 r
.29266 .78392 m
.28293 .77737 L
s
0 1 .556 r
.76134 .49886 m
.75678 .50421 L
s
0 .68 1 r
.61332 .77828 m
.62054 .7801 L
s
.60795 .77912 m
.61332 .77828 L
s
.61332 .77828 m
.61518 .77086 L
s
0 .868 1 r
.40995 .68255 m
.41746 .68567 L
s
.40741 .68168 m
.40995 .68255 L
s
.40995 .68255 m
.41566 .67583 L
s
0 .433 1 r
.6499 .22388 m
.65691 .22002 L
s
.65691 .22002 m
.65215 .21159 L
s
0 1 .504 r
.7218 .40383 m
.72052 .41038 L
s
0 1 .849 r
.68908 .307 m
.68319 .30942 L
s
0 .433 1 r
.65215 .21159 m
.64514 .21543 L
s
0 .68 1 r
.61051 .81456 m
.61518 .77086 L
s
0 .312 1 r
.45495 .77245 m
.45362 .78366 L
s
.44521 .7796 m
.45495 .77245 L
s
0 .868 1 r
.41746 .68567 m
.41494 .68481 L
s
.41566 .67583 m
.41746 .68567 L
s
0 1 .849 r
.68319 .30942 m
.68512 .31694 L
s
0 .484 1 r
.77841 .77367 m
.78426 .77391 L
s
.77102 .77599 m
.77841 .77367 L
s
.77841 .77367 m
.77587 .76576 L
s
.042 0 1 r
.25404 .68514 m
.24513 .67918 L
s
0 .312 1 r
.45362 .78366 m
.44521 .7796 L
s
0 .433 1 r
.64514 .21543 m
.6499 .22388 L
s
0 1 .648 r
.37074 .58561 m
.37744 .58849 L
s
.37046 .58371 m
.37074 .58561 L
s
.37074 .58561 m
.37698 .57967 L
s
0 .868 1 r
.41566 .67583 m
.41494 .68481 L
s
.40741 .68168 m
.41566 .67583 L
s
.39956 .71511 m
.41566 .67583 L
s
0 1 .727 r
.57496 .68192 m
.58086 .68238 L
s
.57024 .68173 m
.57496 .68192 L
s
.57496 .68192 m
.57601 .67458 L
s
0 1 .648 r
.37744 .58849 m
.37718 .5866 L
s
.37698 .57967 m
.37744 .58849 L
s
0 .68 1 r
.62054 .7801 m
.61517 .78095 L
s
.61518 .77086 m
.62054 .7801 L
s
0 .341 1 r
.21615 .58714 m
.20828 .58108 L
s
0 .484 1 r
.78471 .81165 m
.77587 .76576 L
s
0 1 .648 r
.37698 .57967 m
.37718 .5866 L
s
.37046 .58371 m
.37698 .57967 L
s
.36181 .61194 m
.37698 .57967 L
s
0 .68 1 r
.61517 .78095 m
.60795 .77912 L
s
.60795 .77912 m
.61518 .77086 L
s
.61518 .77086 m
.61517 .78095 L
s
1 0 .812 r
.18364 .75626 m
.19456 .76439 L
s
.18135 .75602 m
.18364 .75626 L
s
.18364 .75626 m
.19615 .74921 L
s
0 1 .363 r
.33641 .49177 m
.34012 .49028 L
s
.33177 .4874 m
.33641 .49177 L
s
.33897 .4841 m
.33641 .49177 L
s
0 .484 1 r
.77686 .77624 m
.77102 .77599 L
s
.77102 .77599 m
.77587 .76576 L
s
0 1 .363 r
.33897 .4841 m
.34012 .49028 L
s
.33177 .4874 m
.33897 .4841 L
s
.33547 .48589 m
.33897 .4841 L
s
.32375 .50792 m
.33897 .4841 L
s
0 .868 1 r
.41494 .68481 m
.40741 .68168 L
s
1 0 .812 r
.19456 .76439 m
.19233 .7642 L
s
.19615 .74921 m
.19456 .76439 L
s
0 1 .969 r
.74096 .67718 m
.74454 .67617 L
s
.73394 .67925 m
.74096 .67718 L
s
.74096 .67718 m
.73692 .66993 L
s
0 .484 1 r
.77587 .76576 m
.77686 .77624 L
s
.77587 .76576 m
.78426 .77391 L
s
0 1 .363 r
.33547 .48589 m
.33177 .4874 L
s
0 1 .187 r
.53689 .5858 m
.5416 .58489 L
s
.53283 .5845 m
.53689 .5858 L
s
.53689 .5858 m
.53738 .57874 L
s
0 1 .727 r
.58086 .68238 m
.57614 .6822 L
s
.57601 .67458 m
.58086 .68238 L
s
.57601 .67458 m
.57614 .6822 L
s
.57024 .68173 m
.57601 .67458 L
s
.57369 .71199 m
.57601 .67458 L
s
0 .484 1 r
.78426 .77391 m
.77686 .77624 L
s
0 1 .727 r
.57614 .6822 m
.57024 .68173 L
s
0 1 .969 r
.7375 .67825 m
.73394 .67925 L
s
.73394 .67925 m
.73692 .66993 L
s
.799 0 1 r
.15367 .66564 m
.15332 .66449 L
s
.14357 .65779 m
.15367 .66564 L
s
.15644 .65122 m
.15367 .66564 L
s
0 1 .648 r
.37718 .5866 m
.37046 .58371 L
s
.799 0 1 r
.14316 .65659 m
.14357 .65779 L
s
.14357 .65779 m
.15644 .65122 L
s
0 1 .363 r
.34012 .49028 m
.33547 .48589 L
s
0 1 .187 r
.53738 .57874 m
.53754 .58359 L
s
.53738 .57874 m
.5416 .58489 L
s
.53283 .5845 m
.53738 .57874 L
s
.53656 .6086 m
.53738 .57874 L
s
0 1 .969 r
.73692 .66993 m
.7375 .67825 L
s
.73692 .66993 m
.74454 .67617 L
s
.74852 .70886 m
.73692 .66993 L
s
1 0 .812 r
.19615 .74921 m
.19233 .7642 L
s
.18135 .75602 m
.19615 .74921 L
s
.15519 .80432 m
.19615 .74921 L
s
0 1 .187 r
.5416 .58489 m
.53754 .58359 L
s
.152 1 0 r
.49933 .48346 m
.50113 .48971 L
s
.49744 .48552 m
.49933 .48346 L
s
.49933 .48346 m
.49596 .48875 L
s
.50262 .48648 m
.49933 .48346 L
s
.49914 .50436 m
.49933 .48346 L
s
0 1 .477 r
.70413 .58034 m
.70455 .5784 L
s
.69773 .58286 m
.70413 .58034 L
s
.70413 .58034 m
.69842 .57451 L
s
.075 1 0 r
.46191 .38886 m
.46181 .3946 L
s
.46182 .38725 m
.46191 .38886 L
s
.46191 .38886 m
.45786 .39089 L
s
.46576 .39097 m
.46191 .38886 L
s
.46141 .39927 m
.46191 .38886 L
s
.152 1 0 r
.50113 .48971 m
.50262 .48648 L
s
.49596 .48875 m
.50113 .48971 L
s
0 1 .187 r
.53754 .58359 m
.53283 .5845 L
s
0 1 .477 r
.69813 .58094 m
.69773 .58286 L
s
.69773 .58286 m
.69842 .57451 L
s
.152 1 0 r
.49744 .48552 m
.49596 .48875 L
s
.799 0 1 r
.15644 .65122 m
.15332 .66449 L
s
.14316 .65659 m
.15644 .65122 L
s
.11625 .70099 m
.15644 .65122 L
s
0 1 .477 r
.69842 .57451 m
.69813 .58094 L
s
.69842 .57451 m
.70455 .5784 L
s
.71203 .60525 m
.69842 .57451 L
s
.131 0 1 r
.34772 .76014 m
.35709 .76557 L
s
.34493 .75988 m
.34772 .76014 L
s
.34772 .76014 m
.35635 .75307 L
s
0 1 .969 r
.74454 .67617 m
.7375 .67825 L
s
.075 1 0 r
.46181 .3946 m
.46576 .39097 L
s
.45786 .39089 m
.46181 .3946 L
s
0 1 .165 r
.65953 .48544 m
.66331 .48656 L
s
.66331 .48656 m
.66722 .48221 L
s
.66331 .48656 m
.66043 .47961 L
s
.66043 .47961 m
.65953 .48544 L
s
.66722 .48221 m
.66043 .47961 L
s
.66043 .47961 m
.66344 .48108 L
s
.67524 .50078 m
.66043 .47961 L
s
.131 0 1 r
.35709 .76557 m
.35434 .76534 L
s
.35635 .75307 m
.35709 .76557 L
s
0 1 .687 r
.58615 .29191 m
.58763 .29647 L
s
.59044 .28631 m
.58615 .29191 L
s
.58615 .29191 m
.58434 .28972 L
s
.59372 .29305 m
.58615 .29191 L
s
.60077 .28928 m
.58615 .29191 L
s
0 1 .207 r
.62299 .38537 m
.62341 .39102 L
s
.62859 .38373 m
.62299 .38537 L
s
.62299 .38537 m
.62307 .38522 L
s
.62892 .38953 m
.62299 .38537 L
s
.63816 .39547 m
.62299 .38537 L
s
.152 1 0 r
.50262 .48648 m
.49744 .48552 L
s
.075 1 0 r
.46576 .39097 m
.46182 .38725 L
s
.46182 .38725 m
.45786 .39089 L
s
0 1 .165 r
.66722 .48221 m
.66344 .48108 L
s
0 1 .477 r
.70455 .5784 m
.69813 .58094 L
s
0 1 .207 r
.62341 .39102 m
.62892 .38953 L
s
.62892 .38953 m
.62859 .38373 L
s
1 0 .812 r
.19233 .7642 m
.18135 .75602 L
s
0 .344 1 r
.30783 .66196 m
.31637 .66685 L
s
.30676 .66064 m
.30783 .66196 L
s
.30783 .66196 m
.3166 .65526 L
s
0 1 .165 r
.66344 .48108 m
.65953 .48544 L
s
0 .344 1 r
.31637 .66685 m
.31533 .66555 L
s
.3166 .65526 m
.31637 .66685 L
s
0 .537 1 r
.51316 .76112 m
.52133 .76393 L
s
.50912 .76097 m
.51316 .76112 L
s
.51316 .76112 m
.51781 .75346 L
s
.131 0 1 r
.35635 .75307 m
.35434 .76534 L
s
.34493 .75988 m
.35635 .75307 L
s
.3297 .80137 m
.35635 .75307 L
s
0 1 .207 r
.62307 .38522 m
.62341 .39102 L
s
0 1 .687 r
.58763 .29647 m
.59372 .29305 L
s
.59372 .29305 m
.59044 .28631 L
s
0 1 .207 r
.62859 .38373 m
.62307 .38522 L
s
.799 0 1 r
.15332 .66449 m
.14316 .65659 L
s
0 1 .687 r
.59044 .28631 m
.58434 .28972 L
s
0 .722 1 r
.27552 .56854 m
.2771 .56667 L
s
.26811 .56335 m
.27552 .56854 L
s
.27752 .55795 m
.27552 .56854 L
s
0 .344 1 r
.3166 .65526 m
.31533 .66555 L
s
.30676 .66064 m
.3166 .65526 L
s
.2914 .69781 m
.3166 .65526 L
s
0 1 .687 r
.58434 .28972 m
.58763 .29647 L
s
0 .722 1 r
.26966 .56147 m
.26811 .56335 L
s
.26811 .56335 m
.27752 .55795 L
s
1 0 0 r
.09176 .7439 m
.0904 .74332 L
s
.0794 .73391 m
.09176 .7439 L
s
.09512 .72633 m
.09176 .7439 L
s
0 .537 1 r
.52133 .76393 m
.51732 .7638 L
s
.51781 .75346 m
.52133 .76393 L
s
0 .682 1 r
.67993 .7587 m
.68667 .75925 L
s
.67373 .75947 m
.67993 .7587 L
s
.67993 .7587 m
.68003 .75034 L
s
1 0 0 r
.07795 .73327 m
.0794 .73391 L
s
.0794 .73391 m
.09512 .72633 L
s
0 .722 1 r
.27752 .55795 m
.2771 .56667 L
s
.26966 .56147 m
.27752 .55795 L
s
.25278 .59341 m
.27752 .55795 L
s
.131 0 1 r
.35434 .76534 m
.34493 .75988 L
s
0 .537 1 r
.50493 .79841 m
.51781 .75346 L
s
0 1 .918 r
.47372 .66344 m
.48101 .66525 L
s
.4709 .66208 m
.47372 .66344 L
s
.47372 .66344 m
.47813 .65594 L
s
0 .239 1 r
.8473 .75238 m
.85228 .75161 L
s
.83874 .75528 m
.8473 .75238 L
s
.8473 .75238 m
.8425 .7437 L
s
0 .537 1 r
.51781 .75346 m
.51732 .7638 L
s
.50912 .76097 m
.51781 .75346 L
s
0 1 .918 r
.48101 .66525 m
.47821 .66389 L
s
.47813 .65594 m
.48101 .66525 L
s
0 .537 1 r
.51732 .7638 m
.50912 .76097 L
s
0 .344 1 r
.31533 .66555 m
.30676 .66064 L
s
0 .682 1 r
.68086 .79543 m
.68003 .75034 L
s
1 0 0 r
.09512 .72633 m
.0904 .74332 L
s
.07795 .73327 m
.09512 .72633 L
s
.04372 .78794 m
.09512 .72633 L
s
0 1 .918 r
.47813 .65594 m
.47821 .66389 L
s
.4709 .66208 m
.47813 .65594 L
s
.46726 .69463 m
.47813 .65594 L
s
0 1 .769 r
.64168 .66126 m
.64663 .66034 L
s
.63573 .66134 m
.64168 .66126 L
s
.64168 .66126 m
.64052 .65321 L
s
0 .239 1 r
.84369 .75452 m
.83874 .75528 L
s
.83874 .75528 m
.8425 .7437 L
s
0 .682 1 r
.68047 .76003 m
.67373 .75947 L
s
.67373 .75947 m
.68003 .75034 L
s
0 1 .458 r
.43394 .56551 m
.44062 .5672 L
s
.43355 .56296 m
.43394 .56551 L
s
.43394 .56551 m
.43903 .55888 L
s
0 .682 1 r
.68667 .75925 m
.68047 .76003 L
s
.68003 .75034 m
.68667 .75925 L
s
.68003 .75034 m
.68047 .76003 L
s
0 .722 1 r
.2771 .56667 m
.26966 .56147 L
s
0 1 .458 r
.44062 .5672 m
.44025 .56465 L
s
.43903 .55888 m
.44062 .5672 L
s
.43903 .55888 m
.44025 .56465 L
s
.43355 .56296 m
.43903 .55888 L
s
.42928 .58999 m
.43903 .55888 L
s
0 .239 1 r
.8425 .7437 m
.84369 .75452 L
s
.8425 .7437 m
.85228 .75161 L
s
.85752 .79244 m
.8425 .7437 L
s
0 .725 1 r
.80979 .65454 m
.81195 .6528 L
s
.8017 .65773 m
.80979 .65454 L
s
.80979 .65454 m
.80325 .64706 L
s
0 1 .918 r
.47821 .66389 m
.4709 .66208 L
s
0 1 .222 r
.40057 .46242 m
.40284 .46856 L
s
.3945 .46505 m
.40057 .46242 L
s
.40057 .46242 m
.39758 .46954 L
s
.39976 .46406 m
.40057 .46242 L
s
.39099 .4845 m
.40057 .46242 L
s
.39758 .46954 m
.40284 .46856 L
s
.3945 .46505 m
.39758 .46954 L
s
0 1 .769 r
.64052 .65321 m
.64068 .66042 L
s
.64052 .65321 m
.64663 .66034 L
s
.63573 .66134 m
.64052 .65321 L
s
.64384 .69143 m
.64052 .65321 L
s
0 .725 1 r
.80384 .656 m
.8017 .65773 L
s
.8017 .65773 m
.80325 .64706 L
s
.743 0 1 r
.24446 .73946 m
.25494 .74658 L
s
.24273 .7388 m
.24446 .73946 L
s
.24446 .73946 m
.25605 .73217 L
s
0 1 .769 r
.64068 .66042 m
.63573 .66134 L
s
0 1 .294 r
.60448 .56373 m
.60665 .56117 L
s
.59836 .56382 m
.60448 .56373 L
s
.60448 .56373 m
.60151 .55651 L
s
.743 0 1 r
.25494 .74658 m
.25327 .74595 L
s
.25605 .73217 m
.25494 .74658 L
s
0 .239 1 r
.85228 .75161 m
.84369 .75452 L
s
0 1 .769 r
.64663 .66034 m
.64068 .66042 L
s
0 .725 1 r
.80325 .64706 m
.80384 .656 L
s
.80325 .64706 m
.81195 .6528 L
s
.82114 .68821 m
.80325 .64706 L
s
0 1 .222 r
.40284 .46856 m
.39976 .46406 L
s
0 1 .294 r
.60151 .55651 m
.60052 .56126 L
s
.60151 .55651 m
.60665 .56117 L
s
.59836 .56382 m
.60151 .55651 L
s
.60651 .58657 m
.60151 .55651 L
s
0 1 .458 r
.44025 .56465 m
.43355 .56296 L
s
0 1 .222 r
.39976 .46406 m
.3945 .46505 L
s
0 1 .294 r
.60052 .56126 m
.59836 .56382 L
s
0 1 .863 r
.76427 .55838 m
.76571 .56037 L
s
.76571 .56037 m
.77254 .55612 L
s
.76571 .56037 m
.76443 .55082 L
s
0 1 .038 r
.56305 .46037 m
.56059 .46636 L
s
.56783 .46251 m
.56305 .46037 L
s
.56305 .46037 m
.56226 .4621 L
s
.56615 .46677 m
.56305 .46037 L
s
.56887 .48084 m
.56305 .46037 L
s
0 1 .863 r
.77254 .55612 m
.77113 .55412 L
s
.77254 .55612 m
.76443 .55082 L
s
0 1 .177 r
.5252 .36491 m
.52505 .3709 L
s
.52761 .36261 m
.5252 .36491 L
s
.5252 .36491 m
.52215 .36575 L
s
.53051 .36777 m
.5252 .36491 L
s
.53092 .37424 m
.5252 .36491 L
s
.349 0 1 r
.21354 .64676 m
.21383 .64525 L
s
.20395 .63985 m
.21354 .64676 L
s
.21586 .6332 m
.21354 .64676 L
s
0 1 .038 r
.56059 .46636 m
.56615 .46677 L
s
.56615 .46677 m
.56783 .46251 L
s
0 1 .863 r
.76443 .55082 m
.76427 .55838 L
s
.76443 .55082 m
.77113 .55412 L
s
.78446 .58313 m
.76443 .55082 L
s
.349 0 1 r
.20419 .6383 m
.20395 .63985 L
s
.20395 .63985 m
.21586 .6332 L
s
1 0 0 r
.0904 .74332 m
.07795 .73327 L
s
.743 0 1 r
.25605 .73217 m
.25327 .74595 L
s
.24273 .7388 m
.25605 .73217 L
s
.21998 .78492 m
.25605 .73217 L
s
0 1 .294 r
.60665 .56117 m
.60052 .56126 L
s
0 1 .038 r
.56226 .4621 m
.56059 .46636 L
s
0 1 .63 r
.72607 .4551 m
.72603 .46216 L
s
.73461 .45682 m
.72607 .4551 L
s
.72607 .4551 m
.72978 .45619 L
s
.73086 .46277 m
.72607 .4551 L
s
.74748 .47717 m
.72607 .4551 L
s
.72603 .46216 m
.73086 .46277 L
s
.73086 .46277 m
.73461 .45682 L
s
0 .725 1 r
.81195 .6528 m
.80384 .656 L
s
0 .843 1 r
.65099 .26576 m
.65337 .27095 L
s
.65713 .25933 m
.65099 .26576 L
s
.65099 .26576 m
.65015 .26278 L
s
.66034 .26749 m
.65099 .26576 L
s
.6726 .26261 m
.65099 .26576 L
s
0 1 .707 r
.68824 .36004 m
.6895 .36651 L
s
.69568 .35765 m
.68824 .36004 L
s
.68824 .36004 m
.68939 .35928 L
s
.69578 .36487 m
.68824 .36004 L
s
.71019 .37033 m
.68824 .36004 L
s
0 .184 1 r
.41097 .74227 m
.42013 .74654 L
s
.40836 .74147 m
.41097 .74227 L
s
.41097 .74227 m
.41858 .73455 L
s
.349 0 1 r
.21586 .6332 m
.21383 .64525 L
s
.20419 .6383 m
.21586 .6332 L
s
.18079 .68012 m
.21586 .6332 L
s
0 1 .177 r
.52505 .3709 m
.53051 .36777 L
s
.52215 .36575 m
.52505 .3709 L
s
0 1 .038 r
.56783 .46251 m
.56226 .4621 L
s
0 1 .177 r
.53051 .36777 m
.52761 .36261 L
s
0 1 .63 r
.73461 .45682 m
.72978 .45619 L
s
0 1 .707 r
.6895 .36651 m
.69578 .36487 L
s
.69578 .36487 m
.69568 .35765 L
s
0 .184 1 r
.42013 .74654 m
.41756 .74576 L
s
.41858 .73455 m
.42013 .74654 L
s
0 1 .863 r
.77113 .55412 m
.76427 .55838 L
s
0 1 .177 r
.52761 .36261 m
.52215 .36575 L
s
0 1 .63 r
.72978 .45619 m
.72603 .46216 L
s
.743 0 1 r
.25327 .74595 m
.24273 .7388 L
s
0 .843 1 r
.65337 .27095 m
.66034 .26749 L
s
.66034 .26749 m
.65713 .25933 L
s
0 .661 1 r
.57901 .74204 m
.58693 .7435 L
s
.57442 .7415 m
.57901 .74204 L
s
.57901 .74204 m
.58219 .73342 L
s
0 .656 1 r
.37064 .64302 m
.37898 .64681 L
s
.36983 .64115 m
.37064 .64302 L
s
.37064 .64302 m
.3784 .6358 L
s
0 1 .707 r
.69568 .35765 m
.68939 .35928 L
s
0 .184 1 r
.41858 .73455 m
.41756 .74576 L
s
.40836 .74147 m
.41858 .73455 L
s
.39696 .78189 m
.41858 .73455 L
s
0 1 .707 r
.68939 .35928 m
.6895 .36651 L
s
0 .656 1 r
.37898 .64681 m
.37821 .64496 L
s
.3784 .6358 m
.37898 .64681 L
s
0 .843 1 r
.65713 .25933 m
.65015 .26278 L
s
.65015 .26278 m
.65337 .27095 L
s
.349 0 1 r
.21383 .64525 m
.20419 .6383 L
s
0 .558 1 r
.74847 .73798 m
.75439 .73725 L
s
.74103 .73906 m
.74847 .73798 L
s
.74847 .73798 m
.74635 .72876 L
s
0 .656 1 r
.3784 .6358 m
.37821 .64496 L
s
.36983 .64115 m
.3784 .6358 L
s
.35841 .67686 m
.3784 .6358 L
s
0 1 .981 r
.33742 .54755 m
.33972 .54526 L
s
.33033 .54312 m
.33742 .54755 L
s
.33886 .53754 m
.33742 .54755 L
s
0 .184 1 r
.41756 .74576 m
.40836 .74147 L
s
0 .661 1 r
.58693 .7435 m
.58236 .74296 L
s
.58219 .73342 m
.58693 .7435 L
s
0 1 .981 r
.33886 .53754 m
.33972 .54526 L
s
.33033 .54312 m
.33886 .53754 L
s
.33261 .54081 m
.33886 .53754 L
s
.31955 .57097 m
.33886 .53754 L
s
.33261 .54081 m
.33033 .54312 L
s
0 1 .82 r
.53944 .64342 m
.5464 .6437 L
s
.5357 .64169 m
.53944 .64342 L
s
.53944 .64342 m
.54212 .635 L
s
0 .661 1 r
.58219 .73342 m
.58236 .74296 L
s
.57442 .7415 m
.58219 .73342 L
s
.57466 .77885 m
.58219 .73342 L
s
1 0 .502 r
.15111 .72635 m
.15044 .72542 L
s
.13936 .71731 m
.15111 .72635 L
s
.15412 .70973 m
.15111 .72635 L
s
.13862 .71633 m
.13936 .71731 L
s
.13936 .71731 m
.15412 .70973 L
s
0 .661 1 r
.58236 .74296 m
.57442 .7415 L
s
0 .558 1 r
.74693 .73833 m
.74103 .73906 L
s
.74103 .73906 m
.74635 .72876 L
s
.74635 .72876 m
.74693 .73833 L
s
.74635 .72876 m
.75439 .73725 L
s
.7531 .77579 m
.74635 .72876 L
s
0 .656 1 r
.37821 .64496 m
.36983 .64115 L
s
0 1 .82 r
.54212 .635 m
.54267 .64197 L
s
.54212 .635 m
.5464 .6437 L
s
.5357 .64169 m
.54212 .635 L
s
.53678 .67359 m
.54212 .635 L
s
0 1 .949 r
.71046 .63918 m
.71373 .63705 L
s
.70303 .64025 m
.71046 .63918 L
s
.71046 .63918 m
.7065 .63077 L
s
0 1 .82 r
.5464 .6437 m
.54267 .64197 L
s
0 1 .402 r
.49928 .54471 m
.50595 .54468 L
s
.49766 .5415 m
.49928 .54471 L
s
.49928 .54471 m
.50261 .53704 L
s
0 .558 1 r
.75439 .73725 m
.74693 .73833 L
s
0 1 .981 r
.33972 .54526 m
.33261 .54081 L
s
0 1 .402 r
.50261 .53704 m
.50434 .54146 L
s
.50261 .53704 m
.50595 .54468 L
s
.49766 .5415 m
.50261 .53704 L
s
.49858 .56746 m
.50261 .53704 L
s
1 0 .502 r
.15412 .70973 m
.15044 .72542 L
s
.13862 .71633 m
.15412 .70973 L
s
.10775 .7681 m
.15412 .70973 L
s
0 1 .82 r
.54267 .64197 m
.5357 .64169 L
s
0 1 .949 r
.70627 .63812 m
.70303 .64025 L
s
.70303 .64025 m
.7065 .63077 L
s
0 1 .402 r
.50595 .54468 m
.50434 .54146 L
s
0 1 .949 r
.7065 .63077 m
.70627 .63812 L
s
.7065 .63077 m
.71373 .63705 L
s
.71588 .67031 m
.7065 .63077 L
s
0 1 .226 r
.46371 .43966 m
.46519 .447 L
s
.46077 .44056 m
.46371 .43966 L
s
.46371 .43966 m
.45901 .44518 L
s
.46696 .44239 m
.46371 .43966 L
s
.46006 .46045 m
.46371 .43966 L
s
.46519 .447 m
.46696 .44239 L
s
.45901 .44518 m
.46519 .447 L
s
0 1 .548 r
.66525 .53921 m
.66664 .54206 L
s
.66664 .54206 m
.67346 .53943 L
s
.66664 .54206 m
.66713 .5332 L
s
.66713 .5332 m
.66525 .53921 L
s
.67346 .53943 m
.66713 .5332 L
s
.66713 .5332 m
.67208 .53657 L
s
.67834 .56394 m
.66713 .5332 L
s
0 1 .226 r
.46077 .44056 m
.45901 .44518 L
s
0 1 .548 r
.67346 .53943 m
.67208 .53657 L
s
.354 0 1 r
.30687 .7218 m
.31703 .72786 L
s
.30563 .72063 m
.30687 .7218 L
s
.30687 .7218 m
.31753 .71411 L
s
0 1 .402 r
.50434 .54146 m
.49766 .5415 L
s
0 1 .949 r
.71373 .63705 m
.70627 .63812 L
s
0 1 .368 r
.62828 .43619 m
.62672 .44302 L
s
.63468 .4375 m
.62828 .43619 L
s
.62828 .43619 m
.62855 .43752 L
s
.63285 .44299 m
.62828 .43619 L
s
.64049 .45669 m
.62828 .43619 L
s
.354 0 1 r
.31703 .72786 m
.31584 .72673 L
s
.31753 .71411 m
.31703 .72786 L
s
0 1 .542 r
.59 .33987 m
.59031 .3463 L
s
.59458 .33686 m
.59 .33987 L
s
.59 .33987 m
.58807 .33978 L
s
.59681 .34338 m
.59 .33987 L
s
.60233 .34853 m
.59 .33987 L
s
0 1 .368 r
.62672 .44302 m
.63285 .44299 L
s
.63285 .44299 m
.63468 .4375 L
s
0 1 .226 r
.46696 .44239 m
.46077 .44056 L
s
.354 0 1 r
.31753 .71411 m
.31584 .72673 L
s
.30563 .72063 m
.31753 .71411 L
s
.28652 .765 m
.31753 .71411 L
s
0 .04 1 r
.2751 .62698 m
.27601 .62503 L
s
.2659 .621 m
.2751 .62698 L
s
.27688 .61414 m
.2751 .62698 L
s
0 1 .368 r
.62855 .43752 m
.62672 .44302 L
s
1 0 .502 r
.15044 .72542 m
.13862 .71633 L
s
0 1 .548 r
.67208 .53657 m
.66525 .53921 L
s
0 .04 1 r
.26677 .61901 m
.2659 .621 L
s
.2659 .621 m
.27688 .61414 L
s
0 1 .542 r
.59031 .3463 m
.59681 .34338 L
s
.59681 .34338 m
.59458 .33686 L
s
0 1 .368 r
.63468 .4375 m
.62855 .43752 L
s
0 .416 1 r
.4759 .72352 m
.48496 .72654 L
s
.47323 .72214 m
.4759 .72352 L
s
.4759 .72352 m
.48236 .71498 L
s
0 1 .542 r
.58807 .33978 m
.59031 .3463 L
s
0 .04 1 r
.27688 .61414 m
.27601 .62503 L
s
.26677 .61901 m
.27688 .61414 L
s
.24707 .6587 m
.27688 .61414 L
s
0 1 .542 r
.59458 .33686 m
.58807 .33978 L
s
0 .416 1 r
.48496 .72654 m
.48232 .72516 L
s
.48236 .71498 m
.48496 .72654 L
s
0 .667 1 r
.64685 .72196 m
.6543 .72191 L
s
.64114 .72125 m
.64685 .72196 L
s
.64685 .72196 m
.64808 .71231 L
s
.354 0 1 r
.31584 .72673 m
.30563 .72063 L
s
0 .416 1 r
.48236 .71498 m
.48232 .72516 L
s
.47323 .72214 m
.48236 .71498 L
s
.46603 .76189 m
.48236 .71498 L
s
0 .875 1 r
.43512 .62322 m
.44342 .62581 L
s
.43431 .6207 m
.43512 .62322 L
s
.43512 .62322 m
.44176 .61528 L
s
0 .308 1 r
.81895 .71596 m
.82356 .71407 L
s
.81001 .71786 m
.81895 .71596 L
s
.81895 .71596 m
.81416 .70609 L
s
0 .875 1 r
.44342 .62581 m
.44264 .62329 L
s
.44176 .61528 m
.44342 .62581 L
s
.44176 .61528 m
.44264 .62329 L
s
.43431 .6207 m
.44176 .61528 L
s
.42725 .65535 m
.44176 .61528 L
s
0 .04 1 r
.27601 .62503 m
.26677 .61901 L
s
0 .416 1 r
.48232 .72516 m
.47323 .72214 L
s
0 .667 1 r
.64808 .71231 m
.6486 .7212 L
s
.64808 .71231 m
.6543 .72191 L
s
.64114 .72125 m
.64808 .71231 L
s
.64629 .75876 m
.64808 .71231 L
s
0 1 .788 r
.40086 .52571 m
.40408 .52296 L
s
.39407 .52182 m
.40086 .52571 L
s
.40178 .51606 m
.40086 .52571 L
s
0 1 .855 r
.60761 .62231 m
.61352 .62072 L
s
.60198 .62078 m
.60761 .62231 L
s
.60761 .62231 m
.60764 .61298 L
s
0 .667 1 r
.6543 .72191 m
.6486 .7212 L
s
0 1 .788 r
.40178 .51606 m
.40408 .52296 L
s
.39407 .52182 m
.40178 .51606 L
s
.39727 .51906 m
.40178 .51606 L
s
.38815 .54791 m
.40178 .51606 L
s
0 .308 1 r
.8146 .71598 m
.81001 .71786 L
s
.81001 .71786 m
.81416 .70609 L
s
0 .667 1 r
.6486 .7212 m
.64114 .72125 L
s
0 .308 1 r
.81416 .70609 m
.8146 .71598 L
s
.81416 .70609 m
.82356 .71407 L
s
.8273 .75562 m
.81416 .70609 L
s
0 1 .788 r
.39727 .51906 m
.39407 .52182 L
s
0 1 .855 r
.60764 .61298 m
.6079 .61918 L
s
.60764 .61298 m
.61352 .62072 L
s
.60198 .62078 m
.60764 .61298 L
s
.60819 .65199 m
.60764 .61298 L
s
0 .743 1 r
.78096 .61552 m
.78198 .61267 L
s
.77233 .61825 m
.78096 .61552 L
s
.78096 .61552 m
.77399 .60723 L
s
1 0 .954 r
.21216 .7079 m
.21219 .70655 L
s
.20091 .69982 m
.21216 .7079 L
s
.21473 .69211 m
.21216 .7079 L
s
0 .875 1 r
.44264 .62329 m
.43431 .6207 L
s
1 0 .954 r
.20087 .69842 m
.20091 .69982 L
s
.20091 .69982 m
.21473 .69211 L
s
0 .743 1 r
.77332 .61541 m
.77233 .61825 L
s
.77233 .61825 m
.77399 .60723 L
s
0 1 .855 r
.6079 .61918 m
.60198 .62078 L
s
.61352 .62072 m
.6079 .61918 L
s
0 1 .493 r
.57049 .52245 m
.57268 .5186 L
s
.56361 .5216 m
.57049 .52245 L
s
.57049 .52245 m
.56773 .5141 L
s
0 .743 1 r
.77399 .60723 m
.77332 .61541 L
s
.77399 .60723 m
.78198 .61267 L
s
.78988 .64861 m
.77399 .60723 L
s
0 1 .493 r
.56773 .5141 m
.56578 .51775 L
s
.56773 .5141 m
.57268 .5186 L
s
.56361 .5216 m
.56773 .5141 L
s
.56976 .54431 m
.56773 .5141 L
s
0 .308 1 r
.82356 .71407 m
.8146 .71598 L
s
0 1 .788 r
.40408 .52296 m
.39727 .51906 L
s
0 1 .38 r
.52841 .41581 m
.52757 .42368 L
s
.53028 .41581 m
.52841 .41581 L
s
.52841 .41581 m
.52421 .41884 L
s
.53363 .42066 m
.52841 .41581 L
s
.53102 .43573 m
.52841 .41581 L
s
0 1 .493 r
.56578 .51775 m
.56361 .5216 L
s
0 1 .926 r
.73262 .51639 m
.7364 .51871 L
s
.7364 .51871 m
.74299 .51386 L
s
.7364 .51871 m
.73426 .50879 L
s
1 0 .954 r
.21473 .69211 m
.21219 .70655 L
s
.20087 .69842 m
.21473 .69211 L
s
.17352 .74772 m
.21473 .69211 L
s
0 1 .926 r
.73426 .50879 m
.73262 .51639 L
s
.74299 .51386 m
.73426 .50879 L
s
.73426 .50879 m
.73922 .51152 L
s
.75214 .54069 m
.73426 .50879 L
s
0 1 .38 r
.52757 .42368 m
.53363 .42066 L
s
.52421 .41884 m
.52757 .42368 L
s
0 1 .803 r
.69502 .4109 m
.69437 .41869 L
s
.70322 .41142 m
.69502 .4109 L
s
.69502 .4109 m
.69638 .41178 L
s
.7012 .41831 m
.69502 .4109 L
s
.71409 .43186 m
.69502 .4109 L
s
0 1 .926 r
.74299 .51386 m
.73922 .51152 L
s
0 1 .493 r
.57268 .5186 m
.56578 .51775 L
s
0 1 .38 r
.53363 .42066 m
.53028 .41581 L
s
0 1 .991 r
.65633 .3137 m
.65735 .32078 L
s
.66297 .30994 m
.65633 .3137 L
s
.65633 .3137 m
.65553 .31282 L
s
.66478 .31789 m
.65633 .3137 L
s
.67571 .32211 m
.65633 .3137 L
s
0 1 .803 r
.69437 .41869 m
.7012 .41831 L
s
.7012 .41831 m
.70322 .41142 L
s
0 .743 1 r
.78198 .61267 m
.77332 .61541 L
s
.032 0 1 r
.37092 .70325 m
.3809 .70822 L
s
.37005 .70149 m
.37092 .70325 L
s
.37092 .70325 m
.38061 .69499 L
s
0 1 .38 r
.53028 .41581 m
.52421 .41884 L
s
.032 0 1 r
.3809 .70822 m
.38008 .70648 L
s
.38061 .69499 m
.3809 .70822 L
s
0 1 .926 r
.73922 .51152 m
.73262 .51639 L
s
0 1 .803 r
.69638 .41178 m
.69437 .41869 L
s
0 1 .991 r
.65735 .32078 m
.66478 .31789 L
s
.66478 .31789 m
.66297 .30994 L
s
0 1 .803 r
.70322 .41142 m
.69638 .41178 L
s
.032 0 1 r
.38061 .69499 m
.38008 .70648 L
s
.37005 .70149 m
.38061 .69499 L
s
.35488 .74453 m
.38061 .69499 L
s
1 0 .954 r
.21219 .70655 m
.20087 .69842 L
s
0 .355 1 r
.33838 .60629 m
.33992 .60381 L
s
.32944 .6012 m
.33838 .60629 L
s
.3395 .59402 m
.33838 .60629 L
s
0 .547 1 r
.54269 .7039 m
.55168 .70547 L
s
.53948 .70192 m
.54269 .7039 L
s
.54269 .7039 m
.54772 .69433 L
s
0 1 .991 r
.65553 .31282 m
.65735 .32078 L
s
0 .355 1 r
.33093 .5987 m
.32944 .6012 L
s
.32944 .6012 m
.3395 .59402 L
s
0 1 .991 r
.66297 .30994 m
.65553 .31282 L
s
0 .355 1 r
.3395 .59402 m
.33992 .60381 L
s
.33093 .5987 m
.3395 .59402 L
s
.31518 .63668 m
.3395 .59402 L
s
0 .546 1 r
.71693 .70066 m
.72331 .69901 L
s
.70948 .70033 m
.71693 .70066 L
s
.71693 .70066 m
.71552 .6901 L
s
0 .547 1 r
.55168 .70547 m
.54849 .7035 L
s
.54772 .69433 m
.55168 .70547 L
s
.54772 .69433 m
.54849 .7035 L
s
.53948 .70192 m
.54772 .69433 L
s
.537 .74133 m
.54772 .69433 L
s
.032 0 1 r
.38008 .70648 m
.37005 .70149 L
s
0 .981 1 r
.5015 .6026 m
.50986 .60372 L
s
.50008 .59934 m
.5015 .6026 L
s
.5015 .6026 m
.50672 .59366 L
s
.50986 .60372 m
.50848 .60047 L
s
.50672 .59366 m
.50986 .60372 L
s
.50672 .59366 m
.50848 .60047 L
s
.50008 .59934 m
.50672 .59366 L
s
.49799 .63324 m
.50672 .59366 L
s
0 .546 1 r
.71552 .6901 m
.71585 .69867 L
s
.71552 .6901 m
.72331 .69901 L
s
.70948 .70033 m
.71552 .6901 L
s
.71989 .73812 m
.71552 .6901 L
s
0 .547 1 r
.54849 .7035 m
.53948 .70192 L
s
0 .546 1 r
.71585 .69867 m
.70948 .70033 L
s
0 .355 1 r
.33992 .60381 m
.33093 .5987 L
s
0 .974 1 r
.67856 .59943 m
.68166 .59607 L
s
.67052 .59951 m
.67856 .59943 L
s
.67856 .59943 m
.67473 .58985 L
s
0 1 .721 r
.46533 .50304 m
.47024 .5001 L
s
.45932 .49906 m
.46533 .50304 L
s
.46629 .49348 m
.46533 .50304 L
s
.46629 .49348 m
.47024 .5001 L
s
.45932 .49906 m
.46629 .49348 L
s
.46422 .49611 m
.46629 .49348 L
s
.45864 .52422 m
.46629 .49348 L
s
0 .546 1 r
.72331 .69901 m
.71585 .69867 L
s
0 .974 1 r
.67473 .58985 m
.67361 .59614 L
s
.67473 .58985 m
.68166 .59607 L
s
.67052 .59951 m
.67473 .58985 L
s
.68157 .62978 m
.67473 .58985 L
s
.67361 .59614 m
.67052 .59951 L
s
0 1 .721 r
.46422 .49611 m
.45932 .49906 L
s
0 .981 1 r
.50848 .60047 m
.50008 .59934 L
s
0 1 .725 r
.63443 .49004 m
.63063 .49688 L
s
.64159 .4953 m
.63443 .49004 L
s
.63443 .49004 m
.63639 .49259 L
s
.63584 .49958 m
.63443 .49004 L
s
.64293 .52052 m
.63443 .49004 L
s
.63063 .49688 m
.63584 .49958 L
s
.63584 .49958 m
.64159 .4953 L
s
0 1 .721 r
.47024 .5001 m
.46422 .49611 L
s
.651 0 1 r
.27496 .68852 m
.27567 .68669 L
s
.26409 .6814 m
.27496 .68852 L
s
.277 .67342 m
.27496 .68852 L
s
.26473 .67952 m
.26409 .6814 L
s
.26409 .6814 m
.277 .67342 L
s
0 1 .666 r
.59468 .39082 m
.59352 .39899 L
s
.59951 .39036 m
.59468 .39082 L
s
.59468 .39082 m
.59207 .3926 L
s
.60095 .39676 m
.59468 .39082 L
s
.60395 .41032 m
.59468 .39082 L
s
0 .974 1 r
.68166 .59607 m
.67361 .59614 L
s
0 1 .725 r
.64159 .4953 m
.63639 .49259 L
s
.651 0 1 r
.277 .67342 m
.27567 .68669 L
s
.26473 .67952 m
.277 .67342 L
s
.24112 .72677 m
.277 .67342 L
s
0 1 .725 r
.63639 .49259 m
.63063 .49688 L
s
0 1 .666 r
.59352 .39899 m
.60095 .39676 L
s
.60095 .39676 m
.59951 .39036 L
s
.59207 .3926 m
.59352 .39899 L
s
0 .206 1 r
.43666 .6838 m
.44662 .6876 L
s
.43597 .68134 m
.43666 .6838 L
s
.43666 .6838 m
.44533 .67478 L
s
0 1 .666 r
.59951 .39036 m
.59207 .3926 L
s
0 .206 1 r
.44662 .6876 m
.44598 .68517 L
s
.44533 .67478 m
.44662 .6876 L
s
.44533 .67478 m
.44598 .68517 L
s
.43597 .68134 m
.44533 .67478 L
s
.42513 .72349 m
.44533 .67478 L
s
0 .561 1 r
.61165 .68333 m
.62037 .68316 L
s
.60711 .68094 m
.61165 .68333 L
s
.61165 .68333 m
.61469 .67257 L
s
.651 0 1 r
.27567 .68669 m
.26473 .67952 L
s
0 .579 1 r
.40343 .58467 m
.40558 .58156 L
s
.3946 .58043 m
.40343 .58467 L
s
.40377 .5728 m
.40343 .58467 L
s
.39671 .57729 m
.3946 .58043 L
s
.3946 .58043 m
.40377 .5728 L
s
.40377 .5728 m
.40558 .58156 L
s
.39671 .57729 m
.40377 .5728 L
s
.38518 .61405 m
.40377 .5728 L
s
0 .3 1 r
.78927 .67784 m
.79363 .67475 L
s
.77982 .67873 m
.78927 .67784 L
s
.78927 .67784 m
.78452 .66676 L
s
0 .561 1 r
.61469 .67257 m
.61585 .68077 L
s
.61469 .67257 m
.62037 .68316 L
s
.60711 .68094 m
.61469 .67257 L
s
.60994 .7202 m
.61469 .67257 L
s
.62037 .68316 m
.61585 .68077 L
s
0 .206 1 r
.44598 .68517 m
.43597 .68134 L
s
0 .959 1 r
.57058 .58121 m
.57861 .58006 L
s
.56692 .57753 m
.57058 .58121 L
s
.57058 .58121 m
.57329 .57093 L
s
0 .3 1 r
.78452 .66676 m
.78415 .67563 L
s
.78452 .66676 m
.79363 .67475 L
s
.77982 .67873 m
.78452 .66676 L
s
.79553 .7169 m
.78452 .66676 L
s
.78415 .67563 m
.77982 .67873 L
s
0 .959 1 r
.57329 .57093 m
.57498 .57637 L
s
.57329 .57093 m
.57861 .58006 L
s
.56692 .57753 m
.57329 .57093 L
s
.5707 .61051 m
.57329 .57093 L
s
0 .561 1 r
.61585 .68077 m
.60711 .68094 L
s
0 .959 1 r
.57861 .58006 m
.57498 .57637 L
s
0 .579 1 r
.40558 .58156 m
.39671 .57729 L
s
0 .676 1 r
.74106 .57325 m
.74189 .57716 L
s
.74189 .57716 m
.7511 .57434 L
s
.74189 .57716 m
.74339 .56558 L
s
0 1 .79 r
.53244 .46977 m
.53491 .47925 L
s
.52943 .47221 m
.53244 .46977 L
s
.53244 .46977 m
.52708 .47747 L
s
.53728 .474 m
.53244 .46977 L
s
.53112 .49987 m
.53244 .46977 L
s
0 .676 1 r
.74339 .56558 m
.74106 .57325 L
s
.7511 .57434 m
.74339 .56558 L
s
.74339 .56558 m
.7503 .57043 L
s
.75701 .60696 m
.74339 .56558 L
s
.7511 .57434 m
.7503 .57043 L
s
0 1 .79 r
.53491 .47925 m
.53728 .474 L
s
.52708 .47747 m
.53491 .47925 L
s
0 .3 1 r
.79363 .67475 m
.78415 .67563 L
s
0 .959 1 r
.57498 .57637 m
.56692 .57753 L
s
0 1 .79 r
.52943 .47221 m
.52708 .47747 L
s
0 .921 1 r
.70271 .46484 m
.69988 .47338 L
s
.71166 .46867 m
.70271 .46484 L
s
.70271 .46484 m
.70474 .46711 L
s
.70679 .47492 m
.70271 .46484 L
s
.71815 .49606 m
.70271 .46484 L
s
.69988 .47338 m
.70679 .47492 L
s
.70679 .47492 m
.71166 .46867 L
s
0 .941 1 r
.66255 .36469 m
.66188 .37347 L
s
.66971 .3636 m
.66255 .36469 L
s
.66255 .36469 m
.66138 .36565 L
s
.67018 .37142 m
.66255 .36469 L
s
.67895 .3842 m
.66255 .36469 L
s
0 1 .79 r
.53728 .474 m
.52943 .47221 L
s
.324 0 1 r
.33957 .6682 m
.34093 .66579 L
s
.32893 .66202 m
.33957 .6682 L
s
.34095 .65365 m
.33957 .6682 L
s
.33024 .65958 m
.32893 .66202 L
s
.32893 .66202 m
.34095 .65365 L
s
0 .676 1 r
.7503 .57043 m
.74106 .57325 L
s
0 .921 1 r
.71166 .46867 m
.70474 .46711 L
s
.70474 .46711 m
.69988 .47338 L
s
0 .941 1 r
.66188 .37347 m
.67018 .37142 L
s
.67018 .37142 m
.66971 .3636 L
s
.324 0 1 r
.34095 .65365 m
.34093 .66579 L
s
.33024 .65958 m
.34095 .65365 L
s
.31061 .70523 m
.34095 .65365 L
s
0 .941 1 r
.66138 .36565 m
.66188 .37347 L
s
.66971 .3636 m
.66138 .36565 L
s
0 .346 1 r
.50422 .66346 m
.51432 .66596 L
s
.50336 .66021 m
.50422 .66346 L
s
.50422 .66346 m
.5117 .65346 L
s
.51432 .66596 m
.51351 .66271 L
s
.5117 .65346 m
.51432 .66596 L
s
.5117 .65346 m
.51351 .66271 L
s
.50336 .66021 m
.5117 .65346 L
s
.49737 .70186 m
.5117 .65346 L
s
0 .451 1 r
.68337 .66157 m
.6909 .65924 L
s
.67632 .65951 m
.68337 .66157 L
s
.68337 .66157 m
.68328 .64967 L
s
.324 0 1 r
.34093 .66579 m
.33024 .65958 L
s
0 .694 1 r
.47026 .56215 m
.47308 .55827 L
s
.46139 .55863 m
.47026 .56215 L
s
.46971 .55045 m
.47026 .56215 L
s
.46971 .55045 m
.47308 .55827 L
s
.46139 .55863 m
.46971 .55045 L
s
.46418 .55474 m
.46971 .55045 L
s
.45717 .59078 m
.46971 .55045 L
s
0 .451 1 r
.68328 .64967 m
.68385 .65716 L
s
.68328 .64967 m
.6909 .65924 L
s
.67632 .65951 m
.68328 .64967 L
s
.68494 .69848 m
.68328 .64967 L
s
0 .694 1 r
.46418 .55474 m
.46139 .55863 L
s
0 .451 1 r
.68385 .65716 m
.67632 .65951 L
s
0 .346 1 r
.51351 .66271 m
.50336 .66021 L
s
0 .806 1 r
.64515 .55781 m
.64824 .5531 L
s
.63634 .5569 m
.64515 .55781 L
s
.64515 .55781 m
.64149 .54705 L
s
0 .451 1 r
.6909 .65924 m
.68385 .65716 L
s
0 .806 1 r
.64149 .54705 m
.63941 .55219 L
s
.64149 .54705 m
.64824 .5531 L
s
.63634 .5569 m
.64149 .54705 L
s
.64547 .58714 m
.64149 .54705 L
s
.63941 .55219 m
.63634 .5569 L
s
0 1 .992 r
.60023 .4449 m
.59744 .45473 L
s
.60518 .4469 m
.60023 .4449 L
s
.60023 .4449 m
.59644 .44839 L
s
.60615 .45325 m
.60023 .4449 L
s
.60565 .47482 m
.60023 .4449 L
s
0 .694 1 r
.47308 .55827 m
.46418 .55474 L
s
0 1 .992 r
.59744 .45473 m
.60615 .45325 L
s
.59644 .44839 m
.59744 .45473 L
s
.60615 .45325 m
.60518 .4469 L
s
0 .806 1 r
.64824 .5531 m
.63941 .55219 L
s
0 1 .992 r
.60518 .4469 m
.59644 .44839 L
s
.079 0 1 r
.40603 .64693 m
.40803 .64383 L
s
.39548 .64167 m
.40603 .64693 L
s
.40661 .63275 m
.40603 .64693 L
s
.39743 .63854 m
.39548 .64167 L
s
.39548 .64167 m
.40661 .63275 L
s
.40661 .63275 m
.40803 .64383 L
s
.39743 .63854 m
.40661 .63275 L
s
.38209 .68308 m
.40661 .63275 L
s
0 .372 1 r
.5739 .64228 m
.58422 .64311 L
s
.57207 .63818 m
.5739 .64228 L
s
.5739 .64228 m
.57976 .63099 L
s
.57976 .63099 m
.58243 .63901 L
s
.57976 .63099 m
.58422 .64311 L
s
.57207 .63818 m
.57976 .63099 L
s
.57167 .67962 m
.57976 .63099 L
s
.58422 .64311 m
.58243 .63901 L
s
0 .217 1 r
.75817 .6379 m
.7624 .6335 L
s
.74805 .63777 m
.75817 .6379 L
s
.75817 .6379 m
.75351 .62561 L
s
.75351 .62561 m
.75224 .63336 L
s
.75351 .62561 m
.7624 .6335 L
s
.74805 .63777 m
.75351 .62561 L
s
.76209 .67614 m
.75351 .62561 L
s
.079 0 1 r
.40803 .64383 m
.39743 .63854 L
s
0 .689 1 r
.53735 .52694 m
.5425 .53404 L
s
.52978 .53566 m
.53735 .52694 L
s
.53735 .52694 m
.53871 .53874 L
s
.53354 .53094 m
.53735 .52694 L
s
.53122 .56684 m
.53735 .52694 L
s
.53871 .53874 m
.5425 .53404 L
s
.52978 .53566 m
.53871 .53874 L
s
0 .217 1 r
.75224 .63336 m
.74805 .63777 L
s
0 .689 1 r
.53354 .53094 m
.52978 .53566 L
s
0 .527 1 r
.70677 .53015 m
.71143 .53443 L
s
.71143 .53443 m
.72031 .53012 L
s
.71143 .53443 m
.71136 .522 L
s
.71136 .522 m
.70677 .53015 L
s
.72031 .53012 m
.71136 .522 L
s
.71136 .522 m
.71567 .52582 L
s
.72239 .56309 m
.71136 .522 L
s
0 .372 1 r
.58243 .63901 m
.57207 .63818 L
s
0 .688 1 r
.66969 .41885 m
.66701 .42913 L
s
.67738 .42048 m
.66969 .41885 L
s
.66969 .41885 m
.6679 .42141 L
s
.67647 .4282 m
.66969 .41885 L
s
.68234 .44904 m
.66969 .41885 L
s
0 .217 1 r
.7624 .6335 m
.75224 .63336 L
s
0 .527 1 r
.72031 .53012 m
.71567 .52582 L
s
0 .689 1 r
.5425 .53404 m
.53354 .53094 L
s
0 .688 1 r
.66701 .42913 m
.67647 .4282 L
s
.67647 .4282 m
.67738 .42048 L
s
0 .527 1 r
.71567 .52582 m
.70677 .53015 L
s
0 .688 1 r
.6679 .42141 m
.66701 .42913 L
s
.67738 .42048 m
.6679 .42141 L
s
0 .07 1 r
.47439 .62468 m
.477 .62077 L
s
.46376 .6203 m
.47439 .62468 L
s
.47401 .6107 m
.47439 .62468 L
s
.47401 .6107 m
.477 .62077 L
s
.46376 .6203 m
.47401 .6107 L
s
.46632 .61636 m
.47401 .6107 L
s
.45563 .66029 m
.47401 .6107 L
s
.46632 .61636 m
.46376 .6203 L
s
0 .277 1 r
.64671 .62029 m
.65662 .61843 L
s
.64187 .61585 m
.64671 .62029 L
s
.64671 .62029 m
.64953 .60735 L
s
.64953 .60735 m
.65181 .61397 L
s
.64953 .60735 m
.65662 .61843 L
s
.64187 .61585 m
.64953 .60735 L
s
.64812 .65672 m
.64953 .60735 L
s
.65662 .61843 m
.65181 .61397 L
s
0 .558 1 r
.6067 .50225 m
.61012 .51417 L
s
.60356 .50612 m
.6067 .50225 L
s
.6067 .50225 m
.60037 .51229 L
s
.61334 .50801 m
.6067 .50225 L
s
.60743 .5422 m
.6067 .50225 L
s
0 .07 1 r
.477 .62077 m
.46632 .61636 L
s
0 .558 1 r
.61012 .51417 m
.61334 .50801 L
s
.60037 .51229 m
.61012 .51417 L
s
0 .277 1 r
.65181 .61397 m
.64187 .61585 L
s
0 .558 1 r
.60356 .50612 m
.60037 .51229 L
s
.61334 .50801 m
.60356 .50612 L
s
0 .11 1 r
.5447 .60146 m
.54789 .59658 L
s
.53381 .59789 m
.5447 .60146 L
s
.54318 .58746 m
.5447 .60146 L
s
.54318 .58746 m
.54789 .59658 L
s
.53381 .59789 m
.54318 .58746 L
s
.53695 .59299 m
.54318 .58746 L
s
.53133 .63683 m
.54318 .58746 L
s
.53695 .59299 m
.53381 .59789 L
s
0 .062 1 r
.72555 .596 m
.72977 .59019 L
s
.7146 .59485 m
.72555 .596 L
s
.72555 .596 m
.72103 .5825 L
s
.72103 .5825 m
.71878 .58903 L
s
.72103 .5825 m
.72977 .59019 L
s
.7146 .59485 m
.72103 .5825 L
s
.72682 .63316 m
.72103 .5825 L
s
.71878 .58903 m
.7146 .59485 L
s
0 .308 1 r
.67781 .47633 m
.67281 .48788 L
s
.68601 .48078 m
.67781 .47633 L
s
.67781 .47633 m
.67526 .48028 L
s
.68353 .48836 m
.67781 .47633 L
s
.68589 .51684 m
.67781 .47633 L
s
.67281 .48788 m
.68353 .48836 L
s
.68353 .48836 m
.68601 .48078 L
s
0 .11 1 r
.54789 .59658 m
.53695 .59299 L
s
0 .308 1 r
.67526 .48028 m
.67281 .48788 L
s
0 .062 1 r
.72977 .59019 m
.71878 .58903 L
s
0 .308 1 r
.68601 .48078 m
.67526 .48028 L
s
0 .035 1 r
.61416 .563 m
.62074 .57122 L
s
.60567 .57441 m
.61416 .563 L
s
.61416 .563 m
.61699 .57724 L
s
.60938 .56838 m
.61416 .563 L
s
.60928 .61267 m
.61416 .563 L
s
.61699 .57724 m
.62074 .57122 L
s
.60567 .57441 m
.61699 .57724 L
s
.60938 .56838 m
.60567 .57441 L
s
.62074 .57122 m
.60938 .56838 L
s
.156 0 1 r
.68695 .53728 m
.69129 .552 L
s
.68364 .54247 m
.68695 .53728 L
s
.68695 .53728 m
.67936 .54983 L
s
.69561 .54467 m
.68695 .53728 L
s
.68959 .58778 m
.68695 .53728 L
s
.69129 .552 m
.69561 .54467 L
s
.67936 .54983 m
.69129 .552 L
s
.68364 .54247 m
.67936 .54983 L
s
.69561 .54467 m
.68364 .54247 L
s
0 g
.25 Mabswid
.67137 0 m
.92714 .4158 L
s
.92714 .4158 m
1 .95223 L
s
1 .95223 m
.70506 .5889 L
s
.70506 .5889 m
.67137 0 L
s
.08847 .24498 m
0 .80663 L
s
0 .80663 m
.70506 .5889 L
s
.70506 .5889 m
.67137 0 L
s
.67137 0 m
.08847 .24498 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{259.875, 283.875},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004300016b000`400?l00000o`00003o[03oool2
000005D0oooo002Z0?ooo`80000000<0oooo000000000000E03oool00:P0oooo0P0000030?ooo`80
0000E03oool00:D0oooo0`0000050?ooo`030000003oool0000005<0oooo002S0?ooo`800000203o
ool00`000000oooo0000001C0?ooo`00X03oool3000000X0oooo00@000000?ooo`3oool00000DP3o
ool009h0oooo0P00000=0?ooo`050000003oool0oooo0?ooo`000000D@3oool009`0oooo0P00000?
0?ooo`050000003oool0oooo0?ooo`000000D@3oool009T0oooo0`00000A0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0CP3oool009L0oooo0P00000E0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0C@3oool009@0oooo0`00000G0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0C@3oool00980oooo0P00000J0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0C03oool00900oooo0P00000I0?ooo`040?l0003oool0oooo000000D0oooo
00<000000?ooo`3oool0C03oool008d0oooo0`00000K0?ooo`040?l0003oool0oooo000000H0oooo
00<000000?ooo`3oool0B`3oool008/0oooo0P00000M0?ooo`050?l0003oool0oooo0?ooo`000000
1`3oool00`000000oooo0?ooo`1:0?ooo`00R03oool3000001l0oooo00D0o`000?ooo`3oool0oooo
000000070?ooo`030000003oool0oooo04X0oooo00260?ooo`8000008@3oool00`3o0000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B@3oool008@0oooo0P00000S
0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`18
0?ooo`00P@3oool3000002@0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo04P0oooo001o0?ooo`8000006@3oool00`3o05D0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`170?ooo`00
O03oool3000001/0oooo00<0o`1E0?ooo`3oool02`3oool00`3o0000oooo0?ooo`030?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0A`3oool007X0oooo0P00000M0?ooo`030?l0E@3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo04H0oooo001h0?ooo`8000007`3oool00`3o05D0oooo0?ooo`090?ooo`<0o`001P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04D0oooo001e0?ooo`<000008@3oool00`3o
05D0oooo0?ooo`070?ooo`80o`0000<0oooo0?l0003o00001P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo04D0oooo001c0?ooo`8000008`3oool00`3o05D0oooo0?ooo`090?ooo`<0
o`0000<0oooo0?l0003oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04@0
oooo001`0?ooo`<000009@3oool00`3o05D0oooo0?ooo`090?ooo`@0o`000`3oool0103o0?X0oooo
0?ooo`0000040?ooo`030?l0E@3oool0oooo00L0oooo00<000000?ooo`3oool0@`3oool006h0oooo
0P00000I0?ooo`030?l0Y03oool0oooo00/0oooo00<0o`1E0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`020?ooo`030?l0nP3oool0oooo0080oooo00@000000?ooo`3oool0o`1E2P3oool00`000000
oooo0?ooo`130?ooo`00K03oool2000001/0oooo00<0o`2T0?ooo`3oool02`3oool00`3o05D0oooo
0?ooo`0@0?ooo`030?l0nP3oool0oooo0080oooo00@000000?ooo`3oool0o`1E2`3oool00`000000
oooo0?ooo`120?ooo`00J@3oool3000001d0oooo00<0o`2T0?ooo`3oool02`3oool00`3o05D0oooo
0?ooo`0?0?ooo`030?l0nP3oool0oooo00<0oooo00<000000?ooo`3o05D0303oool00`000000oooo
0?ooo`120?ooo`00I`3oool2000001l0oooo00<0o`2T0?ooo`3oool02`3oool00`3o05D0oooo0?oo
o`0@0?ooo`030?l0nP3oool0oooo00<0oooo00<000000?ooo`3o05D03@3oool00`000000oooo0?oo
o`110?ooo`00I03oool300000240oooo00<0o`2T0?ooo`3oool02@3oool40?l0EA00oooo00<0o`3j
0?ooo`3oool0103oool00`000000o`1E0?ooo`0>0?ooo`030000003oool0oooo0400oooo001R0?oo
o`800000903oool00`3o0:@0oooo0?ooo`090?ooo`<0o`1E00<0oooo0?l0E@3oool03P3oool00`3o
0?X0oooo0?ooo`040?ooo`030000003o05D0oooo00h0oooo00<000000?ooo`3oool0@03oool00600
oooo0P00000V0?ooo`030?l0Y03oool0oooo00X0oooo0`3o05D20?ooo`030:D0o`3oool0oooo00D0
oooo00@0o`2]0?ooo`3oool0oooo0P3o0?X70?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0?`3oool005d0oooo0`00000I0?ooo`030?l0k03oool0oooo00/0oooo00<0o`2T0?ooo`3o
ool02`3oool00`3o05D0oooo0?ooo`020?ooo`030:D0o`3oool0oooo00D0oooo00<0o`2]0?ooo`3o
0?X00`3o0?X70?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0?`3oool005/0oooo
0P00000L0?ooo`030?l0k03oool0oooo00/0oooo00<0o`2T0?ooo`3oool03`3oool00`2U0?l0oooo
0?ooo`050?ooo`030?l0[@3oool0oooo00@0o`3j1@3oool20?l0E@030000003oool0oooo0100oooo
00<000000?ooo`3oool0?P3oool005P0oooo0`00000N0?ooo`030?l0k03oool0oooo00/0oooo00<0
o`2T0?ooo`3oool03`3oool00`2U0?l0oooo0?ooo`050?ooo`040?l0[@3oool0oooo0?ooo`@0o`3j
0P3oool40?l0E@030000003oool0oooo0140oooo00<000000?ooo`3oool0?@3oool005H0oooo0P00
000Q0?ooo`030?l0k03oool0oooo00T0oooo103o0:@?0?ooo`030:D0o`3oool0oooo00D0oooo00<0
o`2]0?ooo`3oool00P3oool30?l0nP<0oooo0`3o05D00`3oool000000?l0E@0B0?ooo`030000003o
ool0oooo03d0oooo001D0?ooo`8000008P3oool00`3o0>`0oooo0?ooo`090?ooo`<0o`2T0P3oool0
0`3o0:@0oooo0?ooo`0<0?ooo`030:D0o`3oool0oooo00D0oooo00<0o`2]0?ooo`3oool02@3oool3
0?l0E@030000003oool0oooo0180oooo00<000000?ooo`3oool0?03oool00540oooo0`00000T0?oo
o`030?l0k03oool0oooo00X0oooo103o0:@>0?ooo`030:D0o`3oool0oooo00H0oooo00<0o`2]0?oo
o`3oool02@3oool20?l0E@030?ooo`000000oooo00<0oooo00<0/03o0?ooo`3oool0103oool00`3o
0:80oooo0?ooo`070?ooo`030000003oool0oooo03/0oooo001?0?ooo`8000009`3oool00`3o0>`0
oooo0?ooo`0;0?ooo`040?l0Y03oool0oooo04h0o`P0oooo00@0o`3n0?ooo`3oool0oooo0P2U0?l7
0?ooo`030?l0[@3oool0oooo00X0oooo00@0<`3o0?ooo`3oool000000`3oool00`2`0?l0oooo0?oo
o`040?ooo`030?l0XP3oool0oooo00P0oooo00<000000?ooo`3oool0>`3oool004`0oooo0`00000J
0?ooo`030=<0o`3oool0oooo00`0oooo00<0o`3/0?ooo`3oool03P3oool00`1>0?l0oooo0?ooo`06
0?ooo`030?l0oP3oool0Y@3o00<0Y@3o1`3oool00`3o0:d0oooo0?ooo`090?ooo`0503<0o`3oool0
oooo0?ooo`0000000`3oool00`2`0?l0oooo0?ooo`040?ooo`030?l0XP3oool0oooo00T0oooo00<0
00000?ooo`3oool0>P3oool004X0oooo0P00000M0?ooo`030=<0o`3oool0oooo00`0oooo00<0o`3/
0?ooo`3oool03@3oool00`1>0?l0oooo0?ooo`060?ooo`030?l0oP3oool0oooo00<0Y@3o00<0oooo
0:D0o`3oool0103oool20?l0[@X0oooo00<0<`3o0?ooo`3oool00P3oool010000000oooo0?ooo`2`
0?l60?ooo`030?l0XP3oool0oooo00X0oooo00<000000?ooo`3oool0>P3oool004P0oooo0P00000O
0?ooo`030=<0o`3oool0oooo00/0oooo0P3o0>`?0?ooo`0304h0o`3oool0oooo00H0oooo00@0o`3n
0?ooo`3oool0oooo0`2U0?l40?ooo`@0o`2]2@3oool00`0c0?l0oooo0?ooo`030?ooo`030000003o
ool0/03o00H0oooo00<0o`2R0?ooo`3oool0303oool00`000000oooo0?ooo`0i0?ooo`00A@3oool3
00000240oooo00<0d`3o0?ooo`3oool02@3oool60?l0k0d0oooo00<0CP3o0?ooo`3oool01P3oool0
1@3o0?h0oooo0?ooo`3oool0Y@3o00H0oooo0`3o0:d00`3oool0o`2]0?ooo`050?ooo`0303<0o`3o
ool0<`3o00H0oooo00<000000?ooo`3oool01@3oool00`3o0:80oooo0?ooo`0=0?ooo`030000003o
ool0oooo03P0oooo00130?ooo`800000903oool00`3C0?l0oooo0?ooo`0:0?ooo`80o`3/00<0oooo
0?l0k03oool0303oool00`1>0?l0oooo0?ooo`060?ooo`030?l0oP3oool0oooo00X0oooo0`3o0:d5
0?ooo`@0<`3o00<0oooo0?l0n`3oool00P3oool00`2`0?l0oooo000000060?ooo`030?l0XP3oool0
oooo00h0oooo00<000000?ooo`3oool0>03oool00400oooo0`00000V0?ooo`030=<0o`3oool0oooo
00X0oooo0`3o0>`80?ooo`030;P0o`3oool0oooo00<0oooo00<0CP3o0?ooo`3oool01P3oool00`3o
0?h0oooo0?ooo`0:0?ooo`030?l0[@3oool0oooo00<0oooo00<0C@3o0?ooo`0c0?l0100c0?l20?oo
o`@0/03o00<000000?ooo`3oool00`3oool00`3o0:80oooo0?ooo`0@0?ooo`030000003oool0oooo
03L0oooo000n0?ooo`8000006@3oool00`2K0?l0oooo0?ooo`0=0?ooo`030=<0o`3oool0oooo00/0
oooo00<0o`3/0040o`3oool01`3oool00`2h0?l0oooo0?ooo`030?ooo`0304h0o`3oool0oooo00H0
oooo00<0o`3n0?ooo`3oool01`3oool00`00=ol0oooo0?ooo`050?ooo`0404d0o`3oool0oooo0?oo
o`<0<`3o00<0o`3k0?ooo`3oool0102`0?l00`000000oooo0?ooo`020?ooo`80o`2R4`3oool00`00
0000oooo0?ooo`0f0?ooo`00?03oool2000001/0oooo00<0V`3o0?ooo`3oool03@3oool00`3C0?l0
oooo0?ooo`0<0?ooo`030040o`3oool0oooo00H0oooo00@0^03o0?ooo`3oool0oooo1@1>0?l50?oo
o`030?l0oP3oool0oooo00L0oooo00<003Oo0?ooo`3oool01P3oool00`1=0?l0oooo0?ooo`020?oo
o`0303<0o`3o0?/0oooo00<0oooo0`2`0?l00`000000oooo0?ooo`040?l0XQ<0oooo00<000000?oo
o`3oool0=P3oool003T0oooo0`00000M0?ooo`0309/0o`3oool0oooo00d0oooo00<0d`3o0?ooo`3o
ool0303oool00`010?l0oooo0?ooo`060?ooo`040;P0o`3oool0oooo0?ooo`@0CP3o103oool40?l0
oPP0oooo00<003Oo0?ooo`3oool01@3oool00`1=0?l0oooo0?ooo`040?ooo`030?l0n`3oool0oooo
0080oooo0`2`0?l00`000000oooo0?ooo`020?l0XP80oooo00<0o`2R0?ooo`3oool04@3oool00`00
0000oooo0?ooo`0e0?ooo`00=`3oool200000240oooo00<0V`3o0?ooo`3oool02P3oool50=<0o``0
oooo00<00@3o0?ooo`3oool01P3oool00`2h0?l0oooo0?ooo`020?ooo`80CP3o1@3oool30?l0oP03
0?ooo`3o0?h0oooo00D0oooo00<003Oo0?ooo`3oool01@3oool00`1=0?l0oooo0?ooo`040?ooo`03
0?l0n`3oool0oooo00H0oooo00<000000?ooo`3oool0103o0:8;0?ooo`030?l0i03oool0oooo00H0
oooo00<000000?ooo`3oool0=@3oool003@0oooo0`00000S0?ooo`0309/0o`3oool0oooo00/0oooo
0`3C0?l=0?ooo`030040o`3oool0oooo00H0oooo00<0^03o0?ooo`3oool02P3oool30?l0oPH0oooo
0P00=ol00`3oool0/`3o0?ooo`040?ooo`0304d0o`3oool0oooo00@0oooo00<0o`3k0?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?l0XP`0oooo00<0o`3T0?ooo`3oool0203oool00`000000oooo
0?ooo`0d0?ooo`00<P3oool2000002H0oooo00<0V`3o0?ooo`3oool02`3oool30=<0o`L0oooo00<0
M@3o0?ooo`3oool00P3oool00`010?l0oooo0?ooo`060?ooo`030;P0o`3oool0oooo00/0oooo00<0
o`3n0?ooo`3oool0103oool3000go`80oooo00@0/`3o0?ooo`3oool0oooo0P1=0?l60?ooo`030?l0
n`3oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`1V0?l0oooo0?ooo`020?ooo`030?l0
i03oool0oooo00T0oooo00<000000?ooo`3oool0<`3oool00300oooo0P00000H0?ooo`0306`0o`3o
ool0oooo00d0oooo00<0V`3o0?ooo`3oool0303oool00`3C0?l0oooo0?ooo`060?ooo`0307D0o`3o
ool0oooo0080oooo00<00@3o0?ooo`3oool01P3oool00`2h0?l0oooo0?ooo`0?0?ooo`03000>o`3o
ool0oooo00@003Oo00@0/`3o0?ooo`3oool0oooo0`1=0?l50?ooo`80o`3k2@3oool00`000000oooo
0?ooo`020?ooo`03000Po`3oool0oooo00<0oooo00<0IP3o0?ooo`3oool00P3oool00`3o0>@0oooo
0?ooo`0:0?ooo`030000003oool0oooo03<0oooo000]0?ooo`<000006P3oool00`1/0?l0oooo0?oo
o`0=0?ooo`0309/0o`3oool0oooo00/0oooo00<004;o0?ooo`3oool01`3oool00`1e0?l0oooo0?oo
o`040040o`L0oooo00<0^03o0?ooo`3oool01P3oool00`00Uol0oooo0?ooo`060?ooo`04000>o`3o
ool0oooo0?ooo`8003Oo00<0oooo0;<0o`3oool00P3oool404d0o`80oooo103o0?/60?ooo`04001^
o`3oool0oooo000000<0oooo00<0023o0?ooo`3oool00`3oool00`1V0?l0oooo0?ooo`020?ooo`03
0?l0i03oool0oooo00`0oooo00<000000?ooo`3oool0<P3oool002/0oooo0P00000N0?ooo`0306`0
o`3oool0oooo00`0oooo0P2K0?l<0?ooo`030012o`3oool0oooo00L0oooo00@0M@3o0?ooo`3oool0
oooo0P010?l00`3oool00@3o0?ooo`030?ooo`@0^03o1P3oool00`00Uol0oooo0?ooo`060?ooo`03
000>o`3oool0oooo00D0oooo00@0/`3o0?ooo`3oool0oooo0`1=0?l30?ooo`<0o`3k00<0oooo0?l0
n`3oool00P3oool2001^o`<0oooo00@000000?ooo`3oool0023o1@3oool00`1V0?l0oooo0?ooo`03
0?ooo`030?l0i03oool0oooo00`0oooo00<000000?ooo`3oool0<P3oool002P0oooo0`00000P0?oo
o`0306`0o`3oool0oooo00/0oooo102K0?l;0?ooo`030012o`3oool0oooo00L0oooo00<0M@3o0?oo
o`3oool00P3oool20040o`H0oooo0P2h0?l00`3oool0^03o0?ooo`040?ooo`03002Go`3oool0oooo
00H0oooo00<000ko0?ooo`3oool0103oool00`2c0?l0oooo0?ooo`090?ooo`<0o`3k00@0oooo001^
o`3oool006ko103oool010008?l00000000Po`008?l50?ooo`0306H0o`3oool0oooo00<0oooo00<0
o`3T0?ooo`3oool03P3oool00`000000oooo0?ooo`0a0?ooo`009P3oool2000002<0oooo00<0K03o
0?ooo`3oool0303oool209/0o``0oooo00<004;o0?ooo`3oool01`3oool00`1e0?l0oooo0?ooo`0:
0?ooo`<0^03o1@3oool00`00Uol0oooo0?ooo`060?ooo`03000>o`3oool0oooo00D0oooo00<0/`3o
0?ooo`3oool02@3oool20?l0n`040?ooo`00K_l006ko001^o`@0oooo0P008?l00`000000oooo0<80
o`030?ooo`80IP3o1@3oool00`3o0>@0oooo0?ooo`0@0?ooo`030000003oool0oooo0300oooo000T
0?ooo`8000009@3oool00`1/0?l0oooo0?ooo`0=0?ooo`0309/0o`3oool0oooo00@0oooo00<0>@3o
0?ooo`3oool00`3oool00`00@_l0oooo0?ooo`060?ooo`0307D0o`3oool0oooo00`0oooo00<0^03o
0?ooo`3oool0103oool01000Uol0oooo0?ooo`1X0?l50?ooo`03000>o`3oool0oooo00D0oooo00<0
/`3o0?ooo`3oool0303oool4001^o`030000o`3oool0oooo0080023o00@000000<80o`3oool0oooo
0`1V0?l40?ooo`030?l0i03oool0o`3T0180oooo00<000000?ooo`3oool0<03oool00240oooo0`00
000G0?ooo`0304L0o`3oool0oooo00h0oooo00<0K03o0?ooo`3oool04`3oool00`0i0?l0oooo0?oo
o`030?ooo`030012o`3oool0oooo00H0oooo00<0M@3o0?ooo`3oool03@3oool01000H?l0oooo0?oo
o`3oool2002Go`040?ooo`00Uol0oooo06P0o`80oooo0`003_l70?ooo`030;<0o`3oool0oooo00h0
oooo0P00K_l010000?l0oooo0?ooo`3oool2000Po`04000000008?l0oooo0?ooo`@0IP3o0P3oool4
0?l0i1<0oooo00<000000?ooo`3oool0;`3oool001l0oooo0P00000J0?ooo`0304L0o`3oool0oooo
00h0oooo0P1/0?l:0?ooo`03001jo`3oool0oooo00L0oooo00<0>@3o0?ooo`3oool00P3oool30012
o`L0oooo00<0M@3o0?ooo`3oool03@3oool00`00H?l0oooo0?ooo`020?ooo`8009Oo00<0oooo06P0
o`3oool00P3oool5000>o`<0oooo0`2c0?l;0?ooo`03002Ao`3oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool010000000oooo0?ooo`3oool306H0o`<0oooo0P3o0>@20?ooo`030?l0i03oool0
oooo0140oooo00<000000?ooo`3oool0;P3oool001`0oooo0`00000M0?ooo`0304L0o`3oool0oooo
00d0oooo0`1/0?l90?ooo`03001jo`3oool0oooo00L0oooo00<0>@3o0?ooo`3oool00P3oool20012
o`030?ooo`00@_l0oooo00<0oooo1@1e0?l40?ooo`03003[o`3oool0oooo00H0oooo00<0063o0?oo
o`3oool01@3oool00`1X0?l0oooo0?ooo`020?ooo`<000ko103oool40;<0o`80oooo00<00>;o0?oo
o`3oool0103oool00`00TOl0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0`P3o0?oo
o`000000203oool40?l0i1@0oooo00<000000?ooo`3oool0;P3oool001X0oooo0P00000P0?ooo`03
04L0o`3oool0oooo00`0oooo101/0?l90?ooo`03001jo`3oool0oooo00L0oooo00<0>@3o0?ooo`3o
ool00`3oool20012o`H0oooo0`1e0?l50?ooo`03003[o`3oool0oooo00D0oooo00<0063o0?ooo`3o
ool01P3oool00`1X0?l0oooo0?ooo`020?ooo`03000>o`3oool0oooo00D0oooo0P2c0?l20?ooo`03
003Ro`3oool0oooo00@0oooo00<0097o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0<80o`3oool0000000P0oooo0P3o0>@=0?ooo`030>@0o`3oool0oooo00L0oooo00<000000?ooo`3o
ool0;@3oool001P0oooo0P00000S0?ooo`0304L0o`3oool0oooo00`0oooo0P1/0?l;0?ooo`03001j
o`3oool0oooo00H0oooo00<0>@3o0?ooo`3oool02`3oool307D0o`D0oooo00<00>_o0?ooo`3oool0
1@3oool00`00H?l0oooo0?ooo`060?ooo`0306P0o`3oool0oooo00X0oooo00@0/`3o003Ro`00h_l0
0>;o1@3oool2002Ao`030?ooo`1a0?l0oooo00@0oooo00<0003o0?ooo`3oool00`3oool010320?l0
oooo0?ooo`00000A0?ooo`0302P0o`3oool0oooo0080oooo00<0i03o0?ooo`3oool0203oool00`00
0000oooo0?ooo`0]0?ooo`005P3oool2000002D0oooo00<0A`3o0?ooo`3oool03@3oool00`1/0?l0
oooo0?ooo`030?ooo`0300H0o`3oool0oooo00<0oooo00<007[o0?ooo`3oool01`3oool00`0i0?l0
oooo0?ooo`0;0?ooo`0307D0o`3oool0oooo00<0oooo00D00>_o0?ooo`3oool0oooo02@0o`040?oo
o`03001Po`3oool0oooo00D0oooo00<0J03o0?ooo`3oool02`3oool3003Ro`040?ooo`00GOl0oooo
0?ooo`@0097o00<0oooo0740o`3oool010000?l40?ooo`030<80o`3oool0`P3o0080oooo00<00000
0?ooo`3oool03P3oool00`0X0?l0oooo0?ooo`020?ooo`030>@0o`3oool0oooo00X0oooo00<00000
0?ooo`3oool0;03oool001H0oooo0P00000D0?ooo`030300o`3oool0oooo00l0oooo00<0A`3o0?oo
o`3oool04P3oool00`060?l0oooo0?ooo`030?ooo`8007[o203oool00`0i0?l0oooo0?ooo`0;0?oo
o`03002Xo`3oool0oooo0080oooo0P00jol30?ooo`0302@0o`3oool0oooo0080oooo00<0063o0?oo
o`3oool01@3oool00`1X0?l0oooo0?ooo`0;0?ooo`@00>;o00<005go0?ooo`3oool01000TOl00`1a
0?l0oooo0?ooo`050000o`80oooo10320?l20?ooo`030000003oool0oooo00T0oooo00D006Oo0?oo
o`3oool0oooo02P0o`050?ooo`030>@0o`3oool0oooo00/0oooo00<000000?ooo`3oool0:`3oool0
01H0oooo00<000000?ooo`000000503oool00`0`0?l0oooo0?ooo`0>0?ooo`80A`3o2@3oool00`00
Y?l0oooo0?ooo`080?ooo`0400H0o`3oool0oooo0?ooo`@007[o1`3oool00`0i0?l0oooo0?ooo`0;
0?ooo`03002Xo`3oool0oooo0080oooo0`00jol20?ooo`0302@0o`3oool0oooo00@0063o103oool3
06P0o`T0oooo00<00?Wo0?ooo`3oool00P3oool2003Ro`03001Mo`3oool0oooo0080oooo0P00TOl0
0`3oool0L@3o0?ooo`020?ooo`<0003o0`3oool20<80o`80oooo00<0`P3o0?ooo`0000002P3oool0
1@00Iol0oooo0?ooo`3oool0:03o00D0oooo00<0i03o0?ooo`3oool0303oool00`000000oooo0?oo
o`0[0?ooo`005P3oool010000000oooo0?ooo`00000C0?ooo`030300o`3oool0oooo00d0oooo1017
0?l80?ooo`03002To`3oool0oooo00P0oooo00<01P3o0?ooo`3oool00P3oool2001jo`H0oooo1@0i
0?l00`3oool00?o?0?ooo`080?ooo`03002Xo`3oool0oooo00<0oooo00@00>_o0?ooo`3oool0903o
0`3oool3001Po`D0oooo1@1X0?l60?ooo`03003io`3oool0oooo00D0oooo00<005go0?ooo`3oool0
103oool00`1a0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo10320?l20?ooo`050000
003oool0oooo0?ooo`00`Ol0103oool2001Wo`<0oooo00<0:03o0?ooo`3oool00`3oool00`3T0?l0
oooo0?ooo`0>0?ooo`030000003oool0oooo02X0oooo000E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool04@3oool00`0`0?l0oooo0?ooo`0=0?ooo`<0A`3o2@3oool00`00Y?l0oooo
0?ooo`070?ooo`0300H0o`3oool0oooo00<0oooo00<007[o0?ooo`3oool01@3oool303T0o`80oooo
00<00?o?0?ooo`3oool01`3oool00`00Z?l0oooo0?ooo`060?ooo`0302@0o`3oool0oooo0080oooo
00<0063o0?ooo`3oool01@3oool206P0o`03003o]@3oool0oooo00D0oooo00<00?Wo0?ooo`3oool0
103oool00`00GOl0oooo0?ooo`050?ooo`030740o`3oool0oooo00L0oooo00<00=Oo0<80o`320?l0
0`3oool00`00`Ol000000?ooo`020031o`80oooo00<006Oo0?ooo`00Iol0103oool00`0X0?l0oooo
0?ooo`030?ooo`030>@0o`3oool0oooo0100oooo00<000000?ooo`3oool0:@3oool001D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`030300o`3oool0oooo00d0oooo0P17
0?l90?ooo`03002To`3oool0oooo00L0oooo00<01P3o0?ooo`3oool0303oool01@0i0?l0oooo0?oo
o`3oool00?o?00<0oooo00<001So0?ooo`3oool00`3oool00`00Z?l0oooo0?ooo`060?ooo`0302@0
o`3oool0oooo00X0oooo00<0J03o003o]@3oool01P3oool00`00nOl0oooo02L0o`050?ooo`03001M
o`3oool0oooo00@0oooo00<0L@3o0?ooo`3oool01P3oool3003Go`040?ooo`00eol00=Oo003Go`80
0<7o00@000000031o`00?_l0oooo1000Iol20?ooo`<0:03o0`3oool30>@0oa<0oooo00<000000?oo
o`3oool0:@3oool001D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`03
0300o`3oool0oooo01<0oooo00<002;o0?ooo`3oool00`3oool00`00Y?l0oooo0?ooo`070?ooo`03
00H0o`3oool0oooo00l0oooo0P00oll20?ooo`03000Ho`3oool0oooo00<0oooo00<00:So0?ooo`3o
ool01P3oool00`0T0?l0oooo0?ooo`090?ooo`800?ne0P3oool01000/_l0oooo0?ooo`3oool2003i
o`80oooo00<09`3o0?ooo`3oool00P3oool00`00GOl0oooo0?ooo`040?ooo`80L@3o203oool4003G
o`<0oooo0P00`Ol01000000003ko0?ooo`3oool4001Wo`80oooo100X0?l20?ooo`<0i03o503oool0
0`000000oooo0?ooo`0X0?ooo`005@3oool00`000000oooo0?ooo`050?ooo`030000000W0?l0oooo
0100oooo0P0`0?lC0?ooo`03000Ro`3oool0oooo00<0oooo00<00:Co0?ooo`3oool01`3oool00`06
0?l0oooo0?ooo`0:0?ooo`04003Vo`3oool0oooo0?ooo`@00?o?00<0oooo000Ho`3oool0103oool0
0`00Z?l0oooo0?ooo`060?ooo`0302@0o`3oool0oooo00T0oooo0`00okD00`3oool00;;o0?ooo`02
0?ooo`<00?Wo00@09`3o0?ooo`3oool0oooo1000GOl30?ooo`@0L@3o2@3oool00`00eol0oooo003M
o`040?ooo`030031o`000000oooo0080oooo0`00Iol30?ooo`<0:03o0`3oool40>@0oa<0oooo00<0
00000?ooo`3oool0:03oool001D0oooo00<000000?ooo`3oool01P3oool00`0000009`3o0?ooo`0?
0?ooo`@0<03o1P3oool00`00_Ol0oooo0?ooo`090?ooo`04000Ro`3oool0oooo0?ooo`@00:Co1`3o
ool300H0o`X0oooo00<00>Ko0?ooo`3oool00P3oool2003oc`80oooo00@001So0?ooo`3oool0oooo
1000Z?l50?ooo`@0903o1@3oool00`00ojX0oooo0?ooo`030?ooo`03003o]@3oool00;;o00@0oooo
0P00nOl00`3oool09`3o0?ooo`020?ooo`<005go103oool50740o`T0oooo00<00=go0?ooo`3oool0
0`3oool00`00?_l000000?ooo`030?ooo`0308d0o`3oool0oooo00P0oooo0P3T0?lF0?ooo`030000
003oool0oooo02L0oooo000E0?ooo`030000003oool0oooo00L0oooo00<0000002L0o`3oool03P3o
ool30300o`P0oooo00<00;go0?ooo`3oool0203oool00`008_l0oooo0?ooo`020?ooo`800:Co1`3o
ool300H0o`03003oV`3oool0oooo00P0oooo00<00>Ko0?ooo`3oool00`3oool01000oll0oooo0?oo
o`006?l40?ooo`800:So1P3oool302@0o`H0oooo00<00?nZ0?ooo`3oool01@3oool00`00/_l0oooo
0?ooo`050?ooo`0302L0o`3oool0oooo0080oooo00<005go0?ooo`3oool0103oool30740o`T0oooo
00<00=go03l0o`3oool00`3oool00`00?_l0oooo000000030?ooo`0308d0o`3oool0oooo01P0oooo
00<0^P3o0?ooo`3oool01`3oool00`000000oooo0?ooo`0V0?ooo`00503oool00`000000oooo0?oo
o`090?ooo`030000000W0?l0oooo00h0oooo0P0`0?l80?ooo`03002mo`3oool0oooo00P0oooo00<0
02;o0?ooo`3oool0303oool200H0o`03003oV`3oool0oooo00P0oooo00<00>Ko0?ooo`3oool01P3o
ool00`006?l0oooo0?ooo`0;0?ooo`0302@0o`3oool0oooo00@0oooo00@00?nZ0?ooo`3oool001_o
1@3oool00`00/_l0oooo0?ooo`040?ooo`0302L0o`3oool0oooo00X0oooo00<0L@3o0?ooo`3oool0
103oool01P00ol00oooo0?ooo`3oool00=go03l0o`D0oooo00<003ko0?ooo`0000000`3oool00`2=
0?l0oooo0?ooo`0G0?ooo`030;X0o`3oool0oooo00P0oooo00<000000?ooo`3oool09P3oool001@0
oooo00<000000?ooo`3oool02P3oool00`0000009`3o0?ooo`0H0?ooo`03002mo`3oool0oooo00L0
oooo00<002;o0?ooo`3oool03`3oool00`00oi/0oooo0?ooo`020?ooo`03001>o`3oool0oooo0080
oooo00<00>Ko0?ooo`3oool01`3oool00`006?l0oooo0?ooo`090?ooo`03003oGP3oool0oooo00D0
oooo00@00?nZ0?ooo`3oool001_o103oool00`00/_l0oooo0?ooo`050?ooo`0302L0o`3oool0oooo
00D0oooo00<00?n_0?ooo`3oool01@3oool01000ol00oooo003o`000ol020?ooo`<00=go00<0?`3o
0?ooo`3oool00`00?_l20?ooo`040000002=0?l0S@3o08d0oaH0oooo00@000Go0?ooo`3oool0^P3o
303oool00`000000oooo0?ooo`0U0?ooo`00503oool00`000000oooo0?ooo`0;0?ooo`030000000W
0?l09`3o0140oooo00<003oo0?ooo`3oool00`3oool2002mo`T0oooo00<002;o0?ooo`3oool03P3o
ool2003oV`<0oooo00<004ko0?ooo`3oool00`3oool00`00i_l0oooo0?ooo`060?ooo`03000Ho`3o
ool0oooo00P0oooo0P00oeh00`3oool00?ko0?ooo`040?ooo`04003oZP3oool0oooo000Ko`@0oooo
00<00;;o0?ooo`3oool0103oool202L0o`H0oooo0P00ojl00`3oool00?n_003o[`020?ooo`@00?o0
103oool3003Mo`<0oooo1000?_l00`3oool0000008d0o`0208d0oaD0oooo00@000Go0?ooo`3oool0
^P3o3P3oool00`000000oooo0?ooo`0T0?ooo`00503oool00`000000oooo0?ooo`0<0?ooo`<09`3o
4@3oool00`00?ol0oooo0?ooo`020?ooo`@00;go1`3oool3000Ro`T0oooo00<00?oY0?ooo`3oool0
0P3oool3003oV`80oooo00@004ko0?ooo`3oool0oooo1000i_l70?ooo`03000Ho`3oool0oooo00L0
oooo0`00oeh00`3oool00?ko0?ooo`020?ooo`800?nZ00<0oooo003oZP006ol00`3oool4002bo`@0
oooo100W0?l50?ooo`<00?n_1@3oool3003o`0@0oooo0P00gOl0100o0?l0oooo0?ooo`3oool3000n
o`80oooo00<0000008d0o`2=0?l00P2=0?l>0?ooo`04002No`3oool0oooo0?ooo`8000Go0P3oool0
0`2j0?l0oooo0?ooo`0=0?ooo`030000003oool0oooo02@0oooo000D0?ooo`030000003oool0oooo
00`0oooo0`0W0?l50?ooo`030034o`3oool0oooo00T0oooo00<003oo0?ooo`3oool00P3oool3002m
o`L0oooo10008_l90?ooo`03003oj@3oool0oooo00<0oooo00D00?nK0?ooo`3oool0oooo001>o`04
0?ooo`800>Ko1P3oool4000Ho`T0oooo00@00?mN0?ooo`3oool00?ko103oool2003oZP030?ooo`00
6ol0oooo0080oooo0`00/_l50?ooo`<09`3o1`3oool01000ojl0oooo0?ooo`00ok@40?ooo`03002L
o`3oool0oooo00@0oooo00<0?`3o0?ooo`3oool0203oool00`000000S@3o0?ooo`0;0?ooo`0406P0
o`3oool009ko002No`<0oooo00D000Go0?ooo`3oool0oooo0;X0o`0A0?ooo`030000003oool0oooo
02<0oooo000D0?ooo`030000003oool0oooo00h0oooo0P0W0?l50?ooo`030034o`3oool0oooo00T0
oooo00<003oo0?ooo`3oool00P3oool2002mo`P0oooo0P008_l;0?ooo`03003oj@3oool0oooo00H0
oooo00<004ko0?ooo`3oool00`3oool00`00i_l0oooo0?ooo`050?ooo`8001So103oool00`00oe/0
oooo0?ooo`060?ooo`03003no`3oool0oooo00D0oooo00<001_o0?ooo`3oool00P3oool00`00/_l0
oooo0?ooo`050?ooo`0302L0o`3oool0oooo00P0oooo00<00?nd0?ooo`3oool00P3oool00`00W?l0
oooo0?ooo`050?ooo`0303l0o`3oool0oooo00P0oooo00<000000?ooo`3oool0203oool2003oo005
06P0o`3oool009ko0?ooo`001Ol00P3oool00`001Ol0oooo0?ooo`020;X0oa80oooo00<000000?oo
o`3oool08`3oool001@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`03
0034o`3oool0oooo00P0oooo00<003oo0?ooo`3oool03@3oool00`00og`0oooo0?ooo`090?ooo`03
003oj@3oool0oooo00H0oooo00<004ko0?ooo`3oool0303oool00`006?l0oooo0?ooo`020?ooo`04
003oF`3oool0oooo001Go`@0oooo00<00?ko0?ooo`3oool01P3oool00`006ol0oooo0?ooo`0=0?oo
o`03003oC@3oool0oooo00@0oooo00<00?nd0007o`3oool00`3oool00`00W?l0oooo0?ooo`040?oo
o`0303l0o`3oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2003oo0040?ooo`00Jol00?ol
003oo0@009ko00<0oooo0005o`001Ol00P001Ol20?ooo`<0^P3o4`3oool00`000000oooo0?ooo`0R
0?ooo`004`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<00<Co0?oo
o`00a?l0203oool00`00?ol0oooo0?ooo`0=0?ooo`03003oO03oool0oooo0080oooo00<007[o0?oo
o`3oool00`3oool00`00onT0oooo0?ooo`070?ooo`03001>o`3oool0oooo00H0oooo00<00?lJ0?oo
o`3oool01`3oool01000oe/0oooo0?ooo`00Eol40?ooo`03003no`3oool0oooo00H0oooo00<001_o
0?ooo`3oool02`3oool2003oC@03003ao`3oool0oooo0080oooo0P00ok@010001ol0oooo0?ooo`3o
ool2002Lo`D0oooo0`0o0?l40?ooo`03003oo@3oool0oooo0080oooo0P00omT010000000oooo0?oo
o`3oool5003oo0030?ooo`00W_l009ko008009ko0P3oool40005o`030?ooo`2j0?l0^P3o00<0^P3o
4`3oool00`000000oooo0?ooo`0Q0?ooo`004`3oool00`000000oooo0?ooo`0B0?ooo`03001>o`3o
ool0oooo00@0oooo0`00a?l80?ooo`<003oo303oool2003oO0<0oooo00<007[o0?ooo`3oool00`3o
ool00`00onT0oooo0?ooo`070?ooo`03001>o`3oool0oooo00H0oooo00D00?lJ0?ooo`3oool0oooo
003o_`040?ooo`800?mK0P3oool01000Eol0oooo0?ooo`3oool2003no`H0oooo0`006ol40?ooo`03
003oA`3oool0oooo00@0oooo0`00odd00`3oool00?7o0?ooo`020?ooo`<00?nd00@000Oo0?ooo`3o
ool0oooo1000W?l30?ooo`@0?`3o00@0oooo003oo@00ood00?om103oool2003of@0300000000omT0
0?oI00800?oI0`00oo`20?ooo`<009ko0`3oool30005o`80oooo102j0?lD0?ooo`030000003oool0
oooo0240oooo000C0?ooo`030000003oool0oooo01<0oooo00<004ko0?ooo`3oool00P3oool40034
o`L0oooo0`00?ol80?ooo`03003ob03oool0oooo0080oooo0`00og`30?ooo`04001jo`3oool0oooo
0?ooo`@00?oY1@3oool4001>o`H0oooo0`00oaX20?ooo`04003o_`3oool0oooo0?ooo`800?mK00@0
oooo003oF`3oool005Oo0`3oool4003no`@0oooo10006ol20?ooo`@00?m71@3oool3003oC@@0oooo
0P00ok@00`001ol0oooo0?ooo`020?ooo`<009co103oool303l0o`80oooo00@00?om0?ooo`00ood0
0?om103oool00`00omT00000003oj0030?ooo`03001[o`3oool0oooo0080oooo00<0J03o0?ooo`3o
ool0603oool00`2P0?l0oooo0?ooo`060?ooo`030000003oool0oooo0200oooo000C0?ooo`030000
003oool0oooo00H0oooo00<00;Go0?ooo`3oool02`3oool00`00C_l0oooo0?ooo`020?ooo`<00<Co
203oool2000oo`P0oooo00<00?o80?ooo`3oool00`3oool2003oO0<0oooo00<007[o0?ooo`3oool0
0P3oool2003oj@L0oooo0P00C_l80?ooo`05003o6P3oool0oooo0?ooo`00okl0103oool2003oF`80
oooo00<005Oo0?ooo`3oool00P3oool2003no`H0oooo0P006ol40?ooo`04003oA`3oool0oooo003o
D@H0oooo00<00?7o0?ooo`3oool0103oool00`001ol0oooo0?ooo`090?ooo`80?`3o103oool2003o
o@030?ooo`00ood00?om0080oooo00<07P3o0000003oool00P3oool00`00Jol0oooo0?ooo`030?oo
o`0306P0o`3oool0oooo01L0oooo00<0X03o0?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?oo
o`004`3oool00`000000oooo0?ooo`070?ooo`800;Go303oool00`00C_l0oooo0?ooo`0G0?ooo`03
003ob03oool0oooo00L0oooo00<007[o0?ooo`3oool0303oool01000C_l0oooo0?ooo`00oad90?oo
o`03003o_`3oool0oooo00D0oooo00<005Oo0?ooo`3oool02`3oool00`006ol0oooo0?ooo`050?oo
o`03003oD@3oool004Ko00@0oooo00<00?7o0?ooo`3oool01@3oool00`001ol0oooo0?ooo`0A0?oo
o`0;003oMP3oool0oooo0?ooo`0N0?l00?oX0000003oool006_o0?ooo`00Jol00P3oool306P0oaD0
oooo00D002?o0?ooo`3oool0oooo0:00o`0;0?ooo`030000003oool0oooo01l0oooo000C0?ooo`03
0000003oool0oooo00T0oooo0P00]Ol00`3oool00;Go0?ooo`070?ooo`0300000000C_l0oooo00X0
oooo00<00?mf0?ooo`3oool01@3oool00`00W?l0oooo0?ooo`020?ooo`03003ob03oool0oooo00P0
oooo00<007[o0?ooo`3oool03P3oool00`00oad0oooo0?ooo`020?ooo`03002=o`3oool0oooo0080
oooo00<00?no0?ooo`3oool01@3oool00`00Eol0oooo0?ooo`0;0?ooo`0301So003oool0oooo00D0
oooo00<00?mA0?ooo`00A_l0103oool00`00lOl0oooo0?ooo`040?ooo`030007o`3oool0oooo00h0
oooo00D00?mf0?ooo`00ogH00?mf0?ooo`04003oj0030?ooo`00000006_o008006_o0`3oool306P0
oa@0oooo00D002?o0?ooo`3oool0oooo0:00o`0=0?ooo`030000003oool0oooo01h0oooo000C0?oo
o`030000003oool0oooo00/0oooo0`00]Ol80?ooo`0400000000C_l004ko001>o`T0oooo0P00ogH0
0`3oool00?mf0?ooo`020?ooo`03002Lo`3oool0oooo00<0oooo0P00olP80?ooo`8007[o103oool0
0`0=o`00oooo0?ooo`080?ooo`03003o7@3oool0oooo0080oooo00<008go0?ooo`3oool00P3oool0
0`00okl0oooo0?ooo`050?ooo`8005Oo2`3oool0100Ho`00oooo0?ooo`00ol440?ooo`04003oD@3o
ool0oooo0016o`80oooo0`00lOl40?ooo`<000Oo2@3oool00`00oe@0oooo0?ooo`030?ooo`<00?mf
0`3oool3003oj080oooo00<00000001[o`00Jol00P00Jol20?ooo`@0J03o4P3oool01@008ol0oooo
0?ooo`3oool0X03o00h0oooo00<000000?ooo`3oool07P3oool00180oooo00<000000?ooo`3oool0
303oool4002eo`L0oooo1000C_l;0?ooo`<00?mf0`3oool01000W?l0oooo0?ooo`3oool4003ob0H0
oooo1000N_l40?ooo`803Ol00`3oool00`00ohX0oooo0?ooo`020?ooo`<00?lM0P3oool01000SOl0
oooo0?ooo`3oool3003o_`D0oooo1000Eol00`3oool02ol00?ooo`060?ooo`806?l00P3oool01000
ol40oooo0?ooo`3oool3003oD@040016o`3oool0oooo0?ooo`@00?7o0`3oool40007o`03003oRP3o
ool0oooo00@0oooo1@00oe@20?ooo`<00?mf0`3oool2003oj00401h0o`3oool0oooo0000008006_o
103oool206P0o``0oooo00@0D`3o0?ooo`3oool0oooo0P00`_l00`3oool002?o0?ooo`020?ooo`03
0:00o`3oool0oooo00h0oooo00<000000?ooo`3oool07@3oool00180oooo00<000000?ooo`3oool0
3@3oool2002eo`T0oooo0`00C_l50?ooo`03003o^`3oool0oooo00<0oooo0`00ogH30?ooo`03002L
o`3oool0oooo0080oooo0P00olP80?ooo`8007[o1@3oool300go0080oooo00<00?n:0?ooo`3oool0
0`3oool01@00oad0oooo0?ooo`3oool008go00<0oooo0P00okl60?ooo`<005Oo00@0oooo00_o000;
o`002ol01P3oool301So0003003o`@3oool0oooo0080oooo0P00oe400`3oool004Ko0?ooo`030?oo
o`800?7o1@3oool20007o`800?n:1P3oool2003oE003000Ro`00ogT0oooo0080oooo0P00ogH50?oo
o`0501h0o`3oool0oooo0?ooo`0000004`3oool00`1C0?l0oooo0?ooo`020032o`030?ooo`008ol0
02?o0080X03o00<0oooo0:00o`3oool04@3oool00`000000oooo0?ooo`0L0?ooo`004P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<00?nk0?ooo`3oool02@3oool00`00
W?l0oooo0?ooo`0<0?ooo`03001jo`3oool0oooo00@0oooo00D03Ol00?ooo`3oool0oooo003oRP09
0?ooo`03002=o`3oool0oooo0080oooo00<00?no0?ooo`3oool01@3oool01@00Eol0oooo0?ooo`3o
ool02ol00080oooo00<01Ol00?ooo`00P?l01@3oool00`00ol40oooo0?ooo`050?ooo`030016o`3o
ool0oooo00/0oooo0`00ohX60?ooo`03000Ro`00ogT0oooo00<0oooo00<00<Ko0?ooo`3oool00`3o
ool00`0N0?l0oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00@00<;o0?ooo`00`_l00<;o
0`008ol20?ooo`<0X03o4`3oool00`000000oooo0?ooo`0L0?ooo`004P3oool00`000000oooo0?oo
o`0D0?ooo`03003oS03oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00ok/0oooo0?oo
o`080?ooo`03002Lo`3oool0oooo00d0oooo00<02_l00?ooo`3oool00P3oool00`00^ol0oooo0?oo
o`020?ooo`03003oRP3oool0oooo00L0oooo00<008go0?ooo`3oool04@3oool00`05o`00oooo0020
o`050?ooo`03003o`@3oool0oooo00D0oooo00<004Ko0?ooo`3oool02`3oool2003oRP030?ooo`00
ohX0oooo00@0oooo00<00?mi0?ooo`3oool00P3oool20036o`<0oooo0`0N0?l40?ooo`030000003o
ool0oooo00/0oooo00@00?o=0024o`3oool0oooo0P00old00`00`_l0oooo0?ooo`02000So`<0oooo
102P0?lC0?ooo`030000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo01D0oooo0P00
oh`20?ooo`05003oS03oool0oooo00000000/Ol01@3oool2003o^`T0oooo00<009co0?ooo`3oool0
303oool00`0:o`00oooo0?ooo`020?ooo`03002ko`3oool0oooo00<0oooo00<00?n:0?ooo`3oool0
1P3oool00`00SOl0oooo0?ooo`0A0?ooo`0300Go003oool0083o00@0oooo0P00ol450?ooo`<004Ko
403oool00`07o`00oooo0?ooo`03003oN@@0oooo0P00a_l40?ooo`@07P3o0`3oool00`000000oooo
0?ooo`050?ooo`03003oW@3oool0oooo0080oooo1@00old30032o`80oooo0`008ol20?ooo`80X03o
5@3oool00`000000oooo0?ooo`0K0?ooo`004P3oool00`000000oooo0?ooo`0G0?ooo`@00?n<0P3o
ool00`0000000;7o0?ooo`030?ooo`<00?nk1`3oool3002Lo`030?ooo`0Eo`00oooo00/0oooo00D0
2_l00?ooo`3oool0oooo002ko`040?ooo`<00?n:1P3oool3002=o`T0oooo00@0Jol00?ooo`3oool0
0?mo0`3oool200Go0080oooo00@0083o0?ooo`3oool0oooo0`00ol450?ooo`@004Ko2`3oool400Oo
00<0oooo0`00ogT40?ooo`<00<Ko0`3oool301h0o`@0oooo00<000000?ooo`3oool00`3oool4003o
W@80oooo0`00old20?ooo`0305<0o`00`_l00<;o01L0oooo00<0U03o0?ooo`3oool01P3oool00`00
0000oooo0?ooo`0J0?ooo`004@3oool00`000000oooo0?ooo`0C0?ooo`03003oa03oool0oooo00<0
oooo0`00oh`30?ooo`03002ao`3oool0oooo00<0oooo0P00ok/80?ooo`8009co0P3oool401Go0080
oooo00<00?mT0?ooo`3oool00P3oool300[o00<0oooo00@00;_o0?ooo`3oool0oooo0P00ohX70?oo
o`8008go00<0@?l00?ooo`3oool01P3oool206_o0080oooo00@00?mo0?ooo`3oool0oooo0`05o`00
0`3oool0083o0?ooo`020?ooo`800?o11`3oool20016o`@0oooo0P0To`060?ooo`<01ol000@00?oV
0?ooo`3oool0oooo0P00ogT50?ooo`800<Ko103oool00`0N0?l0oooo0?ooo`040?ooo`03003o]000
00000?nd00<0oooo0`00oid00`00olH00?nM003oW@02003oW@80oooo00<0D`3o0?ooo`3oool05`3o
ool00`2D0?l0oooo0?ooo`080?ooo`030000003oool0oooo01T0oooo000A0?ooo`030000003oool0
oooo01@0oooo00<00?o40?ooo`3oool02@3oool00`00/Ol0oooo0?ooo`0=0?ooo`04002Lo`3oool0
oooo0?ooo`<05Ol00P3oool00`00of@0oooo0?ooo`030?ooo`802_l00`3oool00`00^ol0oooo0?oo
o`020?ooo`03003oRP3oool0oooo00H0oooo0`10o`000`3oool0C?l00?ooo`020?ooo`03002co`3o
ool0Jol000<0oooo00<00?mo0?ooo`3oool00P3oool00`05o`00oooo0020o`050?ooo`03003o`@3o
ool0oooo00@0oooo00<00?l]0016o`3oool0103oool402Co0003003o4`3oool0oooo00<0oooo00<0
0?oV0?ooo`3oool00`3oool00`008_l0oooo0?ooo`090?ooo`<00?3o103oool00`00ok@00000003o
]0020?ooo`040100o`3oool00?nM003oaP80oooo00<008Co0?ooo`3oool00P1C0?lI0?ooo`0309@0
o`3oool0oooo00T0oooo00<000000?ooo`3oool06@3oool00140oooo00<000000?ooo`3oool05@3o
ool00`00ol@0oooo0?ooo`090?ooo`03002ao`3oool0oooo00X0oooo00<05ol00?ooo`3oool0103o
ool00`00h?l0oooo0?ooo`020?ooo`03003oI03oool0oooo00L0oooo00<00;_o0?ooo`3oool02`3o
ool2043o0080oooo00D0C?l00?ooo`3oool0oooo002co`050?ooo`03003oO`3oool0oooo00@0oooo
00<0083o0?ooo`3oool02@3oool3003o;@H0oooo00@09?l00?ooo`00oa<005co103oool00`00onH0
oooo0?ooo`030?ooo`03000Ro`3oool0oooo00X0oooo0`00l?l40?ooo`03003o]00000000?nd0080
0?nd0P00olH0103oool008Co0024o`00Q?l30?ooo`80D`3o5P3oool00`00;_l0oooo09@0o`0=0?oo
o`030000003oool0oooo01P0oooo000A0?ooo`030000003oool0oooo00H0oooo0P00okd40?ooo`03
003o_@3oool0oooo00L0oooo0`00ol@90?ooo`800;7o2`3oool00`0Go`00oooo0?ooo`030?ooo`03
003Po`3oool0oooo0080oooo00<00?mT0?ooo`3oool01`3oool2002koa00oooo00D0C?l00?ooo`3o
ool0oooo002co`040?ooo`03003oO`3oool0oooo00D0oooo00<0083o0?ooo`3oool02@3oool2003o
;@80oooo00<00?nM0?ooo`3oool00`3oool00`00oa<005co0?ooo`020?ooo`800?oV1@3oool2000R
o``0oooo0`00l?l30?ooo`04003Jo`3oool00000003o@`800?o600<00?nd0?ooo`3oool00`00Q?l2
0?ooo`@0D`3o4`3oool2000^o`030?ooo`2D0?l0oooo00h0oooo00<000000?ooo`3oool05`3oool0
0140oooo00<000000?ooo`3oool0203oool6003o_@T0oooo0P00ol@80?ooo`<00;7o303oool201Oo
00@0oooo00<00>3o0?ooo`3oool00P3oool2003oI0H0oooo1000^ol:0?ooo`03003oB03oool0oooo
00<0oooo00@0C?l00?ooo`3oool00;?o0`3oool3003oO`D0oooo1000P?l;0?ooo`03003o;@1ko`00
0?nM00<0oooo0P00oa<00`3oool005co0?ooo`020?ooo`<00?oV103oool4000Ro`X0oooo0`00l?l0
0`3oool00?m3003o@`02003o@`0400000000olH00?o6003oaP<0oooo0P00Q?l30?ooo`80D`3o3@3o
ool00`1?0?l0oooo0?ooo`040?ooo`04000^o`3oool0oooo09@0oa00oooo00<000000?ooo`3oool0
5`3oool00140oooo00<000000?ooo`3oool0303oool3003o_@P0oooo0`00ol@80?ooo`04002ao`00
o`D00?l50?ooo`800?l50`3oool00`00oe40oooo0?ooo`020?ooo`<05ol00`3oool01000h?l0oooo
0?ooo`3oool3003oI0L0oooo0P00^ol60?ooo`80Xol00`3oool00`00odP0oooo0?ooo`020?ooo`80
C?l00P3oool01000/ol0oooo0?ooo`3oool2003oO`H0oooo0`00P?l;0?ooo`80Nol000<00?nM0?oo
o`3oool00P3oool3003o4`04001Lo`3oool0oooo0?ooo`800?oV1@3oool2000Ro`T0oooo0P00o`h0
1@3oool00?mI0?ooo`3oool00?3o00800?m30P3oool00`000000oooo0100o`0G0?ooo`0304l0o`3o
ool0oooo0080oooo0P00dOl01000;_l0U03o0?ooo`2D0?lB0?ooo`030000003oool0oooo01H0oooo
000A0?ooo`030000003oool0oooo02D0oooo0`00o`D40?ooo`03003oD@3oool0oooo0080oooo0P0G
o`030?ooo`03003Po`3oool0oooo0080oooo0P00of@60?ooo`03053o003oool00;_o00L0oooo0P2S
o`020?ooo`03003oB03oool0oooo0080oooo0P1<o`020?ooo`03002co`3oool0oooo0080oooo00<0
0?mo0?ooo`3oool01@3oool00`00P?l0oooo0?ooo`020?ooo`0608[o003oool0oooo04Oo003oool0
08oo0P3oool207_o0003003oW@3oool0oooo00@0oooo00<005co0?ooo`3oool03P3oool00`00oc@0
oooo0?ooo`030?ooo`H00?l>00<00?3o003Jo`3oool00P3oool00`000000403o0?ooo`0F0?ooo`04
04l0o`3oool0oooo0?ooo`800=7o00<002ko0?ooo`2D0?l00P2D0?lC0?ooo`030000003oool0oooo
01H0oooo000@0?ooo`030000003oool0oooo02L0oooo00<00000003o1@00n_l0103oool00`00oe40
oooo0?ooo`070?ooo`03003Po`3oool0oooo00T0oooo0P1@o`020?ooo`0307go003oool0oooo0080
oooo00<00>3o0:?o003oool00P3oool00`00odP0oooo0?ooo`060?ooo`03002co`3oool0oooo00H0
oooo00<04ol00?ooo`3oool01@3oool308[o00040?ooo`17o`00oooo002?o`@0oooo00<00?nM0?oo
o`3oool0103oool00`00G?l0oooo0?ooo`0=0?ooo`800?ld1@3oool00`00o`h00?mI0?ooo`030?oo
o`06003Jo`00l?l0oooo0?ooo`0@0?l00000503oool00`00Qol0oooo0?ooo`02003Ao`030?ooo`00
dOl00=7o008002ko0P3oool409@0oa<0oooo00<000000?ooo`3oool05@3oool00100oooo00<00000
0?ooo`3oool08@3oool00`05o`00oooo0?ooo`040?ooo`0300000000n_l0oooo00<0oooo00<00?mA
0?ooo`3oool01`3oool3003Po`L0oooo0P1@o`001@3oool0D?l00?ooo`3oool0OOl000@0oooo00<0
0>3o0?ooo`3oool00P3oool00`00odP0oooo0?ooo`060?ooo`03002co`3oool0oooo00D0oooo0`0C
o`090?ooo`0304Oo003oool008oo00D0oooo00<00?nM0?ooo`3oool00P3oool3001Lo`L0oooo0`00
ojX50?ooo`<00?ld0P3oool3003oF@<0oooo0P00f_l40?ooo`030100o`000000403o0140oooo0P00
okH20?ooo`@00?nf00<0oooo000^o`00;_l00P00;_l00`3oool0U03o09@0o`0F0?ooo`030000003o
ool0oooo01@0oooo000@0?ooo`030000003oool0oooo0280oooo0`05o`040?ooo`0300000000n_l0
oooo00<0oooo0P00oe470?ooo`800>3o3P3oool00`1mo`00oooo0?ooo`020?ooo`04003Po`3oool0
oooo0?ooo`<00?m81P3oool3002co`L0oooo00H04ol00?ooo`3oool0hOl00?ooo`00oeh50?ooo`03
04Oo003oool008oo00<0oooo0`00oid40?ooo`@005co1P3oool3003oZPD0oooo00<00?oJ0?ooo`0o
o`000P00oc@00`00oeT002So0?ooo`030?ooo`<00=[o0`3oool00`0@0?l000000?ooo`0:0?ooo`03
01H0o`3oool0oooo00<0oooo1@00okH3003AoaH0oooo00<0V@3o0?ooo`3oool01P3oool00`000000
oooo0?ooo`0D0?ooo`00403oool00`000000oooo0?ooo`0I0?ooo`800?m00`3oool00`00oe<0oooo
0?ooo`030?ooo`801Ol0103oool01000n_l0oooo0?ooo`3oool3003oD@P0oooo00<00>3o0?ooo`3o
ool00P3oool00`2do`00oooo0?ooo`030?ooo`03003o7P3oool0oooo0080oooo0P1mo`020?ooo`04
003Po`3oool0oooo0?ooo`800?m81`3oool2002co`P0oooo00H04ol00?ooo`3oool0hOl00?ooo`00
oeh40?ooo`80Aol000<0oooo002?o`3oool00`3oool00`00oid0oooo0?ooo`040?ooo`8005co1`3o
ool3003oZP<0oooo100oo`020?ooo`<00?mI103oool2003Jo`D0oooo00<000000?ooo`3oool0203o
ool00`0F0?l00?mh003oN002003oN080oooo00D008Oo003o]P00okH0oooo04l0o`0H0?ooo`0309T0
o`3oool0oooo00P0oooo00<000000?ooo`3oool04`3oool00100oooo00<000000?ooo`3oool0503o
ool7003o@0@0oooo00<00?mC0?ooo`3oool00P3oool00`05o`00oooo0?ooo`040?ooo`03003jo`3o
ool0oooo0140oooo0P2do`030?ooo`03003o7P3oool0oooo0080oooo00D0OOl00?ooo`3oool0oooo
003Po`040?ooo`03003oB03oool0oooo00H0oooo00<00;?o0?ooo`3oool01@3oool00`00_Ol0oooo
0>7o00020>7o00030?ooo`00oeh0oooo00<0oooo00<0Aol00?ooo`00Sol0503oool207So0003001I
o`00ojX0oooo0080oooo0P0oo`050?ooo`03000Xo`3oool0oooo00X0oooo00<000000?ooo`3oool0
1P3oool00`00oh405P3o0?ooo`03003oN0030?ooo`00ogP00?mh00<00?mh00<0C`3o0?ooo`3oool0
5@3oool209T0o``0oooo00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`3oool06@3o
ool2003o@0D0oooo00<00?mC0?ooo`3oool0203oool00`00n_l000000?ooo`070?ooo`80=_l0203o
ool20;Co00<0oooo00<00?lN0?ooo`3oool01`3oool00`00h?l0oooo0?ooo`0<0?ooo`040=;o003o
ool0oooo09?o0080oooo00@00;go0?ooo`3oool0hOl00P3oool00`00oeh0oooo0?ooo`040?ooo`03
002?o`3oool0oooo0180oooo0`1ho`000`00ojX0oooo0?ooo`020?ooo`04003ofP3oool0oooo0?oo
o`8002So3@3oool00`000000oooo0?ooo`030?ooo`05003Do`00oh400?n10?ooo`0F0?l00P00okd0
1000ogP008Oo0027o`00Qol20?ooo`<0C`3o5P3oool00`009_l0oooo0?ooo`0<0?ooo`030000003o
ool0oooo0180oooo000@0?ooo`030000003oool0oooo0240oooo0P00oe<90?ooo`800?[o1P3oool3
03Ko0080oooo00<0TOl00?ooo`3oool00`3oool00`00ooX0oooo0?ooo`020?ooo`03003o7P3oool0
oooo00L0oooo0P00h?l30?ooo`0302ko003oool0oooo00L0oooo0P3Bo`001@3oool0Tol00?ooo`3o
ool00;go00@0oooo00<00?mN0?ooo`3oool0103oool2002?o``0oooo0P0go`000`3oool00?nJ0?oo
o`030?ooo`0607So0009o`00oooo0?ooo`00ojX0oooo0P00omX40?ooo`<002So303oool00`000000
0?o=0?ooo`020?ooo`03003Do`3oool00?n100800?n100@00?nm0?ooo`3oool0oooo0`00Qol20?oo
o`80C`3o5@3oool2000Voa00oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3o
ool04`3oool3003o:P80oooo00<00?lZ0?ooo`3oool01`3oool2003oD`P0oooo0`00n_l010000000
oooo0?ooo`3oool203Ko00H0oooo00<0TOl00?ooo`3oool00P3oool00`00ooX0oooo0?ooo`020?oo
o`<00?lN1P3oool2003Po`@0oooo0`0^o`050?ooo`03003o:P3oool0oooo0080oooo00@0Tol00?oo
o`3oool00;go0`3oool3003oGPD0oooo0`00Sol;0?ooo`80=ol000<0oooo0;_o003oool00P3oool0
0`09o`00oooo00Wo00040?ooo`800?oJ103oool2000Xo`X0oooo00@001So0?ooo`3oool000000`00
old4003o;P800?nm0P00oh420?ooo`8008Oo4@3oool00`1N0?l0oooo0?ooo`030?ooo`0409T0o`00
9_l002Ko09T0oa40oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0303o
ool2003oUPP0oooo1000obX90?ooo`800?mC203oool2003jo`030?ooo`000000oooo00@0oooo00<0
0?l70?ooo`3oool00`3oool2097o00<0oooo00@00?oj0?ooo`3oool0oooo0P00oah80?ooo`03003P
o`3oool0oooo0080oooo0P0^o`020?ooo`050?oB003oool0oooo0?ooo`00obX00`3oool309?o0003
0?ooo`00_Ol0oooo0080oooo0P00oeh60?ooo`8008oo0`3oool3003oH@80oooo00<008Co0?ooo`3o
ool00P3oool00`2ko`00=ol00?ooo`030?ooo`802Ol01@3oool00`00omX0oooo0?ooo`030?ooo`03
000Xo`3oool0oooo00H0oooo00<00;3o0?ooo`006?l00`3oool00`0000000?o=003oc@02003o;P80
oooo00<05P3o0?ooo`3oool00P3oool2003oPA80oooo00@0GP3o0?ooo`3oool002Ko0P3oool20039
o`80V@3o4P3oool200000180oooo000?0?ooo`030000003oool0oooo00/0oooo1000oiH90?ooo`03
003o:P3oool0oooo01@0oooo0P2Io`000`000000VOl009Wo00030?ooo`03003o1`3oool0oooo0080
oooo0P2Ao`030?ooo`03003onP3oool0oooo0080oooo00<00?lN0?ooo`3oool02`3oool01@0^o`00
oooo003Uo`3oool0om8000<0oooo00<00?lZ0?ooo`3oool00P3oool00`2Co`00oooo002mo`050?oo
o`03003oGP3oool0oooo00T0oooo1000of400`1Oo`0008Co0?ooo`020?ooo`80^ol000<00?nJ03Oo
003oool00P3oool00`09o`0005Wo0?ooo`0B0?ooo`@00;3o0P0Jo`001000oeP000000?ooo`00old2
003o;P<05P3o5`3oool0101N0?l0oooo0?ooo`009_l30039o`@0V@3o3`3oool3000000030?ooo`00
0000oooo0140oooo000?0?ooo`030000003oool0oooo00H0oooo1@00oiH00`3oool00?nF003oUP0I
0?ooo`800?l7203oool309Wo00<0oooo00<00?l70?ooo`3oool01`3oool00`00ooX0oooo0?ooo`0>
0?ooo`060<_o000^o`00oooo0?ooo`00iOl0oooo0P3odP000`3oool00?lZ0?ooo`060?ooo`03002m
o`3oool0oooo0100oooo0P00of400`3oool0Gol00024o`030?ooo`030;_o0000oiX0oooo00<0oooo
0`00FOlC0?ooo`04002`o`3oool00;3o002`o`@06_l000@0000001[o0000old0oooo0`0F0?lD0?oo
o`03001eo`3oool0GP3o00@00<Wo0`009_l209T0o`h0oooo0`0000040?ooo`030000003oool0oooo
0100oooo000?0?ooo`030000003oool0oooo02L0oooo0P00o`L30?ooo`0308?o003oool0oooo00@0
oooo00<00?oN0?ooo`3oool00P3oool00`00o`L0oooo0?ooo`060?ooo`<00?oj2P3oool20>ko0080
oooo00D0bol00?ooo`3oool0oooo003Uo`040?ooo`03003o:P3oool0oooo00@0oooo1000_Ol<0?oo
o`08003oH`3oool0oooo0?ooo`3co`000?mQ0??o0000Q?l40?ooo`800?nJ103oool4001Io`l0oooo
0`08o`04002`o`05003oF03oool00=Co003Do`0000000P3oool00`00old05P3o01H0o`0C0?ooo`03
003o^@00MOl0oooo00<00<Wo0P00okTA0?ooo`<0000000<0[P3o0?ooo`3oool0103oool00`000000
oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`0U0?ooo`@00?l7103oool00`23o`00oooo
0?ooo`040?ooo`04003ogP3oool0oooo0?ooo`800?l71`3oool2003onP030?ooo`0Oo`007ol000L0
oooo00<00?l30>ko003^o`000P3oool01@3;o`00oooo0?ooo`3oool00>Go00@0oooo0P00obX50?oo
o`<00;go2@3oool208So0080oooo00<00?mS0?ooo`3oool00P3oool00`00of40Gol00024o`040?oo
o`800?nJ1@3oool2001Io`T0oooo00<003ko0?ooo`3oool0103oool300So00030?ooo`00oeP00;3o
00<0oooo0P00e?l01@000000oooo0?ooo`3oool00?o=00`0oooo00<0;`3o0?ooo`3oool0103oool2
003o^@030?ooo`00okT00?ni00800?ni00<00<Wo0?ooo`3oool03@3oool300000080oooo00<0[P3o
0?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`003P3oool00`000000oooo0?ooo`0T0?oo
o`800?l70`3oool00`00o`@0oooo0?ooo`030?ooo`80Pol0103oool00`00omh000000?ooo`020?oo
o`03003o1`3oool0oooo00H0oooo00@00?oj0?ooo`0Oo`007ol01`3oool00`00o`<0oooo0?ooo`02
0?ooo`80bol00P3oool00`00iOl0oooo0?ooo`020?ooo`03003o:P3oool0oooo00D0oooo00<00;go
0?ooo`3oool01P3oool01P00ZOl0oooo08So0028o`00oooo0?oA00D0oooo00<00?mQ05oo0000Q?l0
103oool00`00oiX0oooo0?ooo`040?ooo`03001Io`3oool0oooo00L0oooo00@003ko003oGP00oeh0
0?mN0P3oool3053o0080oooo0P08o`000`00oeP00;3o0?ooo`030?ooo`030000003oool0oooo00d0
oooo00P0;`3o0?ooo`3oool0oooo003oK`00oll0oooo001eo`<00?ni4@3oool3000000<0oooo0P2^
0?l90?ooo`030000003oool0oooo00l0oooo000>0?ooo`030000003oool0oooo02@0oooo0`1Go`03
0?ooo`03003o103oool0oooo00<0oooo00<0Pol00?ooo`3oool00`3oool00`00omh000000?ooo`0;
0?ooo`@07ol000@0oooo0?nd0000ooT0ok@00P3oool00`00o`<0oooo0?ooo`030?ooo`050<_o003o
ool0oooo0?ooo`00iOl03@3oool2003o>@D0oooo00H00:Wo0?ooo`3oool0R?l00?oA0000of<50?oo
o`0305oo003oool008Co01D0oooo00<003ko003oGP00oeh00P3oool3053o0080oooo0P006?l00`3o
ool02?l0002`o`040?ooo`030000003oool0oooo00`0oooo00@0;`3o0?ooo`3oool0oooo1000ofl0
103oool0GP3o05h0o`1N0?l>0?ooo`<000001@3oool00`003?l0oooo0?ooo`090?ooo`030000003o
ool0oooo00l0oooo000>0?ooo`030000003oool0oooo01T0oooo0`00of850?ooo`<0Eol000<0oooo
05Oo003oool0103oool00`00o`@0oooo0?ooo`080?ooo`800?oN00<000000?ooo`3oool02@3oool0
0`0Oo`00oooo0?ooo`030?ooo`80ok@00P3oool00`00o`<0oooo0?ooo`070?ooo`03003Uo`3oool0
oooo00X0oooo0`00ocT30?ooo`030:Oo003oool00:Wo0080oooo00<0R?l00?oA0000of<01@3oool2
0024oa00oooo00<00?om0?ooo`3oool00P3oool20:So00800?mN00@0oooo003oj`3oool00?o[0`3o
ool3000Ho`80oooo00D00;3o0?ooo`3oool0oooo0000000;0?ooo`05002fo`3oool0;`3o003oc`3o
ool00P00oll01000MOl00?m_001eo`3oool4003oK`X0oooo100000060?ooo`8000co303oool00`00
0000oooo0?ooo`0?0?ooo`003P3oool00`000000oooo0?ooo`0I0?ooo`800?mR0`3oool205?o00/0
oooo00<00?l40?ooo`00o`@01`3oool3003ogP030?ooo`000000oooo00D0oooo0P3Bo`00103oool0
7ol00?ooo`3To`040?ooo`03003on@3oool0oooo0080oooo00<00?l30?ooo`3oool0103oool4003U
o`/0oooo00@00?lg003o>@00ocT0ojL00P3oool00`2Wo`00oooo002Yo`030?ooo`800?mS1@3oool3
0024o`h0oooo0`00ood30?ooo`@0Z?l000<00?mN003oj`00on/0103oool2000Ho`<0oooo00D00;3o
0?ooo`3oool0oooo000000020?ooo`0300`0o`3oool0oooo00D0oooo00<00;Ko0?ooo`00ofH00P00
ofH00`00oll0oooo0?ooo`03001eo``0oooo0`0000000`3oool0O@3o0?ooo`040?ooo`040:h0o`00
3?l000co0:h0o`d0oooo00<000000?ooo`3oool03`3oool000h0oooo00<000000?ooo`3oool0603o
ool00`00of80oooo003oHP050?ooo`@0Dol0203oool2003o10P0oooo0P00omh20?ooo`030000003o
ool0oooo00<0oooo0P3Bo`030?ooo`030>Co003oool0oooo0080oooo00@00?oi0?ooo`3oool0oooo
0`00o`<60?ooo`800>Go303oool00`00ocL00?li0?ooo`020?nW00040:Oo003oool0oooo002Yo`<0
oooo0`00of<50?ooo`030024o`3oool0oooo00L0oooo00<005ko0?ooo`3oool00P3oool01022o`00
0?om003oo@00ood20?ooo`03003o0@3oool0oooo0080oooo00<00?mN003oj`00on/0103oool00`00
6?l0oooo0?ooo`060?ooo`030000003oool0303o00L0oooo00@00?lj0?ooo`00ocX00?lj0`00ofH>
0?ooo`<000000`3oool0101m0?l0oooo0?ooo`003?l30?ooo`03000<o`2^0?l0[P3o00h0oooo00<0
00000?ooo`3oool03`3oool000h0oooo00<000000?ooo`3oool05P3oool2003oHPX0oooo0P1Co`09
0?ooo`03003o103oool0oooo00D0oooo0`00oaD30?ooo`060000003oool0oooo0?ooo`3Bo`005?l0
1@3oool01@3To`00oooo0?ooo`3oool00?oi00@0oooo00<00?l30?ooo`3oool01P3oool00`00iOl0
oooo0?ooo`040?ooo`80[_l000H0oooo0?m_003oool0oooo003o=`00ocT20?ooo`<0Yol000<00:Wo
0?ooo`3oool00P3oool2003oHa00oooo00<005ko0?ooo`3oool00P3oool00`22o`000?om003oo@02
0?ooo`<00?l1103oool00`00oeh0oooo0?ooo`0<0?ooo`030000003oool0303o00<0oooo00<00?mh
003oX@00oj400P00oj400`00ocX0;`3o0?ooo`030?ooo`800?mV2@3oool3000000D0oooo00L0O@3o
0?ooo`3oool0oooo000<o`3oool000co00800:co0P2^0?l>0?ooo`030000003oool0oooo00l0oooo
000>0?ooo`030000003oool0oooo01D0oooo00<00?mR003o1P00o`H00P00o`HL0?ooo`800?lE0P3o
ool30?oD00@0oooo00<05?l00?ooo`3oool00P3oool00`3To`00oooo0?ooo`020?ooo`03003on@3o
ool0oooo0140oooo0P2^o`001P3oool0ofl00?ooo`3oool00?lg003o>@<0oooo00<0Yol00?ooo`00
ZOl04`3oool00`00o`T0oooo04Oo00040?ooo`<0a_l000@00?om0?ooo`00?_l003ko5@3oool01`00
0000303o0?ooo`3oool07ol0003oN000]_l00`00oj401000ocX0;`3o02l0o`0_0?l50?ooo`800?mV
103oool3000000D0oooo00@004oo0?ooo`1m0?l00:co0P3oool010003?l00:co002/o`00[?l20:h0
oa00oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0303oool3003odP@0
oooo1000o`H00`3oool00?l6003o1P0L0?ooo`03003o5@3oool0oooo00@0oooo0P3oe0030?ooo`03
01Co003oool0oooo00H0oooo0`00ooT80?ooo`800?lh1@3oool01@3Io`00oooo0?ooo`2^o`00oooo
0080ofl000<0oooo003o=`3oool01@3oool3002Yoa80oooo0P00o`T01000G_l0oooo0?ooo`3oool2
0<Ko00<0oooo00@00?om000no`00?_l003ko4@3oool01000jOl0oooo0?ooo`000002003[o`<07ol0
00@00;Ko003oX@00oj400?nQ0P0_0?l:0?ooo`80000000<0FP3o0?ooo`3oool01@3oool00`00Col0
O@3o07d0o`05002/o`03000<o`3oool0oooo01<0oooo00<000000?ooo`3oool03P3oool000d0oooo
00<000000?ooo`3oool0303oool2003odRD0oooo0P2:o`000`00oaD0oooo0=So00060?ooo`04003o
gP000000oooo0?ooo`<05?l01P3oool2003on@T0oooo0`00ocP01@3oool0ogL00?ooo`3oool0fOl0
0080oooo00@0[_l00?ooo`3oool0oooo0P00ocL60?ooo`800:Wo3P3oool01@00oh`0oooo0?ooo`3o
ool0om0000800?l9103oool2003o]P<0oooo00<00?om000no`00?_l02P3oool00`003_l0oooo0?oo
o`040?ooo`05003Yo`3oool0oooo0?ooo`0000001000jol00`00]_l07ol001oo000201oo0003003o
X@3oool0oooo00H0oooo0`0000000`3oool0FP3o0?ooo`050?ooo`8004oo00<00?oE0?ooo`3oool0
1@00omDF0?ooo`030000003oool0oooo00h0oooo000=0?ooo`030000003oool0oooo00X0oooo0P00
om800`3oool00?oB0?ooo`0S0?ooo`80R_l000@00?lE0?ooo`3oool0oooo0P3Ho`040?ooo`04003o
gP3oool000000?ooo`805?l0203oool00`00ooT0oooo0?ooo`070?ooo`800?lh00<00?lG0?mg003o
M`000P3oool0103Io`00oooo0?ooo`00bOl30?ooo`<00?lg1P3oool00`00ZOl0oooo0?ooo`060?oo
o`04001io`3oool0oooo003obP80oooo00P00?n<0?ooo`3oool0oooo04Oo003od0000?l90?o@00<0
oooo0P00okH30?ooo`03003oo@00?_l0oooo00T0oooo00<000ko0?ooo`3oool0103oool01P00jOl0
oooo02Ko000Vo`00=ol0000000<00>_o1`3oool00`00oj40oooo0?ooo`020?ooo`<000000`3oool0
0`1J0?l0oooo0?ooo`040?ooo`03001?o`00omD00?oE00<00?oE6`3oool00`000000oooo0?ooo`0>
0?ooo`003@3oool00`000000oooo0?ooo`080?ooo`800?oB7@3oool3003oJ@H0oooo0P2:o`030?oo
o`0401[o003oool0oooo0?ooo`80f?l0103oool01@00omh0oooo0000003oool05?l000d0oooo00<0
X_l00?ooo`00i?l00P3oool00`00ocP0oooo003o5`030?ooo`<0fOl000<0oooo0039o`3oool00`3o
ool00`00ocL0oooo0?ooo`0>0?ooo`03001io`3oool00?o:00<00?o:103oool204Oo0003003o2@3o
ool0oooo00L0oooo00<00?om0?ooo`3oool02@3oool00`003_l0oooo0?ooo`030?ooo`0303Oo0000
C_l0=ol000<09_l000<00000003[o`00jol02@3oool01000oj4000000000000000050?ooo`0305X0
o`3oool0oooo0080oooo00<004oo003onP00ooX00P1m0?l2003oeAH0oooo00<07`3o0?ooo`3oool0
103oool00`000000oooo0?ooo`0>0?ooo`003@3oool00`000000oooo0?ooo`060?ooo`800?oB7`3o
ool3003oJ@D0oooo0P3Ko`040?ooo`0301[o003oool0oooo00L0oooo0P00omh00`3oool000000?oo
o`0<0?ooo`80X_l000@0oooo003To`3o@@000?lh0P3oool00`00oaL0oooo0?ooo`020?ooo`040=Wo
003oool0oooo0039oa<0oooo00@0Ool00?ooo`00NOl0oooo0`00olX00`00oh`0oooo0?ooo`020?oo
o`0404Oo0000G_l005ko003o2A<0oooo00D000ko0?ooo`3oool00?lZ0?ooo`02003Yo`<004ko0`0<
0?l0100000009_l00?ooo`00jol60?ooo`<0000000<00?nQ0?ooo`3oool00P3oool00`00P_l0oooo
05X0o`040?ooo`D00?n200<0O@3o0?ooo`3oool0503oool201l0o`L0oooo00<000000?ooo`3oool0
3P3oool000d0oooo00<000000?ooo`3oool09`3oool2003oJ@<0oooo1@3Ko`050?ooo`0301[o003o
ool0oooo00D0oooo0`00omh20?ooo`050000003oool0oooo0?ooo`00oe`01`3oool01`3`o`00X_l0
0?ooo`3oool00>Co0?m10000ocP00P3oool00`00oaL0oooo0?ooo`040?ooo`<00<Wo303oool01000
of`0oooo0?ooo`0Vo`020?ooo`0307oo0000NOl0oooo0080oooo00<00?o:0>;o0000oh`0103oool3
001No`03003o2@3oool0oooo00`0oooo00<00?o_0?ooo`3oool00P3oool00`003_l0YOl0003o<@03
003o:P030?ooo`00C_l004ko008004ko00H0303o0?ooo`000000oooo02Ko0000jol30?ooo`800000
00<0@`3o0?ooo`3oool01@3oool01000P_l0oooo0?ooo`1J0?l4003onP03001?o`00oh800?n20080
oooo1@00oh8@0?ooo`807`3o2@3oool00`000000oooo0?ooo`0>0?ooo`003@3oool00`000000oooo
0?ooo`0T0?ooo`809?l000@00?mY0?ooo`3oool0Z?l0303oool201[o00L0oooo0P00omh30?ooo`04
00000000oe`00?mL003oG080oooo00<00?l30?ooo`3oool00P3oool01@2Ro`00oooo0?ooo`3oool0
0>Co00<0oooo0`00oaL50?ooo`800<Wo1`3oool00`00Sol0oooo0?ooo`030?ooo`03003oK03oool0
9_l000809_l000<0Ool00?ooo`00NOl00`3oool00`00olX0h_l0003oS0040?ooo`8005ko2@3oool0
0`008_l0oooo0?ooo`030?ooo`03003ok`3oool0oooo0080oooo00@00?la0:Go002Uo`00YOl00P00
obX00`2Uo`000>Wo001>o`02001>o`<0oooo00D000000?ooo`3oool0oooo003[o`02000000030?oo
o`130?l0oooo00H0oooo00@008;o05X0o`3oool0FP3o0`00ofTG0?ooo`0301l0o`3oool0oooo0080
7`3o2`3oool00`000000oooo0?ooo`0>0?ooo`00303oool00`000000oooo0?ooo`0U0?ooo`0302Co
0000ofT0oooo00<0oooo102Xo`090?ooo`0301[o003oool0oooo00/0oooo00L00000003oG000oe`0
0?mL0?ooo`00o`<0oid000<0oooo00D0X_l00?ooo`3oool0oooo003To`040?ooo`03003o5`3oool0
oooo00D0oooo00<00<Wo0?ooo`3oool01@3oool00`00Sol0oooo0?ooo`020?ooo`03003oK03oool0
oooo00809_l00P3oDP000`3oool007Wo0?ooo`020?ooo`03003obP00oh`0oooo00l0oooo00<002;o
0?ooo`3oool00`3oool01000onl0oooo09Wo0000okT3003o<@@0oooo00D00?lZ0?ooo`3oool0oooo
001>o`040?ooo`<0000000D00>_o0?ooo`3oool0oooo04<0o`050?ooo`8008;o0P00ofD00`1J0?l0
oooo003oJ@02003oJ@03003oI@3oool0oooo01<0oooo100O0?l2001jo`/0oooo00<000000?ooo`3o
ool03P3oool000`0oooo00<000000?ooo`3oool06P3oool3003oe0H0oooo0P0To`000`00ofT0oooo
0?ooo`050?ooo`80Z?l05`3oool00`00oe`00?[o0?ooo`020?ooo`030?nM003oool0oooo0080oooo
0P3`o`030?ooo`03003To`3oool0oooo0140oooo00H00?nh0?ooo`3oool0oooo0?ml0000of`30?oo
o`0502Ko001oo`00Ool00?ooo`00NOl00`3oool00`00olX0oooo0?ooo`0>0?ooo`03000Ro`3oool0
oooo00<0oooo00<00?o_0:?o002So`001000okT60?ooo`05003o:P3oool0oooo001>o`3oool01000
00030?ooo`03003[o`3oool0@`3o00@0oooo00<008;o003o/`3oool01@00ofD00`3oool00?mY003o
J@02003oJ@h0oooo00@001Ko0?ooo`3oool007[o0P3oool0100O0?l007[o001jo`00N_l>0?ooo`03
0000003oool0oooo00d0oooo000<0?ooo`030000003oool0oooo01X0oooo0P00om@60?ooo`0302Co
001ao`00LOl001d0oooo0P1Wo`020?ooo`03003oG000n_l0oooo0080oooo00<00?l30?ooo`3oool0
0`3oool00`3`o`00oooo003To`03003Toa00oooo0`00okP20?o[00030?ml003oool00?m/00<0oooo
00<09_l007oo0000NOl00P00NOl30?ooo`03003obP3oool0oooo00P0oooo00<00?oC0?ooo`3oool0
0`3oool01@008_l01Ol00?ooo`3oool00?o_0080VOl00P2So`03003o^@03000>o`3oool0oooo00@0
oooo00D00?lZ0?ooo`00000004ko000000030?ooo`060000003oool0oooo002Wo`3oool0@`3o103o
ool01000o`000?nc0?ooo`3oool3003oSPL0oooo0P00ofT;0?ooo`03000Fo`3oool0oooo00D007[o
4@3oool00`000000oooo0?ooo`0=0?ooo`00303oool00`000000oooo0?ooo`0I0?ooo`03003oe03o
ool00?oD00<0oooo0`1ao`000`3oool0LOl00?ooo`0L0?ooo`060>Go001Wo`00Iol00?ooo`00oe`0
oooo0P3oK`030?ooo`800?l31P3oool2003To`/0oooo00<00?mF0?ooo`3oool00`3oool01P2So`00
0?nh003o^000okP0oooo0?ml00800?m/0`3oool0100Vo`00oooo001io`00NOl80?ooo`03000ao`3o
ool0oooo00@0oooo00<00?oC0?ooo`3oool00P3oool01@008_l0<_l00?ooo`3oool008ko00<00?o_
0P3oool00`2So`0000ko003o^@050?ooo`<0000000<00?lZ03D0o`00C_l0103oool00`000000oooo
002Wo`020?ooo`0404<0o`00ok<0oooo003o/`@00?l000<0oooo003oSP00ohh02P3oool2003oJ@L0
oooo0P005_l30?ooo`<007[o4`3oool00`000000oooo0?ooo`0=0?ooo`00303oool00`000000oooo
0?ooo`0G0?ooo`03003oE000om@00?mD01d0oooo0`00oj440?ooo`05007o003oool0oooo06Oo003U
o`000P3oool01P00oe`0oooo003jo`3oool000000?ooo`800?l3203oool00`00i?l0oooo0?ooo`04
0?ooo`03002Ro`3oool0oooo0080oooo00<00?mF02go003oool00P3oool01@2So`00oooo003o^03o
ool0on/00080oooo0`00of`20?ooo`0402Ko003oool0oooo001io`P0oooo00<0037o0?ooo`3oool0
0`3oool00`00om<0oooo0?ooo`020?ooo`040?oO000bo`00<_l003;o008008ko0P00onl40?ooo`04
0:?o0000okT0oooo0?ooo`<000000`3oool00`0e0?l0oooo001>o`040?ooo`0300000000Yol0oooo
0080@`3o0`00ok<20?ooo`04003o003oool0oooo003o00<00?n>4@3oool010005_l0oooo0?ooo`00
n?l30?ooo`D00?So403oool00`000000oooo0?ooo`0=0?ooo`00303oool00`000000oooo0?ooo`0=
0?ooo`800;3o1`3oool2003oe003003oE03oool0oooo01`0oooo0`00oj430?ooo`80oo/000<0oooo
06Oo003oool00P3Uo`002@00oe`0oooo0?ooo`3oool00?[o0?ooo`000000oooo003o0`0?0?ooo`03
002Ro`3oool0oooo0080oooo0P0]o`00203oool0o`000:?o002So`00oooo003o^03oool0on/00P3o
ool2003oK0l0oooo00<0037o0?ooo`3oool00`3oool01000om<0oooo0?ooo`3oool200Go00030?oO
000bo`0008ko00<008ko1P3oool00`00okT00000000000060?ooo`0403D0o`3oool0oooo001>o`<0
oooo00<000000?ooo`130?l00`0No`02003o/`030?ooo`00ond00?o]00H0oooo00<00?n>0?ooo`3o
ool02`3oool010005_l0oooo0034o`00a?l6003hoaD0oooo00<000000?ooo`3oool03@3oool000/0
oooo00<000000?ooo`3oool0303oool3002`o`L0oooo00<00?oD003oE03oool0703oool00`0;o`00
oooo0?ooo`02003oX@80oooo0P3on`020?ooo`0506Oo003oool0oooo0?ooo`3Uo`00103oool2003j
o`030?ooo`000000oooo00l0oooo00<00:;o0?ooo`3oG@000P3oool202go00030?ooo`3o0000oooo
0080Xol000<00?nh002?o`3oool04P3oool00`0Yo`00oooo0?ooo`020?ooo`040?og0000ogh0oooo
0>Ko0080oooo0P05o`000`008_l0oooo002>o`02002>o`@0oooo0`0000001@00okT0oooo0?ooo`3o
ool00;oo00<0oooo00D0=@3o0?ooo`3oool0oooo001>o`03002Wo`0300000000o`L00?l700<07_l0
0P3oool4003ok@H0oooo00<00?n>0?ooo`3oool00`3oool00`00>ol0oooo0?ooo`030?ooo`<00<Co
00<00?n`0?ooo`3oool00P00n?lH0?ooo`030000003oool0oooo00d0oooo000;0?ooo`030000003o
ool0oooo00`0oooo0`00/?l50?ooo`800?mD7P3oool200_o00030?ooo`00oj40om4000<0om40103o
ool00`01o`00oooo0?ooo`050?ooo`<00?[o0P3oool00`000000oooo0?ooo`080?ooo`<00?o90P3o
m`000`00X_l0oooo0?mM00020?ooo`0302go003oool0oooo00<0oooo00@00?nh002?o`00Sol008oo
303oool00`00ol40oooo0?ooo`030?ooo`0302Wo003oool0oooo0080oooo1000ogh20?ooo`<002;o
00D0oooo03;o003oool008ko0?ooo`030000000702d0o`3oool0oooo0?ooo`00okT0oooo002oo`04
0?ooo`0503D0o`3oool0oooo003oOP00C_l00P00Yol00`00o`L00000003o1`0204<0o`0401ko003o
ool07_l00?ooo`<00?o]203oool01@00ohh0oooo0?ooo`3oool003_o0080oooo1000a?l00`005_l0
0?n`003o/003003o/1X0oooo00<000000?ooo`3oool03@3oool000/0oooo00<000000?ooo`3oool0
2`3oool00`00/?l0oooo002`o`0U0?ooo`0400_o003oool02ol0003oX@<0oooo0P3od@040?ooo`80
0Ol01`3oool00`00n_l0oooo0?ooo`020?ooo`030000003oool00;7o00<0oooo00@00?m:0?ooo`3o
ool0oooo0`00olT20?og0007002Ro`3oool0oed00?ooo`00oeH0;Ol0003oEP040?ooo`03003o^000
Sol008oo00L0oooo00<003go0?ooo`3oool00`3oool00`00ol40oooo0?ooo`020?ooo`0302Wo0000
<Ol0oooo0080oooo00@00?oC003oOP00ogh00?mn0`3oool2000Ro`<0oooo00<0<_l0002>o`000000
0`3oool01`0]0?l0oooo0?ooo`3oool00?ni0?ooo`00_ol00`3oool4003oOP0307;o003oool00?lE
00800?lE00@000000?ooo`3oool008Ko0`3oool201ko00030?ooo`00ond0oooo00P0oooo00<00?n>
000ko`00>ol00P3oool30034o`@0oooo0P00ok020?ooo`D00?n`5@3oool00`000000oooo0?ooo`0=
0?ooo`002`3oool00`000000oooo0?ooo`0:0?ooo`03002`o`3oool0oooo01`0oooo0`00ooh40?oo
o`80S_l000@02ol00?ooo`3oool00?nQ0P2io`090?ooo`03007o003oool0oooo00/0oooo00H00000
002ao`3oool0oooo00So0000odX40?ooo`05003ob@3oool0ooL00?ooo`00X_l00`3oool00`0]o`00
0?mF0?ooo`040?ooo`03003o^03oool0oooo00L0oooo00<003go0?ooo`3oool00P3oool00`00ol40
oooo0?ooo`020?ooo`0306[o0000/?l0037o00@0oooo00<00?oC003oOP3om`001@3oool300000003
03;o0000S_l0oooo0080oooo00<0;@3o0?ooo`3oool00`3oool01@00_ol0oooo0?ooo`3oool0=@3o
00800?mn00@0oooo07;o001bo`00L_l00`00oaD00`000000oooo0026o`020026o`@0oooo00<07_l0
0?ooo`00ond0203oool00`00>ol0oooo003oZ@020?ooo`04003oZ@00ohL00?n7003oQaT0oooo0P00
>?l70?ooo`030000003oool0oooo00`0oooo000;0?ooo`030000003oool0oooo00P0oooo0P00/?lN
0?ooo`<00?on1@3oool01@2>o`002ol00?ooo`3oool00?nQ0080oooo0P2io`0G0?ooo`09002ao`3o
ool02?l000So0000odX0oooo0?m4003oool00?o90080[ol000<0ooL00?ooo`00X_l00`3oool00`0]
o`00oooo0?ooo`0>0?ooo`03000mo`3oool0oooo0080oooo00D00?o10?ooo`3oool0oooo06[o0002
002`o`03000ao`3oool0oooo00<0oooo00@00?mn0?ooo`3oool0oooo0`0000040?ooo`07002>o`3o
ool0oooo0?ooo`0]0?l0oooo003oF`020?ooo`04002oo`3oool0oooo0?ooo`80@Ol00`00ogh40?oo
o`800?lE00<000000026o`00Q_l00`00Q_l30?ooo`03001Bo`3oool00?o]00D0oooo00@003_o003j
o`00>ol0oooo1000ojT0103oool00?n7003oQ`00ohLB0?ooo`04000ho`3oool0oooo0?ooo`<003So
2@3oool00`000000oooo0?ooo`0<0?ooo`002`3oool00`000000oooo0?ooo`070?ooo`03002`o`3o
ool0oooo01d0oooo00@00?mU0?ooo`00ooh00?on0P3oool0102ko`00S_l008ko000;o`0O0?ooo`06
0?n7000000002?l000So0000odX0od@00P3oool01000olT0oooo0:oo003oool3002Roa40oooo00<0
??l0000mo`3oool00`3oool00`3ojP000?o10?ooo`020?ooo`@00;3o1P3oool00`00ogh000000000
00050?ooo`03003=o`3oool008ko0080oooo00@0;@3o0?ooo`00oe/0oooo0P00_ol00`3oool0@Ol0
047o000209?o000303D0o`00oh`0oooo00H0oooo00<00?lE0000003oool00`00Q_l30?ooo`05001B
o`3oool0oooo0?ooo`00ond00`3oool2003jo`8003_o0P3oool2003oZ@<0oooo1000ohL?0?ooo`D0
03So303oool00`000000oooo0?ooo`0<0?ooo`002`3oool00`000000oooo0?ooo`060?ooo`03002`
o`3oool0oooo01`0oooo0P00ofD00`3oool00?on0?ooo`030;_o000308ko002ko`00oooo01L0oooo
00D00?m80?ooo`00oo/0oooo0:?o00020<Go0080oooo00@00;7o00So00000000oooo0`00odX00`00
olT0oooo0?ooo`030?ooo`03002Ro`3oool0oooo00D0oooo00<004Ko0?ooo`3oool00P3oool00`00
okH0oooo0?ooo`020?ooo`0303co003oool003go0080oooo00@00?mV0?oZ0000ol400?o10`3oool3
002`o`@0oooo0`0000000`00ogh0:@3o0?ooo`040?ooo`04003=o`3oool0oooo002>o`80oooo00@0
;@3o003oF`3oool0oooo0P00_ol2047o00040?ooo`2Co`00Tol003D0o`800?n<0`3oool01@0W0?l0
oooo0?ooo`3oool0000000<0oooo00@008Ko0?ooo`3oool005;o103oool01P00ond00?[o003jo`00
n_l003_o003o?`@0oooo00<00?nF0?ooo`3oool01P3oool2003oQ``0oooo1000>?l>0?ooo`030000
003oool0oooo00`0oooo000:0?ooo`030000003oool0oooo02H0oooo0P00ofD00`00ooh0oooo0?oo
o`0M0?ooo`03003oB000oo/00?ok0080oooo0P35o`030?ooo`0300So003oool0000000800?m:00<0
oooo003ob@3oool0303oool00`00A_l0oooo0?ooo`020?ooo`03003o]P3oool0oooo0080oooo00<0
??l00?ooo`00?Ol00`00ofH3003o`@@0oooo0P00/?l0103oool000000000000000030?ooo`03003o
OP0Y0?l0oooo00@0oooo00@00<go0?ooo`3oool008ko0`00oe/30?ooo`<00;oo103oool01@2Co`00
0?n<003oS000oh`0oooo00@09`3o00<0oooo00000000oaD00P3oool00`00Q_l0oooo001Bo`040?oo
o`800?[o00<00?o]0?ooo`3oool01000ocl20?ooo`<00?nF203oool2003oQ`P0oooo0P00/Ol20?oo
o`D00;7o2`3oool00`000000oooo0?ooo`0<0?ooo`002P3oool00`000000oooo0?ooo`0J0?ooo`@0
093o1@3oool200go0003003oI@3oool00?on0200oooo0`00oo/20?ooo`050<Go002So`00oooo0?oo
o`08o`000P00/Ol0103oool00000003oBP00olT>0?ooo`030016o`3oool0oooo0080oooo00@00?nf
0?ooo`3oool0oooo0P0lo`02000mo`050?ooo`00ofH00?mV0?no0000ol401@3oool00`00/?l00000
000000060?ooo`03003oOP3oool0oooo00<0oooo00D00<go0?ooo`3oool0oooo02d0o`02003oF`80
c_l00P19o`000`3>o`00oooo0?ooo`060?ooo`03003oS03oool09`3o00D09`3o00L000000?ooo`00
oaD00?oR0?ooo`00Q_l005;o00@0oooo00<00?[o003oH000of000`3oool00`00ocl0oooo0?ooo`02
003o?`<00?nF3P3oool2001bo`H00;7o403oool00`000000oooo0?ooo`0<0?ooo`002P3oool00`00
0000oooo0?ooo`0J0?ooo`<0093o1P3oool0100=o`000?mU0?ooo`00oohL0?ooo`<00?ln0P3oool3
003on`040?ooo`35o`00Xol00:?o0080oooo00<02?l0002ao`3oool00P3oool00`0000000?o90?oo
o`0=0?ooo`050016o`3oool0oooo0?ooo`00okH00P3oool0101do`00oe400?mA000lo`03000mo`03
0?ooo`00ofH0okl000<0oooo0`0000000`00/?l0oooo0?ooo`060?ooo`0302T0o`00odP0oooo00<0
oooo00D00<go0?ooo`1bo`00oooo02d0o`02003oF`0402d0o`3>o`00BOl004Wo0080oooo00<00<ko
0?ooo`3oool0103oool00`00oh`0oooo02L0o`0402L0o`040?ooo`000000oooo003ohP8005;o00<0
08Ko0?ooo`00of000`00of02003o3@`0oooo00<00?nF0?ooo`3oool0103oool01000L_l0oooo0?oo
o`3oool3001bo`<0oooo0`00/OlB0?ooo`030000003oool0oooo00`0oooo000:0?ooo`030000003o
ool0oooo01P0oooo0`00onD2002@o`@0oooo0P0=o`000`00ofD0oooo003ooP0M0?ooo`800?ln0P3o
ool01P3o_0000?ok003oB000odP0oooo0<Go00D0oooo00<00;7o0?ooo`3oool00P3oool00`000000
oooo001>o`040?ooo`03003o/`3oool0oooo0080oooo00H0?_l00?ooo`3oool004Ko0?ooo`3ohP02
003o]P030?ooo`00/Ol0M?l000<0oooo0P00?Ol0103oool00?mV0?ooo`3oool30000000402P0o`3o
ool0oooo002`o`80oooo00<00=?o0?ooo`3oool00`3oool01@00odP0oooo0?ooo`3oool00<go00<0
L_l00`3oool202d0o`<0oooo00<0BOl00?ooo`00c_l00P00c_l60?ooo`03003oS000G?l0oooo0080
9`3o0P3oool00`0000000?oR0?ooo`02001Bo`040026o`00of000?mP003oH080oooo0`00o`d20?oo
o`<00?oL1`3oool00`00oiH0oooo0?ooo`020?ooo`D007;o00<0oooo003ol`00oo<00P00oo<G0?oo
o`030000003oool0oooo00/0oooo000:0?ooo`030000003oool0oooo01P0oooo0P00onD00`00T?l0
oooo0?ooo`020?ooo`803Ol000<0oooo003oI@3oool05P3oool01000^?l0oooo0?ooo`3oool3067o
0080oooo00D00?ln0?oL003og000oooo003on`03003oB0d0oooo00<00000001>o`3oool00`3oool0
0`00ok<0oooo0?ooo`020?ooo`0403ko003oool004Ko0?o=0080on800P00okH2002ao`0807Co003o
ool0oooo0?ooo`00?Ol0oooo00000000ofH2000000<0oooo00@0:03o0?ooo`3oool00;3o0P3oool0
0`00dol0oooo0?ooo`020?ooo`0302T0o`00odP0oooo0080oooo00D00<go07;o003/o`00k?l0003o
B`080?ooo`@00<ko1P3oool01@00oh`005co0?ooo`0W0?l0oooo00<00?oR00D000000?ooo`00D_l0
05;o0026o`050?ooo`05003o3@3oool0oooo003o3@3oool00`00om`80?ooo`04003oUP3oool0oooo
0?ooo`@007;o0`3oool6003ola@0oooo00<000000?ooo`3oool02`3oool000X0oooo00<000000?oo
o`3oool03@3oool2000Ao`T0oooo00<00?oU002@o`3oool07@3oool3002ho`@0oooo00@0HOl007oo
001oo`000?ln103oool01000oo/0oooo003oB000odP>0?ooo`03001>o`3oool0oooo0080oooo00L0
0?nc0?ooo`3oool0oooo03ko003oool00?me0080old00`3oool4002ao`80oooo0`0000000`3oool0
0?mV0?ooo`040?ooo`0302P0o`3oool00;3o0080oooo00<00=?o0?ooo`3oool00P3oool2003oB0@0
oooo0P00cOl00`3oool00?m;003oB`02003oB`H0oooo00<0BOl00?ooo`00c_l01`3oool01@00G?l0
0?n<0?ooo`0W0?l0oooo00800?oR00L0oooo0000000Ko`006ol00?ooo`00ob8008Ko00P0oooo00<0
0?l=003og000om`01`3oool01@00V?l0oooo0?ooo`00oiH00?ko0080oooo1000o_l30?ooo`03003o
l`3oool0oooo0080oooo0`00oo<A0?ooo`030000003oool0oooo00/0oooo00090?ooo`030000003o
ool0oooo00`0oooo10004Ol70?ooo`800?oU00<0093o0?ooo`3oool06`3oool00`00oih0oooo002h
o`02002ho`050<Co003oool0oooo067o003oool00P1oo`001@00och0oooo0?ooo`3oool00?ok0180
oooo00D004ko0000003oool0oooo003o/`020?ooo`030?n0003oool0?_l000800?me00<0old00016
o`3oool00`3oool2002ao`<00000103oool00`00ofH0oooo0?ooo`020?ooo`0402P0o`3oool0oooo
002`o`80oooo00P00=?o0?ooo`3oool0oooo02T0o`3omP00Pol002T0o`H0oooo0`00od/00`3oool0
00So0?ooo`020?ooo`05001Mo`3oool0oooo04Wo0000c_l00`3oool02@00oll0oooo001Lo`00G?l0
oooo003oS03oool00?l^02L0o`03003ohP070000000Ko`00oooo01_o0000ob8008Ko003o8P030?oo
o`03002]o`3oool0oooo00<0oooo00<00?l=003og03oool00`3oool2002Ho`80oooo1@00o_l0103o
ool00?nn003o_P00okhL0?ooo`030000003oool0oooo00/0oooo00090?ooo`030000003oool0oooo
00d0oooo0P004Ol70?ooo`03003oi@3oool0093o01`0oooo0P00oih20?ooo`<00;So00<0a?l00?oo
o`1Qo`000`3oool00`00och0oooo0?ooo`020?ooo`03003on`3oool0oooo0100oooo00H004ko0?ko
00000000oooo04oo003oool20?n000030?ooo`0no`000?me00800?me103oool0100000000;7o07Co
000W0?l50?ooo`03003Co`00ofH0oooo00<0oooo00L00?m30?ooo`3oool00;3o0?ooo`00dol0R?l0
00<0oooo00D0:@3o003oB023o`00Pol00?of00070?ooo`06003oB`002?l000So0008o`3oool005go
103oool01@00c_l0oooo0?ooo`00oll0oooo008005co1000obh00`3oool09`3o0?ooo`020?ooo`04
0000003oool0oooo0?ooo`<00?lR0P3oool3002]o`H0oooo00@00?oL0?ooo`00V?l009So1@3oool2
003no`<0oooo0`00okhL0?ooo`030000003oool0oooo00/0oooo00090?ooo`030000003oool0oooo
00`0oooo00<0017o0?ooo`004Ol01P3oool00`00onD0oooo002@o`0J0?ooo`03003o5@3oool0oooo
00800?nN0P2ko`001@00^?l0oooo0?ooo`3oool0HOl000<0oooo00<00?ln0?ooo`3oool00P3oool0
0`00oo/0oooo0?ooo`080?ooo`03003o]P3oool0oooo0080oooo00L0;ol00?ooo`3oool0oooo001>
o`3no`0009Co00<0Col0103oool01000ogD0oooo0016o`3oool300000004002ao`3oool0oooo02L0
o`D0oooo00<00=?o0?ooo`3oool00P3oool00`00od<0:03o0?ooo`020?ooo`80R?l000<00=?o0?oo
o`3oool00P3oool0100Y0?l0Pol008?o0000mOl70?ooo`D000So00<005go0?ooo`3oool00`3oool0
1000c_l00?o?0?ooo`3oool2001Lo`800?l^00@0oooo05Go001Eo`009`3o0`3oool00`000000oooo
0?ooo`030?ooo`03003o8P3oool0oooo00@00:go103oool2002Ho`05003og03oool0oooo0?ooo`00
oiH02@3oool01000okh0oooo003o_P00okh;0?ooo`03001Lo`3oool0oooo00`0oooo00<000000?oo
o`3oool02`3oool000T0oooo00<000000?ooo`3oool02`3oool00`004Ol0oooo0?ooo`060?ooo`03
003oi@3oool0093o01@0oooo0P00Eol40?ooo`800?lE00<0oooo003oWP3oool00P3oool00`00^?l0
oooo0?ooo`0F0?ooo`03003o]P3oool0oooo0080oooo00@0;ol00>_o003[o`0004ko0`00U?l00`1?
o`000?nc003o/`040?ooo`04003oM@0000000000000000<0oooo00@00;7o0?ooo`3oool09`3o103o
ool00`00dol0oooo0?ooo`030?ooo`03003o@`0X0?l0oooo0080oooo0P3oj0070?ooo`800?Go1`3o
ool40008o`03001Mo`3oool0oooo0080oooo0P00oll01000c_l0oooo0?ooo`3oool2001Lo`@0oooo
00H0EOl002L0o`3oool00?mj0?ooo`0000060?ooo`03003o8P3oool0oooo00<00:go0`3oool3002H
o`03003og03oool00?nF00<00?nF0`3oool00`00okT0oooo0?ooo`060?ooo`800?nn203oool3001L
o`80oooo1@00G?l60?ooo`030000003oool0oooo00/0oooo00090?ooo`030000003oool0oooo00X0
oooo00<0017o0?ooo`3oool0703oool4001Go`<0@?l000D00?lE0?ooo`00oaD0oooo003oWP020?oo
o`03002ho`3oool0oooo01L0oooo00H00?nf0?ooo`3oool0oooo003oY@0_o`020>_o0007001>o`00
U?l009Co002Do`1?o`00oooo000000020?ooo`80000000<00?me0?ooo`3oool0103oool01000/Ol0
oooo0?ooo`0W0?l40?ooo`04003Co`3oool0oooo0?ooo`<00?m30P0X0?l20?ooo`030?oX0000obl0
oooo00D0oooo1000mOl60?ooo`05003oB`3oool000So0?ooo`00GOl0103oool2003oc`03003>o`1K
o`00oooo00P0oooo00D09`3o05Go0000ogX00?mj000000070?ooo`05003o8P00[?l0oooo002]o`00
ol`0103oool2003oc0030?ooo`00om`0oooo00800?nF00@0oooo003oUP00oiH00?nF0`00okT80?oo
o`800?nn1@3oool6001Lo`/0oooo00<000000?ooo`3oool02`3oool000T0oooo00<000000?ooo`3o
ool02@3oool00`004Ol0oooo0?ooo`0L0?ooo`05003^o`00Eol005Oo001Go`3oool00P10o`001@3o
ool00?lE0?ooo`3oool00?nN00<0oooo00<00;So0?ooo`3oool0603oool01`3og`000?nU003oY@00
ojD0;ol00>_o003oool00P00C_l2002Do`0704oo003oool0oooo0000000W0?l0oooo003oM@020?oo
o`03003>o`3oool0oooo0080oooo00@00;7o003oB`3oool09`3o0`3oool00`23o`000=?o0?ooo`02
0?ooo`80onP000@00?m302P0o`3oool0oooo1000obl60?ooo`800?Go1P3oool01@00olX0oooo003o
B`002?l005go00<0oooo00D00?lC0?ooo`3oool0oooo003>o`0205_o000303Ko001Ko`00oooo00D0
oooo00D09`3o0?ooo`00ogX00?mj000000030?ooo`03000?o`3oool0oooo00800:co00<00?lR0?oo
o`00[Ol01@00ol`40?ooo`03003og03oool0oooo00@0oooo0`00okTA0?ooo`8005co3P3oool00`00
0000oooo0?ooo`0:0?ooo`002@3oool00`000000oooo0?ooo`080?ooo`03000Ao`3oool0oooo01/0
oooo0P00k_l20?ooo`8005Oo00@0@?l00?ooo`3oool00?lE0P3oool01@00oih0oooo0?ooo`3oool0
0;So0140oooo00<04Ol00?ooo`3oool00P3oool20<7o000400Go003oool0oml00?oO00<00?nU00L0
jol00?ooo`3oool0oooo002Do`3oool0Col000<0oooo00@0000002L0o`3oool00?me0P3oool02000
c_l0oooo0?ooo`3oool00;7o0?ooo`00od/09`3o0P3oool208?o00800=?o0P3oool0102=o`00onP0
0?oX000X0?l40?ooo`800?l_00<001co0?ooo`3oool0103oool00`00F?l00?Go0?ooo`040?ooo`05
003obP3oool0oooo003oB`002?l01000oa<40?ooo`03003>o`3oool0oooo0080=_l01P3oool00`0W
0?l0oooo0?ooo`0200000080oooo0`003ol00`00[?l0oooo0?ooo`030?ooo`03002]o`00ol`00?o<
0080oooo0P00oeH<0?ooo`03003o^@3oool0oooo00P0oooo1000^?lB0?ooo`030000003oool0oooo
00X0oooo00080?ooo`030000003oool0oooo00P0oooo00<0017o0?ooo`3oool06@3oool3003oU`80
0>ko00<0oooo001Go`10o`000`3oool01000oaD0oooo0?ooo`00oih40?ooo`03002ho`3oool0oooo
0100oooo00D04Ol00?ooo`3oool0oooo0<7o000200Go0080oooo00<00?nf003oY@3oool01@3oool0
0`00U?l0oooo04oo00030?ooo`040000000W0?l0oooo003oM@80oooo00H00<ko0?ooo`3oool0oooo
002ao`00od/202L0o`80oooo0P23o`001000dol0oooo0?ooo`3oool208go00L0oooo0P007?l60?oo
o`03003eo`3oool0oooo00<0oooo00H00?o:0?ooo`3oool0oooo0008o`00GOl2003o4`80V?l0203o
ool0100fo`00oooo0?ooo`00nOl30?ooo`<0000000@0oooo003oNP000000oooo10003ol50?ooo`03
002]o`3oool0oooo0080oooo0`00oeH30?ooo`03003oi@3oool0oooo00H0oooo00<00?ni0?ooo`3o
ool0203oool7002ho`h0oooo00<000000?ooo`3oool02P3oool000P0oooo00<000000?ooo`3oool0
1`3oool00`004Ol0oooo0?ooo`0C0?ooo`806P3o1P3oool01@00oiL00>ko0?ooo`3oool005Oo00`0
oooo00<00;So0?ooo`3oool04@3oool208Co0004001Jo`3oool0oooo00Go00@0oooo00<00?nU0?oo
o`3oool00`3oool00`00U?l0oooo0?ooo`040?ooo`030000000W0?l0oooo00<0oooo00@00<ko0?oo
o`3oool0oooo0`00od/202L0o`80ooP01@3oool00`2=o`000?_o0?ooo`050?ooo`04003o;`007?l0
01co000Lo`@0oooo00<005So003eo`3oool00`3oool2003obP<0oooo00@000So0?ooo`3oool0oooo
0P2Ho`090?ooo`0303Ko0000nOl00?Wo00<00000103oool00`00ogX0oooo00000003000?o`040?oo
o`00oe400?mA003oD@80oooo00<00:go0?ooo`3oool01@3oool2003oEP040?ooo`00onD00?oU003o
i@L0oooo00@00?ni002Ho`3oool0oooo1000V?l30?ooo`03002ho`3oool0oooo00<0oooo0`00^?l;
0?ooo`030000003oool0oooo00X0oooo00080?ooo`030000003oool0oooo01/0oooo100J0?l50?oo
o`05003oU`00k_l0oooo0?ooo`00Eol07@3oool01000oo80oooo0?ooo`3oool3001Jo`030?ooo`05
o`00oooo00<0oooo00<00?nU0?ooo`3oool0103oool00`00U?l0oooo0?ooo`040?ooo`030000000W
0?l0oooo00<0oooo00@00<ko0?ooo`3oool0mOl00P00od/202L0o`03003o?03on000oooo00@0oooo
0`00nol30?ooo`03001>o`3oool0oooo008001co00<0oooo000Lo`3oool00P3oool2001Ho`03003e
o`00o`h0oooo0080oooo00<00?o:07_o001ko`000P3oool00`002?l0oooo0?ooo`030?ooo`0309So
0000ocL0oooo00D0oooo100000000`00nOl00;3o0?ooo`020?ooo`09003o[@3oool0oooo003oNP00
00000?n]0?ooo`003ol0oooo00800?mA00D0oooo003oD@00odh00:go003oD@080?ooo`03003oEP00
onD00?oU00L0oooo0P00V?l00`00okT009So002Ho`030?ooo`03003eo`3oool0oooo01D0oooo00<0
00000?ooo`3oool02P3oool000P0oooo00<000000?ooo`3oool0603oool3001^o`<06P3o103oool2
003oU`040?ooo`00k_l0oooo001GoaX0oooo00<0LOl00?ooo`00oo800P00oo820?ooo`0608Co0000
F_l005[o001Jo`3oool01Ol0103oool00`00ojD0oooo0?ooo`030?ooo`03002Do`00aOl0oooo00<0
oooo00L00?mM0?ooo`0000009`3o0?ooo`1Vo`00oooo00<00<ko0P3eo`030?ooo`800?ll00<0ooP0
0?ooo`3oool00`3oool3003ko`<0oooo00@004ko0?ooo`3oool00?l_0`007?l30?ooo`800?l>00<0
0?Go0?ooo`3oool00`3oool01@1ko`00J_l007_o001ko`0000So00D0oooo0`00ocL20?ooo`<00000
0P3oool00`0fo`00oooo003io`040?ooo`<00?n]00D00?mj0?ooo`000000oooo000?o`050?ooo`80
0?m>00<00:go0?ooo`3oool02@3oool00`00onD0oooo0?ooo`050?ooo`8009So00@00?ni0?ooo`3o
ool0oooo0`00mOlF0?ooo`030000003oool0oooo00X0oooo00080?ooo`030000003oool0oooo01T0
oooo0P00K_l00`3oool06P3o01X0o`030?ooo`04003oU`3oool0oooo003^o`80oooo00<005Oo0?oo
o`3oool05@3oool3003oG003077o003oool0/?l000800?ob0P3oool01@24o`0005[o001Jo`00F_l0
1Ol000@0oooo00<00?nU0?ooo`3oool0103oool00`00U?l00<Go0?ooo`030?ooo`04003oG@3oool0
9`3o02L0o`<0I_l00P00c_l00`1Xo`00oooo0?ooo`030?ooo`<00?ll1P3oool01@00nol0SOl00?oo
o`3oool004ko00<0oooo00<00?l_000Lo`00om40103oool2003o3P03003eo`3oool0oooo00@0oooo
0P1Zo`000`3oool000So0?ooo`060?ooo`<0000000@004Ko0?ooo`3oool0oooo0`00/?l00`00nOl0
oooo0?ooo`020?ooo`800?n]00H0oooo003o1`00ogX00?l7000000003ol60?ooo`03003oCP00[Ol0
oooo00<0oooo00<00;ko0?ooo`3oool01@3oool00`00onD0oooo0?ooo`02003oo0P0oooo1000mOlE
0?ooo`030000003oool0oooo00X0oooo00080?ooo`030000003oool0oooo01T0oooo0P00K_l00`0J
0?l0oooo0?ooo`020?ooo`04003oU`3oool0oooo003^o`80oooo00<005Oo0?ooo`3oool04`3oool2
00oo0080oooo0P00oe`20?ooo`07003olP3oool00?ob0?ooo`24o`00oooo001Jo`020?ooo`0300Go
003oool0oooo0080oooo00<00?nU0?ooo`3oool00`3oool00`00U?l0oooo0035o`040?ooo`03003o
G@3oool09`3o00809`3o00<0I_l00?ooo`3oool00`1Xo`050?ooo`03000Ao`3oool0oooo00D0oooo
00D00?_o0?ooo`3oool0oooo001>o`030?ooo`03003o;`007?l00?oA00D0oooo00<0/_l0003eo`3o
ool01@3oool206[o00030?ooo`002?l0oooo00<0oooo0`0000001000ocL0oooo0016o`00A_l30?oo
o`800;3o00<0oooo003io`3oool01P3oool3003o1`030?ooo`000000oooo00L0oooo00@00?m>0?oo
o`3oool0oooo0P00__l70?ooo`03003oi@00oo`00?ol00800?ol2`3oool3003eoa80oooo00<00000
0?ooo`3oool02P3oool000P0oooo00<000000?ooo`3oool03P3oool209/0o`P0oooo00<006ko0?oo
o`0J0?l01`3oool01000k_l0oooo0?ooo`00EolB0?ooo`0603[o003oool0oooo00oo00002_l03ol0
0P3oool01@00oe`0oooo0?ooo`3oool00?ob00@0oooo00<005[o0?ooo`3oool0303oool01000U?l0
oooo0035o`00aOl20?ooo`<00?mM0P37o`001P0W0?l0oooo0?ooo`3oool00=oo06So00D0oooo0P00
4Ol50?ooo`03003oh@00nol0oooo00<0oooo00D004ko0?ooo`3oool0oooo000Lo`02003od@D0oooo
0P2bo`070?ooo`0406[o003oool000So0?ooo`<0000000@00:Wo0?ooo`3oool00?lg1000A_l01`00
oj80oooo002`o`00/?l00?lX003io`00obP01`3oool01@00o`L0oooo003o1`003ol0000000P0oooo
00<00?m>0?ooo`00__l00`00__l00`3oool00;co002lo`02002lo`040?ooo`00onD0oooo003oo080
oooo0P00oo`3003olPT0oooo0P00mOlA0?ooo`030000003oool0oooo00T0oooo00070?ooo`030000
003oool0oooo00d0oooo102K0?l70?ooo`03001^o`3oool06P3o01d0oooo00<00:_o03[o000jo`00
0`002_l20?ooo`05003oG03oool0oooo0?ooo`00oo801@3oool00`00F_l0oooo0?ooo`060?ooo`03
003oNP3oool0oooo00@0oooo0P00aOl20;;o0080oooo00@00?mM0?ooo`000000aol00`3oool2003O
o`D0oooo10004Ol40?ooo`04003oh@00nol0oooo0?ooo`8004ko00D00?lL0?ooo`3oool0oooo000L
o`0307Wo00D0oooo00<00?lJ0?ooo`3oool01@3oool400000080oooo00D00:Wo0?ooo`3oool0oooo
003o=`040016o`@0oooo00<00?lX003io`3oool00`00obP70?ooo`04000?o`0000000?n5003oQ@L0
oooo00@00?m>002no`00__l00;ko0P00_?l60?ooo`03003oi@3oool0oooo00<0oooo1000oo8<0?oo
o`03001Go`3oool0oooo00`0oooo00<000000?ooo`3oool02@3oool000L0oooo00<000000?ooo`3o
ool03P3oool209/0o`L0oooo00<006ko0?ooo`0J0?l06P3oool00`00oll0oooo002[o`02002[o`03
03[o00002_l000[o008000[o00<0oooo003oG03oool00`3oool00`00oo80oooo0?ooo`020?ooo`03
001Jo`3oool0oooo00L0oooo00@00?mj0?ooo`3oool0oooo0P0go`020?ooo`030035o`2bo`00/_l0
00<0oooo00<00?m/0<Oo003oool00P3oool3003Oo`D0oooo10004Ol30?ooo`03003oh@3oool00?_o
0080oooo0P00oa`01P00C_l0oooo0?ooo`3oool001co07Wo00H0oooo0P00oaX0102bo`00oooo0?oo
o`3oool3000000@00?oJ00<0oooo002Yo`3oool0103oool00`00ocL004Ko0016o`070?ooo`04003i
o`3oool00?l2003o0PP0oooo00<000oo0000003oool0203oool01000odh0oooo002no`00_?l20?oo
o`<00?nc0`3oool00`00onD0oooo0?ooo`030?ooo`<00?ob2P3oool4001Go`d0oooo00<000000?oo
o`3oool02@3oool000L0oooo00<000000?ooo`3oool03@3oool00`2K0?l0oooo09/0o`060?ooo`03
001^o`3oool06P3o01L0oooo00<00?m_0?ooo`00oll00P00oll0103oool0>_l0002[o`00Zol20?oo
o`<000[o00<0oooo003oG03oool00P3oool00`00oo80oooo0?ooo`030?ooo`03001Jo`3oool0oooo
00L0oooo0P00ogX30?ooo`80=ol000<08?l00?ooo`3oool00P3oool3003oK0030<Oo003oool0oooo
0080oooo0P00gol50?ooo`<0017o0`3oool2003oh@030?ooo`00nol0oooo00<00?lL103oool00`00
7?l0LOl00?ooo`050?ooo`<00?lJ0`0000040?ooo`0306[o0000omX00:Wo00800:Wo1@3oool01000
ocL00?nR0016o`0Vo`060?ooo`04003io`3oool00?l2003o0PP0oooo00<000oo003oQ@000000103o
ool00`00=ol00?o;0?ooo`040?ooo`04002no`3oool0oooo0?ooo`<00?nc2`3oool00`00oo80oooo
0?ooo`080?ooo`L005Oo2@3oool00`000000oooo0?ooo`090?ooo`001`3oool00`000000oooo0?oo
o`0<0?ooo`0309/0o`3oool0oooo00H0oooo00@006ko0?ooo`3oool06P3o5@3oool3003oK`0:0?oo
o`00oll00?o?003oc`3oool00:_o0?ooo`00Zol0oooo000:o`<0oooo00<00?mL0?ooo`3oool00P3o
ool00`00oo80oooo0?ooo`020?ooo`03001Jo`3oool0oooo00L0oooo0P00ogX206_o00<0oooo0P0P
o`050?ooo`800?m/00<00000000co`3oool00P3oool00`00gol0oooo0?ooo`040?ooo`03000Ao`00
oc`0oooo0080oooo0`00on401000nol0oooo0?ooo`2Po`050?ooo`04000Lo`1ao`00LOl0077o00D0
oooo0`0000000`00VOl005oo0?ooo`050?ooo`04003ofP00ZOl00:Wo003o6PL0oooo00<004Ko02Ko
000Vo`001@3oool01`00nOl0oooo0?ooo`3oool00?l20?ooo`00oo801@3oool01P003ol0oooo003o
Q@0000000<co0?ooo`<003Oo00<00?o;0?ooo`3oool00P3oool00`00__l0oooo0?ooo`020?ooo`06
003o/`3oool00?nc003o/`3oool00?[o203oool00`00oo80oooo0?ooo`080?ooo`03001Go`3oool0
oooo00<0oooo0`00Eol60?ooo`030000003oool0oooo00T0oooo00070?ooo`030000003oool0oooo
00/0oooo00<0V`3o0?ooo`3oool01P3oool01000K_l0oooo0?ooo`0J0?lD0?ooo`80F@3o0`00ofl0
1@00oll0oooo0?ooo`3oool00:_o00@0oooo00<000[o0?ooo`3oool01@3oool00`00oo80oooo0?oo
o`030?ooo`03001Jo`3oool0oooo00@0oooo00@0G?l00?ooo`3oool0oooo0`1[o`030?ooo`03023o
003oool0oooo0080oooo0P0D0?l01000of`0oooo00000000<ol20?ooo`03003Oo`3oool00?og00D0
oooo00<0017o0011o`00@Ol00P3oool0101Ko`000?oQ003oh@00nol20?ooo`80X?l0103oool01000
7?l0oooo077o0000om420?ooo`<0000000<0oooo003o6P00VOl00P00Gol50?ooo`04003oZ@00omX0
oooo0?ooo`@00?lJ0`3oool01000A_l0oooo02Ko000Vo`090?ooo`04003o0P3oool00?ob003olP<0
oooo00L00<co000?o`00c?l00?n50?ooo`000000oooo00@003Oo1000ol/00`3oool00;ko0?ooo`06
0?ooo`04003o/`00n_l00?[o003jo`L0oooo0P00oo840?ooo`03002Jo`3oool0oooo0100oooo00<0
00000?ooo`3oool02@3oool000L0oooo00<000000?ooo`3oool02`3oool00`2K0?l0oooo0?ooo`08
0?ooo`0301X0o`3oool0oooo00`0oooo0P00/Ol00`3oool003Wo000io`0405T0o`<0oooo00D00?o?
0?ooo`3oool0oooo002[o`030?ooo`03000:o`3oool0oooo00/0oooo00<005[o0?ooo`00o`H00P00
o`H20?ooo`<0G?l00`3oool01P1[o`00oooo0?ooo`00Yol0oooo023o0080oooo100D0?l0103oool0
00000?ooo`00<ol20?ooo`03003Oo`3oool00?og00@0oooo00D0017o0011o`00@Ol0047o0?ooo`03
05_o00D0oooo00<0X?l00?ooo`3oool00P3oool00`007?l0oooo00000003000000D0oooo0`00Gol0
0`3oool00?nY003oZ@02003oZ@040?ooo`00omX0oooo0?ooo`800?lJ1@3oool01P00A_l0oooo0?oo
o`3oool09_l0003oA@P0oooo1000oo80103oool00<co003<o`00c?l20?ooo`03003oQ@00000003Oo
00<003Oo0`3oool3003oUP03002no`3oool0oooo00H0oooo0P00n_l30?ooo`03002Ao`3oool0oooo
00@0oooo00<00?ob0?ooo`3oool00`00V_lA0?ooo`030000003oool0oooo00T0oooo00060?ooo`03
0000003oool0oooo00/0oooo00<0V`3o0?ooo`3oool05P3oool3002ao`@003Wo101I0?l20?ooo`05
003oc`3oool0oooo0?ooo`00Zol00`3oool00`002_l0oooo0?ooo`0?0?ooo`800?l600T00?m00?oo
o`1Lo`00G?l00?ooo`00okP0oooo06_o003oool00`00Yol0103oool08?l00?ooo`3oool401@0o`08
0?ooo`000000oooo000co`3oool00=oo0?ooo`00ooL40?ooo`04003o>@004Ol00?li0011o`<0oooo
00<0Fol00?ooo`3oool00`3oool00`00obD0X?l00?ooo`020?ooo`<000000`00om430?ooo`<009Wo
1000Gol3003oZ@80oooo00<00?oJ0?ooo`3oool00P3oool00`0Vo`00oooo0?ooo`020?ooo`040016
o`3oool0oooo0?ooo`<00?m51`3oool3003olP<0oooo0P00c?l01@3oool00?mh003oQ@00ogP00000
0080oooo00@003Oo0?ooo`3oool0oooo0`00oiH00`00__l0oooo0?ooo`080?ooo`03003jo`3oool0
097o0080097o2@3oool3002Joa40oooo00<000000?ooo`3oool0203oool000H0oooo00<000000?oo
o`3oool02P3oool00`2K0?l0oooo0?ooo`0H0?ooo`800;7o00D0oooo000io`00>Ol003Wo0?ooo`03
05T0o`030?ooo`00oll0oooo0080oooo00<00:_o0?ooo`3oool00P3oool00`002_l0oooo0?ooo`0<
0?ooo`03003o003oool0oooo00<00?m00P3oool3003o^0030?ooo`1[o`00oooo00@00:Oo103oool3
01@0o`060?ooo`000000oooo000co`3oool00=oo1000ooL30?ooo`03000Ao`3oool0oooo0080oooo
00<0C_l00?ooo`3oool00`3oool3003o9@<000000`3oool3003od@<0oooo0`00VOl01`00oaX005oo
001Oo`00Gol0oooo003oZ@0bo`000P3oool00`00omX0oooo0?ooo`020?ooo`809_l00`3oool01`00
A_l0oooo0?ooo`3oool00?m50?ooo`00odD00`3oool01`00bOl0oooo0?ooo`3oool00?nc0?ooo`00
oo801P3oool2003oN005003oQ@3oool000000?ooo`00=ol0103oool2003oUP030?ooo`00__l0oooo
00T0oooo00<00?[o0?ooo`00TOl01000TOl90?ooo`<009[o3P3oool00`000000oooo0?ooo`080?oo
o`001P3oool00`000000oooo0?ooo`090?ooo`0309/0o`3oool0oooo01P0oooo00P00;7o0?ooo`00
/Ol0oooo000io`3oool003Wo05T0o`<0oooo00<00?o?0?ooo`3oool00P3oool01@00Zol0oooo0?oo
o`3oool000[o00X0oooo00<00?l50?ooo`3oool00`00o`030?ooo`800?m00`3oool2003o^0<0oooo
00@00:Oo0?ooo`3oool08?l00P3oool01P00k?l0oooo01@0o`00of`0503o0?ooo`@003?o00D00=oo
0?ooo`00ooL00?og0?ooo`0206_o0003000Ao`3oool0oooo0080oooo0P1>o`050?ooo`<000000P3o
ool01`00P_l0oooo0?ooo`3oool00?oA0?ooo`00okh0103oool01000obD009Wo003o6P00Gol30?oo
o`<0<_l000<0oooo003ofP3oool00`3oool202Ko00<0oooo00<004Ko0?ooo`3oool00`3oool01000
odD0oooo0039o`00Lol40?ooo`800?nc00@00?ob003o/`00ok<00?nc103oool01P00ogP0oooo003o
N000ogP00000000go`H0oooo00@00?nF002no`3oool0oooo0P00^Ol70?ooo`03003jo`3oool0097o
00<0oooo00<0097o0031o`00TOl02@3oool2002Jo``0oooo00<000000?ooo`3oool0203oool000H0
oooo00<000000?ooo`3oool0203oool00`2K0?l0oooo0?ooo`0@0?ooo`80A@3o00<0oooo0<`0o`3<
0?l00`3oool01@00/Ol0oooo0?ooo`3oool003Wo0080oooo00<0F@3o0?ooo`3oool01P3oool01@00
Zol0oooo0?ooo`3oool000[o00X0oooo0`00o`D0103oool00?l0003o0000o`020?ooo`06003o@03o
ool0oooo0?ooo`1B0?l00?nh1@3oool00`00Yol0oooo0?ooo`030?ooo`07003/o`0D0?l0oooo003o
K03oool00?mS00000002000co`03003Oo`0Vo`009_l000@0oooo00<0Jol0000Ao`3oool0103oool0
0`1>o`00oooo0?ooo`03000000050?ooo`00obD005So0?ooo`00P_l0103oool00`00om400?nn0?oo
o`040?ooo`<00?lU00<005oo0?ooo`3oool00P3oool203;o00030?ooo`00omX0oooo00D0oooo00@0
9_l0003oa03oool004Ko103oool01000bOl00?m50039o`3oool2001co`<0oooo0P00ok<00`3oool0
0?ob0?ooo`090?ooo`03003oN0000000oooo00L0oooo00<00?nF0?ooo`00^Ol00`00^Ol20?ooo`04
003Qo`3oool0oooo003jo`H0oooo0`00`OlF0?ooo`030000003oool0oooo00P0oooo00060?ooo`03
0000003oool0oooo00L0oooo00<0V`3o0?ooo`3oool03`3oool304D0o`@0c03o0`3oool01000/Ol0
oooo0?ooo`00>Ol20?ooo`0305T0o`3oool0oooo00/0oooo00<000[o0?ooo`3oool01`3oool2003o
1@06003Vo`3oool0oooo003o003oool005So0P3oool00`00od00oooo0580o`020580o`03003o^03o
ool0oooo0080oooo00<00:Oo0?ooo`3oool0103oool01000k?l0503o0?ooo`3oool3003oH`80oooo
00<00=oo02Ko003oool0103oool00`004Ol0oooo0?ooo`030?ooo`@000000`3oool00`00obD005So
001Ho`020022o`@0oooo00<00?oA003o_P3oool01@3oool00`00obD005oo0?ooo`060?ooo`03003o
:P3oool0oooo00D0oooo0`00ol@00`00A_l0oooo0?ooo`020?ooo`030039o`00odD00<Wo00<007?o
1P3oool00`00oo800?mG003oE`080?ooo`03003o[00000000?n/00@0oooo00D00;;o0?ooo`3oool0
oooo003oUP03002io`80oooo0`00hOl20?ooo`03003jo`3oool0oooo00<0oooo1000`OlE0?ooo`03
0000003oool0oooo00P0oooo00060?ooo`030000003oool0oooo01X0oooo0P150?l00`3oool0c03o
0<`0o`030?ooo`04002ao`3oool0oooo000io`<0oooo00<0F@3o0?ooo`3oool02P3oool00`002_l0
oooo0?ooo`050?ooo`03003o/03oool0oooo00<00>Ko00<0oooo003o0000F?l00P00F?l00`3oool0
0?m00?ooo`040580o`D0oooo00<00:Oo0?ooo`3oool00`3oool00`00k?l0503o003/o`030?ooo`04
003oH`000000oooo00[o00H0oooo00@00?mD000Ao`3oool0oooo0`0000000`00on/0oooo0?ooo`04
0?ooo`@005So00<008;o0?ooo`3oool00P3oool00`00om400?nn0?ooo`050?ooo`0302Wo0000Gol0
oooo00D0oooo0`00obX60?ooo`@00?o41P3oool00`00odD007?o001co`02001co`D0oooo00@00?ob
003oE`00oeL00?mG1`3oool00`00oj`003Oo000000030?ooo`@00;;o0`3oool01000^Ol0oooo0?oo
o`3oool4003Qo`80oooo00<00?[o0?ooo`3oool00`3oool01000`Ol0oooo0?ooo`00`OlD0?ooo`03
0000003oool0oooo00P0oooo00060?ooo`030000003oool0oooo01X0oooo0P150?l00`3oool0c03o
0<`0o`020?ooo`04002ao`3oool0oooo000io`<0oooo00<0F@3o0?ooo`3oool03@3oool3003oM004
0?ooo`00ok000?n`003o/080oooo0`00i_l30?ooo`8005So00@0oooo003o@03oool0oooo0`1B0?l4
0?ooo`03002Wo`3oool0oooo00D0oooo00<0503o0?ooo`0Mo`000`3oool00`0000002_l000[o0004
0?ooo`<00?mD0`0000020?ooo`<00?o[0P3oool00`00omh0oooo0?ooo`04001Ho`060022o`3oool0
oooo0?ooo`00om407Ol01P3oool202Wo0003001Oo`3oool0oooo00@0oooo0P00obX60?ooo`04002i
o`3oool00?o40?ooo`<00?nb103oool01000odD00?mJ001co`00oeX60?ooo`04003olP00oeL00?mG
003oE`T0oooo00@003Oo0000003oool0oooo2000/_l01@00^Ol0oooo0?ooo`3oool00>7o0080oooo
0P00hOl:0?ooo`030031o`3oool0oooo0140oooo00<000000?ooo`3oool0203oool000D0oooo00<0
00000?ooo`3oool04@3oool00`3o0;80oooo0?ooo`060?ooo`0404D0o`3oool0oooo0<`0o`<0oooo
00D00;7o0?ooo`3oool0oooo000io`020?ooo`0305T0o`3oool0oooo00l0oooo0P00og@20?ooo`80
0?n`0P3oool3003Vo`80oooo00@005So0?ooo`00F?l00?m00`3oool20580o`@0oooo00<00?nF002W
o`3oool00P3oool2003o7P030?ooo`0D0?l0oooo00<07Ol00P3oool00`0000002_l000[o00040?oo
o`<00000103oool00`00Iol00?o[0?ooo`020?ooo`800?oN0P3oool00`00obD005So003oA002003o
A0<0oooo00<00?oA01go000Mo`001P3oool00`0Yo`0005oo0?ooo`060?ooo`03003o:P3oool0oooo
00@00;Wo0P3oool00`00ol@0oooo003o/P04003o/P@0oooo00<007?o003oFP00oeX01P3oool00`00
oo80oooo003oE`020?ooo`03003on03oool0oooo00@0oooo00<003Oo003o[00000000P3oool00`00
/_l004co0?ooo`040?ooo`03002io`3oool0oooo00H0oooo00<00>7o0034o`3oool0203oool20031
o`80oooo1000=?l;0?ooo`030000003oool0oooo00P0oooo00050?ooo`030000003oool0oooo00l0
oooo0`3o0;870?ooo`0404D0o`3oool0oooo0<`0o`L0oooo00@003Wo0?ooo`3oool0F@3o4@3oool0
1`00og@02P3o0?ooo`3oool00?n`0?ooo`2V0?l00P3oool00`00i_l0oooo0?ooo`020?ooo`03001H
o`3oool0oooo00<0oooo00<0DP3o0?ooo`00okP0103oool00`00Yol00?nF003oUP020?ooo`800?lN
00<0oooo01@0o`3oool00P0Mo`030?ooo`040000000:o`00oooo0?ooo`<0000000<0oooo003oE03o
ool00`3oool2001Wo`03003oj`3oool0oooo00<00?oN0P3oool01000F?l0oooo003oA000od@40?oo
o`03003od@0Mo`007Ol000H0oooo00<005oo02Wo003oool01`3oool01000obX0oooo002?o`00^Ol4
0?ooo`04003oa03oool0oooo003o/PL0oooo00D007?o0?ooo`3oool00?mb003oFP040?ooo`05003o
lP3oool0oooo003oE`3oool00P00ooP50?ooo`05000go`00oj`0oooo0000003oool00`00C?l20?oo
o`<00?o`00<00;Wo0?ooo`3oool01P3oool30034o`T0oooo00<00<7o0?ooo`00=?l00P00=?l=0?oo
o`030000003oool0oooo00L0oooo00050?ooo`030000003oool0oooo00d0oooo103o0;870?ooo`04
04D0o`3oool0oooo0<`0o`L0oooo00D003Wo0?ooo`3oool0oooo05T0o`090?ooo`05003Eo`3oool0
oooo0?ooo`00MOl00P3oool300X0o`030?ooo`00ok00YP3o0080YP3o00<0oooo003Vo`3oool00`3o
ool00`00F?l0oooo0?ooo`040?ooo`030580o`3oool0oooo00@0oooo00<00:Oo003oUP3oool0103o
ool0100D0?l00?nN0?ooo`0Mo`040?ooo`@000000`3oool2000do`<0oooo0P00Iol00`00on/006Oo
0?ooo`020?ooo`05003ogP3oool0oooo0?ooo`00F?l02@3oool00`00ocD07Ol00?ooo`040?ooo`03
001Oo`0Yo`000?nj00L0oooo00@00?lZ002?o`00Sol00;Wo1@3oool01@00ol@0oooo0?ooo`3oool0
0?li00H0oooo00@007?o0?ooo`00og800?mb1`3oool00`00_Ol00?mG003on002003on0@0oooo00D0
03Oo003om000oj`000000?ooo`04001<o`050?ooo`00oo000?o`0?ooo`00^Ol0203oool20034o``0
oooo1@00=?l;0?ooo`030000003oool0oooo00L0oooo00050?ooo`030000003oool0oooo00h0oooo
0`3o0;860?ooo`0504D0o`3oool0oooo0?ooo`3<0?l02P3oool00`1I0?l0oooo0?ooo`060?ooo`<0
0=Go00L0oooo001eo`00MOl007Go0?ooo`0:0?l0oooo00802P3o00<0oooo0:H0o`3oool00P2V0?l0
0`3oool00>Ko0?ooo`030?ooo`03001Ho`3oool0oooo00<0oooo00<0DP3o0?ooo`3oool00P3oool0
0`00och0oooo0?ooo`020?ooo`03003oC`3oool0oooo0080oooo00<0503o003oWP3oool00P3oool3
00000003003No`3oool004Wo0080oooo1000=?l40?ooo`03001Wo`00on/0oooo0080oooo00<00?lA
0?ooo`3oool00P3oool00`00F?l0oooo00Oo00060?ooo`800?le1P3oool00`00Gol00?nj003o^P03
0?ooo`04003oa03oool0oooo0?ooo`@008oo00<00?mI0?ooo`3oool00P3oool00`00ol@0oooo0?oo
o`03003o>@D0oooo00<007?o0?ooo`00og800P00og850?ooo`<00;go0P00ooP50?ooo`800?od00<0
0?n/0?ooo`0000000`00C?l20?ooo`<00?o`00<0oooo002io`3oool0203oool00`00a?l0oooo0?oo
o`0>0?ooo`8003Co2@3oool00`000000oooo0?ooo`070?ooo`001@3oool00`000000oooo0?ooo`0>
0?ooo`030?l0/P3oool0o`2b00D0oooo00D0A@3o0?ooo`3oool0oooo0<`0o`0D0?ooo`<00=Go0P3o
ool2001eo`80oooo0`0:0?l00`00ok00oooo0:H0o`020:H0o`03003Vo`3oool0oooo0080oooo00<0
05So0?ooo`3oool00`3oool00`1B0?l00?m^003oKP020?ooo`<00?ln0P3oool3003oC`80oooo00<0
503o003oWP00oih00`0000000`3oool00=ko003No`02003No`040019o`3oool0oooo0?ooo`<003Co
0`3oool00`00og<0oooo003oj`020?ooo`<00?lA0`3oool01000F?l01ol000Oo0007o`050?ooo`<0
0?le103oool00`00W_l00?nj003o^P02003o^P80oooo1000ol@01000obX008oo002?o`00Sol2003o
F@<0oooo00<00?o40?ooo`3oool00`00ocT50?ooo`04001co`3oool0oooo003oLPH0oooo1000_Ol0
0`00ooP00;go002mo`040?ooo`07003om03oool00?n/003om0000000oooo001<o`050?ooo`03003o
l000^Ol0oooo0080oooo00<009oo0?ooo`3oool0103oool00`00a?l0oooo0?ooo`040?ooo`<006Ko
203oool2000do`L0oooo00<000000?ooo`3oool01`3oool000D0oooo00<000000?ooo`3oool03@3o
ool00`3o0;80oooo0?ooo`060?ooo`0404D0o`3oool0oooo0<`0oa@0oooo00<00=Go0?ooo`3oool0
0P3oool01@00MOl0oooo0?ooo`3oool02P3o0080oooo00<02P3o0?ooo`2V0?l00P3oool00`2V0?l0
0>Ko0?ooo`030?ooo`03001Ho`3oool0oooo00<0oooo00<0DP3o003oKP00ofh00P3oool2003o?P<0
oooo0P00odl30?ooo`<000001@3oool3003No`<0oooo0P00n_l2000do`80oooo0`00og<01@00on/0
oooo0?ooo`3oool00?lA00<0oooo00@005So0?ooo`3oool01ol01`3oool00`00ocD0oooo0?ooo`02
0?ooo`@009ko00@00?nj0?ooo`3oool0oooo0P00ol@30?ooo`04002?o`3oool0oooo0?ooo`800?mI
0P3oool00`00ol@0oooo0?ooo`030?ooo`03003o>@3oool0oooo0080oooo00@007?o0?ooo`3oool0
0?mb1`3oool2002mo`030?ooo`00ooP0oooo00T0oooo00<00?od00000000C?l01`3oool00`00^Ol0
oooo0?ooo`02002Oo`040?ooo`00Jol006_o001[o`80oooo00<00<Co0?ooo`3oool00`3oool4001V
oa00oooo00<000000?ooo`3oool01`3oool000D0oooo00<000000?ooo`3oool0303oool00`3o0;80
oooo0?ooo`060?ooo`0404D0o`3oool0oooo0<`0o`d0oooo0P070?l20?ooo`80O03o0P3oool01@00
eOl0o`3d0?ooo`3oool007Go00@0oooo00<02P3o0?ooo`3oool00P3oool0102V0?l0oooo0?ooo`00
i_l40?ooo`03001Ho`3oool0oooo00<0oooo00<0DP3o003oKP00ofh00`3oool00`00och0oooo0?oo
o`020?ooo`03003oC`3oool000000080000000<00?nN0?ooo`3oool0103oool00`00g_l0oooo0019
o`030019o`80oooo00<003Co0?ooo`3oool00`3oool00`00og<00?o[0?ooo`030?ooo`05003o4@3o
ool0oooo0?ooo`00F?l00P3oool00`07o`00oooo0?ooo`050?ooo`03003o=@3oool0oooo00<0oooo
0P00W_l00`3oool00?nj0?ooo`030?ooo`05003oa03oool0oooo0?ooo`00Sol01@3oool00`00oeT0
oooo003oa0050?ooo`03003o>@00olX0oooo0080oooo00T007?o0?ooo`3oool0oooo003oLP3oool0
0?oS0?ooo`00Rol01P3oool00`00ooP00?no0?ooo`070?ooo`800?o[00<00000003oj`3oool01P3o
ool00`00oo0009oo002Oo`02002Oo`<006_o0P3oool00`00a?l0oooo0?ooo`040?ooo`<006Ko403o
ool00`000000oooo0?ooo`070?ooo`00103oool00`000000oooo0?ooo`0<0?ooo`030?l0/P3oool0
oooo00H0oooo00D0A@3o0?ooo`3oool0oooo0<`0o`0;0?ooo`<01`3o1@1l0?l0103oool0o`3d0?l0
m03o0?@20?ooo`05001eo`3oool0oooo0?ooo`0:0?l0103oool00`2V0?l0oooo0?ooo`050?ooo`03
003oY@00F?l0oooo0080oooo00<00?nh0?ooo`1B0?l00P3oool00`00ood0oooo003o?P030?ooo`04
002?o`0000000000000000<0oooo00<0203o0?ooo`3oool0103oool00`00g_l0oooo000000020019
o`<0oooo00<003Co0?ooo`3oool0103oool01@00on/0oooo0?ooo`3oool00?mR00@0oooo00@005So
0?ooo`3oool00?oA0P3oool00`00Nol0oooo0?ooo`020?ooo`03003o=@00S?l0oooo00@0oooo00<0
0?ma003o^P3oool01@3oool01000ocd0oooo0?ooo`00Sol40?ooo`03003oG03oool0oooo00H0oooo
0`00olX20?ooo`05001co`3oool0oooo0?ooo`00og800P00on<3002;o`D0oooo00<00?oh003o_`00
okl01`3oool2003oj`030000003oool0oooo00L0oooo0`00Wol0103oool006_o001[o`3oool2001[
o`030?ooo`00a?l0oooo00D0oooo00<006Ko0?ooo`00I_l03`3oool00`000000oooo0?ooo`070?oo
o`00103oool00`000000oooo0?ooo`0;0?ooo`030?l0/P3oool0oooo00X0oooo00<0c03o0?ooo`3o
ool02`3oool300L0o`<0O03o00@0oooo0?l0m03oool0o`3d0P3oool01@00MOl0oooo0?ooo`3oool0
2P3o00@0oooo00<0YP3o0?ooo`3oool01@3oool01000ojD005So003oY@3oool3003o^0030580o`3o
ool00?om00800?om0P3oool400000004003oC`3oool0oooo0?ooo`<0203o00<0oooo003<o`00c?l0
0`3oool00`00g_l00?n]000000030?ooo`03003oDP00=?l0oooo00<0oooo00<00?lf0?ooo`3oool0
0`3oool2003oHP<0oooo00<005So0?ooo`3oool00P00om42001ko`D0oooo0P00S?l40?ooo`800?ma
00<00?nj0?ooo`3oool00`3oool3003o?@030?ooo`00Sol0oooo00<0oooo0`00oe`60?ooo`@00?o:
00<00;?o001co`00/ol00`3oool00`00og8008_o002;o`03002;o`@0oooo00<00?oh003o_`00okl0
203oool00`00on/004co0000000;0?ooo`03002Oo`3oool0oooo00<0oooo0P00Jol00`00a?l0oooo
0?ooo`060?ooo`03001Vo`3oool0oooo00`0oooo00<000000?ooo`3oool01`3oool000@0oooo00<0
00000?ooo`3oool02P3oool00`3o0;80oooo0?ooo`0:0?ooo`030<`0o`3oool0oooo00`0oooo0`07
0?l01@3oool0O03o07`0o`00eOl0oooo0080o`3d00<0oooo001eo`3oool00`3oool00`0:0?l0oooo
0?ooo`020?ooo`030:H0o`3oool0oooo00H0oooo0P00ojD20?ooo`800?nh00@0DP3o0?ooo`3oool0
0?om0`0000020?ooo`<008oo0P3oool400P0o`@00<co00<0oooo003No`00ojd00P00ojd20?ooo`80
0?mB00@003Co0?ooo`3oool0oooo0`00ocH40?ooo`<00?mR0P3oool00`00F?l0oooo0?ooo`03003o
d@8007_o0`3oool4002<o`<0oooo0P00og400`00okX0oooo0?ooo`040?ooo`800?lm00<0oooo002?
o`3oool0103oool00`00oe`0oooo0?ooo`060?ooo`03002co`00olX00;?o00H0oooo00@00?mb003o
h`3oool008_o0P00on<40?ooo`04003on03oool0oooo003o_`P0oooo00<004co003oj`0000002P3o
ool00`00Wol0oooo0?ooo`050?ooo`03001[o`00OOl0oooo00L0oooo0P00I_l=0?ooo`030000003o
ool0oooo00H0oooo00040?ooo`030000003oool0oooo00T0oooo00<0o`2b0?ooo`3oool04@3oool0
0`3k0?l0oooo0?ooo`050?ooo`0500L0o`3oool0oooo0?ooo`1l0?l00`3oool01@3o0?@0oooo0?l0
m03oool007Go00<0oooo00<02P3o0?ooo`3oool00P3oool00`2V0?l0oooo0?ooo`060?ooo`08003o
Y@3oool0oooo0?ooo`00okP0oooo0580o`3oool3000000@0oooo00@008oo0?ooo`3oool008oo0`3o
ool300P0o`030?ooo`00c?l00<co0080oooo00@00=ko003o[@00ojd000000`3oool00`00oe8003Co
0?ooo`020?ooo`03003o=P3oool0oooo00D0oooo00<00?mR0?ooo`3oool0103oool01000om40oooo
001ko`00Nol50?ooo`<008co1@3oool00`00okX00?ma0?ooo`050?ooo`03003o?@00Sol0oooo00D0
oooo00<00?mL0?ooo`3oool01`3oool00`00olX0oooo0?ooo`080?ooo`03002;o`3oool0oooo00D0
oooo00H00?oh0?ooo`3oool00?no0?ooo`00j_l50?ooo`040028o`00C?l00?o[00000080oooo00@0
04ko0?ooo`3oool0oooo0`00Yol00`3oool009oo0?ooo`060?ooo`<007go203oool00`00I_l0oooo
0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00040?ooo`030000003oool0oooo00T0oooo00<0
o`2b0?ooo`3oool03`3oool30?/0o`030?ooo`3o0800o`2000<0oooo00D01`3o0?ooo`3oool0oooo
07`0o`030?ooo`050?l0m03oool0oooo0?ooo`00MOl00`3oool00`0:0?l0oooo0?ooo`030?ooo`03
0:H0o`00eOl0oooo0080oooo0P00U?l00`3oool00?nU0?ooo`030?ooo`06003o^000000000000000
003oool00?om1@3oool00`00Sol0oooo0?ooo`040?ooo`0300P0o`3oool0oooo00@0oooo00D00=ko
0?ooo`3oool0oooo000000030?ooo`03000do`3oool0oooo0080oooo00<00?lf0?ooo`3oool00P3o
ool00`00Dol0oooo003oHP070?ooo`03003od@3oool0oooo00H0oooo00<008co0?ooo`3oool01@3o
ool00`00okX0oooo0?ooo`060?ooo`04002?o`3oool0oooo002Ko`<0oooo00D00?mL0?ooo`3oool0
0:[o003oj`050?ooo`04003obP3oool0oooo003o[@L0oooo00@008_o0?ooo`00okX00?nj103oool0
1@00ooP0oooo0?ooo`3oool00?no00800>[o0`3oool20028o`05001<o`00R?l00?o[0000003oool0
0`00C_l00`3oool00:Oo002Wo`020?ooo`03002Oo`3oool0oooo00D0oooo0P00OOlF0?ooo`030000
003oool0oooo00H0oooo00040?ooo`030000003oool0oooo00P0oooo00<0o`2b0?ooo`3oool03P3o
ool30?/0o`D0o`200P3oool01@070?l0oooo0?ooo`3oool0O03o00@0oooo00<0o`3d0?ooo`3oool0
1@3oool00`0:0?l0oooo0?ooo`020?ooo`040:H0o`00eOl00=Go0?ooo`@009Co0`3oool01000;_l0
00000000000000030?ooo`0305X0o`3oool0oooo00<0oooo00<008oo0?ooo`3oool00P3oool01000
oo00oooo00P0o`3oool2003oXP@0oooo00T00=ko0?ooo`3oool0oooo0000003oool00?nY0?ooo`00
=?l0103oool01000nOl0oooo0?ooo`3oool2001Co`050?ooo`00of8006[o0?ooo`00kOl0103oool0
0`00om40oooo003oW@060?ooo`03002<o`3oool0oooo00D0oooo00<00?mY0?ooo`3oool01@3oool0
0`00okl008oo0?ooo`05002Ko`03003oG03oool00:[o00800:[o0P00on/30?ooo`03003obP3oool0
0?n]00<00?n]1@3oool00`00Rol00?nj003o^P02003o^PL0oooo1000j_l20?ooo`8008So00@004co
0028o`00on/000001@00C_l00`3oool00:Oo002Wo`020?ooo`03002Oo`3oool0oooo00H0oooo00<0
07go0?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`000`3oool00`000000oooo0?ooo`08
0?ooo`030?l0/P3oool0oooo0100oooo0`3k0?l40?l0P0030?ooo`070?l0oooo00<0oooo00D0O03o
0?ooo`3oool0oooo0?l0m0070?ooo`0300X0o`3oool0oooo0080oooo00<0YP3o0?ooo`00eOl00P00
eOl0103oool009Co002Do`00U?l400000004000^o`00okP0oooo0?ooo`<0FP3o1@3oool00`00Sol0
oooo0?ooo`04003ol00400P0o`00oj800?nR003oXP<0oooo0`00ohL20?ooo`0400000000ojT00?nY
000do`@0oooo0P00nOl20?ooo`@005?o0P00J_l4003]o`80oooo00@00?oA003oW@00oid00?nM103o
ool00`00oeh008co003oGP050?ooo`<00?mY1P3oool00`00okl008oo003o_`03002Ko`<0oooo00@0
0?mL002Zo`00Z_l00:[o0P00on/30?ooo`03003obP3oool0oooo00800?n]1`3oool00`00Rol00?nj
003o^P080?ooo`<00>[o1@3oool01@00C?l0oooo0?ooo`00on/00000008004ko1@3oool2002Wo`03
002Oo`3oool0oooo00L0oooo00<007go0?ooo`3oool00`3oool40001o`/0oooo00<000000?ooo`3o
ool01P3oool000<0oooo00<000000?ooo`3oool01`3oool00`3o0;80oooo0?ooo`0A0?ooo`040?/0
o`3oool0n`3o0?ooo`<0o`2000<0oooo00L0o`3oool00P3oool01@1l0?l0oooo0?ooo`3oool0o`3d
00d0oooo00@0YP3o003Eo`3oool00=Go0P3oool300000080oooo0`00;_l20?ooo`@0FP3o103oool0
0`00Sol0oooo0?ooo`020?ooo`800?o`00@0203o0?ooo`3oool00?nR103oool2003oQ`<0oooo00@0
0000003oZ@00ojT003Co0`3oool4003io`80oooo0P00Dol4001Zo`800>go0`3oool01000om40oooo
003oW@00oid50?ooo`03002<o`3oool0oooo00D0oooo00<00?mY0?ooo`3oool01P3oool00`00okl0
oooo0?ooo`02002Ko`<0oooo1@00Z_l00`3oool00?o[0?ooo`020?ooo`05003obP3oool0oooo0?oo
o`00ojd01P3oool00`00Rol0oooo003o^P0:0?ooo`03003Zo`3oool0oooo00P0oooo00<00000001>
o`3oool01P3oool01000Yol009oo0?ooo`00LOl70?ooo`03001mo`3oool0oooo0080oooo0`000Ol<
0?ooo`030000003oool0oooo00H0oooo00030?ooo`030000003oool0oooo0180oooo00<0o`000?oo
o`3oool01@3oool01P3k0?l0oooo0?ooo`3oool0o`200?ooo`80o`2000D01`3o0?ooo`3oool0oooo
07`0o`030?ooo`030?l0m03oool0oooo00H0oooo00<001co0?ooo`3oool00P3oool0102V0?l0oooo
003Eo`3oool3000000D0oooo00<002ko0?ooo`3oool00`3oool305X0o`@0oooo00<008oo0?ooo`3o
ool0103oool00`080?l0oooo003oXP050?ooo`03003oQ`3oool0oooo0080oooo00<00000003oZ@3o
ool01@3oool00`00nOl0oooo0?ooo`030?ooo`03001Co`3oool006[o008006[o103oool00`00om40
oooo0?ooo`070?ooo`03002<o`00oeh0oooo00@0oooo00<007Oo003oJ@3oool01`3oool00`00okl0
oooo0?ooo`070?ooo`03002Zo`3oool0oooo00D0oooo00D00?o:0?ooo`3oool0oooo003o[@060?oo
o`04002;o`3oool0oooo003o^P8008ko1`3oool00`00j_l00<_o003;o`070?ooo`800<;o00<00000
001>o`3oool01P3oool00`00Wol0oooo001ao`02001ao`D0oooo00<007go0?ooo`3oool00`3oool3
0001o`/0oooo00<000000?ooo`3oool01P3oool000<0oooo00<000000?ooo`3oool0403oool30?l0
00H0oooo00D0n`3o0?ooo`3oool0oooo0?l0P0030?ooo`0500L0o`3oool0oooo0?ooo`1l0?l0103o
ool00`3o0?@0oooo0?ooo`040?ooo`<001co0P3oool20440o`040?ooo`000000000000000080oooo
00<009Co0?ooo`3oool00P3oool00`00;_l0oooo0?ooo`040?ooo`0805X0o`3oool0oooo0?ooo`00
ooX0oooo002?o`3oool2003oi@<0oooo00<0203o0?ooo`00o?l01@3oool00`00ohL0oooo0?ooo`03
0?ooo`0300000000ojT0oooo00<0oooo00<00;So0?ooo`00nOl00`3oool01`00omL0oooo0?ooo`3o
ool006[o0?ooo`00oiH0103oool01000om40oooo0?ooo`00oi<50?ooo`03002<o`3oool00?mN00@0
oooo0P00Mol00`00ofT007Oo0?ooo`030?ooo`04003ho`3oool0oooo003o_`@0oooo00<00?nf0?oo
o`3oool00P3oool01000Z_l0oooo0?ooo`3oool2003oZP80oooo00<00?o:0?ooo`3oool00P3oool0
0`00ojd00?o[0?ooo`030?ooo`04002;o`3oool0oooo003o^P@008ko103oool2003;o`03003Zo`3o
ool0oooo00H0oooo0`00`_l00`000000oooo0?ooo`060?ooo`<0077o1`3oool00`00OOl0oooo0?oo
o`050?ooo`030001o`3oool0oooo00P0oooo00<000000?ooo`3oool01P3oool000<0oooo00<00000
0?ooo`3oool03P3oool50?l000H0oooo00@0n`3o0?ooo`3oool0o`20203oool01@1l0?l0oooo0?oo
o`3oool0o`3d00H0oooo00@001co0?ooo`007?l001co0P110?l300000005003Eo`3oool0_P3o0;h0
o`00U?l0103oool00`00;_l0oooo0?ooo`040?ooo`0405X0o`3oool0oooo0?ooo`<00?oj00@008oo
003oi@00onD00?oU0`3oool00`080?l00?co003lo`040?ooo`800:co1@3oool00`00:?l002oo000X
o`020?ooo`800;So00@00?Wo0?ooo`3oool0oooo0`00omL00`3oool006[o0?ooo`04003oUP80oooo
00@00?oA0?ooo`00oi<00?nC1@3oool00`00S?l0oooo003oeP040?ooo`8007Oo00<00?mY0?ooo`00
ZOl00P3oool4003ho`04003o_`3oool0oooo0?ooo`@00?nf0P3oool00`00Z_l0oooo0?ooo`04003o
ZPH0oooo1000on/20?ooo`06002;o`3oool0oooo0?ooo`00okX0oooo0`00S_l40?ooo`04003;o`00
j_l00<_o003;o`L0oooo00<00<;o0?ooo`000000203oool3001ao`P0oooo00<007go0?ooo`3oool0
1@3oool00`000Ol0oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00030?ooo`030000003o
ool0oooo00l0oooo0`3o00060?ooo`040?/0o`3oool0oooo0?l0P0P0oooo00D0O03o0?ooo`3oool0
oooo0?l0m0080?ooo`03000Lo`0000000000008000000P110?l50;h0o`D0oooo00<002ko0?ooo`3o
ool00`3oool00`1J0?l0oooo0?ooo`020?ooo`800?oj0`3oool3003oi@030?ooo`080?l00?co0080
0?co0P3oool4002/o`@0oooo0`00;ol40?ooo`03002ho`00nOl0oooo00<0oooo00@00?oG0?ooo`3o
ool006[o0P3oool2003oUP@0oooo1000oi<40?ooo`03002<o`00omH00?oF00D0oooo00@007Oo003o
J@00ZOl00:Wo0`3oool3003ho`03003o_`3oool0oooo0080oooo0P00okH30?ooo`04002Zo`3oool0
oooo0?ooo`800?nZ1`3oool3003oj`<0oooo00D008_o0?ooo`3oool0oooo003o^P05002>o`@0oooo
00@00>[o0?ooo`3oool00<_o203oool00`00C_l000000?ooo`050?ooo`8003Go0P3oool00`00LOl0
oooo0?ooo`050?ooo`8002Oo1`3oool20001o`P0oooo00<000000?ooo`3oool01@3oool000<0oooo
00<000000?ooo`3oool03`3oool30?l000D0oooo00D0n`3o0?ooo`3oool0oooo0?l0P00;0?ooo`03
0?l0m03oool0oooo00D0oooo0`0000030?ooo`<0@@3o00<0oooo0;h0o`2n0?l00P2n0?l40?ooo`03
000^o`3oool0oooo00@0oooo00D0FP3o0?ooo`3oool0oooo003onP040?ooo`03003oi@3oool0oooo
0080oooo00<0203o003lo`00o?l0103oool3002/o`<0oooo1000;ol50?ooo`03003io`3oool0oooo
0080oooo00@00?oG0?ooo`3oool006[o0P3oool00`00oiH0oooo0?ooo`040?ooo`800?nC00<004[o
0?ooo`3oool00P3oool01000S?l00?oF003oeP00omH50?ooo`@00:Wo1@3oool00`00okl0oooo0?oo
o`030?ooo`05003o]P3oool0oooo0?ooo`00Z_l0103oool01000ojX0oooo0?ooo`00Ool60?ooo`03
003oj`3oool00=Co00P0oooo00<008ko0?ooo`3oool01@3oool01@00j_l0oooo0?ooo`00bol00;Ko
00L0oooo00<004ko0000003oool0103oool4000eo`03001ao`3oool0oooo00D0oooo10009ol70?oo
o`030001o`3oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00080oooo00<000000?ooo`3o
ool03`3oool0103o0000oooo0?ooo`3o00040?ooo`050?/0o`3oool0oooo0?ooo`3o0800303oool0
0`3o0?@0_03o0?ooo`020?ooo`<0000000<001co0?ooo`3oool00P3oool00`110?l0oooo0?ooo`03
0?ooo`<0_P3o0`3oool00`00;_l0oooo0?ooo`020?ooo`03002ao`3oool0FP3o00T0oooo00L00?oU
0?ooo`3oool0oooo00P0o`3oool00?co00D0oooo00<00:co001lo`00O?l00`3oool01000hol002oo
000_o`00;ol50?ooo`03003io`3oool0oooo00@0oooo00D006[o0?ooo`3oool0oooo003oUP060?oo
o`04003oT`00B_l004[o001:o`@0oooo00<00<go003oeP3oool01@3oool01000omP00:Wo002Yo`00
ZOl50?ooo`03003o_`3oool0oooo00@0oooo00@00?nf0?ooo`3oool00:[o103oool00`00ojX0oooo
001oo`03001oo`@0oooo00<00?o[003Do`00e?l00P00e?l60?ooo`03002>o`00jOl00>Wo00D0oooo
00@00>[o0?ooo`3oool0oooo0P00]_l60?ooo`03001>o`00`_l000000080oooo00<003go0?ooo`00
=Ol00`00=Ol00`3oool0077o0?ooo`050?ooo`<002Oo403oool00`000000oooo0?ooo`050?ooo`00
0P3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00H0oooo00@0n`3o0?ooo`3oool0
o`20303oool00`3o0?@0_03o0;`0o`03000000040?l0c`3oool0oooo000Lo`<0oooo00<0@@3o0?oo
o`3oool00`3oool00`2n0?l0oooo0?ooo`040?ooo`03000^o`3oool0oooo00<00;7o00<0FP3o0?oo
o`3oool00P00U?l50?ooo`03001>o`3oool0oooo00<0oooo00<00?co0?ooo`3oool0103oool01@00
[?l007co001lo`00O?l0oooo00800>?o00<002oo003So`3oool00P3oool00`00oml0oooo003io`04
0?ooo`04003oeP3oool0oooo001Zo`<0oooo00<00?Ko0?ooo`3oool0103oool01000oi<004[o001:
o`00B_l30?ooo`800<go00<00?oF003=o`3oool00`3oool2003of003002Yo`3oool0oooo00@0oooo
00<00?ni003o_`3oool01P3oool00`00on80oooo002Zo`050?ooo`05003oZP00Ool007oo002^o`00
Ool0103oool01000on/00=Co003Do`00e?l70?ooo`04002>o`00jOl00>Wo003Yo`L0oooo00@00;Ko
0?ooo`00]_l00;Ko1@3oool01@00C_l00<;o0?ooo`000000oooo008003go103oool00`00=Ol0077o
0?ooo`080?ooo`03000Wo`3oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00080oooo00<0
00000?ooo`3oool03@3oool00`3o0000oooo0?ooo`060?ooo`040?/0o`3oool0oooo0?l0P0`0oooo
00D0_03o00000000000000000?ooo`030?l0c`030?ooo`007?l0oooo00<0oooo00<0@@3o0?ooo`3o
ool00P3oool00`2n0?l0oooo0?ooo`040?ooo`03000^o`3oool0oooo0080oooo0P00/Ol00`1J0?l0
oooo002Do`02002Do`<0oooo0`00C_l50?ooo`030240o`3oool0oooo00<0oooo00@00:co0?ooo`00
O?l007co0`3oool00`00;ol00>?o0?ooo`020?ooo`<00?oO00<00?Wo0?ooo`3oool00`00omH20?oo
o`03001Zo`3oool0oooo00800?Ko1P3oool00`00oi<004[o0029o`050?ooo`03003oeP00cOl00<go
00@0oooo0P00omP00`00ZOl0oooo0?ooo`030?ooo`<00?ni1P3oool3003ohP03002Zo`3oool0oooo
00<0oooo00D00?nZ0?ooo`00[_l00:ko0?ooo`02001oo`80oooo00<00?o[0?ooo`00e?l00P00e?l6
0?ooo`03002>o`00jOl00>Wo00P0oooo0`00]_l70?ooo`03001>o`00`_l0000000@003go103oool0
0`00=Ol0077o0?ooo`070?ooo`03000Wo`3oool0oooo00d0oooo00<000000?ooo`3oool01@3oool0
0080oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`060?ooo`040?/0o`3oool0oooo
0?l0P0X0oooo100000020;`0o`80o`3?00@0oooo0?l0c`3o0<l001co103oool00`110?l0oooo0?oo
o`020?ooo`030;h0o`3oool0oooo00T0oooo00<00;7o0?ooo`1J0?l00`3oool3002Do`030?ooo`00
C_l0oooo008004ko0`3oool30240o`D0oooo00<00:co0?ooo`3oool0103oool00`00;ol000000?oo
o`020?ooo`800?oO1@3oool3003oeP03001Zo`006?l0oooo00@00?Ko1@3oool30029o`D0oooo00<0
0?oF0?ooo`3oool01@3oool00`00omP00:Wo0?ooo`050?ooo`03003o^@3oool0oooo0080oooo00<0
05oo0?ooo`3oool00`00on800`00Z_l0oooo0?ooo`050?ooo`<00:ko1@3oool01@00on/0oooo0?oo
o`3oool00=Co00H0oooo00<008ko0?ooo`00jOl0203oool2001>o`03002fo`3oool0oooo00@0oooo
00@004ko0?ooo`00H_l000000P00?Ol60?ooo`04001ao`00=Ol003;o000bo`H0oooo00<002Oo0?oo
o`3oool0303oool00`000000oooo0?ooo`050?ooo`000P3oool00`000000oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00T0oooo00<0o`200?ooo`3oool01@3oool3000000<0oooo00@0_03o0?ooo`3o
ool0oooo103o0<l01@007?l0oooo0?ooo`3oool0@@3o00D0oooo00<0_P3o0?ooo`3oool0203oool0
1000/Ol0oooo0?ooo`1J0?l20?ooo`03002Do`3oool0oooo00<0oooo0`00C_l20?ooo`@08@3o103o
ool00`00[?l0oooo0?ooo`040?ooo`03000_o`3oool0000000<0oooo00<00?oO0?ooo`3oool0103o
ool01@00omH0oooo0?ooo`00J_l001So0080oooo0`00m_l01000Uol0oooo0?ooo`3oool40029o`D0
oooo00<00?oF0?ooo`3oool01@3oool00`00omP00:Wo0?ooo`050?ooo`04003o^@3oool0oooo0?oo
o`<005oo0P3oool00`00on80oooo0?ooo`020?ooo`040035o`3oool0oooo0?ooo`@00:ko1@3oool0
0`00on/0oooo0?ooo`020?ooo`03003Do`3oool0oooo00<0oooo00@008ko0?ooo`3oool00>Wo1`3o
ool2001>o`03002fo`00C_l0oooo00H0oooo0P00H_l00`00000003go0?ooo`060?ooo`03001ao`00
<_l003;o008003;o1@3oool00`009ol0oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo0002
0?ooo`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool02@3oool00`3o0800oooo0?ooo`03
0?ooo`<000001@3oool00`2l0?l0oooo0?ooo`020?ooo`040?l0c`3oool0o`3?0?l0c`<0oooo00<0
@@3o0?ooo`3oool00`3oool00`2n0?l0oooo0?ooo`020?ooo`8002?o103oool0100N0?l00;7o0?oo
o`1J0?l20?ooo`03002Do`3oool0oooo00@0oooo00<004ko0?ooo`3oool00`3oool30240o`06002E
o`3oool0oooo0?ooo`00[?l00<co103oool01000e_l002oo0?ooo`0000030?ooo`03003og`3oool0
oooo00@0oooo00<00?oF0?ooo`006?l00`006?l00`3oool00?Ko002Go`03002Go`<0oooo0`00ROl5
0?ooo`03003oeP00on80oooo00H0oooo00<00:Wo0?ooo`3oool01@3oool00`00okT0oooo0?ooo`04
001Oo`030?ooo`00on80oooo0080oooo0`00aOl40?ooo`04002^o`3oool00??o003co`<0oooo00<0
0?o[0?ooo`3oool00`3oool00`00fol0oooo0?ooo`020?ooo`04002>o`3oool0oooo003Yo`80oooo
00<007_o0?ooo`3oool00P3oool2001>o`03002fo`3oool0oooo00H0oooo0`00H_l00`000000oooo
0?ooo`060?ooo`<003;o1`3oool00`009ol0oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo
00020?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool0103o0800oooo0?oo
o`3oool300000080o`1A1@3oool00`2l0?l0oooo0?ooo`020?ooo`030?l0c`3oool0oooo00D0oooo
00<0@@3o0?ooo`3oool00P3oool0102n0?l0oooo0?ooo`3oool4000So`80oooo0`0N0?l40?ooo`03
002Do`3oool0oooo00@0oooo00<004ko0?ooo`3oool0103oool00`0Q0?l009Go002Eo`030?ooo`03
002/o`00c?l00<co00<0oooo00D00=Ko000_o`3oool0oooo000000030?ooo`03002]o`3oool0oooo
00@0oooo00<00?oF0?ooo`3oool00P006?l20?ooo`04003fo`3oool009Oo002Go`@0oooo00@00??o
0029o`00lol00??o103oool00`00omH00?oR0?ooo`050?ooo`03002Yo`00ooP0oooo00H0oooo00@0
0?ni0?ooo`3oool0oooo1000Gol00`3oool00?oR0?ooo`030035o`D0oooo00<00:ko0?ooo`00lol0
0P00lol70?ooo`@00=_o0P3oool01P00S_l0oooo0?ooo`3oool00>Wo0?ooo`<007_o1@3oool00`00
]_l004ko0?ooo`060?ooo`04001Ro`3oool003go000000L0oooo0`00<_l70?ooo`0303T0o`009ol0
oooo00/0oooo00<000000?ooo`3oool0103oool000030?ooo`000000oooo00/0oooo00<0o`000?oo
o`3oool02`3oool3000000D0o`1A1@3oool00`2l0?l0oooo0?ooo`020?ooo`030?l0c`3oool0oooo
00@0oooo00<0@@3o0?ooo`3oool00P3oool00`2n0?l0oooo0?ooo`030?ooo`<002?o00<0oooo01h0
o`0N0?l00P0N0?l30?ooo`80P`3o1@3oool00`00C_l0oooo0?ooo`040?ooo`030240o`3oool009Go
00@0oooo00<00:co003<o`3oool00P3oool2003Fo`06000_o`00e_l0oooo0000003oool07P3o0P00
[Ol50?ooo`03003oeP00Col0oooo00D0oooo00@00?Ko0?ooo`3oool009Oo103oool00`00ROl00??o
003co`040?ooo`@00?oR1@3oool00`00ZOl00?oh003on0060?ooo`03003o^@3oool00:ko00H0oooo
00<00?oR0?ooo`3oool00`00aOl40?ooo`04002^o`3oool0oooo003co`P0oooo0`00fol01000C_l0
oooo0?ooo`00S_l40?ooo`D007_o103oool00`00]_l0oooo001>o`080?ooo`03001Ro`000000oooo
00P0oooo00<003;o0?ooo`3oool01@3oool403T0o`X0oooo00<000000?ooo`3oool0103oool00003
0?ooo`000000oooo00X0oooo00<0o`000?ooo`3oool0203oool4000000@0oooo103o05440?ooo`03
0;`0o`3oool0oooo0080oooo00<0o`3?0?ooo`3oool02P3oool00`2n0?l0oooo0?ooo`030?ooo`03
000So`3oool0oooo0080oooo0`0N0?l00`3oool0P`3o08<0o`0208<0o`D0oooo00<004ko001^o`3o
ool00`3oool00`0Q0?l0oooo0?ooo`050?ooo`03003<o`3oool0oooo00<0oooo00@002oo003Fo`3o
ool0oooo0P0N0?l4002]o`040?ooo`00F?l0oooo0?ooo`8004oo1P3oool00`00m_l0oooo0?ooo`05
0?ooo`030029o`3oool00??o00D0oooo0P00on850?ooo`03000do`00ZOl00?oh00800?oh0`3oool0
0`00X_l0oooo0?ooo`02002^o`H0oooo00<00?oR0?ooo`3oool00`3oool01@00aOl0oooo0?ooo`3o
ool00:ko0080oooo00<00??o0?ooo`3oool0203oool01@00fol004ko001>o`00C_l008ko00@0oooo
1000Nol60?ooo`04002fo`3oool004ko001_o`L0oooo00<003go0000003oool0203oool00`00<_l0
oooo0?ooo`040?ooo`<0>@3o2`3oool00`000000oooo0?ooo`040?ooo`0000<0oooo0000003oool0
2P3oool00`3o0000oooo0?ooo`050?ooo`<00000203oool0103o0540oooo0?l0D@3o05430?ooo`03
0;`0o`3oool0oooo0080oooo00<0o`3?0?ooo`3oool02@3oool00`2E0?l0_P3o0?ooo`040?ooo`03
000So`3oool0oooo0080oooo00<07P3o0?ooo`0N0?l00`3oool308<0o`@0oooo00@004ko001^o`00
K_l006ko0`3oool00`0Q0?l007Ko0?ooo`050?ooo`03003<o`3oool0oooo0080oooo00<00=Ko000_
o`3oool00P3oool00`0000007P3o01h0o`02002]o`040?ooo`00F?l005So001Ho`@004oo00D00;7o
0?ooo`3oool0oooo003fo`080?ooo`030029o`3oool00??o00H0oooo00<00?oR0?ooo`3oool00P3o
ool2000do`03002Yo`00ooP0oooo00<0oooo0`00X_l4002^o`80oooo00@00>7o0?ooo`3oool00?oR
2@3oool01@00[_l0oooo0?ooo`3oool00??o00T0oooo00<00=_o001>o`00C_l01`3oool01000P?l0
07_o0020o`00P?l50?ooo`03002fo`3oool0oooo008006oo1P3oool00`00?Ol006;o000000020?oo
o`03000Io`3oool0oooo00@0oooo00<003;o0?ooo`3oool0103oool00`0i0?l0oooo03T0o`0:0?oo
o`030000003oool0oooo00@0oooo00000`3oool000000?ooo`090?ooo`030?l0003oool0oooo00<0
oooo0`00000:0?ooo`030?l0D@3oool0oooo00@0oooo00<0_03o0?ooo`3oool00`3oool00`3o0<l0
oooo0?ooo`070?ooo`80U@3o00<0_P3o0?ooo`3oool00`3oool00`008ol0oooo0?ooo`030?ooo`03
01h0o`3oool0oooo00<0oooo0`230?l40?ooo`07001>o`00K_l006ko0?ooo`00K_l0oooo0240o`02
001fo`D0oooo00<005;o0?ooo`3oool00`3oool00`00e_l0oooo0?ooo`020?ooo`030000003oool0
0:go00<0oooo0`00F?l0103oool004oo001?o`00Col3002ao`050?ooo`00m_l0oooo0?ooo`00gol0
103oool00`00ROl0oooo0?ooo`070?ooo`03003ohP3oool0oooo00<0oooo0P00=?l00`00ooP0oooo
0?ooo`020?ooo`@00:;o00@0oooo002^o`3oool0oooo1000hOl00`00on80oooo0?ooo`040?ooo`04
003Qo`3oool0oooo002^o`<0oooo00<00??o0?ooo`3oool01`3oool01000fol004ko001>o`00C_l6
0?ooo`030020o`00Nol0083o00P0oooo1000Kol50?ooo`05000mo`3oool006;o0000003oool00P00
6Ol50?ooo`03000bo`3oool0oooo00H0oooo00<0>@3o0?ooo`3oool0203oool00`000000oooo0?oo
o`040?ooo`0000<0oooo0000003oool0203oool0103o0000oooo0?ooo`3oool3000000`0oooo00<0
o`1A0?ooo`3oool01@3oool00`2l0?l0oooo0?ooo`020?ooo`030?l0c`3oool0oooo00L0oooo102E
0?l30?ooo`80lP3o1@3oool00`0N0?l0oooo0?ooo`030?ooo`0308<0o`3oool0oooo00@0oooo00<0
04ko0?ooo`3oool00P00K_l20?ooo`040240o`00M_l007Ko001fo`80oooo0`00D_l40?ooo`03003F
o`3oool0oooo00<0oooo00<000000?ooo`00[Ol0103oool01000F?l0oooo0?ooo`00Col20?ooo`80
0;7o0P3oool00`00m_l0oooo003Oo`02003Oo`<0oooo00@008Wo0?ooo`3oool00=Ko1P3oool00`00
on80oooo0?ooo`040?ooo`03000do`00ooP0oooo00@0oooo0P00X_l20?ooo`03002^o`3oool0oooo
00<00>7o1`3oool3003Qo`030?ooo`00[_l0oooo00<0oooo00<00??o0?ooo`00V_l01P3oool01@00
fol0oooo0?ooo`3oool004ko00H0oooo00<007_o0020o`00P?l01`3oool3001_o`L0oooo00@003go
00P0o`080?l000000`006Ol50?ooo`03000bo`3oool0oooo00H0oooo00<0>@3o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`040?ooo`0000<0oooo0000003oool02@3oool3000000h0oooo00<0o`1A
0?ooo`3oool01@3oool00`2l0?l0oooo0?ooo`020?ooo`030?l0c`3oool0oooo00T0oooo0`2E0?l0
0`3oool0lP3o0?80o`020?80o`D0oooo00<07P3o0?ooo`3oool00`3oool00`230?l0oooo0?ooo`06
0?ooo`05001^o`3oool0oooo0?ooo`0Q0?l00`00M_l20?ooo`@005;o0`3oool00`004ol00=Ko0001
o`040?ooo`0300000000[Ol0oooo00H0oooo00D004oo0?ooo`3oool0oooo002ao`060?ooo`03003O
o`3oool0oooo0080oooo00<008Wo003Fo`00e_l00P00e_l50?ooo`03003ohP00Sol0oooo00D0oooo
00<00?oh0?ooo`3oool01@3oool00`00X_l0oooo002^o`030?ooo`800>7o1`3oool4003Qo`03002^
o`00>_l0oooo00<0oooo0`00V_l60?ooo`05003Ko`3oool0oooo0?ooo`00C_l01P3oool00`00Nol0
083o0?ooo`090?ooo`03001_o`3oool0oooo00@0oooo00@003go00P0o`080?l000000P006Ol60?oo
o`04000bo`3oool06`3o01/0o`H0oooo00<0>@3o0?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`0000<000000?ooo`3oool01@3oool400000140oooo00<0o`1A0?ooo`3oool02@3oool00`3o
0<l0oooo0?ooo`090?ooo`0409D0o`3oool0U@3o0?ooo`D0lP3o103oool00`0N0?l0oooo0?ooo`03
0?ooo`0408<0o`3oool0oooo000<o`H0oooo00H006ko0?ooo`3oool0oooo0240o`00M_l50?ooo`<0
05;o0`3oool30001o`03000Co`3oool0oooo008006Go00<00:go0?ooo`3oool01@3oool01@00Col0
oooo0?ooo`3oool00;7o00D0oooo00<00=oo0?ooo`3oool00P3oool00`00ROl0oooo0?ooo`02003F
o`80003o103oool2002?o`H0oooo00<00?oh0?ooo`3oool01P3oool00`00[_l0oooo0?ooo`030?oo
o`03003Qo`3oool0oooo00H0oooo00@00>7o0?ooo`3oool00:ko0P00>_l30?ooo`@009[o00<008?o
0?ooo`3oool00P3oool00`00fol0oooo0?ooo`080?ooo`03001ko`3oool0083o00T0oooo00<006oo
0?ooo`3oool01@3oool300P0o`03000000006Ol0oooo00H0oooo00<003;o01/0o`0K0?l00P0K0?l5
0?ooo`0303T0o`3oool0oooo00H0oooo00<000000?ooo`3oool00`3oool000030000003oool0oooo
0080oooo0`00000D0?ooo`030?l0D@3oool0oooo00X0oooo00<0o`3?0?ooo`3oool02@3oool00`2E
0?l0oooo0?ooo`020?ooo`@0lP3o0`3oool00`0N0?l0oooo0?ooo`030?ooo`0308<0o`3oool000co
008000co1@3oool01P00K_l0oooo0?ooo`3oool08@3o001fo`H0oooo00<005;o0?ooo`3oool00`3o
ool01@004ol0007o0001o`000Ol0oooo008006Go00<00:go001Uo`3oool00P3oool2002Bo`80oooo
00<004oo0?ooo`3oool01`3oool00`00gol0oooo0?ooo`020?ooo`040029o`3oool0oooo003Fo`80
003o0`3oool00`00L?l008oo002?o`02002?o`D0oooo00<00?oh0?ooo`3oool01P3oool00`00[_l0
oooo0?ooo`040?ooo`03003Qo`3oool0oooo00D0oooo00<00>7o0?ooo`00>_l00P00>_l50?ooo`03
002Jo`3oool008?o00<008?o0P3oool00`00fol0oooo0?ooo`020?ooo`8008ko103oool00`00Nol0
oooo0020o`030?ooo`03001Do`3oool0oooo00<0oooo00<006oo0?ooo`3oool01P3oool300P0o`03
000000006Ol0oooo00D0oooo100K0?l70?ooo`0303T0o`3oool0oooo00D0oooo00<000000?ooo`3o
ool00`3oool000030000003oool00000008000005P3oool00`3o0540oooo0?ooo`0:0?ooo`030?l0
c`3oool0oooo0080oooo0P3o09450?ooo`0309D0o`3oool0oooo00<0oooo00<0lP3o0?ooo`3b0?l0
103oool00`0N0?l0oooo0?ooo`030?ooo`0308<0o`3oool000co00<000co0P3oool201D0o`D0oooo
00<007Ko0?ooo`3oool00`3oool00`00D_l0oooo0?ooo`050?ooo`<0007o0P3oool00`00IOl00:go
0?ooo`020?ooo`<009;o00<0oooo001?o`3oool00`3oool00`00T?l0oooo03X0o`030?ooo`03003O
o`3oool0oooo00D0oooo00<00=Ko0000o`3oool0103oool00`00L?l008oo0?ooo`040?ooo`800;Wo
00<00?oh002io`3oool01@3oool00`00b_l00:ko0?ooo`050?ooo`03003Qo`3oool0oooo00H0oooo
00<00>7o0?ooo`00>_l00P00>_l40?ooo`03002Jo`3oool008?o008008?o1`3oool4002>o`<0oooo
00D007_o0?ooo`3oool0083o0?ooo`03001Do`D0oooo00<006oo0?ooo`3oool01`3oool00`080?l0
oooo000000070?ooo`<06`3o3`3oool00`000000oooo0?ooo`030?ooo`000P00000H0?ooo`030?l0
D@3oool0oooo00h0oooo103o09440?ooo`0309D0o`3oool0oooo00<0oooo00<0lP3o0?ooo`3oool0
103oool00`0N0?l0oooo0?ooo`030?ooo`0308<0o`3oool0oooo00<000co00<0oooo01D0o`0E0?l0
0P0E0?l40?ooo`03001fo`1M0?l0oooo00@0oooo00<005;o0?ooo`3oool0103oool00`000Ol0oooo
0?ooo`020?ooo`03001Uo`3oool0000000<0oooo0P00T_l00`3oool009;o001?o`020?ooo`<0093o
0P0j0?l30?ooo`03003Oo`00F?l0oooo00D0oooo00<00=Ko0?ooo`3oool01@3oool00`00Sol0073o
0?ooo`040?ooo`800;Wo1P3oool2003:o`05002^o`00b_l0oooo0?ooo`005Ol0103oool00`00V_l0
oooo0?ooo`040?ooo`03003Qo`3oool0oooo0080oooo00D003[o0?ooo`3oool0oooo002Jo`020?oo
o`8008?o1`3oool3002>o`D0oooo00@007_o0?ooo`3oool0oooo1000E?l40?ooo`03001_o`3oool0
oooo00P0oooo00<0203o000Io`000000203oool00`0K0?l0oooo0?ooo`0=0?ooo`030000003oool0
oooo00<0oooo00000`3oool000000000000F0?ooo`030?l0D@3oool0oooo00h0oooo1@3o09440?oo
o`0309D0o`3oool0oooo0080oooo00<0lP3o0?ooo`3oool02P3oool010230?l0oooo0?ooo`003?l5
0?ooo`805@3o00@0oooo01D0o`3oool0oooo0`1M0?l40?ooo`03001Bo`004Ol0oooo00D0oooo00<0
007o0?ooo`3oool00P3oool00`00IOl0oooo000000040?ooo`8009;o00<0oooo001?o`3oool01@00
T?l203X0o`80oooo0P00F?l00`00<ol0oooo0?ooo`020?ooo`03003Fo`3oool0oooo00H0oooo00<0
08oo001`o`3oool01@3oool00`00^Ol0oooo0?ooo`050?ooo`04003:o`00[_l0oooo0?ooo`<001Go
0P3oool2002Jo`H0oooo00<00>7o0?ooo`3oool01`3oool01@00V_l0oooo0?ooo`3oool008?o00P0
oooo00<008ko0?ooo`3oool00`3oool00`00Nol0oooo0?ooo`04001Do`03000<o`3oool0oooo00<0
oooo00@006oo0?ooo`3oool001Wo1`3oool00`080?l000000?ooo`080?ooo`0301/0o`3oool0oooo
00`0oooo00<000000?ooo`3oool00`3oool000<0oooo00<000000?ooo`3oool04`3oool00`3o0540
oooo0?ooo`0?0?ooo`@0o`2A0`3oool00`2E0?l0oooo0?ooo`030?ooo`030?80o`3oool0oooo00L0
oooo00@0Q`3o0?ooo`3oool0P`3o0P3oool00`003?l0oooo0?ooo`030?ooo`<05@3o0P3oool405d0
o`<0oooo00@0017o001Bo`004Ol0017o0`3oool00`00>_l0007o0?ooo`060?ooo`030000003oool0
oooo0080oooo00<009;o0?ooo`00Col00`3oool3002@o`80>P3o0P3oool4001Ho`8003?o0P3oool0
0`00e_l0oooo001no`060?ooo`03002?o`3oool0oooo00D0oooo00<00;Wo0?ooo`3oool01@3oool0
1000b_l00:ko0?ooo`3oool4000Eo`@009[o0P3oool01000KOl0oooo0?ooo`00hOl90?ooo`05002J
o`3oool0oooo0?ooo`00Pol0203oool00`00S_l0oooo0?ooo`070?ooo`8000co00<005Co0?ooo`3o
ool0103oool00`00Kol0oooo000Io`03000Io`H0oooo00@001Wo0000003oool06`3o1`3oool00`0K
0?l0oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo0140
oooo00<0o`1A0?ooo`3oool0403oool0103o0940oooo0?l0T@3o09420?ooo`0309D0o`3oool0oooo
00<0oooo00<0lP3o0?ooo`3oool01P3oool308L0o`050?ooo`230?l0oooo0?ooo`003?l01@3oool0
0`0E0?l0oooo0?ooo`040?ooo`<0G@3o0`3oool00`00D_l0017o000Ao`020?ooo`8003[o00<0oooo
0001o`3oool0103oool01`00>_l0oooo0000003oool0NP3o0?ooo`00T_l00P3oool00`00Col0oooo
0?ooo`020?ooo`04002@o`3oool0oooo03X0o`<0oooo0`00F?l01@00<ol0oooo0?ooo`3oool00=Ko
00<007ko1@3oool00`00Sol009_o0?ooo`050?ooo`03002io`3oool0oooo00D0oooo00<00<[o0?oo
o`3oool00P3oool2000Eo`80oooo0P00V_l20?ooo`@006go1P3oool2002@o`80oooo00<009[o0?oo
o`3oool00P3oool00`00Pol0oooo0?ooo`060?ooo`03002>o`3oool0oooo00L0oooo00<000co001D
o`3oool01`3oool3000Io`L0oooo00<001Wo0?ooo`0000000`0K0?l50?ooo`0301/0o`3oool0oooo
00/0oooo00<000000?ooo`3oool00`3oool000D0oooo0P00000@0?ooo`030?l0D@3oool0oooo0100
oooo00<0o`2A0?ooo`3oool0103oool00`2E0?l0oooo0?ooo`020?ooo`030?80o`3oool0oooo00H0
oooo00@0Q`3o0?ooo`270?l0Q`3o103oool00`3:0?l0oooo0?ooo`030?ooo`0301D0o`3oool0oooo
00@0oooo00<0G@3o0?ooo`3oool00`3oool00`00D_l0oooo0?ooo`030?ooo`04000jo`000Ol0oooo
000jo`80oooo0`00>_l00`3oool0000007X0o`0207X0o`04002Bo`3oool0oooo0180o`<0oooo00<0
093o0?ooo`3oool01@3oool00`00F?l0oooo000co`050?ooo`8007ko1P3oool00`00Sol009_o0?oo
o`040?ooo`0301/0o`00^Ol0oooo00H0oooo00<00<[o0?ooo`3oool0103oool010005Ol0oooo0?oo
o`00V_l30?ooo`8006go1P3oool4002@o`030?ooo`00V_l0oooo00D0oooo00<0073o0?ooo`3oool0
103oool00`00S_l0oooo0?ooo`080?ooo`03001Do`003?l0oooo00L0oooo0P006Ol80?ooo`06000I
o`0K0?l0000001/0o`3oool06`3o1@3oool00`0K0?l0M03o07@0o`0;0?ooo`030000003oool0oooo
0080oooo00070?ooo`030000003oool0oooo01l0oooo00<0o`2A0?ooo`3oool0103oool00`2E0?l0
oooo0?ooo`020?ooo`030?80o`3oool0oooo00P0oooo0`270?l20?ooo`<0bP3o103oool00`0E0?l0
oooo0?ooo`040?ooo`0305d0o`3oool0oooo00@0oooo00<0017o0?ooo`3oool0103oool010000Ol0
03[o0?ooo`3oool5000jo`D0NP3o00@000co0180o`3oool04P3o0P3oool00`00T?l0oooo0?ooo`05
0?ooo`03001Ho`3oool003?o00H0oooo00<007ko0?ooo`3oool00`3oool01000Sol009_o002Ko`00
Vol30?ooo`<06`3o00<0oooo001lo`3oool0103oool00`00b_l0oooo0?ooo`070?ooo`03002Jo`3o
ool0oooo0080oooo00<006go0?ooo`3oool01@3oool2002@o`80oooo00<009[o0?ooo`3oool00`3o
ool3001`o`030008o`3oool0oooo00<0oooo00<008ko0?ooo`3oool01`3oool00`00E?l0oooo000<
o`090?ooo`03000Io`3oool0oooo00D0oooo00D001Wo01/0o`0K0?l0000001/0o`060?ooo`0301/0
o`1d0?l0M03o0080M03o2@3oool00`000000oooo0?ooo`020?ooo`00203oool2000001h0oooo00<0
o`2A0?ooo`3oool02P3oool00`3b0?l0oooo0?ooo`070?ooo`0408L0o`3oool0Q`3o0?ooo`D0bP3o
0`3oool00`0E0?l0oooo0?ooo`040?ooo`0305d0o`0V0?l09P3o00/0oooo00<0007o0?ooo`3oool0
0`3oool3000jo`040?ooo`000000NP3o07X0o`<000co100B0?l01@3oool0093o0?ooo`3oool003Oo
00<0oooo00<005So0?ooo`3oool01`3oool00`00O_l0oooo0?ooo`030?ooo`03002?o`00Vol009_o
00@0oooo0`0K0?l2001lo`@0oooo00<004Go003:o`3oool01`3oool00`00V_l0oooo0?ooo`040?oo
o`03001]o`3oool0oooo00D0oooo00@0093o0?ooo`3oool009[o1@3oool4001`o`8000So0`3oool0
1@00S_l0oooo0?ooo`3oool003;o00D0oooo00<005Co0?ooo`003?l02@3oool00`006Ol0oooo0?oo
o`080?ooo`030000000K0?l0oooo00D0oooo00@0M03o01/0o`1d0?l0M03o2P3oool00`000000oooo
0?ooo`020?ooo`002P3oool00`000000oooo0?ooo`0K0?ooo`030?l0T@3oool0oooo00T0oooo00<0
lP3o0?ooo`3oool0203oool00`270?l0oooo0?ooo`020?ooo`@0bP3o0`3oool00`0E0?l0oooo0?oo
o`030?ooo`0402H0o`1M0?l09P3o02H0o`@0oooo00<09`3o0?ooo`3oool0103oool00`000Ol0oooo
0?ooo`030?ooo`08000jo`3oool0oooo0?ooo`000000oooo000<o`3oool2000<o`<04P3o00<0oooo
002@o`3oool00`00=ol30?ooo`03001Ho`3oool0oooo00L0oooo00<007ko0?ooo`3oool00`3oool0
0`00Sol009_o0?ooo`040?ooo`806`3o00@007co0?ooo`00O?l007co0P3oool20015o`03003:o`00
AOl0oooo00D0oooo00<007So002Jo`3oool01@3oool00`00KOl0oooo0?ooo`050?ooo`03002@o`3o
ool0oooo00L0oooo0P00L?l20008o`L0oooo1000<_l30?ooo`04001Do`3oool0oooo000<o`80oooo
00<001[o0?ooo`3oool0103oool00`006Ol0oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo
101d0?l:0?ooo`030000003oool0oooo0080oooo000;0?ooo`030000003oool0oooo01T0oooo00<0
o`2A0?ooo`3oool02@3oool0103b0?l0oooo0?ooo`3oool20?l0_PD0oooo00<0Q`3o0?ooo`3oool0
103oool20<X0o`<0oooo00<05@3o0?ooo`3oool0103oool01@1M0?l09P3o02H0o`3oool09P3o0080
oooo0P0W0?l50?ooo`03000jo`3oool0oooo0080oooo00<0GP3o0?ooo`00>_l00P3oool010000000
oooo0?ooo`3oool3000<o`050?ooo`0B0?l0oooo0?ooo`00T?l00P3oool3000go`80oooo00@005So
0?ooo`00FOl005Wo1P3oool00`00O_l0EP3o0?ooo`040?ooo`03002Ko`3oool0oooo00@0oooo0P0K
0?l2001lo`<0oooo0`00AOl60?ooo`8007So00<009[o0?ooo`3oool0303oool00`00T?l0oooo0?oo
o`070?ooo`04001`o`002?l000So0008o`L0oooo0`00<_l50?ooo`03001Do`3oool0oooo0080oooo
0P006_l50?ooo`03000Io`3oool0oooo00P0oooo00<06`3o0000003oool01`3oool00`1d0?l0oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo000<0?ooo`800000603oool00`3o0940oooo0?oo
o`0<0?ooo`@0o`2n1@3oool00`270?l0oooo0?ooo`030?ooo`030<X0o`3oool0oooo00X0oooo00@0
G@3o02H0o`0V0?l09P3o0P3oool402L0o`@0oooo00@0C`3o0?ooo`3oool0oooo0P1N0?l01@00>_l0
oooo0?ooo`3oool0000000<0oooo00D000co0?ooo`3oool0oooo0180o`050?ooo`8003Oo0`3oool0
1000F?l005Wo001Io`00FOl60?ooo`0305H0o`00A_l0oooo00@0oooo00<009_o0?ooo`3oool01P3o
ool00`00O?l0oooo0?ooo`030?ooo`8004Go1@3oool3001ho`03002Jo`00N?l0oooo00H0oooo00@0
06ko0?ooo`3oool03`3o0P3oool00`00T?l0oooo0?ooo`070?ooo`05001`o`3oool0oooo0?ooo`00
2?l01`3oool2000bo`D0oooo00@005Co0?ooo`3oool0oooo10006_l50?ooo`03000Io`3oool0A`3o
00P0oooo00<06`3o0000003oool01`3oool00`1d0?l0oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo000>0?ooo`030000003oool0oooo01@0oooo00<0o`2A0?ooo`3oool0303oool50?l0_P@0
oooo00<0Q`3o0?ooo`3oool00`3oool00`3:0?l0oooo0?ooo`0:0?ooo`0305d0o`3oool09P3o00@0
oooo100W0?l20?ooo`<0C`3o0P3oool305h0o`06000jo`1N0?l0oooo0?ooo`0000006@3o0P3oool0
0`003?l0oooo0?ooo`070?ooo`05000go`3oool0oooo0?ooo`00F?l00P3oool3001Io`@0oooo00@0
EP3o0016o`00A_l0EP3o103oool00`00Vol000go0?ooo`060?ooo`03001lo`3oool0oooo00@0oooo
00<004Go0?ooo`3oool0103oool2001ho`03002Jo`3oool0oooo00D0oooo0P00K_l0103oool03`3o
00l0o`0?0?l20?ooo`03002@o`3oool0oooo00L0oooo00@0073o0?ooo`3oool000So203oool00`00
<_l0oooo0?ooo`030?ooo`04001Do`3oool0oooo0?ooo`<001[o1P3oool00`006Ol0A`3o04L0o`02
04L0o`H0oooo00D06`3o0?ooo`000000oooo05h0o`060?ooo`0307@0o`3oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool000l0oooo0P00000D0?ooo`030?l0T@3oool0oooo00d0oooo103o0;h3
0?ooo`0308L0o`3oool0oooo00@0oooo00<0bP3o0?ooo`3oool01@3oool00`2B0?l0oooo0?ooo`02
0?ooo`0305d0o`0V0?l0oooo00@0oooo00<09`3o0?ooo`3oool00P3oool504l0o`80oooo00<0GP3o
000jo`1N0?l00P3oool301T0o`030?ooo`003?l0oooo00P0oooo00<003Oo0?ooo`3oool00P3oool0
0`00F?l0oooo0?ooo`02001Io`D0oooo1000A_l30?ooo`04000=o`00Vol000go000=o`H0oooo00<0
07co0?ooo`3oool0103oool00`00AOl0oooo0?ooo`050?ooo`03001ho`00V_l0oooo00D0oooo1000
K_l400l0o`030?ooo`00T?l0oooo00<0oooo0P00;ol30?ooo`05001`o`3oool0oooo0?ooo`002?l0
203oool00`00<_l0oooo0?ooo`080?ooo`03000Jo`3oool0oooo00D0oooo1@170?l60?ooo`0301/0
o`000000oooo00<0GP3o103oool00`1d0?l0oooo0?ooo`070?ooo`030000003oool0oooo0040oooo
000A0?ooo`030000003oool0oooo0100oooo00<0o`2A0?ooo`3oool03P3oool0103o0;h0oooo0?l0
_P3o0;h30?ooo`0308L0o`3oool0oooo00<0oooo00<0bP3o0?ooo`3oool0103oool30980o`<0oooo
00<0G@3o0?ooo`0V0?l0103oool00`0W0?l0oooo0?ooo`040?ooo`@0C`3o00@0oooo05h0o`3oool0
03[o0`3oool201T0o`030?ooo`0I0?l000co00<0oooo00<000So0?ooo`3oool00`3oool01000=ol0
oooo0?ooo`2G0?l40?ooo`03001Io`3oool0oooo00D0oooo0`00A_l40?ooo`8000go1`3oool00`00
O?l0oooo0?ooo`0<0?ooo`03001ho`3oool0oooo00H0oooo0P00K_l0103oool03`3o00l0o`0?0?l6
0?ooo`8002oo00D0oooo000_o`00;ol0oooo001`o`050?ooo`03000co`3oool0oooo00@0oooo00<0
03;o0?ooo`3oool0203oool00`006_l0oooo0?ooo`060?ooo`<0A`3o1`3oool00`0K0?l0oooo0000
000405h0o`@0oooo00<0M03o0?ooo`3oool01P3oool00`000000oooo0?ooo`010?ooo`004P3oool2
000000l0oooo00<0o`2A0?ooo`3oool03`3oool00`3o0;h0oooo0?ooo`030?ooo`0308L0o`3oool0
oooo00<0oooo00<0bP3o0?ooo`3oool0103oool50980o`<0oooo00<0^03o0?ooo`3oool00`3oool0
0`0W0?l0oooo0?ooo`040?ooo`0304l0o`3oool0C`3o0080oooo00<0GP3o0?ooo`3oool0103oool2
01T0o`03000<o`3oool0oooo00<000So1`3oool309L0o`<0oooo00<005Wo0?ooo`3oool01@3oool0
0`00A_l0oooo0?ooo`050?ooo`03000=o`3oool0oooo00<0oooo00@004[o001lo`00B_l004[o2`3o
ool00`0h0?l0oooo001ho`090?ooo`05001^o`3oool0oooo0?ooo`0?0?l01P3oool01000;ol0oooo
000_o`00;ol20?ooo`03001`o`3oool0oooo00<0oooo0P00<ol60?ooo`03000bo`3oool0oooo00P0
oooo00<001[o0?ooo`3oool01`3oool00`170?l0oooo0?ooo`060?ooo`0301/0o`1N0?l000000080
GP3o1@3oool00`1d0?l0oooo0?ooo`060?ooo`030000003oool0oooo0040oooo000D0?ooo`030000
003oool0oooo01d0oooo00<0o`2n0?ooo`3oool02P3oool00`3:0?l0oooo0?ooo`050?ooo`@0TP3o
00@0oooo0;P0o`2h0?l0^03o103oool00`0W0?l0oooo0?ooo`040?ooo`0304l0o`3oool0oooo00X0
oooo00<06@3o0?ooo`003?l00`3oool30008o`D0oooo00<0U`3o0080o`2G0?l00P2G0?l01@3oool0
05Wo0?ooo`3oool0=03o00D0oooo00<004Ko0?ooo`3oool01@3oool00`003Ol0oooo0?ooo`040?oo
o`03001lo`00B_l0oooo00L0oooo00<0057o0?ooo`3oool00`0h0?l00`00N?l0oooo0?ooo`070?oo
o`03001^o`3oool0oooo0080oooo00<03`3o0?ooo`3oool0103oool2000_o`<0oooo00<0073o0?oo
o`3oool00P3oool4000co`D0oooo00D003;o0?ooo`3oool0oooo03D0o`060?ooo`03000Jo`3oool0
oooo00P0oooo00<0A`3o0?ooo`3oool01@3oool01@0K0?l0oooo05h0o`000000GP3o00H0oooo00<0
M03o0?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`0K
0?ooo`030?l0_P3oool0oooo00X0oooo00<0bP3o0?ooo`3oool01P3oool0102B0?l0oooo0?ooo`3o
ool50;P0o`<0oooo00<09`3o0?ooo`3oool00P3oool20780o`0304l0o`3oool0oooo00T0oooo00D0
6@3o000000003?l0oooo0=h0o`020?ooo`8000So1@3oool30080o`80U`3o0P3oool01000FOl0=03o
03@0o`0d0?l40?ooo`030016o`3oool0oooo00H0oooo00<000go0?ooo`3oool0103oool00`00O?l0
04[o0?ooo`060?ooo`80057o0P3oool303P0o`03001ho`3oool0oooo00L0oooo00<006ko0?ooo`3o
ool00P3oool00`0?0?l0oooo0?ooo`050?ooo`05000_o`3oool0oooo0?ooo`00L?l0103oool3000c
o`T0oooo0`0e0?l50?ooo`03000Jo`3oool0oooo00P0oooo00<0A`3o0?ooo`3oool02@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0040oooo000F0?ooo`8000006P3oool00`3o0;h0
oooo0?ooo`0;0?ooo`030<X0o`3oool0oooo00D0oooo00<0TP3o0?ooo`3oool00`3oool20;P0o`05
0?ooo`2h0?l0oooo0?ooo`0W0?l01P3oool00`1?0?l0LP3o0780o`030?ooo`80DP3o1@3oool00`0I
0?l00000000<o`030=h0o`030008o`3oool0oooo00@0oooo00D00P3o0?ooo`020?l00P3o09L0o`03
0?ooo`03001Io`3oool0=03o0080=03o0`3oool00`00A_l0oooo000;o`0=0?ooo`03001:o`3oool0
oooo00D0oooo1000DOl20?ooo`80>03o1`3oool010005Ol0oooo0?ooo`00K_l=0?ooo`03000_o`3o
ool0oooo00L0oooo00<003?o0?ooo`3oool01`3oool403D0o`@0oooo00D001[o0?ooo`3oool0oooo
02h0o`070?ooo`0304L0o`3oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`010?ooo`00603oool00`000000oooo0?ooo`0G0?ooo`030?l0_P3oool0oooo00X0oooo00@0
bP3o0?ooo`3oool0o`3D103oool00`2B0?l0oooo0?ooo`040?ooo`<0^03o2@3oool00`1b0?l0C`3o
0780o`020?ooo`@0DP3o1P3oool00`000000gP3o0=h0o`020=h0o`030008o`3oool0oooo00D0oooo
0P020?l70?ooo`80=03o103oool00`00A_l000_o000;o`0=0?ooo`03001:o`3oool0oooo00H0oooo
0P00DOl40?ooo`0303P0o`3oool0oooo00@0oooo10005Ol00`00K_l0oooo0?ooo`040?ooo`03000_
o`3oool0oooo00@0oooo00<002oo0?ooo`3oool01`3oool00`00<ol0oooo0?ooo`080?ooo`80=@3o
1P3oool00`006_l0oooo02h0o`0302h0o`D0oooo00<0A`3o0?ooo`3oool02@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0040oooo000I0?ooo`8000005P3oool00`3o0;h0oooo0?oo
o`0<0?ooo`<0o`3D103oool00`2B0?l0oooo0?ooo`030?ooo`030;P0o`3oool0oooo00X0oooo00<0
C`3o0?ooo`3oool00`3oool20580o`030?ooo`1B0?l0oooo00<0oooo00<0F@3o0000003oool00`3N
0?l01@002?l0oooo0?ooo`3oool0P03o00<0oooo00<00P3o0?ooo`3oool01P3oool00`0d0?l0oooo
0?ooo`030?ooo`040016o`3oool000_o000;o`H0oooo00<001go0?ooo`3oool00`3oool00`00B_l0
oooo0?ooo`070?ooo`03001Ao`3oool0oooo00<0oooo00<0>03o0?ooo`3oool0103oool2000Eo`03
0?ooo`00K_l0oooo00@0oooo0`00;ol60?ooo`03000_o`3oool0oooo00H0oooo00<003?o0?ooo`3o
ool02@3oool00`0e0?l0oooo0?ooo`040?ooo`03000Jo`3oool0;P3o00@0;P3o1@3oool00`170?l0
oooo0?ooo`080?ooo`0305h0o`000000oooo00/0oooo00<000000?ooo`3oool00@3oool001/0oooo
00<000000?ooo`3oool04P3oool00`3o0;h0oooo0?ooo`0;0?ooo`80o`3D00<0oooo0?l0e03o0=@0
0`3oool00`2B0?l0oooo0?ooo`030?ooo`030;P0o`3oool0oooo00X0oooo00<0LP3o04l0o`3oool0
103oool30580o`@0oooo0P1I0?l01@000000oooo0=h0o`3N0?l000So0080oooo10200?l00`3oool0
0P3o0?ooo`080?ooo`0303@0o`3oool0oooo0080oooo00@004Ko0?ooo`002ol000_o1P3oool3000M
o`80oooo0P1_0?l00`00B_l0K`3o06l0o`060?ooo`03001Ao`3oool0oooo00@0oooo00<0>03o0?oo
o`3oool0103oool010005Ol0oooo0?ooo`00K_l50?ooo`@002oo1@3oool01000;ol0oooo0?ooo`3o
ool203`0o`<0oooo00<003?o0?ooo`3oool02P3oool00`0e0?l0oooo0?ooo`060?ooo`<0;P3o4P3o
ool0101N0?l000000:h0o`2^0?l:0?ooo`4000000@3oool10?ooo`00703oool00`000000oooo0?oo
o`0A0?ooo`030?l0_P3oool0oooo00`0oooo103o0=@30?ooo`030980o`3oool0oooo00<0oooo00<0
^03o0?ooo`3oool0103oool20;L0o`@0oooo00<0C`3o0?ooo`3oool0103oool00`1B0?l0oooo0?oo
o`030?ooo`@0F@3o00@0oooo0=h0o`3oool000So0`3oool20800o`80oooo00<00P3o0?ooo`3oool0
0P0o0?l:0?ooo`030016o`3oool000_o00H0oooo1@007Ol20?ooo`<0K`3o1P3oool00`0G0?l0057o
0?ooo`0=0?ooo`03000Eo`3oool0oooo00H0oooo0P00;ol90?ooo`80?03o00D0oooo03`0o`0l0?l0
oooo000co`0<0?ooo`0303D0o`3oool0oooo00P0oooo00<0;P3o0?ooo`3oool0403oool00`1N0?l0
[P3o000000030:h0o`P0oooo0@0000010?ooo`40oooo000M0?ooo`800000403oool00`3o0;h0oooo
0?ooo`0=0?ooo`030?l0e03oool0o`3D00<0oooo00<0TP3o0?ooo`3oool00`3oool00`2h0?l0oooo
0?ooo`030?ooo`@0]`3o2P3oool00`1B0?l0oooo0?ooo`020?ooo`030=80o`3oool0F@3o00<0F@3o
1`3oool20800o`030?ooo`020?l0oooo0080?`3o00<0oooo03l0o`3oool02`3oool00`002ol0[`3o
0?ooo`050?ooo`<001go103oool206l0o`D0oooo0P0G0?l00`00DOl05`3o0?ooo`0<0?ooo`03000E
o`3oool0oooo00H0oooo00<002oo0?ooo`3oool0203oool0100l0?l0oooo03`0o`0l0?l30?ooo`03
000co`3oool0oooo0080oooo00<06P3o0?ooo`3oool01@3oool00`0e0?l0oooo0?ooo`070?ooo`03
02h0o`3oool0oooo0140oooo00@0GP3o0000002^0?l0[P3o2@3oool100000040oooo0@3oool001l0
oooo00<000000?ooo`3oool07@3oool00`3o0=@0oooo0?ooo`090?ooo`030;P0o`3oool0oooo00@0
oooo0P2g0?l00`3oool0]`3o0?ooo`030?ooo`030;d0o`3oool0oooo0080oooo00@0DP3o0?ooo`3o
ool0oooo0`3B0?l0101I0?l0oooo0?ooo`0000060?ooo`050800o`3oool0oooo0?ooo`020?l00P3o
ool203l0o`030?ooo`0o0?l0oooo00@0oooo00<09`3o0?ooo`3oool00`3oool00`002ol0[`3o0:l0
o`050?ooo`03000Mo`3oool0oooo00D0oooo00<0K`3o0?ooo`3oool00`3oool201L0o`03001Ao`3o
ool0oooo00H0oooo00<0017o0?ooo`3oool00`3oool00`005Ol0oooo0?ooo`060?ooo`03000_o`3o
ool0oooo00T0oooo0P0l0?l40?ooo`04000co`3oool0oooo0?ooo`@06P3o1@3oool00`0e0?l0oooo
0?ooo`070?ooo`0302h0o`3oool0oooo0140oooo00<0GP3o0:h0o`0000002P3oool100000040oooo
0@3oool00200oooo0P00000L0?ooo`030?l0e03oool0oooo00T0oooo00<0^03o0?ooo`3oool01@3o
ool30;L0o`<0oooo0`2m0?l30?ooo`040580o`3oool0oooo0?ooo`<0dP3o00D0F@3o0=80o`3oool0
oooo000000060?ooo`040800o`3oool0oooo0080o`@0oooo0P0o0?l50?ooo`809`3o103oool00`2_
0?l000_o0:l0o`020:l0o`@0oooo00<001go0?ooo`3oool01@3oool00`1_0?l0oooo0?ooo`040?oo
o`0301L0o`00DOl0oooo00H0oooo0P004Ol50?ooo`03000Eo`3oool0oooo00@0oooo00@0F@3o0?oo
o`3oool002oo303oool01@0l0?l0oooo0?ooo`3oool003?o00<0oooo1@0J0?l?0?ooo`0302h0o`3o
ool0oooo01<0oooo00<000000?ooo`3oool01`3oool100000040oooo0@3oool00280oooo00<00000
0?ooo`3oool0603oool00`3o0=@0oooo0?ooo`0:0?ooo`030;P0o`3oool0oooo00@0oooo00<0]`3o
0?ooo`3oool00P3oool20;d0o`030?ooo`2m0?l0_@3o00<0oooo00<0DP3o0?ooo`3oool00P3oool2
0=80o`0605T0o`3oool0oooo0?ooo`000000U@3o203oool01@020?l0oooo0?ooo`3oool0?`3o00H0
oooo100W0?l40?ooo`<0[`3o1@3oool00`007Ol0D`3o0?ooo`0<0?ooo`0301L0o`00DOl0oooo00D0
oooo00@0017o0?ooo`004Ol0017o2P3oool305T0o`030?ooo`00;ol0oooo00/0oooo00<0?03o0?oo
o`3oool01P3oool301X0oa00oooo00D0;P3o0?ooo`3oool0oooo08@0o`0A0?ooo`030:h0o`000000
oooo00L0oooo0@0000010?ooo`40oooo000S0?ooo`030000003oool0oooo01L0oooo00<0o`3D0?oo
o`3oool02@3oool00`2h0?l0oooo0?ooo`050?ooo`030;L0o`3oool0oooo00<0oooo102m0?l80?oo
o`030=80o`1I0?l0oooo0080oooo102E0?l;0?ooo`0403l0o`3oool0oooo0?H0o`@0oooo0`0W0?l5
0?ooo`030:l0o`3oool0oooo00<0oooo00<0D`3o000Mo`1C0?l03@3oool00`0G0?l0oooo0?ooo`06
0?ooo`80017o2P3oool205T0o`040?ooo`1I0?l0F@3o000_o`d0oooo00<0?03o0?ooo`3oool01P3o
ool00`0J0?l0oooo0?ooo`0@0?ooo`0302h0o`3oool0Q03o00<0Q03o403oool00`2^0?l000000?oo
o`060?ooo`4000000@3oool10?ooo`00903oool2000001H0oooo00<0o`3D0?ooo`3oool02P3oool3
0?l0e0@0oooo00<0]`3o0?ooo`3oool0103oool00`2m0?l0oooo0;d0o`090?ooo`030=80o`1I0?l0
oooo00<0oooo0P2E0?l00`3oool0U@3o0?ooo`030?ooo`0307/0o`3oool0oooo0080oooo00<0?`3o
0?ooo`3f0?l00P3f0?l40?ooo`809`3o1P3oool00`2_0?l0oooo0?ooo`030?ooo`04000Mo`1C0?l0
D`3o05<0o`H0oooo00<0803o0?ooo`3oool00`3oool00`0G0?l0oooo0?ooo`070?ooo`03000Ao`3o
ool0oooo00T0oooo0`1I0?l00`3oool002oo0?ooo`050?ooo`030240o`3oool0oooo00@0oooo00<0
?03o0?ooo`3oool01P3oool00`0J0?l0oooo0?ooo`0@0?ooo`0302h0o`3oool0Q03o00@0Q03o3`3o
ool00`2^0?l000000?ooo`060?ooo`4000000@3oool10?ooo`009P3oool00`000000oooo0?ooo`0B
0?ooo`030?l0e03oool0oooo00X0oooo103o0=@40?ooo`030;L0o`3oool0oooo00@0oooo00<0_@3o
0?ooo`3oool00P3oool00`3c0?l0oooo0?ooo`030?ooo`030=80o`1I0?l0oooo00@0oooo0`2E0?l3
0?ooo`<0N`3o103oool00`0o0?l0mP3o0?H0o`030?H0o`80oooo00<09`3o0?ooo`3oool0303oool0
0`007Ol0oooo05<0o`060?ooo`<0803o103oool00`0G0?l0oooo0?ooo`050?ooo`0308H0o`004Ol0
oooo00`0oooo00@0F@3o0?ooo`3oool002oo1@3oool40240o`h0oooo00<06P3o0?ooo`3oool04P3o
ool308@0oa40oooo00<0[P3o0000003oool01P3oool100000040oooo000W0?ooo`8000004P3oool0
0`3o0=@0oooo0?ooo`0;0?ooo`80o`3D00D0oooo0?l0e03oool0oooo0;L0o`060?ooo`030;d0o`3o
ool0oooo0080oooo0`3c0?l50?ooo`0305T0o`3oool0oooo0080oooo00H0U@3o0000003oool0oooo
0?l0_@3oool507/0o`D0oooo0`3f0?l30?ooo`0402L0o`3oool0V`3o09/0o`/0oooo00<001go05<0
o`3oool01@3oool50200o`X0oooo0P260?l00`004Ol0oooo0?ooo`0;0?ooo`0305T0o`3oool0oooo
00D0oooo00@08@3o0?ooo`0Q0?l08@3o3`3oool00`0J0?l0oooo0?ooo`0D0?ooo`0308@0o`3oool0
oooo00l0oooo00<0[P3o0?ooo`0000001P3oool100000040oooo000Y0?ooo`030000003oool0oooo
00h0oooo00<0o`3D0?ooo`3oool0303oool30?l0e0X0oooo00@0_@3o0?ooo`3oool0oooo103c0?l:
0?ooo`0309D0o`000000oooo00<0o`2m00D0oooo07/0o`1k0?l0oooo07/0o`050?ooo`80mP3o103o
ool0100W0?l0V`3o0?ooo`2K0?l<0?ooo`0305<0o`3oool0oooo00D0oooo0`0P0?l:0?ooo`<0QP3o
00<0017o08H0o`3oool0303oool00`1I0?l0oooo0?ooo`050?ooo`808@3o403oool00`0J0?l0oooo
0?ooo`020?ooo`80M@3o403oool00`240?l0oooo0?ooo`0@0?ooo`030:h0o`3oool0000000D0oooo
0@0000010?ooo`00:P3oool2000001`0oooo00<0o`3D0?ooo`3oool02P3oool00`2m0?l0oooo0?oo
o`030?ooo`80l`3o00<0oooo0?<0o`3oool00`3oool01`3J0?l0oooo0?ooo`3oool0U@3o0?ooo`00
0000103o0;d0103oool0N`3o07/0o`1k0?l60?ooo`030?H0o`3oool0oooo00<0oooo00D09`3o09/0
o`2K0?l0oooo09/0o`0;0?ooo`0305<0o`3oool0oooo00H0oooo00<0803o0?ooo`3oool02P3oool2
08H0o`03000Ao`3oool0oooo00D0oooo00<0?`3o0?ooo`3oool0103oool00`1I0?l0oooo0?ooo`06
0?ooo`030240o`3oool0oooo00l0oooo00<06P3o0?ooo`3oool00P1e0?l00`3oool0M@3o07D0o`0>
0?ooo`0308@0o`3oool0oooo0100oooo00@0[P3o0?ooo`3oool00000103oool100000040oooo000/
0?ooo`030000003oool0oooo01T0oooo00<0o`3D0?ooo`3oool02@3oool00`2m0?l0oooo0?ooo`04
0?ooo`<0l`3o0`3oool30=X0o`<0oooo00@0U@3o0?ooo`000000oooo103o0;d0101k0?l0oooo0?oo
o`3[0?l:0?ooo`0302L0o`3oool0oooo0080V`3o1P3oool00`1S0?l0oooo0?ooo`030?ooo`0305<0
o`3oool0oooo00D0oooo00<0803o0?ooo`3oool0303oool00`260?l0017o0?ooo`050?ooo`<0?`3o
3`3oool00`0Q0?l0oooo0?ooo`0>0?ooo`0501X0o`3oool0oooo07D0o`3oool00P1e0?l@0?ooo`03
08@0o`3oool0oooo0180oooo00<000000?ooo`3oool00P3oool100000040oooo000]0?ooo`030000
003oool0oooo01L0oooo00<0o`3D0?ooo`3oool02P3oool00`2m0?l0oooo0?ooo`030?ooo`030?<0
o`3oool0oooo0080oooo0P3J0?l00`3oool0fP3o0=X0o`050?ooo`030000003oool0o`2m0080o`2m
00<0oooo07/0o`3oool00`3[0?l90?ooo`0402L0o`3oool0oooo09/0o`D0oooo101S0?l;0?ooo`03
0<40o`0P0?l0`@3o00d0oooo00<0QP3o0?ooo`3oool0103oool01@0o0?l0oooo03l0o`3oool0?`3o
00h0oooo00<08@3o0?ooo`3oool04P3oool207D0oa40oooo00<0Q03o0?ooo`3oool04`3oool01@00
0000oooo0?ooo`3oool000000040oooo000^0?ooo`8000005`3oool00`3o0=@0oooo0?ooo`090?oo
o`030;d0o`3oool0oooo00<0oooo00<0l`3o0?ooo`3oool0103oool40=X0o`D0oooo00<000000?l0
_@3oool00P3oool00`1k0?l0oooo0>/0o`040>/0o`/0oooo00<0V`3o0?ooo`3oool0103oool206<0
o`030?ooo`1S0?l0oooo00P0oooo0P310?l00`0P0?l0`@3o0<40o`0<0?ooo`0308H0o`3oool0oooo
00D0oooo0`0o0?l?0?ooo`030240o`3oool0oooo00<0oooo00<0O`3o0?ooo`3oool03@3oool00`1e
0?l0oooo0?ooo`0@0?ooo`0308@0o`3oool0oooo01<0oooo00@000000?ooo`3oool000000@3oool0
0300oooo00<000000?ooo`3oool04`3oool00`3o0=@0oooo0?ooo`0:0?ooo`80o`2n103oool00`3c
0?l0oooo0?ooo`050?ooo`80fP3o1@3oool00`000000oooo0?l0_@030?ooo`0307/0o`3oool0oooo
00<0j`3o2`3oool00`2K0?l0oooo0?ooo`050?ooo`<0H`3o2`3oool00`310?l0803o0<40o`070?oo
o`030740o`3oool0oooo00<0oooo00<0QP3o0?ooo`3oool01P3oool00`0o0?l0oooo0?ooo`0>0?oo
o`030240o`3oool0oooo0080oooo0`1o0?l?0?ooo`0307D0o`3oool0oooo00l0oooo00<0Q03o0?oo
o`3oool0503oool00`000000oooo000000010?ooo`00<@3oool200000180oooo00<0o`3D0?ooo`3o
ool02@3oool40?l0_P<0oooo00<0l`3o0?ooo`3oool01@3oool0103J0?l0oooo0?ooo`3oool20?l0
_080oooo00<000000?ooo`3oool00P3oool0101k0?l0oooo0?ooo`3oool20>/0o`H0oooo0P2c0?l4
0?ooo`0309/0o`3oool0oooo00@0oooo00<0H`3o0?ooo`3o0?X03@3oool00`0P0?l0oooo0?ooo`05
0?ooo`<0L@3o3@3oool00`0o0?l0oooo0?ooo`0>0?ooo`040240o`3oool0oooo0?ooo`D0O`3o3P3o
ool00`1e0?l0oooo0?ooo`0W0?ooo`4000000@3oool100000000<`3oool00`000000oooo0?ooo`0?
0?ooo`030?l0e03oool0oooo00X0oooo0P3o0;h00`3oool0o`2n0?ooo`080?ooo`040=X0o`3oool0
oooo0?ooo`<0o`2l0P3oool00`000000oooo0?ooo`020?ooo`0507/0o`3oool0oooo0?ooo`3[0?l0
1@3oool40;<0o`/0oooo00@0H`3o0?l0nP3o0?X0o`3j303oool00`310?l0oooo0?ooo`040?ooo`D0
L@3o303oool00`0o0?l0oooo0?ooo`0C0?ooo`<0O`3o3`3oool00`1e0?l0oooo0?ooo`0W0?ooo`40
00000@3oool100000000=03oool00`000000oooo0?ooo`0=0?ooo`030?l0e03oool0oooo00/0oooo
0`3o0;h:0?ooo`0:0=X0o`3oool0oooo0?l0_03oool0o`2l0?ooo`3o0;`0oooo000000L0oooo00<0
j`3o0?ooo`3oool01@3oool20;<0o`030?ooo`2c0?l0oooo00T0oooo00<0H`3o0?l0nP3o0?X00P3o
0?X;0?ooo`030<40o`3oool0oooo00D0oooo0`1a0?l=0?ooo`0303l0o`3oool0oooo01@0oooo00<0
O`3o0?ooo`3oool03`3oool00`1e0?l0oooo0?ooo`0W0?ooo`800000000e0?ooo`8000006`3oool2
0?l0_PX0oooo00<0fP3o0?ooo`3oool00P3oool30?l0_080oooo00@000000?ooo`3o0?<0o`3c103o
ool00`3[0?l0oooo0?ooo`050?ooo`<0/`3o2P3oool00`1S0?l0oooo0?l0nP020?l0nP`0oooo00<0
`@3o0?ooo`3oool01P3oool00`1a0?l0oooo0?ooo`0<0?ooo`0303l0o`3oool0oooo00@0oooo00<0
W`3o0?ooo`3oool03P3oool00`1o0?l0oooo0?ooo`0>0?ooo`0307D0o`3oool0oooo02H0oooo0`00
000003L0oooo00<000000?ooo`3oool05`3oool00`3o0;h0oooo0?ooo`0:0?ooo`030=X0o`3oool0
oooo0080oooo0P3o0;`30?ooo`040000003o0?<0o`3c0?l0l``0oooo00<0/`3o0?ooo`3o0:h02P3o
ool0101S0?l0oooo0?l0nP3o0?X70?ooo`030;40o`3oool0oooo00/0oooo00<0L@3o0?ooo`3oool0
3@3oool00`0o0?l0oooo0?ooo`030?ooo`<0W`3o3`3oool00`1o0?l0oooo0?ooo`0c0?ooo`@00000
0`3oool003P0oooo0P00000F0?ooo`030?l0_P3oool0oooo00X0oooo00<0fP3o0?ooo`3oool00P3o
ool00`3o0;`0oooo0?ooo`030?ooo`050?l0l`3oool0o`3c0?ooo`3o0?<02P3oool00`2c0?l0oooo
0?l0[P020?l0[P/0oooo00<0o`3j0?ooo`3oool0103oool50;40o`/0oooo00<0L@3o0?ooo`3oool0
4P3oool01@2O0?l0oooo09l0o`3oool0W`3o00h0oooo00<0O`3o0?ooo`3oool0;P3oool5000000L0
oooo000j0?ooo`030000003oool0oooo01<0oooo00<0o`2n0?ooo`3oool03`3oool00`3o0;`0oooo
0?ooo`030?ooo`040000003o0?<0o`3c0?l0l`/0oooo00<0/`3o0?l0[P3o0:h00`3o0:h:0?ooo`03
0?l0nP3oool0oooo00D0oooo0`2a0?l<0?ooo`030740o`3oool0oooo01<0oooo0`2O0?l?0?ooo`03
07l0o`3oool0oooo02X0oooo1000000<0?ooo`00>`3oool00`000000oooo0?ooo`0A0?ooo`030?l0
_P3oool0oooo00X0oooo0P3o09430?ooo`030?l0_03oool0oooo00@0oooo00D000000?l0l`3o0?<0
oooo0?l0G0090?ooo`030;<0o`3oool0oooo00<0o`2^1@3oool20?d0o`@0oooo00<0o`3j0?ooo`3o
ool01@3oool20;40o`d0oooo00<0L@3o0?ooo`3oool01@3oool00`3@0?l0oooo0?ooo`0<0?ooo`03
09l0o`3oool0oooo00h0oooo00<0O`3o0?ooo`3oool09P3oool400000100oooo000l0?ooo`800000
4@3oool00`3o0;h0oooo0?ooo`080?ooo`@0o`2A2P3oool00`3o0?<0oooo0?ooo`040?l0G0L0oooo
00<0/`3o0?ooo`3oool00P3o0:h50?ooo`<0o@3o303oool00`2a0?l0oooo0?ooo`0<0?ooo`030740
o`3oool0oooo00@0oooo0`3@0?l>0?ooo`0309l0o`3oool0oooo0340oooo1@00000D0?ooo`00?P3o
ool00`000000oooo0?ooo`0=0?ooo`030?l0_P3oool0oooo00X0oooo0P3o09400`3oool0o`2A0?oo
o`080?ooo`030?l0l`3oool0o`1L00D0o`1L203oool00`3o0:h0oooo0?ooo`040?ooo`050?d0o`3o
ool0o@3o0?ooo`3m0?l02`3oool00`2a0?l0oooo0?ooo`0B0?ooo`050=00o`3oool0d03o0?ooo`3@
0?l03@3oool00`2O0?l0oooo0?ooo`0]0?ooo`@000006@3oool003l0oooo0P00000J0?ooo`<0o`2A
2@3oool0103o0?<000000?ooo`3oool40?l0G0T0oooo00<0o`2^0?ooo`3oool01@3oool30?d0o`/0
oooo00<0/@3o0?ooo`3oool0503oool30=00o`h0oooo00<0W`3o0?ooo`3oool0:03oool5000001d0
oooo00110?ooo`030000003oool0oooo01H0oooo00<0o`2A0?ooo`3o09402P3oool0103o0?<00000
0?ooo`3oool20?l0G0D0oooo0P3o0:d<0?ooo`80o@3o303oool00`2a0?l0oooo0?ooo`060?ooo`80
o`3`3@3oool00`3@0?l0oooo0?ooo`0=0?ooo`0309l0o`3oool0oooo02@0oooo1000000R0?ooo`00
@P3oool2000001H0oooo00<0o`2A0?ooo`3oool02@3oool00`3o0?<0oooo000000020?ooo`030?l0
G03oool0oooo0080oooo1@3o0:d:0?ooo`030?d0o`3oool0oooo00`0oooo00<0/@3o0?ooo`3oool0
1@3oool40?l0l0`0oooo00<0d03o0?ooo`3oool0;`3oool5000002H0oooo00140?ooo`030000003o
ool0oooo0180oooo00<0o`2A0?ooo`3oool0303oool00`000000oooo0?l0G0060?ooo`<0o`2]00<0
oooo0?l0[@3oool0203oool00`3m0?l0oooo0?ooo`0C0?ooo`030?l0l03oool0o`3`0080oooo00<0
o`3`0?ooo`3oool02@3oool00`3@0?l0oooo0?ooo`0[0?ooo`@00000:`3oool004D0oooo00<00000
0?ooo`3oool0403oool00`3o0940oooo0?ooo`090?ooo`070?l0D@3oool0oooo0?ooo`000000oooo
0?l0G0060?ooo`@0o`2]2@3oool00`3m0?l0oooo0?ooo`080?ooo`030?l0Y`3oool0oooo00X0oooo
103o0?0<0?ooo`030=00o`3oool0oooo02L0oooo1000000_0?ooo`00AP3oool200000100oooo00<0
o`2A0?ooo`3oool0203oool30?l0D@80oooo00<000000?ooo`3oool01P3oool00`3o0:d0oooo0?l0
[@0:0?ooo`030?d0o`3oool0oooo00L0oooo0`3o0:L<0?ooo`030?l0l03oool0oooo00`0oooo00<0
d03o0?ooo`3oool08P3oool5000003<0oooo00180?ooo`030000003oool0oooo00`0oooo00<0o`2A
0?ooo`3oool0203oool50?l0D@030?ooo`000000oooo00H0oooo00<0o`2]0?ooo`3oool0503oool4
0?l0Y``0oooo00<0o`3`0?ooo`3oool0;@3oool4000003P0oooo00190?ooo`800000603oool20?l0
D@040?ooo`3o0540o`1A000000L0oooo00<0o`2]0?ooo`3oool05@3oool20?l0Y`030?ooo`3o0:L0
oooo00T0oooo00<0o`3`0?ooo`3oool0:@3oool5000003`0oooo001;0?ooo`030000003oool0oooo
01D0oooo0`3o05420?ooo`030000003oool0oooo00@0oooo00<0o`2]0?ooo`3oool02@3oool00`3o
05H0oooo0?ooo`0:0?ooo`<0o`2W2`3oool00`3o0?00oooo0?ooo`0U0?ooo`@00000@@3oool004`0
oooo00<000000?ooo`3oool0503oool00`3o0540oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<0o`2]0?ooo`3oool01`3oool40?l0EP/0oooo00<0o`2W0?ooo`3oool0;P3oool5000004D0
oooo001=0?ooo`8000004`3oool00`3o0540oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo
0P3o05H0103oool0o`1F0?l0EP3o05H:0?ooo`030?l0Y`3oool0oooo02X0oooo1000001:0?ooo`00
C`3oool00`000000oooo0?ooo`0@0?ooo`030?l0D@3oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`090?ooo`@0o`1F2P3oool00`3o0:L0oooo0?ooo`0W0?ooo`@00000
CP3oool00500oooo0P00000?0?ooo`030?l0D@3oool0oooo00@0oooo00<000000?ooo`3oool0103o
000;0?ooo`80o`1F2`3oool00`3o0:L0oooo0?ooo`0R0?ooo`D00000DP3oool00580oooo00<00000
0?ooo`3oool0303oool00`3o0540oooo0?ooo`040?ooo`030000003oool0o`0000@0o`002P3oool0
0`3o05H0oooo0?ooo`0/0?ooo`@00000E`3oool005<0oooo00<000000?ooo`3oool04P3oool02000
0000oooo0?ooo`3o0000oooo0?l0003oool0o`002@3oool00`3o05H0oooo0?ooo`0W0?ooo`D00000
F`3oool005@0oooo0P00000A0?ooo`030000003oool0oooo0080oooo0`3o00090?ooo`030?l0EP3o
ool0oooo02@0oooo1000001P0?ooo`00EP3oool00`000000oooo0?ooo`0>0?ooo`070000003oool0
oooo0?ooo`3o0000oooo0?l0000:0?ooo`030?l0EP3oool0oooo01l0oooo1@00001T0?ooo`00E`3o
ool2000000h0oooo00@000000?ooo`3oool0o`00:`3oool4000006T0oooo001I0?ooo`030000003o
ool0oooo00/0oooo00@000000?ooo`3oool0o`009`3oool4000006d0oooo001J0?ooo`8000002`3o
ool00`000000oooo0?l0000S0?ooo`D00000L@3oool005`0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0O0?ooo`@00000MP3oool005d0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0J0?ooo`D00000NP3oool005h0oooo0P0000070?ooo`030000003oool0oooo01H0
oooo1000001o0?ooo`00H03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo
1@0000230?ooo`00H@3oool2000000@0oooo00<000000?ooo`3oool03@3oool4000008P0oooo001S
0?ooo`050000003oool0oooo0?ooo`0000002`3oool4000008`0oooo001T0?ooo`040000003oool0
oooo000000H0oooo1@00002@0?ooo`00I@3oool300000080oooo1000002E0?ooo`00I`3oool30000
09T0oooo0000\
\>"],
  ImageRangeCache->{{{129.125, 388}, {402.375, 119.5}} -> {-0.376605, 
  0.393322, 0.0033031, 0.0033031}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[33]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Further examples", "Section",
  Background->GrayLevel[0.900008]],

Cell["\<\
In the previous section all functions provided with the package \
were used for 2-person asymmetric normal form game. It was enough to \
demonstrate possibilities of the package, however results were not very \
meaningful. In order to better understand features of the package two other \
games will be disccussed, namely: coordination games and ultimatum bargaining \
game.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Coordination game", "Subsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
We will discuss three-player coordination game. Consider the \
following situation. There are three hunters. Each of them have a choice to \
hunt for a stag or for a hare. They will succeed in hunting for a stag if and \
only if they all decide to do that. Should it happen one of them will hunt \
for a hare he will succeed but those hunting for a stag will fail. (Please, \
take a look at Fudenberg. D and J. Tirole - \"Game Theory\" p. 3) The very \
first thing we have to do is building payoff functions for all three players \
and define a game.\
\>", "Text"],

Cell[BoxData[
    \(p1[s_] := 
      3*s[\([1, 1]\)]\ *s[\([2, 1]\)]*s[\([3, 1]\)] - s[\([1, 1]\)]; \n
    p2[s_] := 3*s[\([1, 1]\)]\ *s[\([2, 1]\)]*s[\([3, 1]\)] - s[\([2, 1]\)]; 
    \np3[s_] := 
      3*s[\([1, 1]\)]\ *s[\([2, 1]\)]*s[\([3, 1]\)] - s[\([3, 1]\)]; \n
    g\  = \ Game[{p1, p2, p3}, {2, 2, 2}]; \)], "Input",
  CellLabel->"In[3]:="],

Cell["Next, we are ready to solve the game", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquilibriumFilter[\ 
        Solve[\ SamplingEquilibriumEqs[g, {x, y, z}], \ 
          VarList[g, {x, y, z}]]] // ColumnForm\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            \({x[1.`] \[Rule] 1.`, x[2.`] \[Rule] 0, y[1.`] \[Rule] 1.`, 
              y[2.`] \[Rule] 0, z[1.`] \[Rule] 1.`, z[2.`] \[Rule] 0}\)},
          {
            \({x[1.`] \[Rule] 0, x[2.`] \[Rule] 1.`, y[1.`] \[Rule] 0, 
              y[2.`] \[Rule] 1.`, z[1.`] \[Rule] 0, z[2.`] \[Rule] 1.`}\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {{x[ 1.0] -> 1.0, x[ 2.0] -> 0, y[ 1.0] -> 1.0, y[ 2.0] -> 
        0, z[ 1.0] -> 1.0, z[ 2.0] -> 0}, {x[ 1.0] -> 0, x[ 2.0] -> 1.0, y[ 
        1.0] -> 0, y[ 2.0] -> 1.0, z[ 1.0] -> 0, z[ 2.0] -> 1.0}}],
      Editable->False]], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["\<\
As we could expect there are two 1-sampling equilibria: all hunters \
hunt for a stag or all hunters hunt for hares (they are also Nash \
equilibria). More important question is, which one of them is a satble one? \
To answer this question we have to build 1-sampling dynamics. Once again \
we'll use WinningProbabilityDiff[] function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ode\  = \ WinningProbabilityDiff[g, {x, y, z}]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({\(-x[1]\) + y[1]\^2\ z[1]\^2 + y[1]\ y[2]\ z[1]\^2 + 
        y[1]\^2\ z[1]\ z[2] + y[1]\ y[2]\ z[1]\ z[2], 
      \(-x[2]\) + y[1]\ y[2]\ z[1]\^2 + y[2]\^2\ z[1]\^2 + 
        y[1]\^2\ z[1]\ z[2] + 3\ y[1]\ y[2]\ z[1]\ z[2] + 
        2\ y[2]\^2\ z[1]\ z[2] + y[1]\^2\ z[2]\^2 + 2\ y[1]\ y[2]\ z[2]\^2 + 
        y[2]\^2\ z[2]\^2, 
      \(-y[1]\) + x[1]\^2\ z[1]\^2 + x[1]\ x[2]\ z[1]\^2 + 
        x[1]\^2\ z[1]\ z[2] + x[1]\ x[2]\ z[1]\ z[2], 
      \(-y[2]\) + x[1]\ x[2]\ z[1]\^2 + x[2]\^2\ z[1]\^2 + 
        x[1]\^2\ z[1]\ z[2] + 3\ x[1]\ x[2]\ z[1]\ z[2] + 
        2\ x[2]\^2\ z[1]\ z[2] + x[1]\^2\ z[2]\^2 + 2\ x[1]\ x[2]\ z[2]\^2 + 
        x[2]\^2\ z[2]\^2, 
      x[1]\^2\ y[1]\^2 + x[1]\ x[2]\ y[1]\^2 + x[1]\^2\ y[1]\ y[2] + 
        x[1]\ x[2]\ y[1]\ y[2] - z[1], 
      x[1]\ x[2]\ y[1]\^2 + x[2]\^2\ y[1]\^2 + x[1]\^2\ y[1]\ y[2] + 
        3\ x[1]\ x[2]\ y[1]\ y[2] + 2\ x[2]\^2\ y[1]\ y[2] + 
        x[1]\^2\ y[2]\^2 + 2\ x[1]\ x[2]\ y[2]\^2 + x[2]\^2\ y[2]\^2 - z[2]}
      \)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["\<\
As before we have to both drop every second expression and use \
transformation rules to get rid of unnecessary variables to plot a vector \
field.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ode\  = \ Drop[ode, {6}]; \ ode\  = \ Drop[ode, \ {4}]; \ 
    ode = Drop[ode, {2}]; \n
    ode\  = \ \(\(ode\  /. \ x[2] -> \((1 - x[1])\)\) /. 
          y[2] -> \((1 - y[1])\)\) /. z[2] -> \((1 - z[1])\); \ ode\)], 
  "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \({\(-x[1]\) + \((1 - y[1])\)\ y[1]\ \((1 - z[1])\)\ z[1] + 
        y[1]\^2\ \((1 - z[1])\)\ z[1] + \((1 - y[1])\)\ y[1]\ z[1]\^2 + 
        y[1]\^2\ z[1]\^2, 
      \(-y[1]\) + \((1 - x[1])\)\ x[1]\ \((1 - z[1])\)\ z[1] + 
        x[1]\^2\ \((1 - z[1])\)\ z[1] + \((1 - x[1])\)\ x[1]\ z[1]\^2 + 
        x[1]\^2\ z[1]\^2, 
      \((1 - x[1])\)\ x[1]\ \((1 - y[1])\)\ y[1] + 
        x[1]\^2\ \((1 - y[1])\)\ y[1] + \((1 - x[1])\)\ x[1]\ y[1]\^2 + 
        x[1]\^2\ y[1]\^2 - z[1]}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["\<\
Now we are ready to plot out 3-dimentional vector field reflecting \
behavior of three (different) populations of hunters.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlotVectorField3D[ode, \ {x[1], \ 0, \ 1}, \n\ \ \ \ {y[1], \ 0, \ 1}, 
      \ {z[1], \ 0, \ 1}, \ PlotPoints\  -> \ 10, \n\ \ \ \ 
      VectorHeads\  -> \ True, \ ColorFunction -> Hue, 
      ViewPoint -> {0.361, \ \(-2.960\), \ 1.600}]\)], "Input",
  CellLabel->"In[8]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.14457 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0640241 1.23057 -1.11022e-016 1.23057 [
[ 0 0 0 0 ]
[ 1 1.14457 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08053 .06867 m
0 .84747 L
s
0 .84747 m
.22356 1.14457 L
s
.22356 1.14457 m
.26125 .4973 L
s
.26125 .4973 m
.08053 .06867 L
s
.93221 0 m
.93171 .45505 L
s
.93171 .45505 m
.98265 1.11622 L
s
.98265 1.11622 m
1 .79786 L
s
1 .79786 m
.93221 0 L
s
.08053 .06867 m
0 .84747 L
s
0 .84747 m
1 .79786 L
s
1 .79786 m
.93221 0 L
s
.93221 0 m
.08053 .06867 L
s
.26125 .4973 m
.93171 .45505 L
s
.93171 .45505 m
.98265 1.11622 L
s
.98265 1.11622 m
.22356 1.14457 L
s
.22356 1.14457 m
.26125 .4973 L
s
0 0 m
1 0 L
1 1.14457 L
0 1.14457 L
closepath
clip
newpath
0 .536 1 r
.5 Mabswid
.27814 .50661 m
.26955 .48583 L
s
0 .493 1 r
.34752 .50226 m
.33514 .4856 L
s
0 .369 1 r
.41729 .4979 m
.40117 .48537 L
s
0 .17 1 r
.48744 .49351 m
.46766 .48514 L
s
0 .536 1 r
.27157 .48499 m
.27705 .48967 L
s
.26552 .4904 m
.27157 .48499 L
s
.27157 .48499 m
.26955 .48583 L
s
.271 .49508 m
.26552 .4904 L
s
.26552 .4904 m
.26955 .48583 L
s
.27705 .48967 m
.271 .49508 L
s
.26955 .48583 m
.27705 .48967 L
s
.092 0 1 r
.55799 .48909 m
.5346 .48491 L
s
0 .536 1 r
.26955 .48583 m
.271 .49508 L
s
0 .493 1 r
.27477 .56812 m
.27081 .5436 L
s
.33767 .48356 m
.34335 .48827 L
s
.33193 .48968 m
.33767 .48356 L
s
.33767 .48356 m
.33514 .4856 L
s
.33762 .4944 m
.33193 .48968 L
s
.33193 .48968 m
.33514 .4856 L
s
.405 0 1 r
.62892 .48465 m
.60201 .48467 L
s
0 .493 1 r
.34335 .48827 m
.33762 .4944 L
s
.33514 .4856 m
.34335 .48827 L
s
.33514 .4856 m
.33762 .4944 L
s
0 .579 1 r
.34501 .5639 m
.33728 .54382 L
s
0 .369 1 r
.40477 .49375 m
.39869 .48897 L
s
.39869 .48897 m
.40409 .48207 L
s
.39869 .48897 m
.40117 .48537 L
s
.40409 .48207 m
.41018 .48684 L
s
.40409 .48207 m
.40117 .48537 L
s
.761 0 1 r
.70026 .48018 m
.66988 .48443 L
s
0 .369 1 r
.41018 .48684 m
.40477 .49375 L
s
.40117 .48537 m
.40477 .49375 L
s
.40117 .48537 m
.41018 .48684 L
s
0 .578 1 r
.41563 .55965 m
.40418 .54405 L
s
0 .17 1 r
.47247 .49312 m
.46582 .48828 L
s
.46582 .48828 m
.47085 .48055 L
s
.46582 .48828 m
.46766 .48514 L
s
1 0 .85 r
.77199 .47569 m
.73823 .48419 L
s
0 .17 1 r
.47085 .48055 m
.47752 .48539 L
s
.47085 .48055 m
.46766 .48514 L
s
0 .491 1 r
.48665 .55537 m
.47153 .54427 L
s
0 .17 1 r
.47752 .48539 m
.47247 .49312 L
s
.46766 .48514 m
.47247 .49312 L
s
0 .493 1 r
.27197 .54369 m
.27762 .54852 L
s
.2656 .54859 m
.27197 .54369 L
s
.27197 .54369 m
.27081 .5436 L
s
0 .17 1 r
.46766 .48514 m
.47752 .48539 L
s
1 0 .436 r
.84412 .47118 m
.80705 .48395 L
s
0 .493 1 r
.27125 .55343 m
.2656 .54859 L
s
.2656 .54859 m
.27081 .5436 L
s
.27762 .54852 m
.27125 .55343 L
s
.27081 .5436 m
.27762 .54852 L
s
.092 0 1 r
.54069 .49252 m
.53333 .48761 L
s
.53333 .48761 m
.53798 .479 L
s
.53333 .48761 m
.5346 .48491 L
s
0 .921 1 r
.26312 .47027 m
.25514 .45097 L
s
.092 0 1 r
.53798 .479 m
.54536 .48389 L
s
.53798 .479 m
.5346 .48491 L
s
0 .324 1 r
.55807 .55108 m
.53933 .5445 L
s
0 .493 1 r
.27081 .5436 m
.27125 .55343 L
s
.092 0 1 r
.54536 .48389 m
.54069 .49252 L
s
.5346 .48491 m
.54069 .49252 L
s
0 .579 1 r
.33905 .54276 m
.34464 .54753 L
s
.33304 .54823 m
.33905 .54276 L
s
.33905 .54276 m
.33728 .54382 L
s
0 .369 1 r
.27132 .63117 m
.2721 .60276 L
s
.092 0 1 r
.5346 .48491 m
.54536 .48389 L
s
1 0 0 r
.91667 .46663 m
.87636 .48371 L
s
0 .579 1 r
.33862 .553 m
.33304 .54823 L
s
.33304 .54823 m
.33728 .54382 L
s
.405 0 1 r
.60943 .49191 m
.60125 .48696 L
s
.60125 .48696 m
.6055 .47742 L
s
.60125 .48696 m
.60201 .48467 L
s
0 .878 1 r
.33406 .46573 m
.32213 .45017 L
s
0 .579 1 r
.34464 .54753 m
.33862 .553 L
s
.33728 .54382 m
.34464 .54753 L
s
0 .088 1 r
.62989 .54676 m
.60757 .54472 L
s
0 .579 1 r
.33728 .54382 m
.33862 .553 L
s
.405 0 1 r
.6055 .47742 m
.61369 .48236 L
s
.6055 .47742 m
.60201 .48467 L
s
.61369 .48236 m
.60943 .49191 L
s
.60201 .48467 m
.60943 .49191 L
s
0 .578 1 r
.34242 .62707 m
.33947 .60342 L
s
.40646 .54178 m
.41218 .54652 L
s
.40082 .54788 m
.40646 .54178 L
s
.40646 .54178 m
.40418 .54405 L
s
.40654 .55263 m
.40082 .54788 L
s
.40082 .54788 m
.40418 .54405 L
s
.405 0 1 r
.60201 .48467 m
.61369 .48236 L
s
0 .753 1 r
.40541 .46115 m
.38958 .44936 L
s
.761 0 1 r
.67868 .49131 m
.66959 .48633 L
s
.66959 .48633 m
.67341 .47583 L
s
.66959 .48633 m
.66988 .48443 L
s
.207 0 1 r
.70212 .54241 m
.67627 .54495 L
s
0 .578 1 r
.41218 .54652 m
.40654 .55263 L
s
.40418 .54405 m
.41218 .54652 L
s
.40418 .54405 m
.40654 .55263 L
s
.761 0 1 r
.67341 .47583 m
.68251 .4808 L
s
.67341 .47583 m
.66988 .48443 L
s
0 .707 1 r
.41393 .62295 m
.40727 .6041 L
s
.761 0 1 r
.68251 .4808 m
.67868 .49131 L
s
.66988 .48443 m
.67868 .49131 L
s
0 .491 1 r
.475 .55229 m
.46893 .54754 L
s
.46893 .54754 m
.47418 .54074 L
s
.46893 .54754 m
.47153 .54427 L
s
0 .555 1 r
.47716 .45656 m
.45749 .44855 L
s
0 .491 1 r
.47418 .54074 m
.48025 .54549 L
s
.47418 .54074 m
.47153 .54427 L
s
0 .921 1 r
.25702 .45032 m
.26199 .45453 L
s
.25152 .4552 m
.25702 .45032 L
s
.25702 .45032 m
.25514 .45097 L
s
1 0 .85 r
.74842 .49072 m
.73836 .48571 L
s
.73836 .48571 m
.74174 .47423 L
s
.73836 .48571 m
.73823 .48419 L
s
.548 0 1 r
.77476 .53804 m
.74543 .54518 L
s
.761 0 1 r
.66988 .48443 m
.68251 .4808 L
s
0 .921 1 r
.25648 .45942 m
.25152 .4552 L
s
.25152 .4552 m
.25514 .45097 L
s
.26199 .45453 m
.25648 .45942 L
s
.25514 .45097 m
.26199 .45453 L
s
0 .491 1 r
.48025 .54549 m
.475 .55229 L
s
.47153 .54427 m
.475 .55229 L
s
.47153 .54427 m
.48025 .54549 L
s
0 .369 1 r
.27223 .60371 m
.27827 .60879 L
s
.26561 .6082 m
.27223 .60371 L
s
.27223 .60371 m
.2721 .60276 L
s
0 .747 1 r
.48584 .6188 m
.4755 .60477 L
s
0 .921 1 r
.25514 .45097 m
.25648 .45942 L
s
1 0 .85 r
.74174 .47423 m
.75182 .47922 L
s
.74174 .47423 m
.73823 .48419 L
s
.75182 .47922 m
.74842 .49072 L
s
.73823 .48419 m
.74842 .49072 L
s
0 .295 1 r
.54932 .45193 m
.52586 .44773 L
s
0 .369 1 r
.27827 .60879 m
.27165 .61329 L
s
.2721 .60276 m
.27827 .60879 L
s
0 .324 1 r
.544 .55199 m
.5374 .54723 L
s
.5374 .54723 m
.54223 .53967 L
s
.5374 .54723 m
.53933 .5445 L
s
0 .369 1 r
.27165 .61329 m
.26561 .6082 L
s
.26561 .6082 m
.2721 .60276 L
s
1 0 .436 r
.81867 .49011 m
.80757 .4851 L
s
.80757 .4851 m
.81049 .47261 L
s
.80757 .4851 m
.80705 .48395 L
s
0 .324 1 r
.54223 .53967 m
.54884 .54443 L
s
.54223 .53967 m
.53933 .5445 L
s
.926 0 1 r
.84782 .53364 m
.81506 .54542 L
s
0 .878 1 r
.32457 .44841 m
.32971 .45262 L
s
.31937 .454 m
.32457 .44841 L
s
.32457 .44841 m
.32213 .45017 L
s
.32452 .45822 m
.31937 .454 L
s
.31937 .454 m
.32213 .45017 L
s
.25948 .53276 m
.25573 .50962 L
s
0 .324 1 r
.54884 .54443 m
.544 .55199 L
s
.53933 .5445 m
.544 .55199 L
s
1 0 .85 r
.73823 .48419 m
.75182 .47922 L
s
0 .369 1 r
.2721 .60276 m
.27165 .61329 L
s
0 .694 1 r
.55816 .61463 m
.54416 .60545 L
s
0 .878 1 r
.32971 .45262 m
.32452 .45822 L
s
.32213 .45017 m
.32971 .45262 L
s
0 .324 1 r
.53933 .5445 m
.54884 .54443 L
s
0 .578 1 r
.34033 .60331 m
.34602 .60818 L
s
.33411 .60822 m
.34033 .60331 L
s
.34033 .60331 m
.33947 .60342 L
s
0 .878 1 r
.32213 .45017 m
.32452 .45822 L
s
1 0 .436 r
.81049 .47261 m
.82162 .4776 L
s
.81049 .47261 m
.80705 .48395 L
s
.014 0 1 r
.62189 .44728 m
.5947 .44691 L
s
0 .088 1 r
.61355 .55171 m
.60626 .54694 L
s
.60626 .54694 m
.61064 .53856 L
s
.60626 .54694 m
.60757 .54472 L
s
1 0 .436 r
.82162 .4776 m
.81867 .49011 L
s
.80705 .48395 m
.81867 .49011 L
s
0 .17 1 r
.26778 .69582 m
.27342 .66335 L
s
0 .578 1 r
.3398 .6131 m
.33411 .60822 L
s
.33411 .60822 m
.33947 .60342 L
s
.34602 .60818 m
.3398 .6131 L
s
.33947 .60342 m
.34602 .60818 L
s
1 0 .667 r
.92129 .52922 m
.88516 .54565 L
s
1 0 0 r
.8894 .48951 m
.87722 .48449 L
s
.87722 .48449 m
.87969 .47098 L
s
.87722 .48449 m
.87636 .48371 L
s
0 .088 1 r
.61064 .53856 m
.61793 .54333 L
s
.61064 .53856 m
.60757 .54472 L
s
0 .963 1 r
.33132 .52834 m
.32364 .50928 L
s
0 .753 1 r
.39311 .45705 m
.3876 .45281 L
s
.3876 .45281 m
.39244 .44644 L
s
.3876 .45281 m
.38958 .44936 L
s
.39244 .44644 m
.39796 .45068 L
s
.39244 .44644 m
.38958 .44936 L
s
0 .088 1 r
.61793 .54333 m
.61355 .55171 L
s
.60757 .54472 m
.61355 .55171 L
s
0 .578 1 r
.33947 .60342 m
.3398 .6131 L
s
0 .552 1 r
.63089 .61043 m
.61326 .60614 L
s
1 0 .436 r
.80705 .48395 m
.82162 .4776 L
s
0 .753 1 r
.39796 .45068 m
.39311 .45705 L
s
.38958 .44936 m
.39311 .45705 L
s
.38958 .44936 m
.39796 .45068 L
s
0 .088 1 r
.60757 .54472 m
.61793 .54333 L
s
0 .707 1 r
.40875 .60285 m
.41429 .60757 L
s
.40294 .60824 m
.40875 .60285 L
s
.40875 .60285 m
.40727 .6041 L
s
.362 0 1 r
.69487 .4426 m
.66402 .44608 L
s
1 0 0 r
.87969 .47098 m
.89191 .47597 L
s
.87969 .47098 m
.87636 .48371 L
s
0 .491 1 r
.33978 .69185 m
.34171 .66446 L
s
.207 0 1 r
.68361 .55144 m
.67552 .54667 L
s
.67552 .54667 m
.6794 .53744 L
s
.67552 .54667 m
.67627 .54495 L
s
0 .707 1 r
.40847 .61297 m
.40294 .60824 L
s
.40294 .60824 m
.40727 .6041 L
s
1 0 0 r
.89191 .47597 m
.8894 .48951 L
s
.87636 .48371 m
.8894 .48951 L
s
0 .707 1 r
.41429 .60757 m
.40847 .61297 L
s
.40727 .6041 m
.41429 .60757 L
s
0 .961 1 r
.40356 .52389 m
.392 .50893 L
s
0 .555 1 r
.46225 .45591 m
.4562 .45163 L
s
.4562 .45163 m
.46068 .44443 L
s
.4562 .45163 m
.45749 .44855 L
s
.207 0 1 r
.6794 .53744 m
.68751 .54219 L
s
.6794 .53744 m
.67627 .54495 L
s
0 .707 1 r
.40727 .6041 m
.40847 .61297 L
s
0 .555 1 r
.46068 .44443 m
.46674 .4487 L
s
.46068 .44443 m
.45749 .44855 L
s
0 .333 1 r
.70404 .60622 m
.68281 .60683 L
s
.207 0 1 r
.68751 .54219 m
.68361 .55144 L
s
.67627 .54495 m
.68361 .55144 L
s
0 .555 1 r
.46674 .4487 m
.46225 .45591 L
s
.45749 .44855 m
.46225 .45591 L
s
.741 0 1 r
.76828 .4379 m
.73382 .44525 L
s
0 .747 1 r
.47748 .60232 m
.48309 .60696 L
s
.47208 .60825 m
.47748 .60232 L
s
.47748 .60232 m
.4755 .60477 L
s
.41218 .68786 m
.41042 .66558 L
s
1 0 0 r
.87636 .48371 m
.89191 .47597 L
s
.207 0 1 r
.67627 .54495 m
.68751 .54219 L
s
0 .555 1 r
.45749 .44855 m
.46674 .4487 L
s
.548 0 1 r
.75419 .55118 m
.74521 .54643 L
s
.74521 .54643 m
.74856 .5363 L
s
.74521 .54643 m
.74543 .54518 L
s
0 .747 1 r
.47769 .61291 m
.47208 .60825 L
s
.47208 .60825 m
.4755 .60477 L
s
0 .878 1 r
.25684 .50994 m
.26196 .51426 L
s
.25102 .51432 m
.25684 .50994 L
s
.25684 .50994 m
.25573 .50962 L
s
0 .873 1 r
.47622 .51941 m
.4608 .50858 L
s
0 .747 1 r
.48309 .60696 m
.47769 .61291 L
s
.4755 .60477 m
.48309 .60696 L
s
0 .295 1 r
.53192 .45479 m
.52521 .45047 L
s
.52521 .45047 m
.52929 .44238 L
s
.52521 .45047 m
.52586 .44773 L
s
0 .878 1 r
.25614 .51865 m
.25102 .51432 L
s
.25102 .51432 m
.25573 .50962 L
s
0 .747 1 r
.4755 .60477 m
.47769 .61291 L
s
0 .878 1 r
.26196 .51426 m
.25614 .51865 L
s
.25573 .50962 m
.26196 .51426 L
s
0 .048 1 r
.77761 .60197 m
.7528 .60752 L
s
.548 0 1 r
.74856 .5363 m
.75757 .54103 L
s
.74856 .5363 m
.74543 .54518 L
s
0 .17 1 r
.27236 .6651 m
.27899 .67051 L
s
.26556 .66929 m
.27236 .6651 L
s
.27236 .6651 m
.27342 .66335 L
s
0 .295 1 r
.52929 .44238 m
.53601 .44669 L
s
.52929 .44238 m
.52586 .44773 L
s
.548 0 1 r
.75757 .54103 m
.75419 .55118 L
s
.74543 .54518 m
.75419 .55118 L
s
1 0 .857 r
.8421 .43317 m
.80411 .44441 L
s
0 .878 1 r
.25573 .50962 m
.25614 .51865 L
s
0 .921 1 r
.485 .68384 m
.47955 .6667 L
s
0 .295 1 r
.53601 .44669 m
.53192 .45479 L
s
.52586 .44773 m
.53192 .45479 L
s
.926 0 1 r
.82527 .55092 m
.81532 .54621 L
s
.81532 .54621 m
.81813 .53514 L
s
.81532 .54621 m
.81506 .54542 L
s
0 .694 1 r
.54747 .61289 m
.54156 .60829 L
s
.54156 .60829 m
.54651 .60174 L
s
.54156 .60829 m
.54416 .60545 L
s
0 1 .694 r
.24739 .43222 m
.24008 .41454 L
s
0 .17 1 r
.27899 .67051 m
.2722 .67472 L
s
.27342 .66335 m
.27899 .67051 L
s
0 .694 1 r
.54651 .60174 m
.55242 .60633 L
s
.54651 .60174 m
.54416 .60545 L
s
.548 0 1 r
.74543 .54518 m
.75757 .54103 L
s
0 .295 1 r
.52586 .44773 m
.53601 .44669 L
s
0 .963 1 r
.32542 .50855 m
.33043 .51276 L
s
.31995 .51349 m
.32542 .50855 L
s
.32542 .50855 m
.32364 .50928 L
s
0 .705 1 r
.54929 .51491 m
.53006 .50823 L
s
0 .17 1 r
.2722 .67472 m
.26556 .66929 L
s
.26556 .66929 m
.27342 .66335 L
s
.014 0 1 r
.60212 .45367 m
.59465 .44932 L
s
.59465 .44932 m
.59829 .4403 L
s
.59465 .44932 m
.5947 .44691 L
s
0 .694 1 r
.55242 .60633 m
.54747 .61289 L
s
.54416 .60545 m
.54747 .61289 L
s
0 .963 1 r
.32497 .51771 m
.31995 .51349 L
s
.31995 .51349 m
.32364 .50928 L
s
0 .694 1 r
.54416 .60545 m
.55242 .60633 L
s
.289 0 1 r
.8516 .59771 m
.82324 .60822 L
s
.926 0 1 r
.81813 .53514 m
.8281 .53984 L
s
.81813 .53514 m
.81506 .54542 L
s
0 .963 1 r
.33043 .51276 m
.32497 .51771 L
s
.32364 .50928 m
.33043 .51276 L
s
0 .753 1 r
.25576 .59685 m
.25634 .56971 L
s
0 .491 1 r
.34149 .66524 m
.34752 .67029 L
s
.33513 .66969 m
.34149 .66524 L
s
.34149 .66524 m
.34171 .66446 L
s
.926 0 1 r
.8281 .53984 m
.82527 .55092 L
s
.81506 .54542 m
.82527 .55092 L
s
0 .17 1 r
.27342 .66335 m
.2722 .67472 L
s
.014 0 1 r
.59829 .4403 m
.60578 .44464 L
s
.59829 .4403 m
.5947 .44691 L
s
1 0 .436 r
.91635 .42841 m
.87488 .44356 L
s
0 .963 1 r
.32364 .50928 m
.32497 .51771 L
s
0 .999 1 r
.55825 .67981 m
.5491 .66783 L
s
1 0 .667 r
.89685 .55066 m
.88588 .54599 L
s
.88588 .54599 m
.88811 .53398 L
s
.88588 .54599 m
.88516 .54565 L
s
0 .552 1 r
.6178 .61291 m
.61139 .60835 L
s
.61139 .60835 m
.61585 .60111 L
s
.61139 .60835 m
.61326 .60614 L
s
0 1 .738 r
.31997 .42746 m
.30854 .41315 L
s
.014 0 1 r
.60578 .44464 m
.60212 .45367 L
s
.5947 .44691 m
.60212 .45367 L
s
0 .491 1 r
.34752 .67029 m
.34115 .67476 L
s
.34171 .66446 m
.34752 .67029 L
s
0 .552 1 r
.61585 .60111 m
.62227 .60566 L
s
.61585 .60111 m
.61326 .60614 L
s
0 .468 1 r
.62279 .51038 m
.59977 .50788 L
s
0 .491 1 r
.34115 .67476 m
.33513 .66969 L
s
.33513 .66969 m
.34171 .66446 L
s
.092 0 1 r
.26416 .76211 m
.27477 .72543 L
s
0 .961 1 r
.39431 .50709 m
.39944 .51125 L
s
.38923 .51266 m
.39431 .50709 L
s
.39431 .50709 m
.392 .50893 L
s
.926 0 1 r
.81506 .54542 m
.8281 .53984 L
s
.014 0 1 r
.5947 .44691 m
.60578 .44464 L
s
0 .552 1 r
.62227 .60566 m
.6178 .61291 L
s
.61326 .60614 m
.6178 .61291 L
s
.667 0 1 r
.92602 .59341 m
.89414 .60893 L
s
0 .961 1 r
.39435 .51682 m
.38923 .51266 L
s
.38923 .51266 m
.392 .50893 L
s
.362 0 1 r
.67282 .45255 m
.66451 .44819 L
s
.66451 .44819 m
.66772 .4382 L
s
.66451 .44819 m
.66402 .44608 L
s
0 .552 1 r
.61326 .60614 m
.62227 .60566 L
s
0 .961 1 r
.3285 .59255 m
.32519 .56982 L
s
0 .491 1 r
.34171 .66446 m
.34115 .67476 L
s
1 0 .667 r
.88811 .53398 m
.89912 .53863 L
s
.88811 .53398 m
.88516 .54565 L
s
0 .961 1 r
.39944 .51125 m
.39435 .51682 L
s
.392 .50893 m
.39944 .51125 L
s
0 .747 1 r
.41095 .6653 m
.41653 .67007 L
s
.40503 .67008 m
.41095 .6653 L
s
.41095 .6653 m
.41042 .66558 L
s
0 .961 1 r
.392 .50893 m
.39435 .51682 L
s
1 0 .667 r
.89912 .53863 m
.89685 .55066 L
s
.88516 .54565 m
.89685 .55066 L
s
0 .975 1 r
.63191 .67575 m
.61908 .66897 L
s
.362 0 1 r
.66772 .4382 m
.67605 .44256 L
s
.66772 .4382 m
.66402 .44608 L
s
0 .333 1 r
.68868 .61295 m
.6816 .60845 L
s
.6816 .60845 m
.68552 .60046 L
s
.6816 .60845 m
.68281 .60683 L
s
0 1 .865 r
.39296 .42267 m
.37747 .41174 L
s
.362 0 1 r
.67605 .44256 m
.67282 .45255 L
s
.66402 .44608 m
.67282 .45255 L
s
0 .747 1 r
.41061 .67486 m
.40503 .67008 L
s
.40503 .67008 m
.41042 .66558 L
s
.41653 .67007 m
.41061 .67486 L
s
.41042 .66558 m
.41653 .67007 L
s
0 .177 1 r
.69672 .50583 m
.66995 .50753 L
s
0 .333 1 r
.68552 .60046 m
.69261 .60496 L
s
.68552 .60046 m
.68281 .60683 L
s
0 .324 1 r
.33706 .75829 m
.34401 .72698 L
s
0 .873 1 r
.4643 .51598 m
.45886 .51184 L
s
.45886 .51184 m
.46354 .50556 L
s
.45886 .51184 m
.4608 .50858 L
s
0 .333 1 r
.69261 .60496 m
.68868 .61295 L
s
.68281 .60683 m
.68868 .61295 L
s
0 .873 1 r
.46354 .50556 m
.46898 .5097 L
s
.46354 .50556 m
.4608 .50858 L
s
.741 0 1 r
.74403 .45144 m
.73482 .44706 L
s
.73482 .44706 m
.73758 .43609 L
s
.73482 .44706 m
.73382 .44525 L
s
1 0 .667 r
.88516 .54565 m
.89912 .53863 L
s
0 .747 1 r
.41042 .66558 m
.41061 .67486 L
s
0 1 .694 r
.24181 .41407 m
.24624 .4178 L
s
.23688 .41842 m
.24181 .41407 L
s
.24181 .41407 m
.24008 .41454 L
s
0 1 .911 r
.40166 .58823 m
.39447 .56993 L
s
.362 0 1 r
.66402 .44608 m
.67605 .44256 L
s
0 .333 1 r
.68281 .60683 m
.69261 .60496 L
s
0 1 .694 r
.2413 .42216 m
.23688 .41842 L
s
.23688 .41842 m
.24008 .41454 L
s
0 .849 1 r
.706 .67166 m
.68949 .67011 L
s
0 .873 1 r
.46898 .5097 m
.4643 .51598 L
s
.4608 .50858 m
.4643 .51598 L
s
0 .921 1 r
.48072 .6653 m
.48606 .66986 L
s
.47525 .67046 m
.48072 .6653 L
s
.48072 .6653 m
.47955 .6667 L
s
0 .873 1 r
.4608 .50858 m
.46898 .5097 L
s
0 .048 1 r
.7601 .61302 m
.75222 .60858 L
s
.75222 .60858 m
.75554 .59979 L
s
.75222 .60858 m
.7528 .60752 L
s
0 .934 1 r
.46639 .41785 m
.44686 .41033 L
s
0 1 .694 r
.24624 .4178 m
.2413 .42216 L
s
.24008 .41454 m
.24624 .4178 L
s
.741 0 1 r
.73758 .43609 m
.74681 .44045 L
s
.73758 .43609 m
.73382 .44525 L
s
0 .753 1 r
.25651 .57096 m
.26201 .57546 L
s
.25043 .57492 m
.25651 .57096 L
s
.25651 .57096 m
.25634 .56971 L
s
0 .921 1 r
.48059 .67503 m
.47525 .67046 L
s
.47525 .67046 m
.47955 .6667 L
s
0 1 .694 r
.24008 .41454 m
.2413 .42216 L
s
.159 0 1 r
.77107 .50124 m
.7406 .50717 L
s
0 .694 1 r
.41039 .75444 m
.41366 .72853 L
s
0 .921 1 r
.48606 .66986 m
.48059 .67503 L
s
.47955 .6667 m
.48606 .66986 L
s
.741 0 1 r
.74681 .44045 m
.74403 .45144 L
s
.73382 .44525 m
.74403 .45144 L
s
0 .048 1 r
.75554 .59979 m
.76344 .60422 L
s
.75554 .59979 m
.7528 .60752 L
s
0 .705 1 r
.53479 .51518 m
.52886 .51104 L
s
.52886 .51104 m
.5331 .50399 L
s
.52886 .51104 m
.53006 .50823 L
s
0 .048 1 r
.76344 .60422 m
.7601 .61302 L
s
.7528 .60752 m
.7601 .61302 L
s
1 0 .857 r
.81574 .45031 m
.80558 .44593 L
s
.80558 .44593 m
.80788 .43395 L
s
.80558 .44593 m
.80411 .44441 L
s
0 .921 1 r
.47955 .6667 m
.48059 .67503 L
s
0 .753 1 r
.26201 .57546 m
.25594 .57943 L
s
.25634 .56971 m
.26201 .57546 L
s
0 1 .873 r
.47525 .58389 m
.46419 .57004 L
s
0 .705 1 r
.5331 .50399 m
.53904 .50813 L
s
.5331 .50399 m
.53006 .50823 L
s
.092 0 1 r
.27239 .7279 m
.27978 .73376 L
s
.26547 .73191 m
.27239 .7279 L
s
.27239 .7279 m
.27477 .72543 L
s
0 .753 1 r
.25594 .57943 m
.25043 .57492 L
s
.25043 .57492 m
.25634 .56971 L
s
0 1 .738 r
.31087 .41167 m
.31545 .41536 L
s
.30625 .41672 m
.31087 .41167 L
s
.31087 .41167 m
.30854 .41315 L
s
0 .635 1 r
.78053 .66756 m
.76033 .67126 L
s
.741 0 1 r
.73382 .44525 m
.74681 .44045 L
s
0 1 .738 r
.31083 .42041 m
.30625 .41672 L
s
.30625 .41672 m
.30854 .41315 L
s
.289 0 1 r
.83203 .6131 m
.82326 .60873 L
s
.82326 .60873 m
.82593 .59909 L
s
.82326 .60873 m
.82324 .60822 L
s
0 .048 1 r
.7528 .60752 m
.76344 .60422 L
s
0 .705 1 r
.53904 .50813 m
.53479 .51518 L
s
.53006 .50823 m
.53479 .51518 L
s
0 .674 1 r
.54024 .413 m
.51673 .4089 L
s
0 .999 1 r
.55078 .66524 m
.55612 .66965 L
s
.54578 .67085 m
.55078 .66524 L
s
.55078 .66524 m
.5491 .66783 L
s
0 .753 1 r
.25634 .56971 m
.25594 .57943 L
s
0 .705 1 r
.53006 .50823 m
.53904 .50813 L
s
0 .999 1 r
.55112 .67527 m
.54578 .67085 L
s
.54578 .67085 m
.5491 .66783 L
s
.092 0 1 r
.27978 .73376 m
.27287 .73779 L
s
.27477 .72543 m
.27978 .73376 L
s
0 1 .738 r
.31545 .41536 m
.31083 .42041 L
s
.30854 .41315 m
.31545 .41536 L
s
.529 0 1 r
.84586 .49664 m
.81172 .50681 L
s
1 0 .857 r
.80788 .43395 m
.81807 .43831 L
s
.80788 .43395 m
.80411 .44441 L
s
0 1 .738 r
.30854 .41315 m
.31083 .42041 L
s
0 .961 1 r
.32614 .5701 m
.33126 .57435 L
s
.32046 .57447 m
.32614 .5701 L
s
.32614 .5701 m
.32519 .56982 L
s
0 .999 1 r
.48415 .75057 m
.48371 .7301 L
s
0 1 .738 r
.24346 .49571 m
.23998 .47411 L
s
0 .999 1 r
.55612 .66965 m
.55112 .67527 L
s
.5491 .66783 m
.55612 .66965 L
s
.289 0 1 r
.82593 .59909 m
.83473 .60345 L
s
.82593 .59909 m
.82324 .60822 L
s
1 0 .857 r
.81807 .43831 m
.81574 .45031 L
s
.80411 .44441 m
.81574 .45031 L
s
0 .468 1 r
.60583 .51439 m
.59927 .51026 L
s
.59927 .51026 m
.60302 .50239 L
s
.59927 .51026 m
.59977 .50788 L
s
0 .999 1 r
.5491 .66783 m
.55112 .67527 L
s
1 0 .436 r
.88795 .44919 m
.87678 .4448 L
s
.87678 .4448 m
.87863 .4318 L
s
.87678 .4448 m
.87488 .44356 L
s
.289 0 1 r
.83473 .60345 m
.83203 .6131 L
s
.82324 .60822 m
.83203 .6131 L
s
.092 0 1 r
.27287 .73779 m
.26547 .73191 L
s
.26547 .73191 m
.27477 .72543 L
s
0 1 .929 r
.54927 .57951 m
.53436 .57016 L
s
0 .961 1 r
.32558 .57873 m
.32046 .57447 L
s
.32046 .57447 m
.32519 .56982 L
s
.33126 .57435 m
.32558 .57873 L
s
.32519 .56982 m
.33126 .57435 L
s
0 .468 1 r
.60302 .50239 m
.6096 .50651 L
s
.60302 .50239 m
.59977 .50788 L
s
0 .324 1 r
.34253 .72857 m
.34911 .73391 L
s
.33611 .73269 m
.34253 .72857 L
s
.34253 .72857 m
.34401 .72698 L
s
0 .346 1 r
.85549 .66343 m
.8316 .67242 L
s
.667 0 1 r
.90446 .61318 m
.89473 .6089 L
s
.89473 .6089 m
.89673 .59839 L
s
.89473 .6089 m
.89414 .60893 L
s
0 1 .865 r
.38092 .41871 m
.376 .41502 L
s
.376 .41502 m
.38028 .40919 L
s
.376 .41502 m
.37747 .41174 L
s
0 .366 1 r
.61452 .40812 m
.58708 .40747 L
s
0 1 .865 r
.38028 .40919 m
.3852 .41288 L
s
.38028 .40919 m
.37747 .41174 L
s
0 .468 1 r
.6096 .50651 m
.60583 .51439 L
s
.59977 .50788 m
.60583 .51439 L
s
0 .555 1 r
.25193 .6626 m
.25697 .63129 L
s
.092 0 1 r
.27477 .72543 m
.27287 .73779 L
s
0 .975 1 r
.62223 .67557 m
.61663 .67126 L
s
.61663 .67126 m
.62112 .66511 L
s
.61663 .67126 m
.61908 .66897 L
s
0 .961 1 r
.32519 .56982 m
.32558 .57873 L
s
0 .975 1 r
.62112 .66511 m
.62672 .66941 L
s
.62112 .66511 m
.61908 .66897 L
s
1 0 .857 r
.80411 .44441 m
.81807 .43831 L
s
.289 0 1 r
.82324 .60822 m
.83473 .60345 L
s
.926 0 1 r
.92108 .492 m
.88331 .50645 L
s
0 .324 1 r
.34911 .73391 m
.34269 .73804 L
s
.34401 .72698 m
.34911 .73391 L
s
0 1 .78 r
.55834 .74667 m
.55417 .73167 L
s
0 .468 1 r
.59977 .50788 m
.6096 .50651 L
s
1 0 .436 r
.87863 .4318 m
.88983 .43616 L
s
.87863 .4318 m
.87488 .44356 L
s
0 1 .865 r
.3852 .41288 m
.38092 .41871 L
s
.37747 .41174 m
.38092 .41871 L
s
.37747 .41174 m
.3852 .41288 L
s
0 1 .654 r
.31697 .49107 m
.30939 .47317 L
s
0 1 .911 r
.39609 .56916 m
.40103 .57325 L
s
.39082 .57401 m
.39609 .56916 L
s
.39609 .56916 m
.39447 .56993 L
s
0 .975 1 r
.62672 .66941 m
.62223 .67557 L
s
.61908 .66897 m
.62223 .67557 L
s
0 .177 1 r
.6774 .51362 m
.6701 .50949 L
s
.6701 .50949 m
.67333 .50075 L
s
.6701 .50949 m
.66995 .50753 L
s
0 .324 1 r
.34269 .73804 m
.33611 .73269 L
s
.33611 .73269 m
.34401 .72698 L
s
0 .975 1 r
.61908 .66897 m
.62672 .66941 L
s
.667 0 1 r
.89673 .59839 m
.90648 .60266 L
s
.89673 .59839 m
.89414 .60893 L
s
0 .925 1 r
.62372 .57512 m
.60496 .57027 L
s
1 0 .436 r
.88983 .43616 m
.88795 .44919 L
s
.87488 .44356 m
.88795 .44919 L
s
0 1 .911 r
.39575 .5781 m
.39082 .57401 L
s
.39082 .57401 m
.39447 .56993 L
s
.667 0 1 r
.90648 .60266 m
.90446 .61318 L
s
.89414 .60893 m
.90446 .61318 L
s
.405 0 1 r
.26043 .83013 m
.27615 .78906 L
s
0 1 .911 r
.40103 .57325 m
.39575 .5781 L
s
.39447 .56993 m
.40103 .57325 L
s
0 0 1 r
.93088 .65927 m
.90332 .67359 L
s
0 .694 1 r
.41303 .72917 m
.4189 .73407 L
s
.40709 .73345 m
.41303 .72917 L
s
.41303 .72917 m
.41366 .72853 L
s
0 .177 1 r
.67333 .50075 m
.68065 .50487 L
s
.67333 .50075 m
.66995 .50753 L
s
0 .324 1 r
.34401 .72698 m
.34269 .73804 L
s
0 .023 1 r
.68923 .40322 m
.65791 .40602 L
s
0 .934 1 r
.45157 .41703 m
.44616 .41333 L
s
.44616 .41333 m
.45005 .40666 L
s
.44616 .41333 m
.44686 .41033 L
s
0 .849 1 r
.69391 .67591 m
.68782 .67171 L
s
.68782 .67171 m
.69174 .66494 L
s
.68782 .67171 m
.68949 .67011 L
s
0 .873 1 r
.32561 .65844 m
.32678 .63185 L
s
0 1 .911 r
.39447 .56993 m
.39575 .5781 L
s
0 .177 1 r
.68065 .50487 m
.6774 .51362 L
s
.66995 .50753 m
.6774 .51362 L
s
0 .934 1 r
.45005 .40666 m
.45546 .41036 L
s
.45005 .40666 m
.44686 .41033 L
s
0 .849 1 r
.69174 .66494 m
.69783 .66913 L
s
.69174 .66494 m
.68949 .67011 L
s
0 .694 1 r
.4189 .73407 m
.41297 .73836 L
s
.41366 .72853 m
.4189 .73407 L
s
0 1 .665 r
.63296 .74276 m
.62504 .73325 L
s
.667 0 1 r
.89414 .60893 m
.90648 .60266 L
s
1 0 .436 r
.87488 .44356 m
.88983 .43616 L
s
0 1 .659 r
.39091 .48641 m
.37926 .47224 L
s
0 .694 1 r
.41297 .73836 m
.40709 .73345 L
s
.40709 .73345 m
.41366 .72853 L
s
0 .934 1 r
.45546 .41036 m
.45157 .41703 L
s
.44686 .41033 m
.45157 .41703 L
s
0 .849 1 r
.69783 .66913 m
.69391 .67591 L
s
.68949 .67011 m
.69391 .67591 L
s
0 .177 1 r
.66995 .50753 m
.68065 .50487 L
s
.159 0 1 r
.74947 .51285 m
.74136 .50875 L
s
.74136 .50875 m
.74405 .4991 L
s
.74136 .50875 m
.7406 .50717 L
s
0 1 .873 r
.46636 .56815 m
.47133 .57213 L
s
.46153 .57355 m
.46636 .56815 L
s
.46636 .56815 m
.46419 .57004 L
s
0 .934 1 r
.44686 .41033 m
.45546 .41036 L
s
0 .703 1 r
.69861 .57069 m
.67602 .57038 L
s
0 1 .873 r
.46649 .57754 m
.46153 .57355 L
s
.46153 .57355 m
.46419 .57004 L
s
0 .849 1 r
.68949 .67011 m
.69783 .66913 L
s
0 .088 1 r
.33428 .82645 m
.34637 .79104 L
s
0 1 .738 r
.24102 .47465 m
.24559 .47844 L
s
.23577 .47849 m
.24102 .47465 L
s
.24102 .47465 m
.23998 .47411 L
s
0 .694 1 r
.41366 .72853 m
.41297 .73836 L
s
0 .999 1 r
.48387 .72972 m
.48918 .73425 L
s
.47841 .73421 m
.48387 .72972 L
s
.48387 .72972 m
.48371 .7301 L
s
0 1 .873 r
.47133 .57213 m
.46649 .57754 L
s
.46419 .57004 m
.47133 .57213 L
s
.349 0 1 r
.76438 .39829 m
.72922 .40457 L
s
0 .635 1 r
.76615 .67629 m
.75939 .6722 L
s
.75939 .6722 m
.76266 .66474 L
s
.75939 .6722 m
.76033 .67126 L
s
.159 0 1 r
.74405 .4991 m
.75219 .50319 L
s
.74405 .4991 m
.7406 .50717 L
s
0 .674 1 r
.52275 .41537 m
.51673 .41165 L
s
.51673 .41165 m
.52021 .40409 L
s
.51673 .41165 m
.51673 .4089 L
s
0 1 .873 r
.46419 .57004 m
.46649 .57754 L
s
.39971 .65425 m
.39701 .63241 L
s
0 1 .738 r
.24034 .48228 m
.23577 .47849 L
s
.23577 .47849 m
.23998 .47411 L
s
.24559 .47844 m
.24034 .48228 L
s
.23998 .47411 m
.24559 .47844 L
s
.159 0 1 r
.75219 .50319 m
.74947 .51285 L
s
.7406 .50717 m
.74947 .51285 L
s
0 .674 1 r
.52021 .40409 m
.52624 .40781 L
s
.52021 .40409 m
.51673 .4089 L
s
0 1 .67 r
.70802 .73882 m
.69632 .73484 L
s
0 .635 1 r
.76266 .66474 m
.76943 .66882 L
s
.76266 .66474 m
.76033 .67126 L
s
0 .555 1 r
.25603 .6334 m
.26213 .63818 L
s
.24976 .63703 m
.25603 .6334 L
s
.25603 .6334 m
.25697 .63129 L
s
0 .999 1 r
.48918 .73425 m
.48372 .73875 L
s
.48371 .7301 m
.48918 .73425 L
s
.48372 .73875 m
.47841 .73421 L
s
.47841 .73421 m
.48371 .7301 L
s
0 1 .753 r
.46528 .48171 m
.44959 .47129 L
s
0 .635 1 r
.76943 .66882 m
.76615 .67629 L
s
.76033 .67126 m
.76615 .67629 L
s
.529 0 1 r
.82206 .51209 m
.81306 .50801 L
s
.81306 .50801 m
.81519 .49742 L
s
.81306 .50801 m
.81172 .50681 L
s
0 1 .738 r
.23998 .47411 m
.24034 .48228 L
s
0 .674 1 r
.52624 .40781 m
.52275 .41537 L
s
.51673 .4089 m
.52275 .41537 L
s
0 1 .929 r
.5378 .57703 m
.53258 .5731 L
s
.53258 .5731 m
.53693 .56707 L
s
.53258 .5731 m
.53436 .57016 L
s
0 .418 1 r
.77393 .56624 m
.74753 .5705 L
s
0 1 .929 r
.53693 .56707 m
.54216 .57099 L
s
.53693 .56707 m
.53436 .57016 L
s
.159 0 1 r
.7406 .50717 m
.75219 .50319 L
s
0 .552 1 r
.40855 .82276 m
.41697 .79303 L
s
0 .999 1 r
.48371 .7301 m
.48372 .73875 L
s
0 .555 1 r
.26213 .63818 m
.25587 .64183 L
s
.25697 .63129 m
.26213 .63818 L
s
0 .635 1 r
.76033 .67126 m
.76943 .66882 L
s
0 .674 1 r
.51673 .4089 m
.52624 .40781 L
s
.405 0 1 r
.27231 .79217 m
.2806 .79858 L
s
.26535 .79611 m
.27231 .79217 L
s
.27231 .79217 m
.27615 .78906 L
s
0 .346 1 r
.83894 .67669 m
.83138 .67272 L
s
.83138 .67272 m
.83392 .66451 L
s
.83138 .67272 m
.8316 .67242 L
s
0 1 .654 r
.31115 .47277 m
.31559 .47641 L
s
.30626 .47716 m
.31115 .47277 L
s
.31115 .47277 m
.30939 .47317 L
s
.741 0 1 r
.83998 .39333 m
.80103 .40311 L
s
0 .555 1 r
.25587 .64183 m
.24976 .63703 L
s
.24976 .63703 m
.25697 .63129 L
s
0 1 .78 r
.555 .73019 m
.55998 .73444 L
s
.55004 .73496 m
.555 .73019 L
s
.555 .73019 m
.55417 .73167 L
s
0 .366 1 r
.59446 .41372 m
.58774 .40998 L
s
.58774 .40998 m
.59079 .40149 L
s
.58774 .40998 m
.58708 .40747 L
s
0 1 .929 r
.54216 .57099 m
.5378 .57703 L
s
.53436 .57016 m
.5378 .57703 L
s
0 1 .7 r
.47426 .65004 m
.46767 .63298 L
s
.529 0 1 r
.81519 .49742 m
.82421 .50148 L
s
.81519 .49742 m
.81172 .50681 L
s
0 1 .929 r
.53436 .57016 m
.54216 .57099 L
s
0 1 .654 r
.31069 .4808 m
.30626 .47716 L
s
.30626 .47716 m
.30939 .47317 L
s
0 1 .309 r
.2309 .39233 m
.22434 .37646 L
s
0 1 .78 r
.55501 .73921 m
.55004 .73496 L
s
.55004 .73496 m
.55417 .73167 L
s
0 1 .794 r
.78352 .73485 m
.76803 .73645 L
s
.405 0 1 r
.2806 .79858 m
.27366 .80255 L
s
.27615 .78906 m
.2806 .79858 L
s
0 1 .654 r
.31559 .47641 m
.31069 .4808 L
s
.30939 .47317 m
.31559 .47641 L
s
.529 0 1 r
.82421 .50148 m
.82206 .51209 L
s
.81172 .50681 m
.82206 .51209 L
s
0 .346 1 r
.83392 .66451 m
.8415 .66847 L
s
.83392 .66451 m
.8316 .67242 L
s
0 1 .927 r
.54009 .47699 m
.52037 .47034 L
s
0 1 .78 r
.55998 .73444 m
.55501 .73921 L
s
.55417 .73167 m
.55998 .73444 L
s
0 .366 1 r
.59079 .40149 m
.59751 .40521 L
s
.59079 .40149 m
.58708 .40747 L
s
0 .873 1 r
.32672 .63308 m
.33219 .63746 L
s
.32089 .63697 m
.32672 .63308 L
s
.32672 .63308 m
.32678 .63185 L
s
0 .555 1 r
.25697 .63129 m
.25587 .64183 L
s
0 .346 1 r
.8415 .66847 m
.83894 .67669 L
s
.8316 .67242 m
.83894 .67669 L
s
.926 0 1 r
.89514 .51132 m
.88521 .50727 L
s
.88521 .50727 m
.88678 .49573 L
s
.88521 .50727 m
.88331 .50645 L
s
0 1 .654 r
.30939 .47317 m
.31069 .4808 L
s
0 .925 1 r
.60967 .57656 m
.604 .57268 L
s
.604 .57268 m
.60782 .56594 L
s
.604 .57268 m
.60496 .57027 L
s
0 1 .78 r
.55417 .73167 m
.55501 .73921 L
s
0 .083 1 r
.84971 .56177 m
.81949 .57061 L
s
0 .366 1 r
.59751 .40521 m
.59446 .41372 L
s
.58708 .40747 m
.59446 .41372 L
s
0 .975 1 r
.48327 .81904 m
.48796 .79502 L
s
0 .925 1 r
.60782 .56594 m
.61351 .56981 L
s
.60782 .56594 m
.60496 .57027 L
s
0 0 1 r
.91225 .67712 m
.90379 .67328 L
s
.90379 .67328 m
.90554 .66427 L
s
.90379 .67328 m
.90332 .67359 L
s
0 1 .865 r
.23944 .56087 m
.23987 .53516 L
s
0 .873 1 r
.33219 .63746 m
.32636 .64136 L
s
.32678 .63185 m
.33219 .63746 L
s
0 .088 1 r
.34346 .79335 m
.35078 .7991 L
s
.33707 .79726 m
.34346 .79335 L
s
.34346 .79335 m
.34637 .79104 L
s
.529 0 1 r
.81172 .50681 m
.82421 .50148 L
s
0 .346 1 r
.8316 .67242 m
.8415 .66847 L
s
0 .873 1 r
.32636 .64136 m
.32089 .63697 L
s
.32089 .63697 m
.32678 .63185 L
s
.405 0 1 r
.27366 .80255 m
.26535 .79611 L
s
.26535 .79611 m
.27615 .78906 L
s
1 0 .85 r
.91602 .38833 m
.87334 .40163 L
s
0 .366 1 r
.58708 .40747 m
.59751 .40521 L
s
0 1 .626 r
.54924 .64581 m
.53875 .63355 L
s
0 .925 1 r
.61351 .56981 m
.60967 .57656 L
s
.60496 .57027 m
.60967 .57656 L
s
0 1 .659 r
.38162 .47081 m
.38612 .47436 L
s
.3771 .47583 m
.38162 .47081 L
s
.38162 .47081 m
.37926 .47224 L
s
0 .023 1 r
.66668 .41206 m
.6592 .40832 L
s
.6592 .40832 m
.6618 .39886 L
s
.6592 .40832 m
.65791 .40602 L
s
0 1 .665 r
.6264 .73059 m
.63131 .73462 L
s
.62197 .73572 m
.6264 .73059 L
s
.6264 .73059 m
.62504 .73325 L
s
0 1 .659 r
.38161 .47939 m
.3771 .47583 L
s
.3771 .47583 m
.37926 .47224 L
s
0 1 .355 r
.30519 .38734 m
.29434 .37444 L
s
.926 0 1 r
.88678 .49573 m
.89673 .49976 L
s
.88678 .49573 m
.88331 .50645 L
s
0 1 .665 r
.62686 .73976 m
.62197 .73572 L
s
.62197 .73572 m
.62504 .73325 L
s
0 .925 1 r
.60496 .57027 m
.61351 .56981 L
s
0 .978 1 r
.85947 .73087 m
.84015 .73806 L
s
0 .088 1 r
.35078 .7991 m
.3444 .80303 L
s
.34637 .79104 m
.35078 .7991 L
s
.405 0 1 r
.27615 .78906 m
.27366 .80255 L
s
0 .873 1 r
.32678 .63185 m
.32636 .64136 L
s
0 0 1 r
.90554 .66427 m
.91401 .6681 L
s
.90554 .66427 m
.90332 .67359 L
s
0 .833 1 r
.61534 .47224 m
.59163 .46939 L
s
.926 0 1 r
.89673 .49976 m
.89514 .51132 L
s
.88331 .50645 m
.89514 .51132 L
s
0 1 .665 r
.63131 .73462 m
.62686 .73976 L
s
.62504 .73325 m
.63131 .73462 L
s
0 1 .659 r
.38612 .47436 m
.38161 .47939 L
s
.37926 .47224 m
.38612 .47436 L
s
0 .295 1 r
.24801 .73007 m
.25761 .69442 L
s
0 0 1 r
.91401 .6681 m
.91225 .67712 L
s
.90332 .67359 m
.91225 .67712 L
s
0 1 .873 r
.39776 .63268 m
.40274 .63674 L
s
.39237 .63689 m
.39776 .63268 L
s
.39776 .63268 m
.39701 .63241 L
s
0 .023 1 r
.6618 .39886 m
.66929 .40259 L
s
.6618 .39886 m
.65791 .40602 L
s
0 1 .665 r
.62504 .73325 m
.62686 .73976 L
s
0 1 .659 r
.37926 .47224 m
.38161 .47939 L
s
0 .703 1 r
.6821 .57612 m
.67581 .57228 L
s
.67581 .57228 m
.67906 .56477 L
s
.67581 .57228 m
.67602 .57038 L
s
.289 0 1 r
.92593 .55726 m
.89192 .57073 L
s
0 1 .665 r
.55843 .81529 m
.55935 .79703 L
s
0 .023 1 r
.66929 .40259 m
.66668 .41206 L
s
.65791 .40602 m
.66668 .41206 L
s
0 .088 1 r
.3444 .80303 m
.33707 .79726 L
s
.33707 .79726 m
.34637 .79104 L
s
0 1 .659 r
.3139 .55636 m
.31026 .53469 L
s
0 .703 1 r
.67906 .56477 m
.68536 .5686 L
s
.67906 .56477 m
.67602 .57038 L
s
0 1 .873 r
.39735 .64096 m
.39237 .63689 L
s
.39237 .63689 m
.39701 .63241 L
s
.40274 .63674 m
.39735 .64096 L
s
.39701 .63241 m
.40274 .63674 L
s
0 .552 1 r
.415 .7945 m
.4214 .79964 L
s
.40914 .7984 m
.415 .7945 L
s
.415 .7945 m
.41697 .79303 L
s
0 1 .657 r
.62467 .64155 m
.61027 .63412 L
s
0 0 1 r
.90332 .67359 m
.91401 .6681 L
s
0 1 .67 r
.69932 .74037 m
.69419 .73651 L
s
.69419 .73651 m
.69805 .73092 L
s
.69419 .73651 m
.69632 .73484 L
s
0 .703 1 r
.68536 .5686 m
.6821 .57612 L
s
.67602 .57038 m
.6821 .57612 L
s
.349 0 1 r
.73941 .4104 m
.73112 .40665 L
s
.73112 .40665 m
.73326 .3962 L
s
.73112 .40665 m
.72922 .40457 L
s
.926 0 1 r
.88331 .50645 m
.89673 .49976 L
s
.761 0 1 r
.25661 .89994 m
.27757 .8543 L
s
0 1 .753 r
.4531 .47803 m
.44832 .4745 L
s
.44832 .4745 m
.45241 .46877 L
s
.44832 .4745 m
.44959 .47129 L
s
0 1 .488 r
.37991 .38231 m
.36481 .37241 L
s
0 1 .67 r
.69805 .73092 m
.70318 .73478 L
s
.69805 .73092 m
.69632 .73484 L
s
0 1 .753 r
.45241 .46877 m
.45719 .47229 L
s
.45241 .46877 m
.44959 .47129 L
s
0 .023 1 r
.65791 .40602 m
.66929 .40259 L
s
0 .088 1 r
.34637 .79104 m
.3444 .80303 L
s
0 .667 1 r
.93587 .72686 m
.91271 .73967 L
s
0 1 .873 r
.39701 .63241 m
.39735 .64096 L
s
0 .552 1 r
.4214 .79964 m
.41555 .80356 L
s
.41697 .79303 m
.4214 .79964 L
s
0 .703 1 r
.67602 .57038 m
.68536 .5686 L
s
0 .54 1 r
.69104 .46746 m
.66335 .46842 L
s
0 1 .67 r
.70318 .73478 m
.69932 .74037 L
s
.69632 .73484 m
.69932 .74037 L
s
0 1 .309 r
.2259 .37614 m
.22976 .37938 L
s
.22156 .37994 m
.2259 .37614 L
s
.2259 .37614 m
.22434 .37646 L
s
0 .705 1 r
.32264 .72605 m
.32841 .69542 L
s
0 .418 1 r
.75505 .5757 m
.74805 .57191 L
s
.74805 .57191 m
.75067 .56358 L
s
.74805 .57191 m
.74753 .5705 L
s
0 1 .67 r
.69632 .73484 m
.70318 .73478 L
s
0 1 .753 r
.45719 .47229 m
.4531 .47803 L
s
.44959 .47129 m
.4531 .47803 L
s
0 1 .7 r
.46911 .6322 m
.47381 .63604 L
s
.46419 .6368 m
.46911 .6322 L
s
.46911 .6322 m
.46767 .63298 L
s
0 1 .753 r
.44959 .47129 m
.45719 .47229 L
s
0 1 .309 r
.22542 .38318 m
.22156 .37994 L
s
.22156 .37994 m
.22434 .37646 L
s
.349 0 1 r
.73326 .3962 m
.74157 .39993 L
s
.73326 .3962 m
.72922 .40457 L
s
0 .552 1 r
.41555 .80356 m
.40914 .7984 L
s
.40914 .7984 m
.41697 .79303 L
s
0 1 .395 r
.63403 .81153 m
.63113 .79905 L
s
0 1 .309 r
.22976 .37938 m
.22542 .38318 L
s
.22434 .37646 m
.22976 .37938 L
s
0 1 .7 r
.46888 .64065 m
.46419 .6368 L
s
.46419 .6368 m
.46767 .63298 L
s
0 1 .535 r
.3888 .55183 m
.3811 .53421 L
s
0 .418 1 r
.75067 .56358 m
.75769 .56735 L
s
.75067 .56358 m
.74753 .5705 L
s
0 1 .309 r
.22434 .37646 m
.22542 .38318 L
s
.349 0 1 r
.74157 .39993 m
.73941 .4104 L
s
.72922 .40457 m
.73941 .4104 L
s
0 1 .865 r
.24005 .53668 m
.24501 .54059 L
s
.23455 .54009 m
.24005 .53668 L
s
.24005 .53668 m
.23987 .53516 L
s
0 1 .794 r
.77238 .74105 m
.76675 .73735 L
s
.76675 .73735 m
.76993 .7312 L
s
.76675 .73735 m
.76803 .73645 L
s
0 .975 1 r
.4869 .79559 m
.49247 .80019 L
s
.48156 .79954 m
.4869 .79559 L
s
.4869 .79559 m
.48796 .79502 L
s
0 1 .7 r
.47381 .63604 m
.46888 .64065 L
s
.46767 .63298 m
.47381 .63604 L
s
0 1 .79 r
.70055 .63727 m
.68222 .63469 L
s
0 .552 1 r
.41697 .79303 m
.41555 .80356 L
s
.741 0 1 r
.81265 .40874 m
.80348 .40498 L
s
.80348 .40498 m
.80518 .39352 L
s
.80348 .40498 m
.80103 .40311 L
s
0 .418 1 r
.75769 .56735 m
.75505 .5757 L
s
.74753 .5705 m
.75505 .5757 L
s
0 1 .927 r
.52515 .4767 m
.51993 .47319 L
s
.51993 .47319 m
.52356 .46667 L
s
.51993 .47319 m
.52037 .47034 L
s
.207 0 1 r
.33142 .89642 m
.34878 .8567 L
s
0 1 .694 r
.45509 .37725 m
.43576 .37037 L
s
0 1 .794 r
.76993 .7312 m
.77557 .73489 L
s
.76993 .7312 m
.76803 .73645 L
s
0 1 .7 r
.46767 .63298 m
.46888 .64065 L
s
0 1 .927 r
.52356 .46667 m
.52879 .47017 L
s
.52356 .46667 m
.52037 .47034 L
s
0 1 .865 r
.24501 .54059 m
.23951 .54401 L
s
.23987 .53516 m
.24501 .54059 L
s
0 .975 1 r
.49247 .80019 m
.48713 .80415 L
s
.48796 .79502 m
.49247 .80019 L
s
0 1 .794 r
.77557 .73489 m
.77238 .74105 L
s
.76803 .73645 m
.77238 .74105 L
s
0 .206 1 r
.76719 .46266 m
.73555 .46745 L
s
0 1 .865 r
.23951 .54401 m
.23455 .54009 L
s
.23455 .54009 m
.23987 .53516 L
s
.349 0 1 r
.72922 .40457 m
.74157 .39993 L
s
0 .083 1 r
.82852 .57529 m
.82072 .57156 L
s
.82072 .57156 m
.82268 .56237 L
s
.82072 .57156 m
.81949 .57061 L
s
0 .295 1 r
.25542 .69731 m
.2623 .70249 L
s
.24903 .70073 m
.25542 .69731 L
s
.25542 .69731 m
.25761 .69442 L
s
0 1 .929 r
.39772 .72202 m
.39961 .69643 L
s
0 .418 1 r
.74753 .5705 m
.75769 .56735 L
s
0 .975 1 r
.48713 .80415 m
.48156 .79954 L
s
.48156 .79954 m
.48796 .79502 L
s
0 1 .355 r
.29654 .37322 m
.30054 .37638 L
s
.29252 .37771 m
.29654 .37322 L
s
.29654 .37322 m
.29434 .37444 L
s
0 1 .794 r
.76803 .73645 m
.77557 .73489 L
s
0 1 .927 r
.52879 .47017 m
.52515 .4767 L
s
.52037 .47034 m
.52515 .4767 L
s
0 1 .355 r
.29651 .38087 m
.29252 .37771 L
s
.29252 .37771 m
.29434 .37444 L
s
0 1 .626 r
.54075 .63164 m
.5454 .63532 L
s
.53634 .63672 m
.54075 .63164 L
s
.54075 .63164 m
.53875 .63355 L
s
0 1 .248 r
.71009 .80774 m
.70331 .80108 L
s
.741 0 1 r
.80518 .39352 m
.81437 .39725 L
s
.80518 .39352 m
.80103 .40311 L
s
0 1 .626 r
.54098 .64041 m
.53634 .63672 L
s
.53634 .63672 m
.53875 .63355 L
s
0 1 .927 r
.52037 .47034 m
.52879 .47017 L
s
0 1 .504 r
.46415 .54727 m
.45238 .53373 L
s
0 1 .865 r
.23987 .53516 m
.23951 .54401 L
s
0 .978 1 r
.84602 .74176 m
.83969 .73824 L
s
.83969 .73824 m
.84208 .73145 L
s
.83969 .73824 m
.84015 .73806 L
s
0 .975 1 r
.48796 .79502 m
.48713 .80415 L
s
0 .295 1 r
.2623 .70249 m
.25592 .70592 L
s
.25761 .69442 m
.2623 .70249 L
s
0 1 .355 r
.30054 .37638 m
.29651 .38087 L
s
.29434 .37444 m
.30054 .37638 L
s
0 .083 1 r
.82268 .56237 m
.8305 .56608 L
s
.82268 .56237 m
.81949 .57061 L
s
0 1 .355 r
.29434 .37444 m
.29651 .38087 L
s
.761 0 1 r
.27216 .85797 m
.28145 .86504 L
s
.26523 .86196 m
.27216 .85797 L
s
.27216 .85797 m
.27757 .8543 L
s
0 1 .665 r
.55914 .79662 m
.56402 .80076 L
s
.55431 .80066 m
.55914 .79662 L
s
.55914 .79662 m
.55935 .79703 L
s
0 .987 1 r
.77688 .63296 m
.75461 .63527 L
s
0 1 .659 r
.31129 .53535 m
.31582 .53896 L
s
.30617 .53915 m
.31129 .53535 L
s
.31129 .53535 m
.31026 .53469 L
s
.741 0 1 r
.81437 .39725 m
.81265 .40874 L
s
.80103 .40311 m
.81265 .40874 L
s
0 1 .626 r
.5454 .63532 m
.54098 .64041 L
s
.53875 .63355 m
.5454 .63532 L
s
0 .833 1 r
.59774 .4754 m
.59196 .4719 L
s
.59196 .4719 m
.59509 .46453 L
s
.59196 .4719 m
.59163 .46939 L
s
0 .333 1 r
.40667 .89288 m
.42036 .85911 L
s
0 1 .626 r
.53875 .63355 m
.54098 .64041 L
s
0 1 .959 r
.53071 .37217 m
.50719 .36831 L
s
1 0 .85 r
.88639 .40707 m
.87631 .4033 L
s
.87631 .4033 m
.87758 .39081 L
s
.87631 .4033 m
.87334 .40163 L
s
0 .083 1 r
.8305 .56608 m
.82852 .57529 L
s
.81949 .57061 m
.82852 .57529 L
s
0 .978 1 r
.84208 .73145 m
.84842 .73497 L
s
.84208 .73145 m
.84015 .73806 L
s
.84842 .73497 m
.84602 .74176 L
s
.84015 .73806 m
.84602 .74176 L
s
0 .295 1 r
.25592 .70592 m
.24903 .70073 L
s
.24903 .70073 m
.25761 .69442 L
s
0 1 .665 r
.56402 .80076 m
.55919 .80482 L
s
.55935 .79703 m
.56402 .80076 L
s
.159 0 1 r
.8438 .45782 m
.80822 .46648 L
s
0 .833 1 r
.59509 .46453 m
.60088 .46802 L
s
.59509 .46453 m
.59163 .46939 L
s
0 1 .659 r
.3107 .54277 m
.30617 .53915 L
s
.30617 .53915 m
.31026 .53469 L
s
0 1 .665 r
.55919 .80482 m
.55431 .80066 L
s
.55431 .80066 m
.55935 .79703 L
s
.289 0 1 r
.90248 .57488 m
.89383 .57121 L
s
.89383 .57121 m
.89511 .56113 L
s
.89383 .57121 m
.89192 .57073 L
s
0 1 .659 r
.31582 .53896 m
.3107 .54277 L
s
.31026 .53469 m
.31582 .53896 L
s
.761 0 1 r
.28145 .86504 m
.27454 .86906 L
s
.27757 .8543 m
.28145 .86504 L
s
0 1 .626 r
.47324 .71795 m
.47123 .69744 L
s
0 .705 1 r
.32717 .69753 m
.33322 .70214 L
s
.32126 .70105 m
.32717 .69753 L
s
.32717 .69753 m
.32841 .69542 L
s
0 1 .355 r
.22666 .45685 m
.22349 .43695 L
s
0 1 .488 r
.36817 .3786 m
.36387 .37548 L
s
.36387 .37548 m
.36754 .37021 L
s
.36387 .37548 m
.36481 .37241 L
s
.741 0 1 r
.80103 .40311 m
.81437 .39725 L
s
0 .833 1 r
.60088 .46802 m
.59774 .4754 L
s
.59163 .46939 m
.59774 .4754 L
s
0 1 .657 r
.61367 .64023 m
.60882 .63665 L
s
.60882 .63665 m
.61268 .631 L
s
.60882 .63665 m
.61027 .63412 L
s
0 .978 1 r
.84015 .73806 m
.84842 .73497 L
s
0 .083 1 r
.81949 .57061 m
.8305 .56608 L
s
0 1 .488 r
.36754 .37021 m
.37184 .37334 L
s
.36754 .37021 m
.36481 .37241 L
s
0 1 .248 r
.7866 .80393 m
.7759 .80312 L
s
0 1 .665 r
.55935 .79703 m
.55919 .80482 L
s
0 1 .657 r
.61268 .631 m
.61753 .63458 L
s
.61268 .631 m
.61027 .63412 L
s
0 .667 1 r
.92021 .74251 m
.91307 .73916 L
s
.91307 .73916 m
.91455 .73166 L
s
.91307 .73916 m
.91271 .73967 L
s
0 .295 1 r
.25761 .69442 m
.25592 .70592 L
s
0 1 .659 r
.31026 .53469 m
.3107 .54277 L
s
0 1 .569 r
.53994 .54268 m
.52411 .53325 L
s
1 0 .85 r
.87758 .39081 m
.88769 .39455 L
s
.87758 .39081 m
.87334 .40163 L
s
0 .833 1 r
.59163 .46939 m
.60088 .46802 L
s
0 .705 1 r
.33322 .70214 m
.32732 .70567 L
s
.32841 .69542 m
.33322 .70214 L
s
.289 0 1 r
.89511 .56113 m
.90378 .56478 L
s
.89511 .56113 m
.89192 .57073 L
s
.207 0 1 r
.34431 .85965 m
.35251 .86593 L
s
.33804 .86347 m
.34431 .85965 L
s
.34431 .85965 m
.34878 .8567 L
s
0 1 .488 r
.37184 .37334 m
.36817 .3786 L
s
.36481 .37241 m
.36817 .3786 L
s
0 .694 1 r
.85366 .62862 m
.82745 .63585 L
s
0 1 .395 r
.63165 .79757 m
.63607 .80135 L
s
.62736 .80178 m
.63165 .79757 L
s
.63165 .79757 m
.63113 .79905 L
s
0 1 .488 r
.36481 .37241 m
.37184 .37334 L
s
0 1 .657 r
.61753 .63458 m
.61367 .64023 L
s
.61027 .63412 m
.61367 .64023 L
s
0 .54 1 r
.67086 .4741 m
.66442 .47061 L
s
.66442 .47061 m
.66702 .46236 L
s
.66442 .47061 m
.66335 .46842 L
s
0 .849 1 r
.48237 .88932 m
.49232 .86153 L
s
0 1 .535 r
.38286 .53391 m
.38716 .53733 L
s
.37815 .5382 m
.38286 .53391 L
s
.38286 .53391 m
.3811 .53421 L
s
0 .731 1 r
.60678 .36705 m
.5791 .36624 L
s
0 1 .657 r
.61027 .63412 m
.61753 .63458 L
s
0 .667 1 r
.91455 .73166 m
.92171 .73501 L
s
.91455 .73166 m
.91271 .73967 L
s
0 .705 1 r
.32732 .70567 m
.32126 .70105 L
s
.32126 .70105 m
.32841 .69542 L
s
1 0 .85 r
.88769 .39455 m
.88639 .40707 L
s
.87334 .40163 m
.88639 .40707 L
s
0 .934 1 r
.2353 .62775 m
.23976 .59776 L
s
.289 0 1 r
.90378 .56478 m
.90248 .57488 L
s
.89192 .57073 m
.90248 .57488 L
s
0 1 .395 r
.63178 .80557 m
.62736 .80178 L
s
.62736 .80178 m
.63113 .79905 L
s
.761 0 1 r
.27454 .86906 m
.26523 .86196 L
s
.26523 .86196 m
.27757 .8543 L
s
0 .667 1 r
.92171 .73501 m
.92021 .74251 L
s
.91271 .73967 m
.92021 .74251 L
s
0 1 .535 r
.38244 .54162 m
.37815 .5382 L
s
.37815 .5382 m
.3811 .53421 L
s
.548 0 1 r
.92086 .45296 m
.88138 .4655 L
s
0 1 .395 r
.63607 .80135 m
.63178 .80557 L
s
.63113 .79905 m
.63607 .80135 L
s
.207 0 1 r
.35251 .86593 m
.34626 .86978 L
s
.34878 .8567 m
.35251 .86593 L
s
0 .54 1 r
.66702 .46236 m
.67348 .46584 L
s
.66702 .46236 m
.66335 .46842 L
s
0 1 .407 r
.54921 .71387 m
.54326 .69846 L
s
0 1 .535 r
.38716 .53733 m
.38244 .54162 L
s
.3811 .53421 m
.38716 .53733 L
s
.761 0 1 r
.27757 .8543 m
.27454 .86906 L
s
0 1 .274 r
.30192 .45198 m
.29449 .43541 L
s
0 1 .929 r
.39929 .69769 m
.40459 .70181 L
s
.39386 .70136 m
.39929 .69769 L
s
.39929 .69769 m
.39961 .69643 L
s
0 1 .395 r
.63113 .79905 m
.63178 .80557 L
s
0 1 .79 r
.68694 .64011 m
.68166 .63661 L
s
.68166 .63661 m
.6849 .63031 L
s
.68166 .63661 m
.68222 .63469 L
s
0 .705 1 r
.32841 .69542 m
.32732 .70567 L
s
0 1 .694 r
.44039 .37637 m
.43564 .37326 L
s
.43564 .37326 m
.43893 .36714 L
s
.43564 .37326 m
.43576 .37037 L
s
0 1 .396 r
.86357 .8001 m
.8489 .80518 L
s
0 1 .535 r
.3811 .53421 m
.38244 .54162 L
s
0 .54 1 r
.67348 .46584 m
.67086 .4741 L
s
.66335 .46842 m
.67086 .4741 L
s
0 .667 1 r
.91271 .73967 m
.92171 .73501 L
s
0 1 .79 r
.6849 .63031 m
.69018 .63381 L
s
.6849 .63031 m
.68222 .63469 L
s
0 1 .725 r
.6162 .53806 m
.59628 .53277 L
s
0 1 .694 r
.43893 .36714 m
.44367 .37025 L
s
.43893 .36714 m
.43576 .37037 L
s
.289 0 1 r
.89192 .57073 m
.90378 .56478 L
s
1 0 .85 r
.87334 .40163 m
.88769 .39455 L
s
.014 0 1 r
.24398 .79933 m
.25826 .75916 L
s
0 1 .929 r
.40459 .70181 m
.39917 .70549 L
s
.39961 .69643 m
.40459 .70181 L
s
0 .333 1 r
.41687 .86131 m
.424 .86684 L
s
.4112 .86498 m
.41687 .86131 L
s
.41687 .86131 m
.42036 .85911 L
s
0 .346 1 r
.93091 .62426 m
.90073 .63644 L
s
0 1 .79 r
.69018 .63381 m
.68694 .64011 L
s
.68222 .63469 m
.68694 .64011 L
s
0 1 .929 r
.39917 .70549 m
.39386 .70136 L
s
.39386 .70136 m
.39961 .69643 L
s
0 .206 1 r
.7445 .47281 m
.73732 .46933 L
s
.73732 .46933 m
.73938 .46016 L
s
.73732 .46933 m
.73555 .46745 L
s
.207 0 1 r
.34626 .86978 m
.33804 .86347 L
s
.33804 .86347 m
.34878 .8567 L
s
0 .54 1 r
.66335 .46842 m
.67348 .46584 L
s
0 1 .248 r
.7044 .79844 m
.70868 .80193 L
s
.70068 .80292 m
.7044 .79844 L
s
.7044 .79844 m
.70331 .80108 L
s
0 1 .694 r
.44367 .37025 m
.44039 .37637 L
s
.43576 .37037 m
.44039 .37637 L
s
0 1 .248 r
.70496 .80641 m
.70068 .80292 L
s
.70068 .80292 m
.70331 .80108 L
s
0 1 .67 r
.55852 .88574 m
.56465 .86396 L
s
0 .389 1 r
.68331 .3619 m
.65151 .36415 L
s
0 1 .504 r
.45474 .53238 m
.45902 .53569 L
s
.45048 .53724 m
.45474 .53238 L
s
.45474 .53238 m
.45238 .53373 L
s
0 1 .753 r
.31074 .62338 m
.31116 .59774 L
s
0 1 .79 r
.68222 .63469 m
.69018 .63381 L
s
0 1 .694 r
.43576 .37037 m
.44367 .37025 L
s
0 1 .504 r
.45476 .54055 m
.45048 .53724 L
s
.45048 .53724 m
.45238 .53373 L
s
0 1 .248 r
.70868 .80193 m
.70496 .80641 L
s
.70331 .80108 m
.70868 .80193 L
s
0 .333 1 r
.424 .86684 m
.41834 .87053 L
s
.42036 .85911 m
.424 .86684 L
s
.207 0 1 r
.34878 .8567 m
.34626 .86978 L
s
0 1 .248 r
.70331 .80108 m
.70496 .80641 L
s
0 1 .299 r
.62565 .70975 m
.6157 .69948 L
s
0 1 .929 r
.39961 .69643 m
.39917 .70549 L
s
0 .987 1 r
.76077 .64002 m
.75489 .6366 L
s
.75489 .6366 m
.75744 .62959 L
s
.75489 .6366 m
.75461 .63527 L
s
0 .206 1 r
.73938 .46016 m
.74657 .46363 L
s
.73938 .46016 m
.73555 .46745 L
s
1 0 .85 r
.25269 .9716 m
.27903 .9212 L
s
0 1 .286 r
.37763 .44708 m
.36594 .43385 L
s
0 1 .355 r
.22445 .43771 m
.22845 .44094 L
s
.21981 .44099 m
.22445 .43771 L
s
.22445 .43771 m
.22349 .43695 L
s
0 1 .626 r
.47176 .69776 m
.47645 .70149 L
s
.46682 .70166 m
.47176 .69776 L
s
.47176 .69776 m
.47123 .69744 L
s
0 1 .504 r
.45902 .53569 m
.45476 .54055 L
s
.45238 .53373 m
.45902 .53569 L
s
0 1 .959 r
.51314 .37415 m
.50786 .37104 L
s
.50786 .37104 m
.51072 .36402 L
s
.50786 .37104 m
.50719 .36831 L
s
0 1 .667 r
.941 .79624 m
.9223 .80724 L
s
0 1 .504 r
.45238 .53373 m
.45476 .54055 L
s
0 1 .956 r
.69291 .53342 m
.66892 .53228 L
s
0 .987 1 r
.75744 .62959 m
.76332 .633 L
s
.75744 .62959 m
.75461 .63527 L
s
0 .206 1 r
.74657 .46363 m
.7445 .47281 L
s
.73555 .46745 m
.7445 .47281 L
s
0 1 .355 r
.22381 .44422 m
.21981 .44099 L
s
.21981 .44099 m
.22349 .43695 L
s
0 .468 1 r
.31959 .79547 m
.33007 .76059 L
s
0 1 .355 r
.22845 .44094 m
.22381 .44422 L
s
.22349 .43695 m
.22845 .44094 L
s
0 .333 1 r
.41834 .87053 m
.4112 .86498 L
s
.4112 .86498 m
.42036 .85911 L
s
0 1 .959 r
.51072 .36402 m
.51602 .36713 L
s
.51072 .36402 m
.50719 .36831 L
s
0 1 .626 r
.47151 .7054 m
.46682 .70166 L
s
.46682 .70166 m
.47123 .69744 L
s
0 1 .248 r
.77879 .80735 m
.77428 .80409 L
s
.77428 .80409 m
.77732 .79923 L
s
.77428 .80409 m
.7759 .80312 L
s
0 1 .626 r
.47645 .70149 m
.47151 .7054 L
s
.47123 .69744 m
.47645 .70149 L
s
0 .849 1 r
.48982 .86295 m
.49591 .86776 L
s
.48472 .86649 m
.48982 .86295 L
s
.48982 .86295 m
.49232 .86153 L
s
0 .987 1 r
.76332 .633 m
.76077 .64002 L
s
.75461 .63527 m
.76077 .64002 L
s
.159 0 1 r
.81864 .47152 m
.81067 .46806 L
s
.81067 .46806 m
.81218 .45794 L
s
.81067 .46806 m
.80822 .46648 L
s
0 .934 1 r
.23893 .6002 m
.2445 .60434 L
s
.23322 .60327 m
.23893 .6002 L
s
.23893 .6002 m
.23976 .59776 L
s
0 1 .248 r
.77732 .79923 m
.78184 .80248 L
s
.77732 .79923 m
.7759 .80312 L
s
.63514 .88214 m
.63737 .86641 L
s
0 .023 1 r
.7603 .35672 m
.72441 .36205 L
s
0 1 .959 r
.51602 .36713 m
.51314 .37415 L
s
.50719 .36831 m
.51314 .37415 L
s
0 1 .355 r
.22349 .43695 m
.22381 .44422 L
s
0 1 .504 r
.38663 .61899 m
.38298 .59772 L
s
0 1 .569 r
.52766 .53954 m
.52318 .53628 L
s
.52318 .53628 m
.52694 .53077 L
s
.52318 .53628 m
.52411 .53325 L
s
0 .206 1 r
.73555 .46745 m
.74657 .46363 L
s
0 .333 1 r
.42036 .85911 m
.41834 .87053 L
s
0 1 .248 r
.78184 .80248 m
.77879 .80735 L
s
.7759 .80312 m
.77879 .80735 L
s
0 1 .569 r
.52694 .53077 m
.53143 .53402 L
s
.52694 .53077 m
.52411 .53325 L
s
0 .987 1 r
.75461 .63527 m
.76332 .633 L
s
0 1 .626 r
.47123 .69744 m
.47151 .7054 L
s
0 .849 1 r
.49591 .86776 m
.49081 .87132 L
s
.49232 .86153 m
.49591 .86776 L
s
0 1 .248 r
.7759 .80312 m
.78184 .80248 L
s
0 .694 1 r
.83513 .63996 m
.82855 .63663 L
s
.82855 .63663 m
.83034 .62883 L
s
.82855 .63663 m
.82745 .63585 L
s
0 1 .959 r
.50719 .36831 m
.51602 .36713 L
s
0 1 .316 r
.70254 .70562 m
.68857 .70051 L
s
0 .934 1 r
.2445 .60434 m
.23879 .60741 L
s
.23976 .59776 m
.2445 .60434 L
s
.548 0 1 r
.32848 .96825 m
.35126 .92401 L
s
0 1 .39 r
.4538 .44215 m
.43786 .43228 L
s
.159 0 1 r
.81218 .45794 m
.82016 .46139 L
s
.81218 .45794 m
.80822 .46648 L
s
.014 0 1 r
.2547 .76276 m
.2625 .76843 L
s
.24825 .76607 m
.2547 .76276 L
s
.2547 .76276 m
.25826 .75916 L
s
0 1 .407 r
.54452 .69774 m
.54881 .70118 L
s
.54011 .70194 m
.54452 .69774 L
s
.54452 .69774 m
.54326 .69846 L
s
0 1 .274 r
.29623 .43531 m
.30005 .43835 L
s
.29192 .43914 m
.29623 .43531 L
s
.29623 .43531 m
.29449 .43541 L
s
0 1 .569 r
.53143 .53402 m
.52766 .53954 L
s
.52411 .53325 m
.52766 .53954 L
s
0 .731 1 r
.58643 .37194 m
.58052 .36882 L
s
.58052 .36882 m
.58295 .36086 L
s
.58052 .36882 m
.5791 .36624 L
s
0 .849 1 r
.49081 .87132 m
.48472 .86649 L
s
.48472 .86649 m
.49232 .86153 L
s
0 .934 1 r
.23879 .60741 m
.23322 .60327 L
s
.23322 .60327 m
.23976 .59776 L
s
0 1 .569 r
.52411 .53325 m
.53143 .53402 L
s
0 .753 1 r
.77008 .52874 m
.74201 .53179 L
s
0 .694 1 r
.83034 .62883 m
.83693 .63215 L
s
.83034 .62883 m
.82745 .63585 L
s
0 1 .396 r
.85327 .80836 m
.84821 .80533 L
s
.84821 .80533 m
.85043 .79995 L
s
.84821 .80533 m
.8489 .80518 L
s
0 1 .407 r
.54439 .70539 m
.54011 .70194 L
s
.54011 .70194 m
.54326 .69846 L
s
0 1 .274 r
.29574 .44218 m
.29192 .43914 L
s
.29192 .43914 m
.29449 .43541 L
s
0 .925 1 r
.39566 .79159 m
.40228 .76204 L
s
.159 0 1 r
.82016 .46139 m
.81864 .47152 L
s
.80822 .46648 m
.81864 .47152 L
s
0 .731 1 r
.58295 .36086 m
.58887 .36397 L
s
.58295 .36086 m
.5791 .36624 L
s
0 1 .67 r
.56314 .86454 m
.56825 .8687 L
s
.55858 .868 m
.56314 .86454 L
s
.56314 .86454 m
.56465 .86396 L
s
0 1 .274 r
.30005 .43835 m
.29574 .44218 L
s
.29449 .43541 m
.30005 .43835 L
s
0 1 .407 r
.54881 .70118 m
.54439 .70539 L
s
.54326 .69846 m
.54881 .70118 L
s
0 .694 1 r
.83693 .63215 m
.83513 .63996 L
s
.82745 .63585 m
.83513 .63996 L
s
.548 0 1 r
.89328 .47024 m
.88448 .46678 L
s
.88448 .46678 m
.88544 .4557 L
s
.88448 .46678 m
.88138 .4655 L
s
.014 0 1 r
.2625 .76843 m
.25608 .77176 L
s
.25826 .75916 m
.2625 .76843 L
s
0 .849 1 r
.49232 .86153 m
.49081 .87132 L
s
0 1 .396 r
.85043 .79995 m
.8555 .80298 L
s
.85043 .79995 m
.8489 .80518 L
s
.075 1 0 r
.71221 .87851 m
.71047 .86887 L
s
.362 0 1 r
.83775 .35151 m
.79782 .35993 L
s
0 .934 1 r
.23976 .59776 m
.23879 .60741 L
s
0 1 .753 r
.31127 .59942 m
.31617 .60309 L
s
.30598 .60272 m
.31127 .59942 L
s
.31127 .59942 m
.31116 .59774 L
s
0 1 .396 r
.8555 .80298 m
.85327 .80836 L
s
.8489 .80518 m
.85327 .80836 L
s
1 0 .85 r
.27194 .92537 m
.28231 .93317 L
s
.26511 .92954 m
.27194 .92537 L
s
.27194 .92537 m
.27903 .9212 L
s
0 1 .725 r
.60114 .53857 m
.59626 .53535 L
s
.59626 .53535 m
.59946 .5291 L
s
.59626 .53535 m
.59628 .53277 L
s
0 1 .274 r
.29449 .43541 m
.29574 .44218 L
s
0 1 .338 r
.46298 .61457 m
.45524 .5977 L
s
0 1 .407 r
.54326 .69846 m
.54439 .70539 L
s
0 .731 1 r
.58887 .36397 m
.58643 .37194 L
s
.5791 .36624 m
.58643 .37194 L
s
.075 1 0 r
.21359 .35047 m
.20786 .3366 L
s
0 .346 1 r
.90999 .63992 m
.90265 .63667 L
s
.90265 .63667 m
.90364 .62804 L
s
.90265 .63667 m
.90073 .63644 L
s
0 1 .67 r
.56825 .8687 m
.5637 .87217 L
s
.56465 .86396 m
.56825 .8687 L
s
0 1 .725 r
.59946 .5291 m
.60435 .53231 L
s
.59946 .5291 m
.59628 .53277 L
s
.159 0 1 r
.80822 .46648 m
.82016 .46139 L
s
0 1 .396 r
.8489 .80518 m
.8555 .80298 L
s
0 .694 1 r
.82745 .63585 m
.83693 .63215 L
s
0 1 .456 r
.7799 .70146 m
.76186 .70154 L
s
0 1 .67 r
.5637 .87217 m
.55858 .868 L
s
.55858 .868 m
.56465 .86396 L
s
0 1 .753 r
.31617 .60309 m
.31087 .60641 L
s
.31116 .59774 m
.31617 .60309 L
s
0 .048 1 r
.40473 .96488 m
.42384 .92684 L
s
0 1 .575 r
.53043 .43719 m
.51025 .43071 L
s
1 0 .85 r
.28231 .93317 m
.27552 .93738 L
s
.27903 .9212 m
.28231 .93317 L
s
0 .731 1 r
.5791 .36624 m
.58887 .36397 L
s
0 1 .753 r
.31087 .60641 m
.30598 .60272 L
s
.30598 .60272 m
.31116 .59774 L
s
0 .468 1 r
.32749 .76351 m
.33432 .76847 L
s
.3216 .76677 m
.32749 .76351 L
s
.32749 .76351 m
.33007 .76059 L
s
.548 0 1 r
.88544 .4557 m
.89426 .45913 L
s
.88544 .4557 m
.88138 .4655 L
s
.014 0 1 r
.25608 .77176 m
.24825 .76607 L
s
.24825 .76607 m
.25826 .75916 L
s
0 1 .667 r
.92836 .80943 m
.92257 .80662 L
s
.92257 .80662 m
.92378 .80063 L
s
.92257 .80662 m
.9223 .80724 L
s
0 1 .725 r
.60435 .53231 m
.60114 .53857 L
s
.59628 .53277 m
.60114 .53857 L
s
0 .389 1 r
.66022 .36973 m
.65364 .3666 L
s
.65364 .3666 m
.65564 .35767 L
s
.65364 .3666 m
.65151 .36415 L
s
0 1 .299 r
.61755 .69763 m
.62171 .70087 L
s
.61371 .70223 m
.61755 .69763 L
s
.61755 .69763 m
.6157 .69948 L
s
.61786 .70548 m
.61371 .70223 L
s
.61371 .70223 m
.6157 .69948 L
s
0 1 .286 r
.36834 .43282 m
.37218 .43575 L
s
.36441 .43728 m
.36834 .43282 L
s
.36834 .43282 m
.36594 .43385 L
s
0 .418 1 r
.84772 .52404 m
.81557 .5313 L
s
0 .346 1 r
.90364 .62804 m
.91099 .63128 L
s
.90364 .62804 m
.90073 .63644 L
s
0 1 .286 r
.36826 .44022 m
.36441 .43728 L
s
.36441 .43728 m
.36594 .43385 L
s
0 1 .725 r
.59628 .53277 m
.60435 .53231 L
s
0 1 .67 r
.56465 .86396 m
.5637 .87217 L
s
0 1 .657 r
.47219 .78768 m
.47487 .76349 L
s
.014 0 1 r
.25826 .75916 m
.25608 .77176 L
s
0 1 .488 r
.22231 .5231 m
.22262 .49899 L
s
.548 0 1 r
.89426 .45913 m
.89328 .47024 L
s
.88138 .4655 m
.89328 .47024 L
s
0 1 .248 r
.6368 .86607 m
.64107 .86966 L
s
.63277 .86949 m
.6368 .86607 L
s
.6368 .86607 m
.63737 .86641 L
s
0 1 .667 r
.92378 .80063 m
.92958 .80343 L
s
.92378 .80063 m
.9223 .80724 L
s
0 1 .753 r
.31116 .59774 m
.31087 .60641 L
s
0 .468 1 r
.33432 .76847 m
.32844 .77175 L
s
.33007 .76059 m
.33432 .76847 L
s
0 .346 1 r
.91099 .63128 m
.90999 .63992 L
s
.90073 .63644 m
.90999 .63992 L
s
0 1 .299 r
.62171 .70087 m
.61786 .70548 L
s
.6157 .69948 m
.62171 .70087 L
s
0 .389 1 r
.65564 .35767 m
.66223 .36078 L
s
.65564 .35767 m
.65151 .36415 L
s
0 1 .667 r
.92958 .80343 m
.92836 .80943 L
s
.9223 .80724 m
.92836 .80943 L
s
.246 1 0 r
.78975 .87486 m
.78396 .87135 L
s
0 1 .299 r
.6157 .69948 m
.61786 .70548 L
s
.761 0 1 r
.91568 .34627 m
.87173 .3578 L
s
0 1 .956 r
.67516 .53763 m
.66975 .53444 L
s
.66975 .53444 m
.67236 .52739 L
s
.66975 .53444 m
.66892 .53228 L
s
.548 0 1 r
.34509 .92753 m
.35429 .93444 L
s
.33903 .9314 m
.34509 .92753 L
s
.34509 .92753 m
.35126 .92401 L
s
0 1 .286 r
.37218 .43575 m
.36826 .44022 L
s
.36594 .43385 m
.37218 .43575 L
s
0 1 .504 r
.38397 .59853 m
.38832 .60185 L
s
.37911 .60216 m
.38397 .59853 L
s
.38397 .59853 m
.38298 .59772 L
s
0 1 .286 r
.36594 .43385 m
.36826 .44022 L
s
0 1 .274 r
.53979 .61012 m
.52793 .59768 L
s
0 1 .248 r
.64107 .86966 m
.63704 .87309 L
s
.63737 .86641 m
.64107 .86966 L
s
.026 1 0 r
.28967 .34522 m
.27947 .33393 L
s
0 1 .248 r
.63704 .87309 m
.63277 .86949 L
s
.63277 .86949 m
.63737 .86641 L
s
0 1 .956 r
.67236 .52739 m
.67778 .53057 L
s
.67236 .52739 m
.66892 .53228 L
s
0 .389 1 r
.66223 .36078 m
.66022 .36973 L
s
.65151 .36415 m
.66022 .36973 L
s
0 1 .699 r
.85772 .69727 m
.83558 .70258 L
s
0 .468 1 r
.32844 .77175 m
.3216 .76677 L
s
.3216 .76677 m
.33007 .76059 L
s
0 1 .667 r
.9223 .80724 m
.92958 .80343 L
s
.548 0 1 r
.35429 .93444 m
.34826 .93835 L
s
.35126 .92401 m
.35429 .93444 L
s
0 1 .504 r
.38346 .60549 m
.37911 .60216 L
s
.37911 .60216 m
.38298 .59772 L
s
0 .635 1 r
.48144 .96149 m
.49678 .92968 L
s
0 .346 1 r
.90073 .63644 m
.91099 .63128 L
s
0 1 .825 r
.60753 .43221 m
.58311 .42912 L
s
.548 0 1 r
.88138 .4655 m
.89426 .45913 L
s
0 1 .504 r
.38832 .60185 m
.38346 .60549 L
s
.38298 .59772 m
.38832 .60185 L
s
1 0 .85 r
.27552 .93738 m
.26511 .92954 L
s
.26511 .92954 m
.27903 .9212 L
s
0 1 .248 r
.63737 .86641 m
.63704 .87309 L
s
0 1 .316 r
.69195 .70565 m
.68763 .70254 L
s
.68763 .70254 m
.69082 .69743 L
s
.68763 .70254 m
.68857 .70051 L
s
0 .925 1 r
.40069 .76421 m
.40657 .76851 L
s
.39532 .76746 m
.40069 .76421 L
s
.40069 .76421 m
.40228 .76204 L
s
0 .674 1 r
.23106 .69643 m
.23964 .66197 L
s
0 .023 1 r
.73453 .36751 m
.72722 .36437 L
s
.72722 .36437 m
.72879 .35444 L
s
.72722 .36437 m
.72441 .36205 L
s
0 1 .956 r
.67778 .53057 m
.67516 .53763 L
s
.66892 .53228 m
.67516 .53763 L
s
0 1 .316 r
.69082 .69743 m
.69514 .70054 L
s
.69082 .69743 m
.68857 .70051 L
s
1 0 .85 r
.27903 .9212 m
.27552 .93738 L
s
0 .048 1 r
.92583 .51931 m
.8896 .5308 L
s
0 .389 1 r
.65151 .36415 m
.66223 .36078 L
s
0 1 .39 r
.44136 .43832 m
.43729 .43542 L
s
.43729 .43542 m
.44078 .43023 L
s
.43729 .43542 m
.43786 .43228 L
s
0 .468 1 r
.33007 .76059 m
.32844 .77175 L
s
0 1 .39 r
.44078 .43023 m
.44486 .43312 L
s
.44078 .43023 m
.43786 .43228 L
s
0 1 .299 r
.54919 .78375 m
.54787 .76494 L
s
0 1 .504 r
.38298 .59772 m
.38346 .60549 L
s
0 1 .956 r
.66892 .53228 m
.67778 .53057 L
s
0 1 .286 r
.29857 .51837 m
.29464 .49791 L
s
.075 1 0 r
.71072 .86751 m
.71439 .87064 L
s
.70726 .87098 m
.71072 .86751 L
s
.71072 .86751 m
.71047 .86887 L
s
0 1 .316 r
.69514 .70054 m
.69195 .70565 L
s
.68857 .70051 m
.69195 .70565 L
s
0 .925 1 r
.40657 .76851 m
.4012 .77178 L
s
.40228 .76204 m
.40657 .76851 L
s
0 .753 1 r
.7497 .5367 m
.74367 .53354 L
s
.74367 .53354 m
.74565 .52565 L
s
.74367 .53354 m
.74201 .53179 L
s
0 .048 1 r
.41866 .92968 m
.42667 .93573 L
s
.4133 .93327 m
.41866 .92968 L
s
.41866 .92968 m
.42384 .92684 L
s
0 1 .316 r
.68857 .70051 m
.69514 .70054 L
s
.218 1 0 r
.86777 .8712 m
.85784 .87383 L
s
0 .023 1 r
.72879 .35444 m
.73611 .35756 L
s
.72879 .35444 m
.72441 .36205 L
s
.075 1 0 r
.71092 .87412 m
.70726 .87098 L
s
.70726 .87098 m
.71047 .86887 L
s
0 1 .32 r
.61707 .60565 m
.60105 .59767 L
s
.075 1 0 r
.20922 .33641 m
.21251 .33915 L
s
.20552 .33963 m
.20922 .33641 L
s
.20922 .33641 m
.20786 .3366 L
s
0 1 .39 r
.44486 .43312 m
.44136 .43832 L
s
.43786 .43228 m
.44136 .43832 L
s
0 1 .338 r
.45699 .59754 m
.46099 .60062 L
s
.45261 .60158 m
.45699 .59754 L
s
.45699 .59754 m
.45524 .5977 L
s
.075 1 0 r
.71439 .87064 m
.71092 .87412 L
s
.71047 .86887 m
.71439 .87064 L
s
0 1 .39 r
.43786 .43228 m
.44486 .43312 L
s
0 .925 1 r
.4012 .77178 m
.39532 .76746 L
s
.39532 .76746 m
.40228 .76204 L
s
.362 0 1 r
.23984 .87046 m
.25894 .82556 L
s
0 1 .116 r
.36621 .33994 m
.35156 .33125 L
s
.075 1 0 r
.2088 .34237 m
.20552 .33963 L
s
.20552 .33963 m
.20786 .3366 L
s
.548 0 1 r
.34826 .93835 m
.33903 .9314 L
s
.33903 .9314 m
.35126 .92401 L
s
.075 1 0 r
.71047 .86887 m
.71092 .87412 L
s
0 .753 1 r
.74565 .52565 m
.7517 .5288 L
s
.74565 .52565 m
.74201 .53179 L
s
0 .048 1 r
.42667 .93573 m
.42133 .93933 L
s
.42384 .92684 m
.42667 .93573 L
s
0 .978 1 r
.93602 .69306 m
.90973 .70363 L
s
0 1 .338 r
.4566 .60467 m
.45261 .60158 L
s
.45261 .60158 m
.45524 .5977 L
s
.075 1 0 r
.21251 .33915 m
.2088 .34237 L
s
.20786 .3366 m
.21251 .33915 L
s
0 1 .456 r
.76664 .70588 m
.7619 .70288 L
s
.7619 .70288 m
.76435 .69717 L
s
.7619 .70288 m
.76186 .70154 L
s
0 .023 1 r
.73611 .35756 m
.73453 .36751 L
s
.72441 .36205 m
.73453 .36751 L
s
0 1 .794 r
.55862 .95808 m
.57009 .93253 L
s
.548 0 1 r
.35126 .92401 m
.34826 .93835 L
s
0 .876 1 r
.68509 .42719 m
.65644 .42752 L
s
.075 1 0 r
.20786 .3366 m
.2088 .34237 L
s
0 1 .927 r
.3075 .69221 m
.31207 .66239 L
s
0 1 .657 r
.47427 .76485 m
.47926 .76857 L
s
.46941 .76814 m
.47427 .76485 L
s
.47427 .76485 m
.47487 .76349 L
s
0 1 .338 r
.46099 .60062 m
.4566 .60467 L
s
.45524 .5977 m
.46099 .60062 L
s
.362 0 1 r
.80936 .36529 m
.80127 .36213 L
s
.80127 .36213 m
.80242 .35118 L
s
.80127 .36213 m
.79782 .35993 L
s
0 .925 1 r
.40228 .76204 m
.4012 .77178 L
s
0 1 .456 r
.76435 .69717 m
.76909 .70016 L
s
.76435 .69717 m
.76186 .70154 L
s
0 1 .488 r
.22282 .50078 m
.22721 .50407 L
s
.21791 .50362 m
.22282 .50078 L
s
.22282 .50078 m
.22262 .49899 L
s
0 .753 1 r
.7517 .5288 m
.7497 .5367 L
s
.74201 .53179 m
.7497 .5367 L
s
0 1 .575 r
.51503 .43646 m
.51058 .43358 L
s
.51058 .43358 m
.5136 .42758 L
s
.51058 .43358 m
.51025 .43071 L
s
0 1 .338 r
.45524 .5977 m
.4566 .60467 L
s
0 1 .033 r
.62665 .7798 m
.62127 .76641 L
s
0 1 .575 r
.5136 .42758 m
.51806 .43045 L
s
.5136 .42758 m
.51025 .43071 L
s
0 1 .456 r
.76909 .70016 m
.76664 .70588 L
s
.76186 .70154 m
.76664 .70588 L
s
1 0 .436 r
.24866 1.0452 m
.28053 .98984 L
s
0 1 .169 r
.37529 .5136 m
.3671 .49683 L
s
.246 1 0 r
.78545 .87526 m
.78198 .87249 L
s
.78198 .87249 m
.7848 .86885 L
s
.78198 .87249 m
.78396 .87135 L
s
0 .023 1 r
.72441 .36205 m
.73611 .35756 L
s
.246 1 0 r
.7848 .86885 m
.78828 .87162 L
s
.7848 .86885 m
.78396 .87135 L
s
0 .418 1 r
.82476 .53579 m
.81803 .53266 L
s
.81803 .53266 m
.81936 .52388 L
s
.81803 .53266 m
.81557 .5313 L
s
0 1 .657 r
.47926 .76857 m
.4744 .77188 L
s
.47487 .76349 m
.47926 .76857 L
s
0 .635 1 r
.49264 .93184 m
.49946 .93702 L
s
.48792 .93514 m
.49264 .93184 L
s
.49264 .93184 m
.49678 .92968 L
s
0 1 .488 r
.22721 .50407 m
.2223 .50692 L
s
.22262 .49899 m
.22721 .50407 L
s
0 .753 1 r
.74201 .53179 m
.7517 .5288 L
s
0 1 0 r
.94626 .8675 m
.93211 .87633 L
s
0 1 .657 r
.4744 .77188 m
.46941 .76814 L
s
.46941 .76814 m
.47487 .76349 L
s
0 .048 1 r
.42133 .93933 m
.4133 .93327 L
s
.4133 .93327 m
.42384 .92684 L
s
0 1 .456 r
.76186 .70154 m
.76909 .70016 L
s
0 1 .488 r
.2223 .50692 m
.21791 .50362 L
s
.21791 .50362 m
.22262 .49899 L
s
0 1 .471 r
.69482 .60115 m
.67462 .59765 L
s
.246 1 0 r
.78828 .87162 m
.78545 .87526 L
s
.78396 .87135 m
.78545 .87526 L
s
.78396 .87135 m
.78828 .87162 L
s
.362 0 1 r
.80242 .35118 m
.81052 .35431 L
s
.80242 .35118 m
.79782 .35993 L
s
0 .674 1 r
.23765 .66527 m
.24402 .66973 L
s
.2318 .66808 m
.23765 .66527 L
s
.23765 .66527 m
.23964 .66197 L
s
0 1 .575 r
.51806 .43045 m
.51503 .43646 L
s
.51025 .43071 m
.51503 .43646 L
s
0 1 .274 r
.5303 .59644 m
.5342 .59939 L
s
.52644 .60099 m
.5303 .59644 L
s
.5303 .59644 m
.52793 .59768 L
s
0 .177 1 r
.31646 .86677 m
.33178 .82742 L
s
0 1 .334 r
.44322 .33463 m
.42413 .32854 L
s
.026 1 0 r
.28154 .33295 m
.28491 .33556 L
s
.27813 .33685 m
.28154 .33295 L
s
.28154 .33295 m
.27947 .33393 L
s
0 .048 1 r
.42384 .92684 m
.42133 .93933 L
s
0 1 .274 r
.53033 .60395 m
.52644 .60099 L
s
.52644 .60099 m
.52793 .59768 L
s
.026 1 0 r
.28151 .33946 m
.27813 .33685 L
s
.27813 .33685 m
.27947 .33393 L
s
0 .635 1 r
.49946 .93702 m
.49476 .94034 L
s
.49678 .92968 m
.49946 .93702 L
s
0 1 .699 r
.84189 .70617 m
.83658 .70327 L
s
.83658 .70327 m
.83819 .69686 L
s
.83658 .70327 m
.83558 .70258 L
s
0 1 .575 r
.51025 .43071 m
.51806 .43045 L
s
0 .418 1 r
.81936 .52388 m
.8261 .527 L
s
.81936 .52388 m
.81557 .5313 L
s
0 1 .488 r
.22262 .49899 m
.2223 .50692 L
s
0 1 .657 r
.47487 .76349 m
.4744 .77188 L
s
0 1 .248 r
.63627 .95465 m
.64376 .9354 L
s
0 .54 1 r
.76313 .42214 m
.73026 .42591 L
s
.026 1 0 r
.28491 .33556 m
.28151 .33946 L
s
.27947 .33393 m
.28491 .33556 L
s
0 1 .569 r
.3844 .68797 m
.38491 .66283 L
s
.362 0 1 r
.81052 .35431 m
.80936 .36529 L
s
.79782 .35993 m
.80936 .36529 L
s
0 .674 1 r
.24402 .66973 m
.23818 .67255 L
s
.23964 .66197 m
.24402 .66973 L
s
0 1 .299 r
.54819 .7654 m
.55242 .76865 L
s
.54385 .76881 m
.54819 .7654 L
s
.54819 .7654 m
.54787 .76494 L
s
.026 1 0 r
.27947 .33393 m
.28151 .33946 L
s
0 1 .699 r
.83819 .69686 m
.84351 .69975 L
s
.83819 .69686 m
.83558 .70258 L
s
.761 0 1 r
.8847 .36306 m
.87578 .35988 L
s
.87578 .35988 m
.87652 .34789 L
s
.87578 .35988 m
.87173 .3578 L
s
0 1 .274 r
.5342 .59939 m
.53033 .60395 L
s
.52793 .59768 m
.5342 .59939 L
s
0 1 .825 r
.58924 .43461 m
.58429 .43174 L
s
.58429 .43174 m
.58682 .42488 L
s
.58429 .43174 m
.58311 .42912 L
s
0 1 .274 r
.52793 .59768 m
.53033 .60395 L
s
0 .418 1 r
.8261 .527 m
.82476 .53579 L
s
.81557 .5313 m
.82476 .53579 L
s
.362 0 1 r
.25387 .82981 m
.26271 .83608 L
s
.24745 .83313 m
.25387 .82981 L
s
.25387 .82981 m
.25894 .82556 L
s
0 1 .286 r
.29575 .49894 m
.29966 .50189 L
s
.2912 .50217 m
.29575 .49894 L
s
.29575 .49894 m
.29464 .49791 L
s
.218 1 0 r
.86071 .87653 m
.85694 .87406 L
s
.85694 .87406 m
.85896 .87007 L
s
.85694 .87406 m
.85784 .87383 L
s
.102 1 0 r
.70459 .77582 m
.69507 .76788 L
s
0 1 .699 r
.84351 .69975 m
.84189 .70617 L
s
.83558 .70258 m
.84189 .70617 L
s
0 .635 1 r
.49476 .94034 m
.48792 .93514 L
s
.48792 .93514 m
.49678 .92968 L
s
0 .048 1 r
.90032 .53489 m
.89284 .53177 L
s
.89284 .53177 m
.8935 .52209 L
s
.89284 .53177 m
.8896 .5308 L
s
.218 1 0 r
.85896 .87007 m
.86273 .87255 L
s
.85896 .87007 m
.85784 .87383 L
s
.926 0 1 r
.32547 1.04203 m
.3538 .99305 L
s
0 1 .151 r
.45248 .50881 m
.44001 .49573 L
s
0 1 .299 r
.54809 .77207 m
.54385 .76881 L
s
.54385 .76881 m
.54787 .76494 L
s
0 1 .825 r
.58682 .42488 m
.59177 .42774 L
s
.58682 .42488 m
.58311 .42912 L
s
0 1 .794 r
.56702 .93397 m
.57267 .93833 L
s
.56289 .93701 m
.56702 .93397 L
s
.56702 .93397 m
.57009 .93253 L
s
0 1 .299 r
.55242 .76865 m
.54809 .77207 L
s
.54787 .76494 m
.55242 .76865 L
s
0 .674 1 r
.23818 .67255 m
.2318 .66808 L
s
.2318 .66808 m
.23964 .66197 L
s
.218 1 0 r
.86273 .87255 m
.86071 .87653 L
s
.85784 .87383 m
.86071 .87653 L
s
0 1 .286 r
.29511 .50513 m
.2912 .50217 L
s
.2912 .50217 m
.29464 .49791 L
s
.29966 .50189 m
.29511 .50513 L
s
.29464 .49791 m
.29966 .50189 L
s
0 .635 1 r
.49678 .92968 m
.49476 .94034 L
s
.362 0 1 r
.79782 .35993 m
.81052 .35431 L
s
.26271 .83608 m
.25631 .83942 L
s
.25894 .82556 m
.26271 .83608 L
s
0 .418 1 r
.81557 .5313 m
.8261 .527 L
s
.218 1 0 r
.85784 .87383 m
.86273 .87255 L
s
0 1 .709 r
.77304 .59662 m
.74863 .59763 L
s
0 1 .699 r
.83558 .70258 m
.84351 .69975 L
s
0 .978 1 r
.91767 .70648 m
.91169 .70369 L
s
.91169 .70369 m
.91238 .69652 L
s
.91169 .70369 m
.90973 .70363 L
s
0 1 .927 r
.31109 .66503 m
.3166 .66887 L
s
.3057 .66793 m
.31109 .66503 L
s
.31109 .66503 m
.31207 .66239 L
s
0 1 .32 r
.60466 .6033 m
.60063 .60042 L
s
.60063 .60042 m
.6039 .59526 L
s
.60063 .60042 m
.60105 .59767 L
s
0 1 .794 r
.57267 .93833 m
.56855 .94138 L
s
.57009 .93253 m
.57267 .93833 L
s
0 1 .825 r
.59177 .42774 m
.58924 .43461 L
s
.58311 .42912 m
.58924 .43461 L
s
.761 0 1 r
.87652 .34789 m
.88547 .35104 L
s
.87652 .34789 m
.87173 .3578 L
s
0 .703 1 r
.39356 .86305 m
.40501 .8293 L
s
0 1 .609 r
.5207 .32928 m
.4972 .32582 L
s
0 1 .32 r
.6039 .59526 m
.60794 .59813 L
s
.6039 .59526 m
.60105 .59767 L
s
0 1 .299 r
.54787 .76494 m
.54809 .77207 L
s
1 0 .436 r
.27167 .99444 m
.28319 1.00305 L
s
.26499 .99892 m
.27167 .99444 L
s
.27167 .99444 m
.28053 .98984 L
s
0 1 .116 r
.35481 .33662 m
.35117 .33407 L
s
.35117 .33407 m
.35421 .32938 L
s
.35117 .33407 m
.35156 .33125 L
s
0 .674 1 r
.23964 .66197 m
.23818 .67255 L
s
0 1 .116 r
.35421 .32938 m
.35786 .33192 L
s
.35421 .32938 m
.35156 .33125 L
s
0 .048 1 r
.8935 .52209 m
.901 .52518 L
s
.8935 .52209 m
.8896 .5308 L
s
0 1 .286 r
.29464 .49791 m
.29511 .50513 L
s
.246 1 0 r
.71439 .9512 m
.7178 .93828 L
s
0 1 .825 r
.58311 .42912 m
.59177 .42774 L
s
0 .177 1 r
.84164 .41706 m
.80457 .4243 L
s
0 1 0 r
.93669 .8779 m
.93229 .8757 L
s
.93229 .8757 m
.93322 .87121 L
s
.93229 .8757 m
.93211 .87633 L
s
0 .978 1 r
.91238 .69652 m
.91838 .69931 L
s
.91238 .69652 m
.90973 .70363 L
s
0 1 .274 r
.46178 .6837 m
.45817 .66326 L
s
0 1 .033 r
.62239 .76584 m
.62607 .76874 L
s
.61863 .76947 m
.62239 .76584 L
s
.62239 .76584 m
.62127 .76641 L
s
0 1 .927 r
.3166 .66887 m
.31121 .67178 L
s
.31207 .66239 m
.3166 .66887 L
s
0 1 .794 r
.56855 .94138 m
.56289 .93701 L
s
.56289 .93701 m
.57009 .93253 L
s
0 1 .32 r
.60794 .59813 m
.60466 .6033 L
s
.60105 .59767 m
.60466 .6033 L
s
0 1 .116 r
.35786 .33192 m
.35481 .33662 L
s
.35156 .33125 m
.35481 .33662 L
s
0 .876 1 r
.66398 .43278 m
.65846 .42991 L
s
.65846 .42991 m
.66046 .42214 L
s
.65846 .42991 m
.65644 .42752 L
s
1 0 .436 r
.28319 1.00305 m
.27656 1.00758 L
s
.28053 .98984 m
.28319 1.00305 L
s
.026 1 0 r
.20901 .41604 m
.20623 .39804 L
s
0 .177 1 r
.3277 .83107 m
.33546 .8365 L
s
.32193 .83419 m
.3277 .83107 L
s
.3277 .83107 m
.33178 .82742 L
s
0 1 .116 r
.35156 .33125 m
.35786 .33192 L
s
0 1 .32 r
.60105 .59767 m
.60794 .59813 L
s
.761 0 1 r
.88547 .35104 m
.8847 .36306 L
s
.87173 .3578 m
.8847 .36306 L
s
0 1 .033 r
.62232 .77237 m
.61863 .76947 L
s
.61863 .76947 m
.62127 .76641 L
s
0 .048 1 r
.901 .52518 m
.90032 .53489 L
s
.8896 .5308 m
.90032 .53489 L
s
0 1 .169 r
.36902 .49697 m
.37264 .49971 L
s
.36487 .5007 m
.36902 .49697 L
s
.36902 .49697 m
.3671 .49683 L
s
0 1 0 r
.93322 .87121 m
.93763 .87341 L
s
.93322 .87121 m
.93211 .87633 L
s
.078 1 0 r
.783 .77182 m
.76928 .76937 L
s
0 .978 1 r
.91838 .69931 m
.91767 .70648 L
s
.90973 .70363 m
.91767 .70648 L
s
0 1 .927 r
.31121 .67178 m
.3057 .66793 L
s
.3057 .66793 m
.31207 .66239 L
s
0 1 0 r
.93763 .87341 m
.93669 .8779 L
s
.93211 .87633 m
.93669 .8779 L
s
.362 0 1 r
.25631 .83942 m
.24745 .83313 L
s
.24745 .83313 m
.25894 .82556 L
s
0 1 .248 r
.64179 .93608 m
.6463 .93965 L
s
.63821 .93888 m
.64179 .93608 L
s
.64179 .93608 m
.64376 .9354 L
s
0 1 .794 r
.57009 .93253 m
.56855 .94138 L
s
.289 0 1 r
.40274 1.03884 m
.42741 .99628 L
s
0 1 .234 r
.53015 .50399 m
.51338 .49463 L
s
0 1 .033 r
.62607 .76874 m
.62232 .77237 L
s
.62127 .76641 m
.62607 .76874 L
s
0 1 .169 r
.36848 .50344 m
.36487 .5007 L
s
.36487 .5007 m
.3671 .49683 L
s
0 .876 1 r
.66046 .42214 m
.66599 .425 L
s
.66046 .42214 m
.65644 .42752 L
s
.362 0 1 r
.25894 .82556 m
.25631 .83942 L
s
0 .177 1 r
.33546 .8365 m
.3297 .83964 L
s
.33178 .82742 m
.33546 .8365 L
s
0 1 .033 r
.62127 .76641 m
.62232 .77237 L
s
0 1 .471 r
.67958 .6027 m
.67519 .59987 L
s
.67519 .59987 m
.6778 .59401 L
s
.67519 .59987 m
.67462 .59765 L
s
0 1 0 r
.93211 .87633 m
.93763 .87341 L
s
0 .987 1 r
.85175 .59206 m
.8231 .59761 L
s
0 1 .248 r
.6463 .93965 m
.64272 .94246 L
s
.64376 .9354 m
.6463 .93965 L
s
0 1 .169 r
.37264 .49971 m
.36848 .50344 L
s
.3671 .49683 m
.37264 .49971 L
s
0 .978 1 r
.90973 .70363 m
.91838 .69931 L
s
.926 0 1 r
.34583 .99705 m
.3561 1.0047 L
s
.34006 1.00112 m
.34583 .99705 L
s
.34583 .99705 m
.3538 .99305 L
s
0 1 .569 r
.38493 .6647 m
.38963 .66802 L
s
.37999 .66776 m
.38493 .6647 L
s
.38493 .6647 m
.38491 .66283 L
s
0 1 .927 r
.31207 .66239 m
.31121 .67178 L
s
0 1 .79 r
.47112 .85931 m
.47861 .83118 L
s
0 1 .924 r
.59866 .32391 m
.57076 .32308 L
s
0 .048 1 r
.8896 .5308 m
.901 .52518 L
s
0 1 .471 r
.6778 .59401 m
.6822 .59684 L
s
.6778 .59401 m
.67462 .59765 L
s
0 1 .334 r
.42866 .33381 m
.42464 .33129 L
s
.42464 .33129 m
.42729 .32574 L
s
.42464 .33129 m
.42413 .32854 L
s
0 .876 1 r
.66599 .425 m
.66398 .43278 L
s
.65644 .42752 m
.66398 .43278 L
s
.761 0 1 r
.87173 .3578 m
.88547 .35104 L
s
0 1 .169 r
.3671 .49683 m
.36848 .50344 L
s
0 1 .694 r
.21784 .59115 m
.22173 .56264 L
s
0 1 .248 r
.64272 .94246 m
.63821 .93888 L
s
.63821 .93888 m
.64376 .9354 L
s
0 1 .334 r
.42729 .32574 m
.43132 .32825 L
s
.42729 .32574 m
.42413 .32854 L
s
.631 1 0 r
.793 .94773 m
.79221 .94117 L
s
.207 0 1 r
.92063 .41194 m
.87936 .42267 L
s
.926 0 1 r
.3561 1.0047 m
.35037 1.0088 L
s
.3538 .99305 m
.3561 1.0047 L
s
0 1 .067 r
.53964 .67941 m
.53184 .6637 L
s
.102 1 0 r
.6968 .76617 m
.70027 .76883 L
s
.6937 .77013 m
.6968 .76617 L
s
.6968 .76617 m
.69507 .76788 L
s
0 1 .471 r
.6822 .59684 m
.67958 .6027 L
s
.67462 .59765 m
.67958 .6027 L
s
.102 1 0 r
.69717 .7728 m
.6937 .77013 L
s
.6937 .77013 m
.69507 .76788 L
s
0 .54 1 r
.73923 .43095 m
.73307 .42807 L
s
.73307 .42807 m
.73455 .41936 L
s
.73307 .42807 m
.73026 .42591 L
s
0 .876 1 r
.65644 .42752 m
.66599 .425 L
s
0 1 .569 r
.38963 .66802 m
.38469 .67108 L
s
.38491 .66283 m
.38963 .66802 L
s
0 1 .248 r
.64376 .9354 m
.64272 .94246 L
s
0 .703 1 r
.40196 .8323 m
.40863 .83692 L
s
.39677 .83525 m
.40196 .8323 L
s
.40196 .8323 m
.40501 .8293 L
s
0 1 .569 r
.38469 .67108 m
.37999 .66776 L
s
.37999 .66776 m
.38491 .66283 L
s
.103 1 0 r
.28611 .41092 m
.27888 .39586 L
s
0 .177 1 r
.3297 .83964 m
.32193 .83419 L
s
.32193 .83419 m
.33178 .82742 L
s
0 1 .334 r
.43132 .32825 m
.42866 .33381 L
s
.42413 .32854 m
.42866 .33381 L
s
0 1 .471 r
.67462 .59765 m
.6822 .59684 L
s
0 1 .099 r
.86189 .76779 m
.8439 .77086 L
s
0 1 .151 r
.4426 .49489 m
.44615 .49752 L
s
.43891 .49921 m
.4426 .49489 L
s
.4426 .49489 m
.44001 .49573 L
s
0 1 .334 r
.42413 .32854 m
.43132 .32825 L
s
.246 1 0 r
.71691 .93813 m
.72037 .941 L
s
.71386 .94075 m
.71691 .93813 L
s
.71691 .93813 m
.7178 .93828 L
s
1 0 .436 r
.28053 .98984 m
.27656 1.00758 L
s
.26499 .99892 m
.28053 .98984 L
s
0 1 .151 r
.44245 .50184 m
.43891 .49921 L
s
.43891 .49921 m
.44001 .49573 L
s
0 .346 1 r
.48049 1.03563 m
.50136 .99952 L
s
1 0 .436 r
.27656 1.00758 m
.26499 .99892 L
s
0 1 .408 r
.60829 .49914 m
.58721 .49352 L
s
0 .177 1 r
.33178 .82742 m
.3297 .83964 L
s
.102 1 0 r
.70027 .76883 m
.69717 .7728 L
s
.69507 .76788 m
.70027 .76883 L
s
.69507 .76788 m
.69717 .7728 L
s
0 .54 1 r
.73455 .41936 m
.74072 .42222 L
s
.73455 .41936 m
.73026 .42591 L
s
0 1 .709 r
.75504 .60214 m
.75016 .59934 L
s
.75016 .59934 m
.75206 .59272 L
s
.75016 .59934 m
.74863 .59763 L
s
0 .366 1 r
.2267 .76698 m
.23952 .72784 L
s
0 .703 1 r
.40863 .83692 m
.40345 .83989 L
s
.40501 .8293 m
.40863 .83692 L
s
.246 1 0 r
.72037 .941 m
.71732 .94362 L
s
.7178 .93828 m
.72037 .941 L
s
0 1 .569 r
.38491 .66283 m
.38469 .67108 L
s
.289 0 1 r
.4204 .99967 m
.4294 1.00636 L
s
.41547 1.00332 m
.4204 .99967 L
s
.4204 .99967 m
.42741 .99628 L
s
0 .635 1 r
.93093 .58748 m
.89801 .59759 L
s
.246 1 0 r
.71732 .94362 m
.71386 .94075 L
s
.71386 .94075 m
.7178 .93828 L
s
0 1 .274 r
.45912 .66427 m
.46314 .66718 L
s
.45466 .66757 m
.45912 .66427 L
s
.45912 .66427 m
.45817 .66326 L
s
0 1 .316 r
.54916 .85554 m
.5526 .83307 L
s
0 1 .151 r
.44615 .49752 m
.44245 .50184 L
s
.44001 .49573 m
.44615 .49752 L
s
0 .731 1 r
.67709 .3185 m
.64481 .32033 L
s
0 1 .709 r
.75206 .59272 m
.75695 .5955 L
s
.75206 .59272 m
.74863 .59763 L
s
0 1 .609 r
.50306 .33101 m
.49856 .3285 L
s
.49856 .3285 m
.50081 .32203 L
s
.49856 .3285 m
.4972 .32582 L
s
0 1 .151 r
.44001 .49573 m
.44245 .50184 L
s
.026 1 0 r
.20709 .39898 m
.21049 .40164 L
s
.20308 .40169 m
.20709 .39898 L
s
.20709 .39898 m
.20623 .39804 L
s
0 1 .39 r
.29512 .58656 m
.2948 .56202 L
s
0 .54 1 r
.74072 .42222 m
.73923 .43095 L
s
.73026 .42591 m
.73923 .43095 L
s
.246 1 0 r
.7178 .93828 m
.71732 .94362 L
s
.289 0 1 r
.4294 1.00636 m
.4245 1.01004 L
s
.42741 .99628 m
.4294 1.00636 L
s
.078 1 0 r
.77268 .77333 m
.76907 .77082 L
s
.76907 .77082 m
.7714 .76639 L
s
.76907 .77082 m
.76928 .76937 L
s
.8 1 0 r
.87208 .94423 m
.86699 .94408 L
s
0 .703 1 r
.40345 .83989 m
.39677 .83525 L
s
.39677 .83525 m
.40501 .8293 L
s
0 1 .609 r
.50081 .32203 m
.50531 .32453 L
s
.50081 .32203 m
.4972 .32582 L
s
0 1 .274 r
.45867 .67048 m
.45466 .66757 L
s
.45466 .66757 m
.45817 .66326 L
s
.078 1 0 r
.7714 .76639 m
.77502 .7689 L
s
.7714 .76639 m
.76928 .76937 L
s
0 .177 1 r
.81499 .42912 m
.80815 .42623 L
s
.80815 .42623 m
.8091 .41656 L
s
.80815 .42623 m
.80457 .4243 L
s
.022 1 0 r
.61797 .67509 m
.60594 .66414 L
s
0 1 .709 r
.75695 .5955 m
.75504 .60214 L
s
.74863 .59763 m
.75504 .60214 L
s
.026 1 0 r
.20648 .40435 m
.20308 .40169 L
s
.20308 .40169 m
.20623 .39804 L
s
.21049 .40164 m
.20648 .40435 L
s
.20623 .39804 m
.21049 .40164 L
s
0 1 .79 r
.47662 .83349 m
.48222 .83736 L
s
.47198 .83631 m
.47662 .83349 L
s
.47662 .83349 m
.47861 .83118 L
s
.926 0 1 r
.35037 1.0088 m
.34006 1.00112 L
s
.34006 1.00112 m
.3538 .99305 L
s
.3538 .99305 m
.35037 1.0088 L
s
0 1 .274 r
.46314 .66718 m
.45867 .67048 L
s
.45817 .66326 m
.46314 .66718 L
s
.741 0 1 r
.23559 .94353 m
.25963 .8937 L
s
.078 1 0 r
.36369 .40577 m
.35199 .39365 L
s
0 .54 1 r
.73026 .42591 m
.74072 .42222 L
s
0 .703 1 r
.40501 .8293 m
.40345 .83989 L
s
0 1 .609 r
.50531 .32453 m
.50306 .33101 L
s
.4972 .32582 m
.50306 .33101 L
s
0 1 .396 r
.94127 .76374 m
.91894 .77235 L
s
0 1 .694 r
.221 .56542 m
.22603 .56887 L
s
.21586 .56788 m
.221 .56542 L
s
.221 .56542 m
.22173 .56264 L
s
.078 1 0 r
.77502 .7689 m
.77268 .77333 L
s
.76928 .76937 m
.77268 .77333 L
s
.631 1 0 r
.79226 .94008 m
.79495 .94237 L
s
.78979 .9426 m
.79226 .94008 L
s
.79226 .94008 m
.79221 .94117 L
s
0 1 .234 r
.51701 .50032 m
.51332 .49773 L
s
.51332 .49773 m
.5165 .49272 L
s
.51332 .49773 m
.51338 .49463 L
s
0 1 .709 r
.74863 .59763 m
.75695 .5955 L
s
.026 1 0 r
.20623 .39804 m
.20648 .40435 L
s
0 1 .234 r
.5165 .49272 m
.5202 .4953 L
s
.5165 .49272 m
.51338 .49463 L
s
0 .987 1 r
.83102 .60161 m
.82556 .59883 L
s
.82556 .59883 m
.82671 .59138 L
s
.82556 .59883 m
.8231 .59761 L
s
0 .978 1 r
.55872 1.0324 m
.57566 1.00278 L
s
0 1 .654 r
.68692 .49426 m
.66149 .49241 L
s
.078 1 0 r
.76928 .76937 m
.77502 .7689 L
s
.631 1 0 r
.79247 .94491 m
.78979 .9426 L
s
.78979 .9426 m
.79221 .94117 L
s
0 1 .274 r
.45817 .66326 m
.45867 .67048 L
s
0 1 .79 r
.48222 .83736 m
.47759 .84019 L
s
.47861 .83118 m
.48222 .83736 L
s
.631 1 0 r
.79495 .94237 m
.79247 .94491 L
s
.79221 .94117 m
.79495 .94237 L
s
0 .833 1 r
.30417 .76292 m
.31301 .72871 L
s
0 1 .609 r
.4972 .32582 m
.50531 .32453 L
s
0 .177 1 r
.8091 .41656 m
.81596 .41943 L
s
.8091 .41656 m
.80457 .4243 L
s
0 .346 1 r
.49539 1.00231 m
.50311 1.00803 L
s
.49121 1.00554 m
.49539 1.00231 L
s
.49539 1.00231 m
.50136 .99952 L
s
.631 1 0 r
.79221 .94117 m
.79247 .94491 L
s
0 1 .694 r
.22603 .56887 m
.22089 .57134 L
s
.22173 .56264 m
.22603 .56887 L
s
.102 1 0 r
.62768 .85176 m
.62697 .83497 L
s
0 .987 1 r
.82671 .59138 m
.83219 .59414 L
s
.82671 .59138 m
.8231 .59761 L
s
0 1 .067 r
.53361 .66372 m
.53714 .66635 L
s
.52968 .66737 m
.53361 .66372 L
s
.53361 .66372 m
.53184 .6637 L
s
0 .366 1 r
.75601 .31305 m
.71938 .31755 L
s
0 1 .79 r
.47759 .84019 m
.47198 .83631 L
s
.47198 .83631 m
.47861 .83118 L
s
0 1 .234 r
.5202 .4953 m
.51701 .50032 L
s
.51338 .49463 m
.51701 .50032 L
s
0 1 .924 r
.57798 .32822 m
.57295 .32571 L
s
.57295 .32571 m
.57478 .31828 L
s
.57295 .32571 m
.57076 .32308 L
s
0 1 .099 r
.84882 .77395 m
.84479 .77156 L
s
.84479 .77156 m
.84622 .76653 L
s
.84479 .77156 m
.8439 .77086 L
s
0 .346 1 r
.50311 1.00803 m
.49895 1.01128 L
s
.50136 .99952 m
.50311 1.00803 L
s
0 1 .234 r
.51338 .49463 m
.5202 .4953 L
s
1 0 0 r
.24452 1.12081 m
.28206 1.06027 L
s
0 .366 1 r
.23623 .73194 m
.24355 .73684 L
s
.23032 .7346 m
.23623 .73194 L
s
.23623 .73194 m
.23952 .72784 L
s
0 1 .151 r
.37288 .58194 m
.36829 .56139 L
s
.289 0 1 r
.4245 1.01004 m
.41547 1.00332 L
s
.41547 1.00332 m
.42741 .99628 L
s
.103 1 0 r
.28059 .39605 m
.28376 .39848 L
s
.2769 .39929 m
.28059 .39605 L
s
.28059 .39605 m
.27888 .39586 L
s
.289 0 1 r
.42741 .99628 m
.4245 1.01004 L
s
0 1 .694 r
.22089 .57134 m
.21586 .56788 L
s
.21586 .56788 m
.22173 .56264 L
s
0 1 .067 r
.53321 .67 m
.52968 .66737 L
s
.52968 .66737 m
.53184 .6637 L
s
0 .177 1 r
.81596 .41943 m
.81499 .42912 L
s
.80457 .4243 m
.81499 .42912 L
s
.667 1 0 r
.95166 .94071 m
.94215 .94701 L
s
0 1 .099 r
.84622 .76653 m
.85026 .76892 L
s
.84622 .76653 m
.8439 .77086 L
s
.103 1 0 r
.28007 .40172 m
.2769 .39929 L
s
.2769 .39929 m
.27888 .39586 L
s
.207 0 1 r
.89127 .42729 m
.88368 .42438 L
s
.88368 .42438 m
.88412 .41373 L
s
.88368 .42438 m
.87936 .42267 L
s
0 1 .924 r
.57478 .31828 m
.57982 .32078 L
s
.57478 .31828 m
.57076 .32308 L
s
0 .987 1 r
.83219 .59414 m
.83102 .60161 L
s
.8231 .59761 m
.83102 .60161 L
s
0 1 .021 r
.69678 .67074 m
.68046 .66458 L
s
0 1 .316 r
.55169 .83462 m
.55624 .8378 L
s
.54757 .83737 m
.55169 .83462 L
s
.55169 .83462 m
.5526 .83307 L
s
0 1 .79 r
.47861 .83118 m
.47759 .84019 L
s
0 1 .067 r
.53714 .66635 m
.53321 .67 L
s
.53184 .6637 m
.53714 .66635 L
s
.159 0 1 r
.31325 .94001 m
.33354 .89598 L
s
0 1 .044 r
.44174 .40059 m
.42558 .39144 L
s
.103 1 0 r
.28376 .39848 m
.28007 .40172 L
s
.27888 .39586 m
.28376 .39848 L
s
0 1 .099 r
.85026 .76892 m
.84882 .77395 L
s
.8439 .77086 m
.84882 .77395 L
s
.8 1 0 r
.86839 .94636 m
.86589 .94449 L
s
.86589 .94449 m
.86763 .94186 L
s
.86589 .94449 m
.86699 .94408 L
s
0 .366 1 r
.24355 .73684 m
.23765 .73951 L
s
.23952 .72784 m
.24355 .73684 L
s
0 1 .408 r
.59214 .49884 m
.58813 .49626 L
s
.58813 .49626 m
.59076 .49048 L
s
.58813 .49626 m
.58721 .49352 L
s
.8 1 0 r
.86763 .94186 m
.87014 .94374 L
s
.86763 .94186 m
.86699 .94408 L
s
0 1 .694 r
.22173 .56264 m
.22089 .57134 L
s
0 .635 1 r
.90751 .60109 m
.9014 .59833 L
s
.9014 .59833 m
.90177 .59002 L
s
.9014 .59833 m
.89801 .59759 L
s
0 1 .067 r
.53184 .6637 m
.53321 .67 L
s
0 1 .39 r
.2951 .56413 m
.29939 .56707 L
s
.29033 .56684 m
.2951 .56413 L
s
.2951 .56413 m
.2948 .56202 L
s
.103 1 0 r
.27888 .39586 m
.28007 .40172 L
s
.8 1 0 r
.87014 .94374 m
.86839 .94636 L
s
.86699 .94408 m
.86839 .94636 L
s
0 1 .924 r
.57982 .32078 m
.57798 .32822 L
s
.57076 .32308 m
.57798 .32822 L
s
.741 0 1 r
.25297 .89853 m
.26291 .90548 L
s
.24664 .90198 m
.25297 .89853 L
s
.25297 .89853 m
.25963 .8937 L
s
0 .177 1 r
.80457 .4243 m
.81596 .41943 L
s
0 1 .396 r
.63744 1.02915 m
.65031 1.00606 L
s
0 1 .408 r
.59076 .49048 m
.59478 .49304 L
s
.59076 .49048 m
.58721 .49352 L
s
0 1 .956 r
.76603 .48934 m
.73625 .49129 L
s
0 .987 1 r
.8231 .59761 m
.83219 .59414 L
s
.8 1 0 r
.86699 .94408 m
.87014 .94374 L
s
0 1 .099 r
.8439 .77086 m
.85026 .76892 L
s
0 1 .316 r
.55624 .8378 m
.55213 .84056 L
s
.5526 .83307 m
.55624 .8378 L
s
0 .978 1 r
.5708 1.00495 m
.57721 1.00971 L
s
.56729 1.00777 m
.5708 1.00495 L
s
.5708 1.00495 m
.57566 1.00278 L
s
0 1 .725 r
.38212 .75884 m
.38689 .72958 L
s
.207 0 1 r
.88412 .41373 m
.89172 .41661 L
s
.88412 .41373 m
.87936 .42267 L
s
0 1 .316 r
.55213 .84056 m
.54757 .83737 L
s
.54757 .83737 m
.5526 .83307 L
s
0 .346 1 r
.49895 1.01128 m
.49121 1.00554 L
s
.49121 1.00554 m
.50136 .99952 L
s
0 1 .396 r
.92552 .77464 m
.92093 .77233 L
s
.92093 .77233 m
.92134 .76661 L
s
.92093 .77233 m
.91894 .77235 L
s
0 .346 1 r
.50136 .99952 m
.49895 1.01128 L
s
0 1 .924 r
.57076 .32308 m
.57982 .32078 L
s
0 .978 1 r
.57721 1.00971 m
.57372 1.01253 L
s
.57566 1.00278 m
.57721 1.00971 L
s
0 .635 1 r
.90177 .59002 m
.9079 .59276 L
s
.90177 .59002 m
.89801 .59759 L
s
0 1 .39 r
.29939 .56707 m
.29463 .56978 L
s
.2948 .56202 m
.29939 .56707 L
s
.418 1 0 r
.70669 .84795 m
.70173 .83688 L
s
.014 0 1 r
.83542 .30757 m
.79445 .31475 L
s
.022 1 0 r
.60836 .66305 m
.61168 .66552 L
s
.60504 .66715 m
.60836 .66305 L
s
.60836 .66305 m
.60594 .66414 L
s
0 1 .408 r
.59478 .49304 m
.59214 .49884 L
s
.58721 .49352 m
.59214 .49884 L
s
0 .731 1 r
.65342 .32543 m
.6478 .3229 L
s
.6478 .3229 m
.64923 .31449 L
s
.6478 .3229 m
.64481 .32033 L
s
0 1 .39 r
.29463 .56978 m
.29033 .56684 L
s
.29033 .56684 m
.2948 .56202 L
s
.022 1 0 r
.60836 .66964 m
.60504 .66715 L
s
.60504 .66715 m
.60594 .66414 L
s
0 .366 1 r
.23765 .73951 m
.23032 .7346 L
s
.23032 .7346 m
.23952 .72784 L
s
.741 0 1 r
.26291 .90548 m
.25662 .90896 L
s
.25963 .8937 m
.26291 .90548 L
s
0 .833 1 r
.31076 .73223 m
.31709 .73636 L
s
.30536 .73482 m
.31076 .73223 L
s
.31076 .73223 m
.31301 .72871 L
s
1 0 .667 r
.32237 1.11783 m
.3564 1.06388 L
s
0 1 0 r
.45113 .5773 m
.44222 .56077 L
s
0 1 .396 r
.92134 .76661 m
.92593 .7689 L
s
.92134 .76661 m
.91894 .77235 L
s
0 1 .316 r
.5526 .83307 m
.55213 .84056 L
s
0 1 .408 r
.58721 .49352 m
.59478 .49304 L
s
.078 1 0 r
.35443 .39299 m
.35758 .39529 L
s
.35111 .39689 m
.35443 .39299 L
s
.35443 .39299 m
.35199 .39365 L
s
.46 1 0 r
.19541 .30648 m
.19059 .29483 L
s
.667 1 0 r
.94523 .94801 m
.94225 .94647 L
s
.94225 .94647 m
.94288 .94348 L
s
.94225 .94647 m
.94215 .94701 L
s
1 0 0 r
.27137 1.06524 m
.28407 1.07474 L
s
.26489 1.07017 m
.27137 1.06524 L
s
.27137 1.06524 m
.28206 1.06027 L
s
.078 1 0 r
.35426 .3992 m
.35111 .39689 L
s
.35111 .39689 m
.35199 .39365 L
s
0 .366 1 r
.23952 .72784 m
.23765 .73951 L
s
.207 0 1 r
.89172 .41661 m
.89127 .42729 L
s
.87936 .42267 m
.89127 .42729 L
s
.102 1 0 r
.6271 .83566 m
.6307 .83827 L
s
.62352 .83841 m
.6271 .83566 L
s
.6271 .83566 m
.62697 .83497 L
s
0 1 .189 r
.77609 .66636 m
.75541 .66502 L
s
0 .635 1 r
.9079 .59276 m
.90751 .60109 L
s
.89801 .59759 m
.90751 .60109 L
s
0 .731 1 r
.64923 .31449 m
.65485 .317 L
s
.64923 .31449 m
.64481 .32033 L
s
0 1 .396 r
.92593 .7689 m
.92552 .77464 L
s
.91894 .77235 m
.92552 .77464 L
s
.667 1 0 r
.94288 .94348 m
.94586 .94502 L
s
.94288 .94348 m
.94215 .94701 L
s
.022 1 0 r
.61168 .66552 m
.60836 .66964 L
s
.60594 .66414 m
.61168 .66552 L
s
0 1 .39 r
.2948 .56202 m
.29463 .56978 L
s
0 .418 1 r
.39139 .93647 m
.40781 .89827 L
s
0 1 .248 r
.52028 .39538 m
.49964 .38921 L
s
0 1 .654 r
.66782 .49738 m
.66337 .49481 L
s
.66337 .49481 m
.6654 .48819 L
s
.66337 .49481 m
.66149 .49241 L
s
.022 1 0 r
.60594 .66414 m
.60836 .66964 L
s
.667 1 0 r
.94586 .94502 m
.94523 .94801 L
s
.94215 .94701 m
.94523 .94801 L
s
0 .833 1 r
.31709 .73636 m
.3117 .73897 L
s
.31301 .72871 m
.31709 .73636 L
s
0 .978 1 r
.57372 1.01253 m
.56729 1.00777 L
s
.56729 1.00777 m
.57566 1.00278 L
s
.078 1 0 r
.35758 .39529 m
.35426 .3992 L
s
.35199 .39365 m
.35758 .39529 L
s
1 0 0 r
.28407 1.07474 m
.27766 1.07972 L
s
.28206 1.06027 m
.28407 1.07474 L
s
.159 0 1 r
.32783 .90027 m
.33663 .90629 L
s
.32227 .90339 m
.32783 .90027 L
s
.32783 .90027 m
.33354 .89598 L
s
.078 1 0 r
.35199 .39365 m
.35426 .3992 L
s
.102 1 0 r
.62713 .84103 m
.62352 .83841 L
s
.62352 .83841 m
.62697 .83497 L
s
0 1 .151 r
.36955 .56273 m
.37323 .56529 L
s
.3652 .56577 m
.36955 .56273 L
s
.36955 .56273 m
.36829 .56139 L
s
0 1 .396 r
.64662 1.0076 m
.65172 1.0114 L
s
.64371 1.01 m
.64662 1.0076 L
s
.64662 1.0076 m
.65031 1.00606 L
s
.667 1 0 r
.94215 .94701 m
.94586 .94502 L
s
.102 1 0 r
.6307 .83827 m
.62713 .84103 L
s
.62697 .83497 m
.6307 .83827 L
s
0 .978 1 r
.57566 1.00278 m
.57372 1.01253 L
s
.218 1 0 r
.71664 1.02588 m
.7253 1.00935 L
s
0 .703 1 r
.84563 .4844 m
.81147 .49016 L
s
0 1 .654 r
.6654 .48819 m
.66986 .49075 L
s
.6654 .48819 m
.66149 .49241 L
s
0 1 .396 r
.91894 .77235 m
.92593 .7689 L
s
0 .635 1 r
.89801 .59759 m
.9079 .59276 L
s
0 .731 1 r
.65485 .317 m
.65342 .32543 L
s
.64481 .32033 m
.65342 .32543 L
s
.207 0 1 r
.87936 .42267 m
.89172 .41661 L
s
0 1 .32 r
.46055 .75473 m
.46117 .73046 L
s
0 1 .396 r
.65172 1.0114 m
.64882 1.0138 L
s
.65031 1.00606 m
.65172 1.0114 L
s
0 .833 1 r
.3117 .73897 m
.30536 .73482 L
s
.30536 .73482 m
.31301 .72871 L
s
0 1 .116 r
.20431 .48341 m
.20455 .46109 L
s
0 1 .021 r
.68413 .66937 m
.68073 .66696 L
s
.68073 .66696 m
.68336 .66227 L
s
.68073 .66696 m
.68046 .66458 L
s
0 1 .151 r
.36887 .56834 m
.3652 .56577 L
s
.3652 .56577 m
.36829 .56139 L
s
.102 1 0 r
.62697 .83497 m
.62713 .84103 L
s
.159 0 1 r
.33663 .90629 m
.33109 .90943 L
s
.33354 .89598 m
.33663 .90629 L
s
0 1 .021 r
.68336 .66227 m
.68676 .66468 L
s
.68336 .66227 m
.68046 .66458 L
s
.563 1 0 r
.78619 .84411 m
.77688 .8388 L
s
.741 0 1 r
.25662 .90896 m
.24664 .90198 L
s
.24664 .90198 m
.25963 .8937 L
s
.405 0 1 r
.91532 .30206 m
.87004 .31194 L
s
0 .366 1 r
.72938 .32264 m
.72313 .32008 L
s
.72313 .32008 m
.72416 .31066 L
s
.72313 .32008 m
.71938 .31755 L
s
0 1 .151 r
.37323 .56529 m
.36887 .56834 L
s
.36829 .56139 m
.37323 .56529 L
s
0 1 .654 r
.66986 .49075 m
.66782 .49738 L
s
.66149 .49241 m
.66782 .49738 L
s
.741 0 1 r
.25963 .8937 m
.25662 .90896 L
s
0 1 .725 r
.38572 .73247 m
.39106 .73589 L
s
.3808 .73505 m
.38572 .73247 L
s
.38572 .73247 m
.38689 .72958 L
s
.667 0 1 r
.4007 1.11483 m
.43106 1.0675 L
s
0 .731 1 r
.64481 .32033 m
.65485 .317 L
s
.042 1 0 r
.52986 .57262 m
.51659 .56014 L
s
1 0 .667 r
.34654 1.06829 m
.35793 1.07676 L
s
.34114 1.0727 m
.34654 1.06829 L
s
.34654 1.06829 m
.3564 1.06388 L
s
0 .833 1 r
.31301 .72871 m
.3117 .73897 L
s
0 1 .044 r
.42904 .39674 m
.42573 .39448 L
s
.42573 .39448 m
.42862 .38982 L
s
.42573 .39448 m
.42558 .39144 L
s
.404 1 0 r
.27337 .30096 m
.26389 .29148 L
s
0 1 .044 r
.42862 .38982 m
.43194 .39208 L
s
.42862 .38982 m
.42558 .39144 L
s
0 1 .654 r
.66149 .49241 m
.66986 .49075 L
s
0 1 .396 r
.64882 1.0138 m
.64371 1.01 L
s
.64371 1.01 m
.65031 1.00606 L
s
.418 1 0 r
.70276 .83656 m
.70565 .83876 L
s
.6998 .83944 m
.70276 .83656 L
s
.70276 .83656 m
.70173 .83688 L
s
0 1 .151 r
.36829 .56139 m
.36887 .56834 L
s
0 1 .456 r
.85588 .66196 m
.83079 .66547 L
s
0 1 .021 r
.68676 .66468 m
.68413 .66937 L
s
.68046 .66458 m
.68413 .66937 L
s
0 1 .956 r
.74403 .49595 m
.73905 .49336 L
s
.73905 .49336 m
.74046 .48585 L
s
.73905 .49336 m
.73625 .49129 L
s
0 1 .396 r
.65031 1.00606 m
.64882 1.0138 L
s
1 0 .667 r
.35793 1.07676 m
.35258 1.08121 L
s
.3564 1.06388 m
.35793 1.07676 L
s
.418 1 0 r
.70269 .84164 m
.6998 .83944 L
s
.6998 .83944 m
.70173 .83688 L
s
0 1 .021 r
.68046 .66458 m
.68676 .66468 L
s
0 .366 1 r
.72416 .31066 m
.73042 .31319 L
s
.72416 .31066 m
.71938 .31755 L
s
0 .987 1 r
.47001 .9329 m
.48244 .90057 L
s
0 1 .514 r
.59931 .39013 m
.57418 .38696 L
s
0 1 .725 r
.39106 .73589 m
.38614 .73848 L
s
.38689 .72958 m
.39106 .73589 L
s
0 .418 1 r
.40312 .90201 m
.41075 .90709 L
s
.39825 .90481 m
.40312 .90201 L
s
.40312 .90201 m
.40781 .89827 L
s
0 1 .959 r
.21324 .66108 m
.22082 .62795 L
s
.218 1 0 r
.72286 1.01024 m
.72664 1.0131 L
s
.72048 1.01224 m
.72286 1.01024 L
s
.72286 1.01024 m
.7253 1.00935 L
s
.418 1 0 r
.70565 .83876 m
.70269 .84164 L
s
.70173 .83688 m
.70565 .83876 L
s
0 1 .044 r
.43194 .39208 m
.42904 .39674 L
s
.42558 .39144 m
.42904 .39674 L
s
0 1 0 r
.44434 .56118 m
.44758 .56351 L
s
.44045 .56468 m
.44434 .56118 L
s
.44434 .56118 m
.44222 .56077 L
s
0 1 .044 r
.42558 .39144 m
.43194 .39208 L
s
0 1 .725 r
.38614 .73848 m
.3808 .73505 L
s
.3808 .73505 m
.38689 .72958 L
s
.8 1 0 r
.79633 1.0226 m
.80065 1.01266 L
s
0 1 .956 r
.74046 .48585 m
.74545 .48843 L
s
.74046 .48585 m
.73625 .49129 L
s
0 .333 1 r
.92572 .47943 m
.88718 .48903 L
s
.418 1 0 r
.70173 .83688 m
.70269 .84164 L
s
.46 1 0 r
.19174 .29475 m
.19442 .29697 L
s
.1887 .29737 m
.19174 .29475 L
s
.19174 .29475 m
.19059 .29483 L
s
.218 1 0 r
.72664 1.0131 m
.72427 1.0151 L
s
.7253 1.00935 m
.72664 1.0131 L
s
.159 0 1 r
.33109 .90943 m
.32227 .90339 L
s
.32227 .90339 m
.33354 .89598 L
s
0 1 .189 r
.7605 .66917 m
.75679 .66679 L
s
.75679 .66679 m
.75864 .66141 L
s
.75679 .66679 m
.75541 .66502 L
s
.022 1 0 r
.53947 .7506 m
.53586 .73135 L
s
0 1 0 r
.44369 .56701 m
.44045 .56468 L
s
.44045 .56468 m
.44222 .56077 L
s
.159 0 1 r
.33354 .89598 m
.33109 .90943 L
s
0 .366 1 r
.73042 .31319 m
.72938 .32264 L
s
.71938 .31755 m
.72938 .32264 L
s
1 0 0 r
.28206 1.06027 m
.27766 1.07972 L
s
.26489 1.07017 m
.28206 1.06027 L
s
.46 1 0 r
.19138 .29959 m
.1887 .29737 L
s
.1887 .29737 m
.19059 .29483 L
s
0 .418 1 r
.41075 .90709 m
.4059 .90991 L
s
.40781 .89827 m
.41075 .90709 L
s
.078 1 0 r
.28246 .47843 m
.27827 .45938 L
s
.46 1 0 r
.19442 .29697 m
.19138 .29959 L
s
.19059 .29483 m
.19442 .29697 L
s
0 1 .189 r
.75864 .66141 m
.76236 .66379 L
s
.75864 .66141 m
.75541 .66502 L
s
.218 1 0 r
.72427 1.0151 m
.72048 1.01224 L
s
.72048 1.01224 m
.7253 1.00935 L
s
.667 0 1 r
.42212 1.07136 m
.43217 1.07879 L
s
.41772 1.07524 m
.42212 1.07136 L
s
.42212 1.07136 m
.43106 1.0675 L
s
.014 0 1 r
.80586 .31983 m
.79892 .31725 L
s
.79892 .31725 m
.79957 .30679 L
s
.79892 .31725 m
.79445 .31475 L
s
.487 1 0 r
.86618 .84025 m
.85242 .84073 L
s
0 1 .725 r
.38689 .72958 m
.38614 .73848 L
s
1 0 0 r
.27766 1.07972 m
.26489 1.07017 L
s
0 1 .32 r
.46108 .73262 m
.46547 .73543 L
s
.45663 .73526 m
.46108 .73262 L
s
.46108 .73262 m
.46117 .73046 L
s
0 1 .956 r
.74545 .48843 m
.74403 .49595 L
s
.73625 .49129 m
.74403 .49595 L
s
.46 1 0 r
.19059 .29483 m
.19138 .29959 L
s
0 1 0 r
.44758 .56351 m
.44369 .56701 L
s
.44222 .56077 m
.44758 .56351 L
s
0 0 1 r
.47952 1.11181 m
.50605 1.07114 L
s
0 1 .033 r
.60908 .56792 m
.59141 .5595 L
s
0 1 .248 r
.50439 .39433 m
.50077 .39207 L
s
.50077 .39207 m
.5032 .38657 L
s
.50077 .39207 m
.49964 .38921 L
s
.218 1 0 r
.7253 1.00935 m
.72427 1.0151 L
s
0 .023 1 r
.22221 .83948 m
.2394 .79545 L
s
.245 1 0 r
.35181 .29541 m
.33767 .28812 L
s
0 1 0 r
.44222 .56077 m
.44369 .56701 L
s
.563 1 0 r
.77893 .84243 m
.77636 .84047 L
s
.77636 .84047 m
.77856 .8373 L
s
.77636 .84047 m
.77688 .8388 L
s
0 1 .116 r
.20475 .46313 m
.20856 .46579 L
s
.20045 .46538 m
.20475 .46313 L
s
.20475 .46313 m
.20455 .46109 L
s
.563 1 0 r
.77856 .8373 m
.78114 .83926 L
s
.77856 .8373 m
.77688 .8388 L
s
.667 0 1 r
.43217 1.07879 m
.42781 1.0827 L
s
.43106 1.0675 m
.43217 1.07879 L
s
0 1 .189 r
.76236 .66379 m
.7605 .66917 L
s
.75541 .66502 m
.7605 .66917 L
s
0 .366 1 r
.71938 .31755 m
.73042 .31319 L
s
0 .703 1 r
.82074 .49452 m
.81517 .49191 L
s
.81517 .49191 m
.81597 .48349 L
s
.81517 .49191 m
.81147 .49016 L
s
0 1 .248 r
.5032 .38657 m
.50683 .38882 L
s
.5032 .38657 m
.49964 .38921 L
s
0 1 .794 r
.93618 .65753 m
.90661 .66592 L
s
0 1 .956 r
.73625 .49129 m
.74545 .48843 L
s
0 .987 1 r
.47885 .90373 m
.48529 .90791 L
s
.47459 .90623 m
.47885 .90373 L
s
.47885 .90373 m
.48244 .90057 L
s
0 1 .32 r
.46547 .73543 m
.46101 .73807 L
s
.46117 .73046 m
.46547 .73543 L
s
0 1 .456 r
.54913 .92932 m
.55744 .90288 L
s
0 1 .825 r
.67883 .38485 m
.64921 .3847 L
s
0 1 .189 r
.75541 .66502 m
.76236 .66379 L
s
.8 1 0 r
.79947 1.01284 m
.80197 1.01482 L
s
.7976 1.01448 m
.79947 1.01284 L
s
.79947 1.01284 m
.80065 1.01266 L
s
.014 0 1 r
.79957 .30679 m
.80652 .30935 L
s
.79957 .30679 m
.79445 .31475 L
s
0 1 .32 r
.46101 .73807 m
.45663 .73526 L
s
.45663 .73526 m
.46117 .73046 L
s
0 .418 1 r
.4059 .90991 m
.39825 .90481 L
s
.39825 .90481 m
.40781 .89827 L
s
.563 1 0 r
.78114 .83926 m
.77893 .84243 L
s
.77688 .8388 m
.77893 .84243 L
s
.77688 .8388 m
.78114 .83926 L
s
0 1 .575 r
.29158 .65664 m
.29496 .62779 L
s
0 1 .116 r
.20856 .46579 m
.20426 .46804 L
s
.20455 .46109 m
.20856 .46579 L
s
1 0 .667 r
.3564 1.06388 m
.35258 1.08121 L
s
.34114 1.0727 m
.3564 1.06388 L
s
.8 1 0 r
.80197 1.01482 m
.8001 1.01646 L
s
.80065 1.01266 m
.80197 1.01482 L
s
0 .418 1 r
.40781 .89827 m
.4059 .90991 L
s
0 1 .456 r
.83742 .66902 m
.83325 .66665 L
s
.83325 .66665 m
.83426 .66051 L
s
.83325 .66665 m
.83079 .66547 L
s
0 1 .116 r
.20426 .46804 m
.20045 .46538 L
s
.20045 .46538 m
.20455 .46109 L
s
0 1 .248 r
.50683 .38882 m
.50439 .39433 L
s
.49964 .38921 m
.50439 .39433 L
s
0 .703 1 r
.81597 .48349 m
.82154 .48608 L
s
.81597 .48349 m
.81147 .49016 L
s
.042 1 0 r
.51941 .5595 m
.52247 .56173 L
s
.51605 .56357 m
.51941 .5595 L
s
.51941 .5595 m
.51659 .56014 L
s
1 .727 0 r
.87652 1.01929 m
.87635 1.01598 L
s
.042 1 0 r
.51911 .5658 m
.51605 .56357 L
s
.51605 .56357 m
.51659 .56014 L
s
1 0 .667 r
.35258 1.08121 m
.34114 1.0727 L
s
.8 1 0 r
.8001 1.01646 m
.7976 1.01448 L
s
.7976 1.01448 m
.80065 1.01266 L
s
0 1 .959 r
.21901 .63166 m
.22487 .63538 L
s
.21371 .63384 m
.21901 .63166 L
s
.21901 .63166 m
.22082 .62795 L
s
0 1 .248 r
.49964 .38921 m
.50683 .38882 L
s
.266 1 0 r
.61889 .74644 m
.61094 .73224 L
s
0 .987 1 r
.48529 .90791 m
.48105 .91042 L
s
.48244 .90057 m
.48529 .90791 L
s
.404 1 0 r
.2658 .29072 m
.26854 .29276 L
s
.26305 .29402 m
.2658 .29072 L
s
.2658 .29072 m
.26389 .29148 L
s
.26579 .29606 m
.26305 .29402 L
s
.26305 .29402 m
.26389 .29148 L
s
.8 1 0 r
.80065 1.01266 m
.8001 1.01646 L
s
0 0 1 r
.49812 1.07445 m
.50681 1.08083 L
s
.49462 1.07779 m
.49812 1.07445 L
s
.49812 1.07445 m
.50605 1.07114 L
s
1 0 .857 r
.23122 1.01862 m
.26033 .96364 L
s
.181 1 0 r
.36109 .47342 m
.35243 .45765 L
s
0 1 .32 r
.46117 .73046 m
.46101 .73807 L
s
0 1 .456 r
.83426 .66051 m
.83844 .66288 L
s
.83426 .66051 m
.83079 .66547 L
s
0 1 .116 r
.20455 .46109 m
.20426 .46804 L
s
.014 0 1 r
.80652 .30935 m
.80586 .31983 L
s
.79445 .31475 m
.80586 .31983 L
s
.405 0 1 r
.88287 .31702 m
.87519 .31439 L
s
.87519 .31439 m
.87549 .30289 L
s
.87519 .31439 m
.87004 .31194 L
s
.218 1 0 r
.94667 .83637 m
.92836 .84267 L
s
.487 1 0 r
.85592 .84338 m
.85318 .84154 L
s
.85318 .84154 m
.85444 .83788 L
s
.85318 .84154 m
.85242 .84073 L
s
.022 1 0 r
.5368 .73265 m
.54032 .73498 L
s
.53285 .73545 m
.5368 .73265 L
s
.5368 .73265 m
.53586 .73135 L
s
.404 1 0 r
.26854 .29276 m
.26579 .29606 L
s
.26389 .29148 m
.26854 .29276 L
s
.26389 .29148 m
.26579 .29606 L
s
0 .703 1 r
.82154 .48608 m
.82074 .49452 L
s
.81147 .49016 m
.82074 .49452 L
s
0 0 1 r
.50681 1.08083 m
.50334 1.0842 L
s
.50605 1.07114 m
.50681 1.08083 L
s
.042 1 0 r
.52247 .56173 m
.51911 .5658 L
s
.51659 .56014 m
.52247 .56173 L
s
0 1 .514 r
.58029 .39193 m
.57625 .38966 L
s
.57625 .38966 m
.5782 .38327 L
s
.57625 .38966 m
.57418 .38696 L
s
0 .667 1 r
.55883 1.10878 m
.58137 1.07479 L
s
0 1 .211 r
.6888 .56318 m
.66667 .55886 L
s
.042 1 0 r
.51659 .56014 m
.51911 .5658 L
s
0 1 .959 r
.22487 .63538 m
.21958 .63758 L
s
.22082 .62795 m
.22487 .63538 L
s
.487 1 0 r
.85444 .83788 m
.85719 .83972 L
s
.85444 .83788 m
.85242 .84073 L
s
0 .333 1 r
.89796 .4931 m
.89175 .49046 L
s
.89175 .49046 m
.89192 .4811 L
s
.89175 .49046 m
.88718 .48903 L
s
0 .54 1 r
.30074 .83559 m
.31397 .79675 L
s
0 1 .456 r
.83844 .66288 m
.83742 .66902 L
s
.83079 .66547 m
.83742 .66902 L
s
.008 1 0 r
.43075 .28982 m
.41195 .28473 L
s
0 .987 1 r
.48105 .91042 m
.47459 .90623 L
s
.47459 .90623 m
.48244 .90057 L
s
.667 0 1 r
.43106 1.0675 m
.42781 1.0827 L
s
.41772 1.07524 m
.43106 1.0675 L
s
.078 1 0 r
.27947 .46076 m
.28273 .46302 L
s
.27549 .4634 m
.27947 .46076 L
s
.27947 .46076 m
.27827 .45938 L
s
0 .023 1 r
.2347 .80028 m
.24308 .80572 L
s
.22879 .8029 m
.2347 .80028 L
s
.2347 .80028 m
.2394 .79545 L
s
.022 1 0 r
.53637 .73779 m
.53285 .73545 L
s
.53285 .73545 m
.53586 .73135 L
s
0 1 .514 r
.5782 .38327 m
.58224 .38553 L
s
.5782 .38327 m
.57418 .38696 L
s
.487 1 0 r
.85719 .83972 m
.85592 .84338 L
s
.85242 .84073 m
.85592 .84338 L
s
0 1 .456 r
.55501 .90543 m
.56025 .90873 L
s
.55129 .90766 m
.55501 .90543 L
s
.55501 .90543 m
.55744 .90288 L
s
.667 0 1 r
.42781 1.0827 m
.41772 1.07524 L
s
1 .727 0 r
.87631 1.01532 m
.87778 1.01658 L
s
.87499 1.0167 m
.87631 1.01532 L
s
.87631 1.01532 m
.87635 1.01598 L
s
.014 0 1 r
.79445 .31475 m
.80652 .30935 L
s
0 .987 1 r
.48244 .90057 m
.48105 .91042 L
s
.022 1 0 r
.54032 .73498 m
.53637 .73779 L
s
.53586 .73135 m
.54032 .73498 L
s
0 .703 1 r
.81147 .49016 m
.82154 .48608 L
s
.078 1 0 r
.62874 .92571 m
.63281 .90521 L
s
0 .833 1 r
.75885 .37954 m
.72473 .38243 L
s
1 .727 0 r
.87647 1.01796 m
.87499 1.0167 L
s
.87499 1.0167 m
.87635 1.01598 L
s
0 1 .959 r
.21958 .63758 m
.21371 .63384 L
s
.21371 .63384 m
.22082 .62795 L
s
0 1 .794 r
.91485 .66891 m
.91015 .66652 L
s
.91015 .66652 m
.91027 .65956 L
s
.91015 .66652 m
.90661 .66592 L
s
0 1 .456 r
.83079 .66547 m
.83844 .66288 L
s
.487 1 0 r
.85242 .84073 m
.85719 .83972 L
s
1 .727 0 r
.87778 1.01658 m
.87647 1.01796 L
s
.87635 1.01598 m
.87778 1.01658 L
s
.405 0 1 r
.87549 .30289 m
.88318 .30548 L
s
.87549 .30289 m
.87004 .31194 L
s
.078 1 0 r
.27875 .46567 m
.27549 .4634 L
s
.27549 .4634 m
.27827 .45938 L
s
0 1 .234 r
.37041 .65218 m
.36951 .62762 L
s
1 .727 0 r
.87635 1.01598 m
.87647 1.01796 L
s
0 1 .033 r
.59515 .56467 m
.59202 .56246 L
s
.59202 .56246 m
.59477 .55773 L
s
.59202 .56246 m
.59141 .5595 L
s
.078 1 0 r
.28273 .46302 m
.27875 .46567 L
s
.27827 .45938 m
.28273 .46302 L
s
0 .333 1 r
.89192 .4811 m
.89814 .48371 L
s
.89192 .4811 m
.88718 .48903 L
s
0 1 .033 r
.59477 .55773 m
.5979 .55993 L
s
.59477 .55773 m
.59141 .5595 L
s
0 1 .514 r
.58224 .38553 m
.58029 .39193 L
s
.57418 .38696 m
.58029 .39193 L
s
1 .667 0 r
.95721 1.01596 m
.95242 1.01931 L
s
0 .023 1 r
.24308 .80572 m
.2372 .80835 L
s
.2394 .79545 m
.24308 .80572 L
s
0 1 .456 r
.56025 .90873 m
.55654 .91097 L
s
.55744 .90288 m
.56025 .90873 L
s
.022 1 0 r
.53586 .73135 m
.53637 .73779 L
s
0 1 .575 r
.29425 .63094 m
.2992 .63398 L
s
.28935 .6332 m
.29425 .63094 L
s
.29425 .63094 m
.29496 .62779 L
s
0 1 .959 r
.22082 .62795 m
.21958 .63758 L
s
0 .667 1 r
.57453 1.07755 m
.58183 1.08289 L
s
.57184 1.08035 m
.57453 1.07755 L
s
.57453 1.07755 m
.58137 1.07479 L
s
.366 1 0 r
.6988 .74226 m
.68644 .73313 L
s
.218 1 0 r
.93354 .84445 m
.93039 .84267 L
s
.93039 .84267 m
.93053 .83836 L
s
.93039 .84267 m
.92836 .84267 L
s
0 1 .794 r
.91027 .65956 m
.91498 .66193 L
s
.91027 .65956 m
.90661 .66592 L
s
.245 1 0 r
.3408 .29261 m
.33785 .29065 L
s
.33785 .29065 m
.34024 .28655 L
s
.33785 .29065 m
.33767 .28812 L
s
1 0 .857 r
.25199 .969 m
.26311 .9767 L
s
.24581 .9727 m
.25199 .969 L
s
.25199 .969 m
.26033 .96364 L
s
.078 1 0 r
.27827 .45938 m
.27875 .46567 L
s
.245 1 0 r
.34024 .28655 m
.34319 .28851 L
s
.34024 .28655 m
.33767 .28812 L
s
.529 0 1 r
.30995 1.01529 m
.33534 .96633 L
s
.176 1 0 r
.44022 .46838 m
.42706 .45592 L
s
0 1 .514 r
.57418 .38696 m
.58224 .38553 L
s
0 .667 1 r
.58183 1.08289 m
.57917 1.0857 L
s
.58137 1.07479 m
.58183 1.08289 L
s
0 0 1 r
.50605 1.07114 m
.50334 1.0842 L
s
.49462 1.07779 m
.50605 1.07114 L
s
0 1 .456 r
.55654 .91097 m
.55129 .90766 L
s
.55129 .90766 m
.55744 .90288 L
s
.266 1 0 r
.61279 .73252 m
.61565 .73456 L
s
.60943 .73562 m
.61279 .73252 L
s
.61279 .73252 m
.61094 .73224 L
s
.218 1 0 r
.93053 .83836 m
.93368 .84013 L
s
.93053 .83836 m
.92836 .84267 L
s
0 1 .825 r
.6567 .38954 m
.65219 .38725 L
s
.65219 .38725 m
.65365 .37992 L
s
.65219 .38725 m
.64921 .3847 L
s
0 1 .033 r
.5979 .55993 m
.59515 .56467 L
s
.59141 .5595 m
.59515 .56467 L
s
0 0 1 r
.50334 1.0842 m
.49462 1.07779 L
s
.405 0 1 r
.88318 .30548 m
.88287 .31702 L
s
.87004 .31194 m
.88287 .31702 L
s
0 1 .667 r
.63863 1.10572 m
.65701 1.07847 L
s
0 1 .471 r
.76901 .55842 m
.74238 .55822 L
s
.266 1 0 r
.61229 .73766 m
.60943 .73562 L
s
.60943 .73562 m
.61094 .73224 L
s
.245 1 0 r
.34319 .28851 m
.3408 .29261 L
s
.33767 .28812 m
.3408 .29261 L
s
0 1 .033 r
.59141 .5595 m
.5979 .55993 L
s
0 1 .575 r
.2992 .63398 m
.2943 .63624 L
s
.29496 .62779 m
.2992 .63398 L
s
0 .333 1 r
.89814 .48371 m
.89796 .4931 L
s
.88718 .48903 m
.89796 .4931 L
s
1 .667 0 r
.95397 1.01979 m
.95246 1.01899 L
s
.95246 1.01899 m
.95278 1.0175 L
s
.95246 1.01899 m
.95242 1.01931 L
s
0 1 .456 r
.55744 .90288 m
.55654 .91097 L
s
0 1 .794 r
.91498 .66193 m
.91485 .66891 L
s
.90661 .66592 m
.91485 .66891 L
s
.245 1 0 r
.33767 .28812 m
.34319 .28851 L
s
0 1 .956 r
.37977 .83168 m
.38892 .79806 L
s
1 0 .857 r
.26311 .9767 m
.25698 .98044 L
s
.26033 .96364 m
.26311 .9767 L
s
0 .54 1 r
.3103 .80109 m
.31761 .80563 L
s
.305 .80349 m
.3103 .80109 L
s
.3103 .80109 m
.31397 .79675 L
s
0 1 .282 r
.51018 .2842 m
.48673 .28131 L
s
.218 1 0 r
.93368 .84013 m
.93354 .84445 L
s
.92836 .84267 m
.93354 .84445 L
s
1 .667 0 r
.95278 1.0175 m
.95429 1.0183 L
s
.95278 1.0175 m
.95242 1.01931 L
s
.95429 1.0183 m
.95397 1.01979 L
s
.95242 1.01931 m
.95397 1.01979 L
s
.078 1 0 r
.63158 .90708 m
.63561 .90956 L
s
.62837 .90909 m
.63158 .90708 L
s
.63158 .90708 m
.63281 .90521 L
s
0 1 .575 r
.2943 .63624 m
.28935 .6332 L
s
.28935 .6332 m
.29496 .62779 L
s
.181 1 0 r
.35453 .45823 m
.35742 .46026 L
s
.35093 .46139 m
.35453 .45823 L
s
.35453 .45823 m
.35243 .45765 L
s
0 1 .825 r
.65365 .37992 m
.65817 .3822 L
s
.65365 .37992 m
.64921 .3847 L
s
.266 1 0 r
.61565 .73456 m
.61229 .73766 L
s
.61094 .73224 m
.61565 .73456 L
s
1 .667 0 r
.95242 1.01931 m
.95429 1.0183 L
s
0 .023 1 r
.2372 .80835 m
.22879 .8029 L
s
.22879 .8029 m
.2394 .79545 L
s
.218 1 0 r
.92836 .84267 m
.93368 .84013 L
s
0 1 .794 r
.90661 .66592 m
.91498 .66193 L
s
0 .333 1 r
.88718 .48903 m
.89814 .48371 L
s
.181 1 0 r
.35382 .46343 m
.35093 .46139 L
s
.35093 .46139 m
.35243 .45765 L
s
.563 1 0 r
.70885 .92208 m
.70854 .90754 L
s
0 .468 1 r
.83937 .37419 m
.80074 .38014 L
s
0 1 .211 r
.67177 .5636 m
.66838 .56137 L
s
.66838 .56137 m
.67047 .55587 L
s
.66838 .56137 m
.66667 .55886 L
s
0 .023 1 r
.2394 .79545 m
.2372 .80835 L
s
.405 0 1 r
.87004 .31194 m
.88318 .30548 L
s
.266 1 0 r
.61094 .73224 m
.61229 .73766 L
s
.042 1 0 r
.44974 .64769 m
.44449 .62745 L
s
.078 1 0 r
.63561 .90956 m
.6324 .91157 L
s
.63281 .90521 m
.63561 .90956 L
s
0 .54 1 r
.31761 .80563 m
.31233 .80805 L
s
.31397 .79675 m
.31761 .80563 L
s
0 1 .667 r
.65136 1.08067 m
.65725 1.08495 L
s
.64939 1.08292 m
.65136 1.08067 L
s
.65136 1.08067 m
.65701 1.07847 L
s
0 1 .575 r
.29496 .62779 m
.2943 .63624 L
s
0 1 .211 r
.67047 .55587 m
.67386 .55809 L
s
.67047 .55587 m
.66667 .55886 L
s
0 .667 1 r
.58137 1.07479 m
.57917 1.0857 L
s
.57184 1.08035 m
.58137 1.07479 L
s
.404 1 0 r
.19046 .37312 m
.18813 .35725 L
s
.181 1 0 r
.35742 .46026 m
.35382 .46343 L
s
.35243 .45765 m
.35742 .46026 L
s
0 1 .234 r
.36991 .63011 m
.37398 .63257 L
s
.3654 .63254 m
.36991 .63011 L
s
.36991 .63011 m
.36951 .62762 L
s
0 1 .825 r
.65817 .3822 m
.6567 .38954 L
s
.64921 .3847 m
.6567 .38954 L
s
.078 1 0 r
.6324 .91157 m
.62837 .90909 L
s
.62837 .90909 m
.63281 .90521 L
s
.529 0 1 r
.32789 .9712 m
.33781 .97789 L
s
.32263 .97445 m
.32789 .9712 L
s
.32789 .9712 m
.33534 .96633 L
s
0 .667 1 r
.57917 1.0857 m
.57184 1.08035 L
s
0 1 .667 r
.65725 1.08495 m
.6553 1.08721 L
s
.65701 1.07847 m
.65725 1.08495 L
s
.008 1 0 r
.41636 .28921 m
.41309 .28728 L
s
.41309 .28728 m
.41511 .2823 L
s
.41309 .28728 m
.41195 .28473 L
s
.298 1 0 r
.77922 .73805 m
.76235 .73403 L
s
.181 1 0 r
.35243 .45765 m
.35382 .46343 L
s
0 .083 1 r
.38916 1.01193 m
.41068 .96903 L
s
.064 1 0 r
.51985 .46331 m
.50214 .45417 L
s
.008 1 0 r
.41511 .2823 m
.41838 .28422 L
s
.41511 .2823 m
.41195 .28473 L
s
.366 1 0 r
.68886 .7377 m
.68633 .73578 L
s
.68633 .73578 m
.68899 .73223 L
s
.68633 .73578 m
.68644 .73313 L
s
.68899 .73223 m
.69152 .73414 L
s
.68899 .73223 m
.68644 .73313 L
s
.078 1 0 r
.63281 .90521 m
.6324 .91157 L
s
0 .833 1 r
.73364 .38716 m
.72859 .38483 L
s
.72859 .38483 m
.72956 .37654 L
s
.72859 .38483 m
.72473 .38243 L
s
0 1 .825 r
.64921 .3847 m
.65817 .3822 L
s
0 1 .211 r
.67386 .55809 m
.67177 .5636 L
s
.66667 .55886 m
.67177 .5636 L
s
.529 0 1 r
.33781 .97789 m
.33258 .98117 L
s
.33534 .96633 m
.33781 .97789 L
s
0 1 0 r
.71894 1.10265 m
.73299 1.08215 L
s
0 1 .79 r
.84973 .55363 m
.81854 .55758 L
s
0 1 .234 r
.37398 .63257 m
.36947 .63501 L
s
.36951 .62762 m
.37398 .63257 L
s
.36947 .63501 m
.3654 .63254 L
s
.3654 .63254 m
.36951 .62762 L
s
0 .54 1 r
.31233 .80805 m
.305 .80349 L
s
.305 .80349 m
.31397 .79675 L
s
0 1 .956 r
.38635 .80187 m
.39257 .80555 L
s
.38159 .80408 m
.38635 .80187 L
s
.38635 .80187 m
.38892 .79806 L
s
0 1 .211 r
.66667 .55886 m
.67386 .55809 L
s
.008 1 0 r
.41838 .28422 m
.41636 .28921 L
s
.41195 .28473 m
.41636 .28921 L
s
0 1 .471 r
.45929 .82775 m
.46425 .79938 L
s
0 1 .609 r
.59012 .27854 m
.56201 .27788 L
s
.563 1 0 r
.70854 .90862 m
.71137 .9104 L
s
.70584 .91052 m
.70854 .90862 L
s
.70854 .90862 m
.70854 .90754 L
s
1 0 .857 r
.26033 .96364 m
.25698 .98044 L
s
.24581 .9727 m
.26033 .96364 L
s
0 .54 1 r
.31397 .79675 m
.31233 .80805 L
s
0 1 .334 r
.19947 .55267 m
.20283 .52582 L
s
.176 1 0 r
.42991 .45555 m
.43266 .45749 L
s
.42676 .45935 m
.42991 .45555 L
s
.42991 .45555 m
.42706 .45592 L
s
.008 1 0 r
.41195 .28473 m
.41838 .28422 L
s
.366 1 0 r
.69152 .73414 m
.68886 .7377 L
s
.68644 .73313 m
.68886 .7377 L
s
.68644 .73313 m
.69152 .73414 L
s
0 1 .667 r
.65701 1.07847 m
.6553 1.08721 L
s
.64939 1.08292 m
.65701 1.07847 L
s
0 .833 1 r
.72956 .37654 m
.73462 .37885 L
s
.72956 .37654 m
.72473 .38243 L
s
.176 1 0 r
.4295 .4613 m
.42676 .45935 L
s
.42676 .45935 m
.42706 .45592 L
s
0 1 .471 r
.74893 .56256 m
.74515 .5603 L
s
.74515 .5603 m
.74654 .55397 L
s
.74515 .5603 m
.74238 .55822 L
s
1 0 .857 r
.25698 .98044 m
.24581 .9727 L
s
0 1 .667 r
.6553 1.08721 m
.64939 1.08292 L
s
.929 1 0 r
.78946 .91842 m
.78465 .90989 L
s
0 .088 1 r
.92039 .36882 m
.87725 .37783 L
s
.563 1 0 r
.70867 .9123 m
.70584 .91052 L
s
.70584 .91052 m
.70854 .90754 L
s
0 1 0 r
.72861 1.0838 m
.73306 1.08702 L
s
.72728 1.0855 m
.72861 1.0838 L
s
.72861 1.0838 m
.73299 1.08215 L
s
.563 1 0 r
.71137 .9104 m
.70867 .9123 L
s
.70854 .90754 m
.71137 .9104 L
s
0 1 .234 r
.36951 .62762 m
.36947 .63501 L
s
0 1 .956 r
.39257 .80555 m
.38782 .80777 L
s
.38892 .79806 m
.39257 .80555 L
s
.22 1 0 r
.52956 .64317 m
.51988 .62728 L
s
0 1 .471 r
.74654 .55397 m
.75032 .55622 L
s
.74654 .55397 m
.74238 .55822 L
s
0 1 0 r
.73306 1.08702 m
.73174 1.08873 L
s
.73299 1.08215 m
.73306 1.08702 L
s
0 .083 1 r
.40422 .97341 m
.41291 .97909 L
s
.39979 .9762 m
.40422 .97341 L
s
.40422 .97341 m
.41068 .96903 L
s
.473 1 0 r
.26949 .36774 m
.26251 .35439 L
s
.042 1 0 r
.44594 .62914 m
.44922 .63118 L
s
.44187 .63186 m
.44594 .62914 L
s
.44594 .62914 m
.44449 .62745 L
s
.176 1 0 r
.43266 .45749 m
.4295 .4613 L
s
.42706 .45592 m
.43266 .45749 L
s
.563 1 0 r
.70854 .90754 m
.70867 .9123 L
s
0 1 .282 r
.49246 .28582 m
.48881 .2839 L
s
.48881 .2839 m
.49044 .27797 L
s
.48881 .2839 m
.48673 .28131 L
s
.176 1 0 r
.42706 .45592 m
.4295 .4613 L
s
.298 1 0 r
.7661 .73786 m
.76354 .73595 L
s
.76354 .73595 m
.76537 .73181 L
s
.76354 .73595 m
.76235 .73403 L
s
0 .833 1 r
.73462 .37885 m
.73364 .38716 L
s
.72473 .38243 m
.73364 .38716 L
s
.078 1 0 r
.86014 .73381 m
.83867 .73493 L
s
.298 1 0 r
.76537 .73181 m
.76794 .73371 L
s
.76537 .73181 m
.76235 .73403 L
s
0 .694 1 r
.46888 1.00856 m
.48637 .97174 L
s
0 1 .138 r
.59998 .4582 m
.57769 .45241 L
s
.404 1 0 r
.18888 .35835 m
.19166 .36042 L
s
.18552 .36046 m
.18888 .35835 L
s
.18888 .35835 m
.18813 .35725 L
s
0 1 .956 r
.38782 .80777 m
.38159 .80408 L
s
.38159 .80408 m
.38892 .79806 L
s
0 .083 1 r
.41291 .97909 m
.40851 .98191 L
s
.41068 .96903 m
.41291 .97909 L
s
0 .468 1 r
.81109 .38477 m
.80545 .3824 L
s
.80545 .3824 m
.80595 .37311 L
s
.80545 .3824 m
.80074 .38014 L
s
0 1 .282 r
.49044 .27797 m
.49409 .27988 L
s
.49044 .27797 m
.48673 .28131 L
s
.042 1 0 r
.44514 .63391 m
.44187 .63186 L
s
.44187 .63186 m
.44449 .62745 L
s
0 1 .471 r
.75032 .55622 m
.74893 .56256 L
s
.74238 .55822 m
.74893 .56256 L
s
0 .731 1 r
.20852 .73296 m
.21988 .695 L
s
.529 0 1 r
.33534 .96633 m
.33258 .98117 L
s
.32263 .97445 m
.33534 .96633 L
s
0 1 0 r
.73299 1.08215 m
.73174 1.08873 L
s
.72728 1.0855 m
.73299 1.08215 L
s
.529 0 1 r
.33258 .98117 m
.32263 .97445 L
s
0 .833 1 r
.72473 .38243 m
.73462 .37885 L
s
0 1 .471 r
.46285 .8026 m
.46795 .80547 L
s
.45856 .80468 m
.46285 .8026 L
s
.46285 .8026 m
.46425 .79938 L
s
0 1 0 r
.73174 1.08873 m
.72728 1.0855 L
s
0 1 .956 r
.38892 .79806 m
.38782 .80777 L
s
.667 1 0 r
.79976 1.09956 m
.8093 1.08586 L
s
.042 1 0 r
.44922 .63118 m
.44514 .63391 L
s
.44449 .62745 m
.44922 .63118 L
s
0 .849 1 r
.93096 .5488 m
.89517 .55693 L
s
.404 1 0 r
.18831 .36253 m
.18552 .36046 L
s
.18552 .36046 m
.18813 .35725 L
s
.19166 .36042 m
.18831 .36253 L
s
.18813 .35725 m
.19166 .36042 L
s
.929 1 0 r
.78573 .90995 m
.78757 .91129 L
s
.78367 .91192 m
.78573 .90995 L
s
.78573 .90995 m
.78465 .90989 L
s
.298 1 0 r
.76794 .73371 m
.7661 .73786 L
s
.76235 .73403 m
.7661 .73786 L
s
0 1 .471 r
.74238 .55822 m
.75032 .55622 L
s
0 1 .021 r
.53931 .82379 m
.53997 .8007 L
s
0 1 .959 r
.67055 .27285 m
.6378 .27442 L
s
.929 1 0 r
.7855 .91325 m
.78367 .91192 L
s
.78367 .91192 m
.78465 .90989 L
s
0 1 .79 r
.8266 .56155 m
.82235 .55923 L
s
.82235 .55923 m
.82303 .55202 L
s
.82235 .55923 m
.81854 .55758 L
s
0 1 .282 r
.49409 .27988 m
.49246 .28582 L
s
.48673 .28131 m
.49246 .28582 L
s
.064 1 0 r
.50579 .45926 m
.50297 .45732 L
s
.50297 .45732 m
.50562 .45276 L
s
.50297 .45732 m
.50214 .45417 L
s
.298 1 0 r
.76235 .73403 m
.76794 .73371 L
s
0 1 .044 r
.2787 .54784 m
.27764 .52457 L
s
.064 1 0 r
.50562 .45276 m
.50844 .4547 L
s
.50562 .45276 m
.50214 .45417 L
s
0 .468 1 r
.80595 .37311 m
.81159 .37547 L
s
.80595 .37311 m
.80074 .38014 L
s
.667 1 0 r
.80628 1.08696 m
.80928 1.08911 L
s
.80549 1.08809 m
.80628 1.08696 L
s
.80628 1.08696 m
.8093 1.08586 L
s
.404 1 0 r
.18813 .35725 m
.18831 .36253 L
s
.042 1 0 r
.44449 .62745 m
.44514 .63391 L
s
0 1 .334 r
.2022 .52891 m
.20667 .53166 L
s
.19764 .53076 m
.2022 .52891 L
s
.2022 .52891 m
.20283 .52582 L
s
.929 1 0 r
.78757 .91129 m
.7855 .91325 L
s
.78465 .90989 m
.78757 .91129 L
s
.667 1 0 r
.80928 1.08911 m
.80849 1.09025 L
s
.8093 1.08586 m
.80928 1.08911 L
s
1 .969 0 r
.87059 .91475 m
.86114 .91225 L
s
0 1 .282 r
.48673 .28131 m
.49409 .27988 L
s
.929 1 0 r
.78465 .90989 m
.7855 .91325 L
s
0 1 .471 r
.46795 .80547 m
.46366 .80756 L
s
.46425 .79938 m
.46795 .80547 L
s
0 .694 1 r
.48098 .97562 m
.48842 .98029 L
s
.47729 .97797 m
.48098 .97562 L
s
.48098 .97562 m
.48637 .97174 L
s
0 1 .79 r
.82303 .55202 m
.82728 .55433 L
s
.82303 .55202 m
.81854 .55758 L
s
.272 1 0 r
.60989 .63862 m
.59571 .62711 L
s
.078 1 0 r
.84395 .73812 m
.84111 .73617 L
s
.84111 .73617 m
.84201 .7313 L
s
.84111 .73617 m
.83867 .73493 L
s
.349 0 1 r
.21761 .91401 m
.23928 .86487 L
s
.427 1 0 r
.34902 .36232 m
.33737 .35151 L
s
0 1 .471 r
.46366 .80756 m
.45856 .80468 L
s
.45856 .80468 m
.46425 .79938 L
s
.22 1 0 r
.52226 .62799 m
.52494 .62981 L
s
.51872 .63114 m
.52226 .62799 L
s
.52226 .62799 m
.51988 .62728 L
s
.064 1 0 r
.50844 .4547 m
.50579 .45926 L
s
.50214 .45417 m
.50579 .45926 L
s
0 .083 1 r
.41068 .96903 m
.40851 .98191 L
s
.39979 .9762 m
.41068 .96903 L
s
0 1 .609 r
.56908 .28244 m
.565 .2805 L
s
.565 .2805 m
.56625 .27359 L
s
.565 .2805 m
.56201 .27788 L
s
.667 1 0 r
.8093 1.08586 m
.80849 1.09025 L
s
.80549 1.08809 m
.8093 1.08586 L
s
0 1 .334 r
.20667 .53166 m
.20212 .53352 L
s
.20283 .52582 m
.20667 .53166 L
s
0 .083 1 r
.40851 .98191 m
.39979 .9762 L
s
.667 1 0 r
.80849 1.09025 m
.80549 1.08809 L
s
.078 1 0 r
.84201 .7313 m
.84486 .73324 L
s
.84201 .7313 m
.83867 .73493 L
s
.064 1 0 r
.50214 .45417 m
.50844 .4547 L
s
0 1 .248 r
.94157 .72954 m
.91542 .73584 L
s
0 .694 1 r
.48842 .98029 m
.48475 .98265 L
s
.48637 .97174 m
.48842 .98029 L
s
.22 1 0 r
.52139 .63296 m
.51872 .63114 L
s
.51872 .63114 m
.51988 .62728 L
s
0 .468 1 r
.81159 .37547 m
.81109 .38477 L
s
.80074 .38014 m
.81109 .38477 L
s
0 1 .699 r
.5491 1.00516 m
.56241 .97446 L
s
0 .088 1 r
.88907 .38238 m
.88279 .37996 L
s
.88279 .37996 m
.88282 .36966 L
s
.88279 .37996 m
.87725 .37783 L
s
0 1 .408 r
.68062 .45307 m
.65371 .45064 L
s
0 1 .471 r
.46425 .79938 m
.46366 .80756 L
s
0 .731 1 r
.21686 .69959 m
.2237 .70369 L
s
.21148 .70157 m
.21686 .69959 L
s
.21686 .69959 m
.21988 .695 L
s
0 1 .334 r
.20212 .53352 m
.19764 .53076 L
s
.19764 .53076 m
.20283 .52582 L
s
.473 1 0 r
.2642 .35485 m
.26669 .35665 L
s
.26113 .3575 m
.2642 .35485 L
s
.2642 .35485 m
.26251 .35439 L
s
0 1 .79 r
.82728 .55433 m
.8266 .56155 L
s
.81854 .55758 m
.8266 .56155 L
s
1 .969 0 r
.86319 .91451 m
.86173 .9133 L
s
.86173 .9133 m
.86287 .91099 L
s
.86173 .9133 m
.86114 .91225 L
s
0 1 .609 r
.56625 .27359 m
.57034 .27551 L
s
.56625 .27359 m
.56201 .27788 L
s
0 1 .825 r
.28794 .72869 m
.29512 .69528 L
s
0 1 .021 r
.53978 .80324 m
.54374 .80538 L
s
.53593 .80528 m
.53978 .80324 L
s
.53978 .80324 m
.53997 .8007 L
s
1 .969 0 r
.86287 .91099 m
.86433 .91219 L
s
.86287 .91099 m
.86114 .91225 L
s
.473 1 0 r
.26362 .3593 m
.26113 .3575 L
s
.26113 .3575 m
.26251 .35439 L
s
.078 1 0 r
.84486 .73324 m
.84395 .73812 L
s
.83867 .73493 m
.84395 .73812 L
s
.22 1 0 r
.52494 .62981 m
.52139 .63296 L
s
.51988 .62728 m
.52494 .62981 L
s
0 .849 1 r
.90479 .56055 m
.9 .55817 L
s
.9 .55817 m
.89995 .55005 L
s
.9 .55817 m
.89517 .55693 L
s
1 .667 0 r
.88108 1.09645 m
.88594 1.08958 L
s
0 .468 1 r
.80074 .38014 m
.81159 .37547 L
s
0 1 .79 r
.81854 .55758 m
.82728 .55433 L
s
0 1 .138 r
.58265 .45726 m
.5796 .45528 L
s
.5796 .45528 m
.5817 .4499 L
s
.5796 .45528 m
.57769 .45241 L
s
0 1 .334 r
.20283 .52582 m
.20212 .53352 L
s
.078 1 0 r
.83867 .73493 m
.84486 .73324 L
s
.473 1 0 r
.26669 .35665 m
.26362 .3593 L
s
.26251 .35439 m
.26669 .35665 L
s
.366 1 0 r
.61984 .8198 m
.61607 .80203 L
s
0 .674 1 r
.7515 .26712 m
.71411 .27094 L
s
1 .969 0 r
.86433 .91219 m
.86319 .91451 L
s
.86114 .91225 m
.86319 .91451 L
s
.22 1 0 r
.51988 .62728 m
.52139 .63296 L
s
1 .667 0 r
.88439 1.09013 m
.8859 1.09121 L
s
.88404 1.0907 m
.88439 1.09013 L
s
.88439 1.09013 m
.88594 1.08958 L
s
.8859 1.09121 m
.88555 1.09178 L
s
.88594 1.08958 m
.8859 1.09121 L
s
1 .969 0 r
.86114 .91225 m
.86433 .91219 L
s
0 .731 1 r
.2237 .70369 m
.21833 .70569 L
s
.21988 .695 m
.2237 .70369 L
s
1 0 .436 r
.22673 1.09582 m
.26106 1.03546 L
s
0 1 .138 r
.5817 .4499 m
.58476 .45187 L
s
.5817 .4499 m
.57769 .45241 L
s
.176 1 0 r
.35843 .54297 m
.35289 .52331 L
s
0 1 .609 r
.57034 .27551 m
.56908 .28244 L
s
.56201 .27788 m
.56908 .28244 L
s
0 .088 1 r
.88282 .36966 m
.88911 .37206 L
s
.88282 .36966 m
.87725 .37783 L
s
.473 1 0 r
.26251 .35439 m
.26362 .3593 L
s
0 1 .699 r
.55817 .97785 m
.56434 .98149 L
s
.55513 .97975 m
.55817 .97785 L
s
.55817 .97785 m
.56241 .97446 L
s
0 1 .044 r
.27814 .52711 m
.28182 .52928 L
s
.27389 .5292 m
.27814 .52711 L
s
.27814 .52711 m
.27764 .52457 L
s
0 1 .248 r
.92233 .73843 m
.91908 .7364 L
s
.91908 .7364 m
.91901 .73073 L
s
.91908 .7364 m
.91542 .73584 L
s
0 1 .021 r
.54374 .80538 m
.53989 .80743 L
s
.53997 .8007 m
.54374 .80538 L
s
1 .667 0 r
.88594 1.08958 m
.88555 1.09178 L
s
.88404 1.0907 m
.88594 1.08958 L
s
0 1 .021 r
.53989 .80743 m
.53593 .80528 L
s
.53593 .80528 m
.53997 .8007 L
s
0 .694 1 r
.48637 .97174 m
.48475 .98265 L
s
.47729 .97797 m
.48637 .97174 L
s
1 .667 0 r
.88555 1.09178 m
.88404 1.0907 L
s
.8 1 0 r
.95222 .91105 m
.938 .91462 L
s
0 .694 1 r
.48475 .98265 m
.47729 .97797 L
s
0 .849 1 r
.89995 .55005 m
.90474 .55241 L
s
.89995 .55005 m
.89517 .55693 L
s
.349 0 1 r
.23306 .87037 m
.24259 .87643 L
s
.22724 .87306 m
.23306 .87037 L
s
.23306 .87037 m
.23928 .86487 L
s
.186 1 0 r
.69073 .63405 m
.67197 .62694 L
s
0 1 .609 r
.56201 .27788 m
.57034 .27551 L
s
0 1 .248 r
.91901 .73073 m
.92225 .73274 L
s
.91901 .73073 m
.91542 .73584 L
s
0 .206 1 r
.29723 .9103 m
.31496 .86659 L
s
.272 1 0 r
.59883 .62668 m
.6012 .62845 L
s
.59591 .6304 m
.59883 .62668 L
s
.59883 .62668 m
.59571 .62711 L
s
0 1 .699 r
.56434 .98149 m
.56131 .98341 L
s
.56241 .97446 m
.56434 .98149 L
s
.275 1 0 r
.42906 .35687 m
.4127 .34862 L
s
.272 1 0 r
.59828 .63217 m
.59591 .6304 L
s
.59591 .6304 m
.59571 .62711 L
s
0 1 .959 r
.64623 .27905 m
.64166 .27708 L
s
.64166 .27708 m
.64256 .26916 L
s
.64166 .27708 m
.6378 .27442 L
s
0 1 .138 r
.58476 .45187 m
.58265 .45726 L
s
.57769 .45241 m
.58265 .45726 L
s
0 1 .021 r
.53997 .8007 m
.53989 .80743 L
s
.8 1 0 r
.9417 .91602 m
.94005 .91476 L
s
.94005 .91476 m
.94 .91179 L
s
.94005 .91476 m
.938 .91462 L
s
0 1 .044 r
.28182 .52928 m
.27757 .53138 L
s
.27764 .52457 m
.28182 .52928 L
s
.27757 .53138 m
.27389 .5292 L
s
.27389 .5292 m
.27764 .52457 L
s
0 .731 1 r
.21833 .70569 m
.21148 .70157 L
s
.21148 .70157 m
.21988 .695 L
s
0 1 .138 r
.57769 .45241 m
.58476 .45187 L
s
.349 0 1 r
.24259 .87643 m
.23679 .87914 L
s
.23928 .86487 m
.24259 .87643 L
s
.8 1 0 r
.94 .91179 m
.94165 .91305 L
s
.94 .91179 m
.938 .91462 L
s
0 1 .825 r
.29323 .69942 m
.29906 .70268 L
s
.28829 .70131 m
.29323 .69942 L
s
.29323 .69942 m
.29512 .69528 L
s
0 1 .099 r
.62983 1.00174 m
.63879 .9772 L
s
0 1 .725 r
.76177 .4479 m
.73021 .44886 L
s
0 .088 1 r
.88911 .37206 m
.88907 .38238 L
s
.87725 .37783 m
.88907 .38238 L
s
0 .731 1 r
.21988 .695 m
.21833 .70569 L
s
0 .849 1 r
.90474 .55241 m
.90479 .56055 L
s
.89517 .55693 m
.90479 .56055 L
s
.366 1 0 r
.6171 .80372 m
.61994 .80532 L
s
.61372 .80587 m
.6171 .80372 L
s
.6171 .80372 m
.61607 .80203 L
s
.427 1 0 r
.33987 .35118 m
.34227 .35285 L
s
.33715 .35452 m
.33987 .35118 L
s
.33987 .35118 m
.33737 .35151 L
s
0 1 .408 r
.36787 .72439 m
.37076 .69557 L
s
.427 1 0 r
.33955 .35619 m
.33715 .35452 L
s
.33715 .35452 m
.33737 .35151 L
s
0 1 .959 r
.64256 .26916 m
.64713 .27111 L
s
.64256 .26916 m
.6378 .27442 L
s
0 1 .248 r
.92225 .73274 m
.92233 .73843 L
s
.91542 .73584 m
.92233 .73843 L
s
1 0 .436 r
.25096 1.04129 m
.26329 1.04981 L
s
.24498 1.04537 m
.25096 1.04129 L
s
.25096 1.04129 m
.26106 1.03546 L
s
.8 1 0 r
.94165 .91305 m
.9417 .91602 L
s
.938 .91462 m
.9417 .91602 L
s
0 1 .408 r
.66005 .45529 m
.65665 .45326 L
s
.65665 .45326 m
.65819 .44698 L
s
.65665 .45326 m
.65371 .45064 L
s
0 1 .248 r
.91542 .73584 m
.92225 .73274 L
s
.8 1 0 r
.938 .91462 m
.94165 .91305 L
s
.272 1 0 r
.6012 .62845 m
.59828 .63217 L
s
.59571 .62711 m
.6012 .62845 L
s
.59571 .62711 m
.59828 .63217 L
s
0 .849 1 r
.89517 .55693 m
.90474 .55241 L
s
1 0 0 r
.01 w
.96292 1.09331 Mdot
0 1 .044 r
.5 Mabswid
.27764 .52457 m
.27757 .53138 L
s
0 1 .699 r
.56131 .98341 m
.55513 .97975 L
s
.55513 .97975 m
.56241 .97446 L
s
0 .088 1 r
.87725 .37783 m
.88911 .37206 L
s
0 1 .699 r
.56241 .97446 m
.56131 .98341 L
s
.366 1 0 r
.61656 .80747 m
.61372 .80587 L
s
.61372 .80587 m
.61607 .80203 L
s
.636 1 0 r
.70088 .81579 m
.69257 .80336 L
s
0 .295 1 r
.83296 .26135 m
.79093 .26743 L
s
0 1 .825 r
.29906 .70268 m
.29413 .70458 L
s
.29512 .69528 m
.29906 .70268 L
s
0 1 .099 r
.63581 .98007 m
.64068 .9827 L
s
.63331 .98154 m
.63581 .98007 L
s
.63581 .98007 m
.63879 .9772 L
s
0 1 .408 r
.65819 .44698 m
.6616 .449 L
s
.65819 .44698 m
.65371 .45064 L
s
.427 1 0 r
.34227 .35285 m
.33955 .35619 L
s
.33737 .35151 m
.34227 .35285 L
s
.33737 .35151 m
.33955 .35619 L
s
.926 0 1 r
.30655 1.09269 m
.33719 1.03854 L
s
.298 1 0 r
.43866 .53808 m
.42858 .52205 L
s
.366 1 0 r
.61994 .80532 m
.61656 .80747 L
s
.61607 .80203 m
.61994 .80532 L
s
0 .206 1 r
.30973 .87167 m
.31814 .87675 L
s
.30464 .874 m
.30973 .87167 L
s
.30973 .87167 m
.31496 .86659 L
s
1 0 .436 r
.26329 1.04981 m
.25738 1.05394 L
s
.26106 1.03546 m
.26329 1.04981 L
s
.176 1 0 r
.35448 .52515 m
.35743 .52691 L
s
.35057 .52761 m
.35448 .52515 L
s
.35448 .52515 m
.35289 .52331 L
s
0 1 .959 r
.64713 .27111 m
.64623 .27905 L
s
.6378 .27442 m
.64623 .27905 L
s
.845 1 0 r
.17627 .2602 m
.17248 .25101 L
s
.186 1 0 r
.67581 .63148 m
.67345 .62967 L
s
.67345 .62967 m
.67566 .62526 L
s
.67345 .62967 m
.67197 .62694 L
s
0 1 .099 r
.64068 .9827 m
.63818 .98418 L
s
.63879 .9772 m
.64068 .9827 L
s
.366 1 0 r
.61607 .80203 m
.61656 .80747 L
s
0 1 .021 r
.77208 .62944 m
.74866 .62677 L
s
0 1 .825 r
.29413 .70458 m
.28829 .70131 L
s
.28829 .70131 m
.29512 .69528 L
s
.186 1 0 r
.67566 .62526 m
.67802 .62707 L
s
.67566 .62526 m
.67197 .62694 L
s
.176 1 0 r
.35352 .52938 m
.35057 .52761 L
s
.35057 .52761 m
.35289 .52331 L
s
0 .753 1 r
.37735 .90658 m
.391 .86832 L
s
0 .674 1 r
.72391 .27566 m
.7188 .27364 L
s
.7188 .27364 m
.71936 .26469 L
s
.7188 .27364 m
.71411 .27094 L
s
.042 1 0 r
.50961 .35138 m
.48852 .3457 L
s
0 1 .408 r
.6616 .449 m
.66005 .45529 L
s
.65371 .45064 m
.66005 .45529 L
s
.349 0 1 r
.23928 .86487 m
.23679 .87914 L
s
.22724 .87306 m
.23928 .86487 L
s
0 1 .959 r
.6378 .27442 m
.64713 .27111 L
s
.349 0 1 r
.23679 .87914 m
.22724 .87306 L
s
0 .206 1 r
.31814 .87675 m
.31308 .87909 L
s
.31496 .86659 m
.31814 .87675 L
s
0 1 .825 r
.29512 .69528 m
.29413 .70458 L
s
.176 1 0 r
.35743 .52691 m
.35352 .52938 L
s
.35289 .52331 m
.35743 .52691 L
s
0 1 .408 r
.37006 .69917 m
.37485 .70166 L
s
.36551 .70105 m
.37006 .69917 L
s
.37006 .69917 m
.37076 .69557 L
s
0 1 .099 r
.63818 .98418 m
.63331 .98154 L
s
.63331 .98154 m
.63879 .9772 L
s
.63879 .9772 m
.63818 .98418 L
s
0 1 .408 r
.65371 .45064 m
.6616 .449 L
s
.487 1 0 r
.71107 .9983 m
.71553 .97995 L
s
0 .925 1 r
.84343 .44269 m
.80718 .44707 L
s
.636 1 0 r
.69465 .80396 m
.69657 .80529 L
s
.6919 .80641 m
.69465 .80396 L
s
.69465 .80396 m
.69257 .80336 L
s
.926 0 1 r
.32791 1.04393 m
.33899 1.05138 L
s
.32304 1.04745 m
.32791 1.04393 L
s
.32791 1.04393 m
.33719 1.03854 L
s
.275 1 0 r
.41609 .35317 m
.41359 .35152 L
s
.41359 .35152 m
.41589 .34738 L
s
.41359 .35152 m
.4127 .34862 L
s
.636 1 0 r
.69382 .80775 m
.6919 .80641 L
s
.6919 .80641 m
.69257 .80336 L
s
0 1 .725 r
.73798 .45333 m
.73416 .45123 L
s
.73416 .45123 m
.73512 .44402 L
s
.73416 .45123 m
.73021 .44886 L
s
.186 1 0 r
.67802 .62707 m
.67581 .63148 L
s
.67197 .62694 m
.67581 .63148 L
s
.275 1 0 r
.41589 .34738 m
.41839 .34903 L
s
.41589 .34738 m
.4127 .34862 L
s
0 1 .033 r
.4483 .72007 m
.44681 .69585 L
s
.176 1 0 r
.35289 .52331 m
.35352 .52938 L
s
0 .674 1 r
.71936 .26469 m
.72447 .26668 L
s
.71936 .26469 m
.71411 .27094 L
s
.186 1 0 r
.67197 .62694 m
.67802 .62707 L
s
.245 1 0 r
.18537 .44165 m
.1856 .42134 L
s
.487 1 0 r
.71394 .98226 m
.71743 .98391 L
s
.71184 .98334 m
.71394 .98226 L
s
.71394 .98226 m
.71553 .97995 L
s
.926 0 1 r
.33899 1.05138 m
.33417 1.05494 L
s
.33719 1.03854 m
.33899 1.05138 L
s
0 1 .408 r
.37485 .70166 m
.3703 .70355 L
s
.37076 .69557 m
.37485 .70166 L
s
.712 1 0 r
.78243 .81175 m
.76946 .8047 L
s
.092 0 1 r
.91493 .25555 m
.86827 .2639 L
s
0 1 .725 r
.73512 .44402 m
.73895 .4461 L
s
.73512 .44402 m
.73021 .44886 L
s
0 .753 1 r
.38685 .87297 m
.39412 .87706 L
s
.3824 .87495 m
.38685 .87297 L
s
.38685 .87297 m
.391 .86832 L
s
.636 1 0 r
.69657 .80529 m
.69382 .80775 L
s
.69257 .80336 m
.69657 .80529 L
s
.275 1 0 r
.41839 .34903 m
.41609 .35317 L
s
.4127 .34862 m
.41609 .35317 L
s
.289 0 1 r
.38687 1.08953 m
.41363 1.04164 L
s
.301 1 0 r
.51941 .53316 m
.50471 .52078 L
s
.636 1 0 r
.69257 .80336 m
.69382 .80775 L
s
0 1 .021 r
.75393 .63086 m
.75136 .62895 L
s
.75136 .62895 m
.75279 .62376 L
s
.75136 .62895 m
.74866 .62677 L
s
0 1 .408 r
.3703 .70355 m
.36551 .70105 L
s
.36551 .70105 m
.37076 .69557 L
s
.275 1 0 r
.4127 .34862 m
.41839 .34903 L
s
.298 1 0 r
.43113 .52299 m
.43354 .52456 L
s
.42766 .52598 m
.43113 .52299 L
s
.43113 .52299 m
.42858 .52205 L
s
.487 1 0 r
.71743 .98391 m
.71534 .98499 L
s
.71553 .97995 m
.71743 .98391 L
s
.776 1 0 r
.25621 .25439 m
.24755 .24696 L
s
0 .206 1 r
.31308 .87909 m
.30464 .874 L
s
.30464 .874 m
.31496 .86659 L
s
.31496 .86659 m
.31308 .87909 L
s
1 0 .436 r
.26106 1.03546 m
.25738 1.05394 L
s
.24498 1.04537 m
.26106 1.03546 L
s
.298 1 0 r
.43007 .52755 m
.42766 .52598 L
s
.42766 .52598 m
.42858 .52205 L
s
0 .674 1 r
.72447 .26668 m
.72391 .27566 L
s
.71411 .27094 m
.72391 .27566 L
s
0 1 .021 r
.75279 .62376 m
.75536 .62566 L
s
.75279 .62376 m
.74866 .62677 L
s
.487 1 0 r
.71534 .98499 m
.71184 .98334 L
s
.71184 .98334 m
.71553 .97995 L
s
0 1 .316 r
.85395 .6248 m
.82578 .6266 L
s
.845 1 0 r
.17339 .25102 m
.17544 .2527 L
s
.17104 .25302 m
.17339 .25102 L
s
.17339 .25102 m
.17248 .25101 L
s
.487 1 0 r
.71553 .97995 m
.71534 .98499 L
s
0 1 .408 r
.37076 .69557 m
.3703 .70355 L
s
0 .753 1 r
.39412 .87706 m
.38969 .87905 L
s
.391 .86832 m
.39412 .87706 L
s
0 .295 1 r
.80212 .27225 m
.79642 .27018 L
s
.79642 .27018 m
.79666 .26017 L
s
.79642 .27018 m
.79093 .26743 L
s
0 1 .709 r
.45799 .90282 m
.46741 .87006 L
s
0 1 .248 r
.59066 .34585 m
.56483 .34277 L
s
.845 1 0 r
.17309 .2547 m
.17104 .25302 L
s
.17104 .25302 m
.17248 .25101 L
s
0 1 .725 r
.73895 .4461 m
.73798 .45333 L
s
.73021 .44886 m
.73798 .45333 L
s
.845 1 0 r
.17544 .2527 m
.17309 .2547 L
s
.17248 .25101 m
.17544 .2527 L
s
1 0 .436 r
.25738 1.05394 m
.24498 1.04537 L
s
.289 0 1 r
.40528 1.04658 m
.41508 1.05296 L
s
.40142 1.04953 m
.40528 1.04658 L
s
.40528 1.04658 m
.41363 1.04164 L
s
0 1 .033 r
.44734 .69879 m
.45106 .70063 L
s
.44315 .70079 m
.44734 .69879 L
s
.44734 .69879 m
.44681 .69585 L
s
0 1 .609 r
.19449 .62388 m
.20107 .59227 L
s
.712 1 0 r
.77184 .80828 m
.77037 .80693 L
s
.77037 .80693 m
.77227 .80396 L
s
.77037 .80693 m
.76946 .8047 L
s
0 .674 1 r
.71411 .27094 m
.72447 .26668 L
s
.298 1 0 r
.43354 .52456 m
.43007 .52755 L
s
.42858 .52205 m
.43354 .52456 L
s
.712 1 0 r
.77227 .80396 m
.77375 .8053 L
s
.77227 .80396 m
.76946 .8047 L
s
.845 1 0 r
.17248 .25101 m
.17309 .2547 L
s
.042 1 0 r
.49319 .3502 m
.49046 .34852 L
s
.49046 .34852 m
.49233 .34349 L
s
.49046 .34852 m
.48852 .3457 L
s
0 1 .725 r
.73021 .44886 m
.73895 .4461 L
s
0 .925 1 r
.81643 .45137 m
.81212 .4492 L
s
.81212 .4492 m
.81251 .44103 L
s
.81212 .4492 m
.80718 .44707 L
s
1 .969 0 r
.79283 .99484 m
.79262 .98271 L
s
0 1 .021 r
.75536 .62566 m
.75393 .63086 L
s
.74866 .62677 m
.75393 .63086 L
s
0 .552 1 r
.92561 .43746 m
.88464 .44527 L
s
.298 1 0 r
.42858 .52205 m
.43007 .52755 L
s
.042 1 0 r
.49233 .34349 m
.49506 .34516 L
s
.49233 .34349 m
.48852 .3457 L
s
0 1 .021 r
.74866 .62677 m
.75536 .62566 L
s
.289 0 1 r
.41508 1.05296 m
.41126 1.05594 L
s
.41363 1.04164 m
.41508 1.05296 L
s
.272 1 0 r
.52925 .71572 m
.52326 .69613 L
s
1 .969 0 r
.79258 .98435 m
.79456 .9851 L
s
.79077 .98518 m
.79258 .98435 L
s
.79258 .98435 m
.79262 .98271 L
s
0 .295 1 r
.79666 .26017 m
.80237 .26221 L
s
.79666 .26017 m
.79093 .26743 L
s
.245 1 0 r
.18577 .42361 m
.189 .4256 L
s
.1821 .42524 m
.18577 .42361 L
s
.18577 .42361 m
.1856 .42134 L
s
.427 1 0 r
.2655 .43641 m
.26109 .41896 L
s
.712 1 0 r
.77375 .8053 m
.77184 .80828 L
s
.76946 .8047 m
.77184 .80828 L
s
0 1 .033 r
.44687 .70263 m
.44315 .70079 L
s
.44315 .70079 m
.44681 .69585 L
s
0 1 .709 r
.46443 .87425 m
.47052 .87736 L
s
.46051 .87591 m
.46443 .87425 L
s
.46443 .87425 m
.46741 .87006 L
s
.712 1 0 r
.76946 .8047 m
.77375 .8053 L
s
.926 0 1 r
.33719 1.03854 m
.33417 1.05494 L
s
.32304 1.04745 m
.33719 1.03854 L
s
0 .753 1 r
.38969 .87905 m
.3824 .87495 L
s
.3824 .87495 m
.391 .86832 L
s
0 1 .033 r
.45106 .70063 m
.44687 .70263 L
s
.44681 .69585 m
.45106 .70063 L
s
0 1 .316 r
.83258 .63028 m
.82968 .62826 L
s
.82968 .62826 m
.83029 .6222 L
s
.82968 .62826 m
.82578 .6266 L
s
0 .753 1 r
.391 .86832 m
.38969 .87905 L
s
0 .925 1 r
.81251 .44103 m
.81682 .44318 L
s
.81251 .44103 m
.80718 .44707 L
s
.563 1 0 r
.86451 .80769 m
.84674 .80605 L
s
1 .969 0 r
.79274 .98593 m
.79077 .98518 L
s
.79077 .98518 m
.79262 .98271 L
s
.79456 .9851 m
.79274 .98593 L
s
.79262 .98271 m
.79456 .9851 L
s
.042 1 0 r
.49506 .34516 m
.49319 .3502 L
s
.48852 .3457 m
.49319 .3502 L
s
0 .346 1 r
.46771 1.08636 m
.4904 1.04475 L
s
1 .969 0 r
.79262 .98271 m
.79274 .98593 L
s
.184 1 0 r
.60067 .52821 m
.58129 .5195 L
s
.245 1 0 r
.189 .4256 m
.18533 .42723 L
s
.1856 .42134 m
.189 .4256 L
s
.301 1 0 r
.50806 .52067 m
.5102 .52221 L
s
.50513 .52432 m
.50806 .52067 L
s
.50806 .52067 m
.50471 .52078 L
s
.50726 .52587 m
.50513 .52432 L
s
.50513 .52432 m
.50471 .52078 L
s
.926 0 1 r
.33417 1.05494 m
.32304 1.04745 L
s
.245 1 0 r
.18533 .42723 m
.1821 .42524 L
s
.1821 .42524 m
.1856 .42134 L
s
0 1 .316 r
.83029 .6222 m
.8332 .62421 L
s
.83029 .6222 m
.82578 .6266 L
s
0 .389 1 r
.20366 .80688 m
.21891 .76386 L
s
.589 1 0 r
.33666 .24854 m
.32311 .24287 L
s
0 1 .033 r
.44681 .69585 m
.44687 .70263 L
s
.042 1 0 r
.48852 .3457 m
.49506 .34516 L
s
0 1 .709 r
.47052 .87736 m
.46661 .87904 L
s
.46741 .87006 m
.47052 .87736 L
s
.563 1 0 r
.8506 .80897 m
.84911 .80747 L
s
.84911 .80747 m
.85001 .8038 L
s
.84911 .80747 m
.84674 .80605 L
s
0 1 .609 r
.19944 .59638 m
.20479 .59933 L
s
.1947 .59791 m
.19944 .59638 L
s
.19944 .59638 m
.20107 .59227 L
s
0 1 .67 r
.93634 .62014 m
.90335 .62643 L
s
0 .346 1 r
.48306 1.04925 m
.49157 1.05455 L
s
.48012 1.05163 m
.48306 1.04925 L
s
.48306 1.04925 m
.4904 1.04475 L
s
0 .295 1 r
.80237 .26221 m
.80212 .27225 L
s
.79093 .26743 m
.80212 .27225 L
s
.092 0 1 r
.88088 .26883 m
.87453 .2667 L
s
.87453 .2667 m
.87446 .25562 L
s
.87453 .2667 m
.86827 .2639 L
s
.776 1 0 r
.24928 .24637 m
.25135 .24784 L
s
.24723 .24905 m
.24928 .24637 L
s
.24928 .24637 m
.24755 .24696 L
s
.24929 .25053 m
.24723 .24905 L
s
.24723 .24905 m
.24755 .24696 L
s
0 1 .189 r
.53914 .89905 m
.54419 .87181 L
s
.563 1 0 r
.85001 .8038 m
.8515 .80529 L
s
.85001 .8038 m
.84674 .80605 L
s
0 1 .575 r
.67224 .3403 m
.64163 .33982 L
s
.245 1 0 r
.1856 .42134 m
.18533 .42723 L
s
.272 1 0 r
.525 .69823 m
.52769 .69962 L
s
.52124 .7005 m
.525 .69823 L
s
.525 .69823 m
.52326 .69613 L
s
0 .925 1 r
.81682 .44318 m
.81643 .45137 L
s
.80718 .44707 m
.81643 .45137 L
s
0 1 .248 r
.27483 .61921 m
.277 .59148 L
s
.57083 .34724 m
.56779 .34552 L
s
.56779 .34552 m
.56921 .33954 L
s
.56779 .34552 m
.56483 .34277 L
s
0 .552 1 r
.89539 .44941 m
.89054 .44716 L
s
.89054 .44716 m
.89036 .438 L
s
.89054 .44716 m
.88464 .44527 L
s
.301 1 0 r
.5102 .52221 m
.50726 .52587 L
s
.50471 .52078 m
.5102 .52221 L
s
.50471 .52078 m
.50726 .52587 L
s
0 .346 1 r
.49157 1.05455 m
.48866 1.05695 L
s
.4904 1.04475 m
.49157 1.05455 L
s
.289 0 1 r
.41363 1.04164 m
.41126 1.05594 L
s
.40142 1.04953 m
.41363 1.04164 L
s
.776 1 0 r
.25135 .24784 m
.24929 .25053 L
s
.24755 .24696 m
.25135 .24784 L
s
.24755 .24696 m
.24929 .25053 L
s
0 1 .316 r
.8332 .62421 m
.83258 .63028 L
s
.82578 .6266 m
.83258 .63028 L
s
0 .295 1 r
.79093 .26743 m
.80237 .26221 L
s
0 .925 1 r
.80718 .44707 m
.81682 .44318 L
s
0 1 .709 r
.46661 .87904 m
.46051 .87591 L
s
.46051 .87591 m
.46741 .87006 L
s
0 1 .316 r
.82578 .6266 m
.8332 .62421 L
s
1 .593 0 r
.87512 .99135 m
.87006 .98548 L
s
0 1 .609 r
.20479 .59933 m
.20005 .60086 L
s
.20107 .59227 m
.20479 .59933 L
s
.272 1 0 r
.52392 .7019 m
.52124 .7005 L
s
.52124 .7005 m
.52326 .69613 L
s
1 .593 0 r
.87151 .98591 m
.87188 .98634 L
s
.87027 .98698 m
.87151 .98591 L
s
.87151 .98591 m
.87006 .98548 L
s
.87064 .98741 m
.87027 .98698 L
s
.87027 .98698 m
.87006 .98548 L
s
0 1 .709 r
.46741 .87006 m
.46661 .87904 L
s
.563 1 0 r
.84674 .80605 m
.8506 .80897 L
s
.84674 .80605 m
.8515 .80529 L
s
.8515 .80529 m
.8506 .80897 L
s
0 1 .248 r
.56921 .33954 m
.57226 .34125 L
s
.56921 .33954 m
.56483 .34277 L
s
.463 1 0 r
.61072 .71134 m
.60012 .69642 L
s
0 1 .67 r
.91173 .62972 m
.90842 .62758 L
s
.90842 .62758 m
.90821 .62062 L
s
.90842 .62758 m
.90335 .62643 L
s
0 1 .189 r
.54251 .87549 m
.54735 .87766 L
s
.539 .87689 m
.54251 .87549 L
s
.54251 .87549 m
.54419 .87181 L
s
.289 0 1 r
.41126 1.05594 m
.40142 1.04953 L
s
1 .593 0 r
.87006 .98548 m
.87064 .98741 L
s
.87006 .98548 m
.87188 .98634 L
s
.092 0 1 r
.87446 .25562 m
.88083 .25771 L
s
.87446 .25562 m
.86827 .2639 L
s
.427 1 0 r
.2624 .42067 m
.26498 .42222 L
s
.25898 .42271 m
.2624 .42067 L
s
.2624 .42067 m
.26109 .41896 L
s
.741 0 1 r
.21287 .99066 m
.23915 .93616 L
s
0 .389 1 r
.21457 .76927 m
.22251 .77385 L
s
.20918 .77116 m
.21457 .76927 L
s
.21457 .76927 m
.21891 .76386 L
s
.504 1 0 r
.34615 .43113 m
.33705 .41657 L
s
1 .593 0 r
.87188 .98634 m
.87064 .98741 L
s
.272 1 0 r
.52769 .69962 m
.52392 .7019 L
s
.52326 .69613 m
.52769 .69962 L
s
0 .552 1 r
.89036 .438 m
.89522 .44023 L
s
.89036 .438 m
.88464 .44527 L
s
0 1 .609 r
.20005 .60086 m
.1947 .59791 L
s
.1947 .59791 m
.20107 .59227 L
s
.246 1 0 r
.94711 .8036 m
.92443 .80741 L
s
.184 1 0 r
.58507 .52427 m
.58296 .52266 L
s
.58296 .52266 m
.58529 .51823 L
s
.58296 .52266 m
.58129 .5195 L
s
.272 1 0 r
.52326 .69613 m
.52392 .7019 L
s
.427 1 0 r
.26155 .42426 m
.25898 .42271 L
s
.25898 .42271 m
.26109 .41896 L
s
0 1 .67 r
.90821 .62062 m
.91153 .62275 L
s
.90821 .62062 m
.90335 .62643 L
s
.184 1 0 r
.58529 .51823 m
.58741 .51984 L
s
.58529 .51823 m
.58129 .5195 L
s
.246 1 0 r
.92993 .80975 m
.92819 .80805 L
s
.92819 .80805 m
.92801 .80355 L
s
.92819 .80805 m
.92443 .80741 L
s
0 .978 1 r
.54907 1.08316 m
.5675 1.04787 L
s
0 1 .033 r
.68246 .52322 m
.65833 .51822 L
s
0 1 .248 r
.57226 .34125 m
.57083 .34724 L
s
.56483 .34277 m
.57083 .34724 L
s
.427 1 0 r
.26498 .42222 m
.26155 .42426 L
s
.26109 .41896 m
.26498 .42222 L
s
0 1 .189 r
.54735 .87766 m
.54384 .87907 L
s
.54419 .87181 m
.54735 .87766 L
s
0 1 .609 r
.20107 .59227 m
.20005 .60086 L
s
0 .978 1 r
.56126 1.05193 m
.56846 1.05615 L
s
.55915 1.05373 m
.56126 1.05193 L
s
.56126 1.05193 m
.5675 1.04787 L
s
0 .876 1 r
.2842 .80278 m
.29529 .76458 L
s
.322 1 0 r
.41762 .24266 m
.39918 .23876 L
s
0 .389 1 r
.22251 .77385 m
.21714 .77575 L
s
.21891 .76386 m
.22251 .77385 L
s
0 .346 1 r
.4904 1.04475 m
.48866 1.05695 L
s
.48012 1.05163 m
.4904 1.04475 L
s
.246 1 0 r
.92801 .80355 m
.92975 .80524 L
s
.92801 .80355 m
.92443 .80741 L
s
0 1 .248 r
.2766 .59516 m
.28099 .59735 L
s
.27214 .59675 m
.2766 .59516 L
s
.2766 .59516 m
.277 .59148 L
s
.56483 .34277 m
.57226 .34125 L
s
.589 1 0 r
.32608 .24646 m
.32387 .24508 L
s
.32387 .24508 m
.32558 .24156 L
s
.32387 .24508 m
.32311 .24287 L
s
0 1 .189 r
.54384 .87907 m
.539 .87689 L
s
.539 .87689 m
.54419 .87181 L
s
.427 1 0 r
.26109 .41896 m
.26155 .42426 L
s
0 .978 1 r
.56846 1.05615 m
.56637 1.05796 L
s
.5675 1.04787 m
.56846 1.05615 L
s
.463 1 0 r
.60292 .69742 m
.60477 .69865 L
s
.59973 .70017 m
.60292 .69742 L
s
.60292 .69742 m
.60012 .69642 L
s
.589 1 0 r
.32558 .24156 m
.3278 .24294 L
s
.32558 .24156 m
.32311 .24287 L
s
1 .727 0 r
.94998 .98954 m
.94987 .98869 L
s
.94987 .98869 m
.94978 .98684 L
s
.94987 .98869 m
.94787 .98827 L
s
.741 0 1 r
.23133 .9423 m
.24206 .94905 L
s
.22565 .94517 m
.23133 .9423 L
s
.23133 .9423 m
.23915 .93616 L
s
.298 1 0 r
.62081 .89525 m
.62133 .87357 L
s
0 1 .927 r
.75435 .3347 m
.71893 .33684 L
s
.092 0 1 r
.88083 .25771 m
.88088 .26883 L
s
.86827 .2639 m
.88088 .26883 L
s
0 .346 1 r
.48866 1.05695 m
.48012 1.05163 L
s
0 1 .189 r
.54419 .87181 m
.54384 .87907 L
s
0 1 .575 r
.649 .34428 m
.64559 .3425 L
s
.64559 .3425 m
.64657 .33555 L
s
.64559 .3425 m
.64163 .33982 L
s
.184 1 0 r
.58741 .51984 m
.58507 .52427 L
s
.58129 .5195 m
.58507 .52427 L
s
.463 1 0 r
.60158 .7014 m
.59973 .70017 L
s
.59973 .70017 m
.60012 .69642 L
s
1 .727 0 r
.94978 .98684 m
.94989 .98769 L
s
.94978 .98684 m
.94787 .98827 L
s
0 .552 1 r
.89522 .44023 m
.89539 .44941 L
s
.88464 .44527 m
.89539 .44941 L
s
.246 1 0 r
.92443 .80741 m
.92993 .80975 L
s
.92443 .80741 m
.92975 .80524 L
s
.064 1 0 r
.35568 .61451 m
.35336 .59069 L
s
1 .727 0 r
.94787 .98827 m
.94998 .98954 L
s
.94787 .98827 m
.94989 .98769 L
s
.95793 .98785 m
.94787 .98827 L
s
0 1 .67 r
.91153 .62275 m
.91173 .62972 L
s
.90335 .62643 m
.91173 .62972 L
s
.90335 .62643 m
.91153 .62275 L
s
.184 1 0 r
.58129 .5195 m
.58741 .51984 L
s
0 .552 1 r
.88464 .44527 m
.89522 .44023 L
s
.246 1 0 r
.92975 .80524 m
.92993 .80975 L
s
.589 1 0 r
.3278 .24294 m
.32608 .24646 L
s
.32311 .24287 m
.32608 .24646 L
s
1 .727 0 r
.94989 .98769 m
.94998 .98954 L
s
0 1 .248 r
.28099 .59735 m
.27653 .59895 L
s
.277 .59148 m
.28099 .59735 L
s
.092 0 1 r
.86827 .2639 m
.88083 .25771 L
s
.298 1 0 r
.6211 .87663 m
.62457 .87794 L
s
.61789 .87789 m
.6211 .87663 L
s
.6211 .87663 m
.62133 .87357 L
s
.589 1 0 r
.32311 .24287 m
.3278 .24294 L
s
0 1 .575 r
.64657 .33555 m
.64999 .33732 L
s
.64657 .33555 m
.64163 .33982 L
s
0 .876 1 r
.29204 .76962 m
.29893 .77324 L
s
.28719 .77126 m
.29204 .76962 L
s
.29204 .76962 m
.29529 .76458 L
s
.498 1 0 r
.69271 .70693 m
.6774 .69671 L
s
.741 0 1 r
.24206 .94905 m
.23643 .95195 L
s
.23915 .93616 m
.24206 .94905 L
s
0 1 .248 r
.27653 .59895 m
.27214 .59675 L
s
.27214 .59675 m
.277 .59148 L
s
.504 1 0 r
.33938 .41752 m
.34147 .41884 L
s
.33628 .42014 m
.33938 .41752 L
s
.33938 .41752 m
.33705 .41657 L
s
.463 1 0 r
.60477 .69865 m
.60158 .7014 L
s
.60012 .69642 m
.60477 .69865 L
s
.159 0 1 r
.29361 .98714 m
.31598 .9383 L
s
0 1 .033 r
.66347 .52273 m
.66119 .521 L
s
.66119 .521 m
.66288 .51572 L
s
.66119 .521 m
.65833 .51822 L
s
.46 1 0 r
.42732 .42582 m
.41347 .41416 L
s
.463 1 0 r
.60012 .69642 m
.60158 .7014 L
s
0 .389 1 r
.21714 .77575 m
.20918 .77116 L
s
.20918 .77116 m
.21891 .76386 L
s
.21891 .76386 m
.21714 .77575 L
s
0 .978 1 r
.5675 1.04787 m
.56637 1.05796 L
s
.55915 1.05373 m
.5675 1.04787 L
s
.504 1 0 r
.33838 .42147 m
.33628 .42014 L
s
.33628 .42014 m
.33705 .41657 L
s
0 1 .033 r
.66288 .51572 m
.66516 .51744 L
s
.66288 .51572 m
.65833 .51822 L
s
0 1 .248 r
.277 .59148 m
.27653 .59895 L
s
0 1 .396 r
.63988 1.05463 m
.64575 1.05776 L
s
.6385 1.05584 m
.63988 1.05463 L
s
.63988 1.05463 m
.64493 1.05101 L
s
.298 1 0 r
.62457 .87794 m
.62136 .8792 L
s
.62133 .87357 m
.62457 .87794 L
s
.62136 .8792 m
.61789 .87789 L
s
.61789 .87789 m
.62133 .87357 L
s
0 1 .396 r
.63095 1.07994 m
.64493 1.05101 L
s
0 1 .32 r
.76477 .5182 m
.73582 .51692 L
s
0 .978 1 r
.56637 1.05796 m
.55915 1.05373 L
s
0 1 .575 r
.64999 .33732 m
.649 .34428 L
s
.64163 .33982 m
.649 .34428 L
s
0 .876 1 r
.29893 .77324 m
.29409 .77488 L
s
.29529 .76458 m
.29893 .77324 L
s
.504 1 0 r
.34147 .41884 m
.33838 .42147 L
s
.33705 .41657 m
.34147 .41884 L
s
0 1 .396 r
.64575 1.05776 m
.64439 1.05898 L
s
.64493 1.05101 m
.64575 1.05776 L
s
0 1 .654 r
.36525 .79866 m
.37205 .7653 L
s
.008 1 0 r
.49911 .23673 m
.47575 .23463 L
s
.298 1 0 r
.62133 .87357 m
.62136 .8792 L
s
.064 1 0 r
.35422 .59378 m
.35761 .59535 L
s
.35004 .59559 m
.35422 .59378 L
s
.35422 .59378 m
.35336 .59069 L
s
.159 0 1 r
.30907 .94406 m
.31865 .94976 L
s
.3043 .94644 m
.30907 .94406 L
s
.30907 .94406 m
.31598 .9383 L
s
.322 1 0 r
.40342 .24245 m
.40098 .24109 L
s
.40098 .24109 m
.40235 .23665 L
s
.40098 .24109 m
.39918 .23876 L
s
.504 1 0 r
.33705 .41657 m
.33838 .42147 L
s
.498 1 0 r
.67995 .70111 m
.67855 .69979 L
s
.67855 .69979 m
.68098 .69641 L
s
.67855 .69979 m
.6774 .69671 L
s
0 1 .575 r
.64163 .33982 m
.64999 .33732 L
s
.498 1 0 r
.68098 .69641 m
.68239 .69772 L
s
.68098 .69641 m
.6774 .69671 L
s
0 1 .927 r
.7277 .34133 m
.72385 .33947 L
s
.72385 .33947 m
.7244 .33151 L
s
.72385 .33947 m
.71893 .33684 L
s
.322 1 0 r
.40235 .23665 m
.4048 .238 L
s
.40235 .23665 m
.39918 .23876 L
s
0 1 .033 r
.66516 .51744 m
.66347 .52273 L
s
.65833 .51822 m
.66347 .52273 L
s
.712 1 0 r
.70301 .89142 m
.69885 .87534 L
s
0 .705 1 r
.83698 .32907 m
.79673 .33385 L
s
0 1 .033 r
.65833 .51822 m
.66516 .51744 L
s
.301 1 0 r
.43705 .60977 m
.43014 .5899 L
s
0 1 .396 r
.64493 1.05101 m
.64439 1.05898 L
s
.6385 1.05584 m
.64493 1.05101 L
s
.712 1 0 r
.70017 .87752 m
.7021 .87822 L
s
.69726 .8789 m
.70017 .87752 L
s
.70017 .87752 m
.69885 .87534 L
s
.064 1 0 r
.35343 .59716 m
.35004 .59559 L
s
.35004 .59559 m
.35336 .59069 L
s
.159 0 1 r
.31865 .94976 m
.31391 .95217 L
s
.31598 .9383 m
.31865 .94976 L
s
0 .876 1 r
.29409 .77488 m
.28719 .77126 L
s
.28719 .77126 m
.29529 .76458 L
s
.776 1 0 r
.17092 .32794 m
.16913 .31443 L
s
.064 1 0 r
.35761 .59535 m
.35343 .59716 L
s
.35336 .59069 m
.35761 .59535 L
s
0 1 .654 r
.37001 .76993 m
.37579 .77261 L
s
.36557 .77138 m
.37001 .76993 L
s
.37001 .76993 m
.37205 .7653 L
s
.322 1 0 r
.4048 .238 m
.40342 .24245 L
s
.39918 .23876 m
.40342 .24245 L
s
.741 0 1 r
.23915 .93616 m
.23643 .95195 L
s
.22565 .94517 m
.23915 .93616 L
s
0 .876 1 r
.29529 .76458 m
.29409 .77488 L
s
0 1 .927 r
.7244 .33151 m
.72826 .33335 L
s
.7244 .33151 m
.71893 .33684 L
s
.498 1 0 r
.6774 .69671 m
.67995 .70111 L
s
.6774 .69671 m
.68239 .69772 L
s
0 1 .32 r
.7424 .52121 m
.73983 .51935 L
s
.73983 .51935 m
.74086 .51316 L
s
.73983 .51935 m
.73582 .51692 L
s
.498 1 0 r
.68239 .69772 m
.67995 .70111 L
s
.712 1 0 r
.69919 .8796 m
.69726 .8789 L
s
.69726 .8789 m
.69885 .87534 L
s
.366 1 0 r
.77523 .70249 m
.75509 .697 L
s
0 1 .396 r
.64439 1.05898 m
.6385 1.05584 L
s
.322 1 0 r
.39918 .23876 m
.4048 .238 L
s
.46 1 0 r
.41666 .41418 m
.41852 .41547 L
s
.41399 .41753 m
.41666 .41418 L
s
.41666 .41418 m
.41347 .41416 L
s
.41584 .41883 m
.41399 .41753 L
s
.41399 .41753 m
.41347 .41416 L
s
.741 0 1 r
.23643 .95195 m
.22565 .94517 L
s
0 .418 1 r
.37487 .98361 m
.39314 .94044 L
s
.304 1 0 r
.50901 .42048 m
.49036 .41174 L
s
.218 1 0 r
.71893 1.05734 m
.72347 1.05938 L
s
.71817 1.05795 m
.71893 1.05734 L
s
.71893 1.05734 m
.72269 1.05415 L
s
.064 1 0 r
.35336 .59069 m
.35343 .59716 L
s
0 1 .32 r
.74086 .51316 m
.74343 .515 L
s
.74086 .51316 m
.73582 .51692 L
s
.712 1 0 r
.7021 .87822 m
.69919 .8796 L
s
.69885 .87534 m
.7021 .87822 L
s
.69885 .87534 m
.69919 .8796 L
s
.218 1 0 r
.72347 1.05938 m
.72272 1.06 L
s
.72269 1.05415 m
.72347 1.05938 L
s
0 1 .654 r
.37579 .77261 m
.37136 .77406 L
s
.37205 .7653 m
.37579 .77261 L
s
.366 1 0 r
.75901 .70093 m
.75767 .69942 L
s
.75767 .69942 m
.75924 .69527 L
s
.75767 .69942 m
.75509 .697 L
s
.218 1 0 r
.71336 1.0767 m
.72269 1.05415 L
s
0 1 .657 r
.84761 .51315 m
.81377 .51562 L
s
0 .418 1 r
.38724 .94583 m
.39566 .95047 L
s
.38327 .94773 m
.38724 .94583 L
s
.38724 .94583 m
.39314 .94044 L
s
0 1 .927 r
.72826 .33335 m
.7277 .34133 L
s
.71893 .33684 m
.7277 .34133 L
s
.301 1 0 r
.43222 .59219 m
.43465 .59336 L
s
.4284 .59441 m
.43222 .59219 L
s
.43222 .59219 m
.43014 .5899 L
s
0 1 .211 r
.44683 .79452 m
.44919 .76602 L
s
.46 1 0 r
.41852 .41547 m
.41584 .41883 L
s
.41347 .41416 m
.41852 .41547 L
s
0 1 .334 r
.58112 .23077 m
.55284 .23046 L
s
.366 1 0 r
.75924 .69527 m
.76058 .69677 L
s
.75924 .69527 m
.75509 .697 L
s
.46 1 0 r
.41347 .41416 m
.41584 .41883 L
s
.008 1 0 r
.48129 .23845 m
.47857 .23708 L
s
.47857 .23708 m
.4796 .23165 L
s
.47857 .23708 m
.47575 .23463 L
s
.218 1 0 r
.72269 1.05415 m
.72272 1.06 L
s
.71817 1.05795 m
.72269 1.05415 L
s
.008 1 0 r
.18013 .51214 m
.183 .48717 L
s
0 1 .927 r
.71893 .33684 m
.72826 .33335 L
s
0 .705 1 r
.80693 .33836 m
.80258 .33642 L
s
.80258 .33642 m
.80272 .32743 L
s
.80258 .33642 m
.79673 .33385 L
s
0 1 .654 r
.37136 .77406 m
.36557 .77138 L
s
.36557 .77138 m
.37205 .7653 L
s
.159 0 1 r
.31598 .9383 m
.31391 .95217 L
s
.3043 .94644 m
.31598 .9383 L
s
0 1 .32 r
.74343 .515 m
.7424 .52121 L
s
.73582 .51692 m
.7424 .52121 L
s
.301 1 0 r
.43082 .59558 m
.4284 .59441 L
s
.4284 .59441 m
.43014 .5899 L
s
.008 1 0 r
.4796 .23165 m
.48233 .23302 L
s
.4796 .23165 m
.47575 .23463 L
s
0 1 .32 r
.73582 .51692 m
.74343 .515 L
s
.218 1 0 r
.72272 1.06 m
.71817 1.05795 L
s
.963 1 0 r
.78574 .88757 m
.77674 .87711 L
s
0 .324 1 r
.92014 .3234 m
.87504 .33084 L
s
0 .418 1 r
.39566 .95047 m
.39172 .95238 L
s
.39314 .94044 m
.39566 .95047 L
s
0 1 .654 r
.37205 .7653 m
.37136 .77406 L
s
.776 1 0 r
.16974 .31567 m
.1719 .31713 L
s
.16708 .31716 m
.16974 .31567 L
s
.16974 .31567 m
.16913 .31443 L
s
.963 1 0 r
.77935 .87794 m
.77992 .87858 L
s
.77716 .87983 m
.77935 .87794 L
s
.77935 .87794 m
.77674 .87711 L
s
.77773 .88047 m
.77716 .87983 L
s
.77716 .87983 m
.77674 .87711 L
s
.159 0 1 r
.31391 .95217 m
.3043 .94644 L
s
.427 1 0 r
.51895 .60501 m
.50734 .58909 L
s
.366 1 0 r
.75509 .697 m
.75901 .70093 L
s
.75509 .697 m
.76058 .69677 L
s
0 1 .211 r
.4485 .77017 m
.45307 .77197 L
s
.44436 .77151 m
.4485 .77017 L
s
.4485 .77017 m
.44919 .76602 L
s
.366 1 0 r
.76058 .69677 m
.75901 .70093 L
s
0 1 .657 r
.82185 .5197 m
.81892 .51771 L
s
.81892 .51771 m
.81928 .51057 L
s
.81892 .51771 m
.81377 .51562 L
s
.301 1 0 r
.43465 .59336 m
.43082 .59558 L
s
.43014 .5899 m
.43465 .59336 L
s
.83 1 0 r
.25198 .32227 m
.24533 .31087 L
s
0 .705 1 r
.80272 .32743 m
.80707 .32935 L
s
.80272 .32743 m
.79673 .33385 L
s
.776 1 0 r
.16924 .31862 m
.16708 .31716 L
s
.16708 .31716 m
.16913 .31443 L
s
.1719 .31713 m
.16924 .31862 L
s
.16913 .31443 m
.1719 .31713 L
s
.304 1 0 r
.49393 .41627 m
.49209 .41491 L
s
.49209 .41491 m
.49427 .41072 L
s
.49209 .41491 m
.49036 .41174 L
s
.963 1 0 r
.77674 .87711 m
.77773 .88047 L
s
.77674 .87711 m
.77992 .87858 L
s
.8 1 0 r
.7984 1.06006 m
.80163 1.06102 L
s
.79813 1.06006 m
.7984 1.06006 L
s
.7984 1.06006 m
.80078 1.05732 L
s
.008 1 0 r
.48233 .23302 m
.48129 .23845 L
s
.47575 .23463 m
.48129 .23845 L
s
.301 1 0 r
.43014 .5899 m
.43082 .59558 L
s
.102 1 0 r
.85829 .69802 m
.8332 .69729 L
s
.304 1 0 r
.49427 .41072 m
.49612 .41207 L
s
.49427 .41072 m
.49036 .41174 L
s
.8 1 0 r
.80163 1.06102 m
.80137 1.06102 L
s
.80078 1.05732 m
.80163 1.06102 L
s
.963 1 0 r
.77992 .87858 m
.77773 .88047 L
s
0 1 .657 r
.81928 .51057 m
.82221 .51254 L
s
.81928 .51057 m
.81377 .51562 L
s
0 .987 1 r
.45665 .98005 m
.47065 .9426 L
s
.064 1 0 r
.59123 .4151 m
.56772 .4093 L
s
.776 1 0 r
.16913 .31443 m
.16924 .31862 L
s
.102 1 0 r
.83865 .70081 m
.83714 .69907 L
s
.83714 .69907 m
.83779 .69406 L
s
.83714 .69907 m
.8332 .69729 L
s
.8 1 0 r
.80078 1.05732 m
.80137 1.06102 L
s
.79813 1.06006 m
.80078 1.05732 L
s
.7963 1.07345 m
.80078 1.05732 L
s
.008 1 0 r
.47575 .23463 m
.48233 .23302 L
s
0 1 .924 r
.18938 .69713 m
.19926 .66054 L
s
0 1 .211 r
.45307 .77197 m
.44894 .77331 L
s
.44919 .76602 m
.45307 .77197 L
s
0 .987 1 r
.46587 .94761 m
.4731 .95118 L
s
.46258 .94903 m
.46587 .94761 L
s
.46587 .94761 m
.47065 .9426 L
s
.008 1 0 r
.18244 .49057 m
.18638 .49258 L
s
.17847 .49178 m
.18244 .49057 L
s
.18244 .49057 m
.183 .48717 L
s
0 .418 1 r
.39314 .94044 m
.39172 .95238 L
s
.38327 .94773 m
.39314 .94044 L
s
.102 1 0 r
.83779 .69406 m
.83931 .69579 L
s
.83779 .69406 m
.8332 .69729 L
s
0 1 .211 r
.44894 .77331 m
.44436 .77151 L
s
.44436 .77151 m
.44919 .76602 L
s
.8 1 0 r
.80137 1.06102 m
.79813 1.06006 L
s
0 .975 1 r
.93099 .50807 m
.89219 .51432 L
s
.427 1 0 r
.5105 .59036 m
.51217 .59141 L
s
.50717 .59316 m
.5105 .59036 L
s
.5105 .59036 m
.50734 .58909 L
s
.304 1 0 r
.49612 .41207 m
.49393 .41627 L
s
.49036 .41174 m
.49393 .41627 L
s
0 1 .334 r
.55969 .23446 m
.55664 .23304 L
s
.55664 .23304 m
.55736 .2266 L
s
.55664 .23304 m
.55284 .23046 L
s
0 .418 1 r
.39172 .95238 m
.38327 .94773 L
s
.186 1 0 r
.52894 .79034 m
.52672 .76675 L
s
0 1 .694 r
.66366 .22477 m
.63045 .22627 L
s
.427 1 0 r
.50884 .59422 m
.50717 .59316 L
s
.50717 .59316 m
.50734 .58909 L
s
0 .705 1 r
.80707 .32935 m
.80693 .33836 L
s
.79673 .33385 m
.80693 .33836 L
s
0 1 .211 r
.44919 .76602 m
.44894 .77331 L
s
.304 1 0 r
.49036 .41174 m
.49612 .41207 L
s
0 .324 1 r
.88669 .33539 m
.88179 .33336 L
s
.88179 .33336 m
.88153 .32332 L
s
.88179 .33336 m
.87504 .33084 L
s
.929 1 0 r
.85734 .8817 m
.85723 .88066 L
s
.85723 .88066 m
.85827 .87801 L
s
.85723 .88066 m
.85501 .87889 L
s
0 .987 1 r
.4731 .95118 m
.46983 .9526 L
s
.47065 .9426 m
.4731 .95118 L
s
.008 1 0 r
.18638 .49258 m
.18241 .49379 L
s
.183 .48717 m
.18638 .49258 L
s
.275 1 0 r
.2614 .50705 m
.25964 .48526 L
s
0 .705 1 r
.79673 .33385 m
.80707 .32935 L
s
.929 1 0 r
.85827 .87801 m
.85838 .87904 L
s
.85827 .87801 m
.85501 .87889 L
s
0 1 .657 r
.81377 .51562 m
.82185 .5197 L
s
.81377 .51562 m
.82221 .51254 L
s
.82221 .51254 m
.82185 .5197 L
s
.102 1 0 r
.8332 .69729 m
.83865 .70081 L
s
.8332 .69729 m
.83931 .69579 L
s
0 1 .334 r
.55736 .2266 m
.56042 .228 L
s
.55736 .2266 m
.55284 .23046 L
s
.929 1 0 r
.86901 .88369 m
.85501 .87889 L
s
0 .975 1 r
.90181 .51819 m
.89845 .51606 L
s
.89845 .51606 m
.89814 .50795 L
s
.89845 .51606 m
.89219 .51432 L
s
.008 1 0 r
.18241 .49379 m
.17847 .49178 L
s
.17847 .49178 m
.183 .48717 L
s
.102 1 0 r
.83931 .69579 m
.83865 .70081 L
s
.929 1 0 r
.85501 .87889 m
.85734 .8817 L
s
.85501 .87889 m
.85838 .87904 L
s
.186 1 0 r
.5275 .77024 m
.53073 .7713 L
s
.5236 .77166 m
.5275 .77024 L
s
.5275 .77024 m
.52672 .76675 L
s
0 1 .924 r
.19651 .66561 m
.20289 .66888 L
s
.19165 .66689 m
.19651 .66561 L
s
.19651 .66561 m
.19926 .66054 L
s
.83 1 0 r
.24701 .31156 m
.24877 .31271 L
s
.24457 .31361 m
.24701 .31156 L
s
.24701 .31156 m
.24533 .31087 L
s
1 .727 0 r
.87935 1.0629 m
.88077 1.06237 L
s
.87787 1.06248 m
.87935 1.0629 L
s
.87921 1.0605 m
.87935 1.0629 L
s
.416 1 0 r
.60138 .60022 m
.58498 .58829 L
s
1 .727 0 r
.8793 1.06196 m
.87921 1.0605 L
s
.87921 1.0605 m
.87787 1.06248 L
s
.88077 1.06237 m
.87921 1.0605 L
s
.87978 1.07017 m
.87921 1.0605 L
s
.929 1 0 r
.85838 .87904 m
.85734 .8817 L
s
.427 1 0 r
.51217 .59141 m
.50884 .59422 L
s
.50734 .58909 m
.51217 .59141 L
s
.83 1 0 r
.24633 .31476 m
.24457 .31361 L
s
.24457 .31361 m
.24533 .31087 L
s
.064 1 0 r
.5726 .41375 m
.57061 .41228 L
s
.57061 .41228 m
.57227 .40718 L
s
.57061 .41228 m
.56772 .4093 L
s
.427 1 0 r
.50734 .58909 m
.50884 .59422 L
s
0 .324 1 r
.88153 .32332 m
.88643 .32532 L
s
.88153 .32332 m
.87504 .33084 L
s
0 .023 1 r
.19867 .88292 m
.21792 .8346 L
s
.747 1 0 r
.33358 .31656 m
.32202 .30729 L
s
.008 1 0 r
.183 .48717 m
.18241 .49379 L
s
1 .727 0 r
.8793 1.06196 m
.87787 1.06248 L
s
0 1 .248 r
.9188 .70072 m
.917 .69875 L
s
.917 .69875 m
.91673 .69282 L
s
.917 .69875 m
.91173 .69758 L
s
1 .727 0 r
.88077 1.06237 m
.8793 1.06196 L
s
.064 1 0 r
.57227 .40718 m
.57427 .40864 L
s
.57227 .40718 m
.56772 .4093 L
s
0 .975 1 r
.89814 .50795 m
.90151 .51006 L
s
.89814 .50795 m
.89219 .51432 L
s
0 .987 1 r
.47065 .9426 m
.46983 .9526 L
s
.46258 .94903 m
.47065 .9426 L
s
.83 1 0 r
.24877 .31271 m
.24633 .31476 L
s
.24533 .31087 m
.24877 .31271 L
s
0 1 .248 r
.94188 .69353 m
.91173 .69758 L
s
0 1 .334 r
.56042 .228 m
.55969 .23446 L
s
.55284 .23046 m
.55969 .23446 L
s
.186 1 0 r
.52683 .77272 m
.5236 .77166 L
s
.5236 .77166 m
.52672 .76675 L
s
0 1 .456 r
.54498 .9494 m
.55099 .95189 L
s
.54221 .95034 m
.54498 .9494 L
s
.54498 .9494 m
.54851 .94476 L
s
.83 1 0 r
.24533 .31087 m
.24633 .31476 L
s
0 .987 1 r
.46983 .9526 m
.46258 .94903 L
s
0 1 .924 r
.20289 .66888 m
.19804 .67016 L
s
.19926 .66054 m
.20289 .66888 L
s
0 1 .456 r
.53897 .97647 m
.54851 .94476 L
s
0 1 .234 r
.67398 .40968 m
.64556 .40685 L
s
.186 1 0 r
.53073 .7713 m
.52683 .77272 L
s
.52672 .76675 m
.53073 .7713 L
s
0 1 .248 r
.91673 .69282 m
.91853 .69478 L
s
.91673 .69282 m
.91173 .69758 L
s
0 1 .334 r
.55284 .23046 m
.56042 .228 L
s
.275 1 0 r
.26038 .48822 m
.2634 .48958 L
s
.25658 .48969 m
.26038 .48822 L
s
.26038 .48822 m
.25964 .48526 L
s
0 1 .514 r
.27085 .69263 m
.27634 .6602 L
s
.631 1 0 r
.93767 .88303 m
.93748 .88155 L
s
.93748 .88155 m
.9373 .87799 L
s
.93748 .88155 m
.93365 .88069 L
s
.186 1 0 r
.52672 .76675 m
.52683 .77272 L
s
.416 1 0 r
.58756 .59304 m
.58631 .59187 L
s
.58631 .59187 m
.58898 .58833 L
s
.58631 .59187 m
.58498 .58829 L
s
0 .023 1 r
.21215 .84079 m
.22127 .84592 L
s
.20682 .84268 m
.21215 .84079 L
s
.21215 .84079 m
.21792 .8346 L
s
.416 1 0 r
.58898 .58833 m
.59024 .58949 L
s
.58898 .58833 m
.58498 .58829 L
s
0 1 .456 r
.55099 .95189 m
.54823 .95283 L
s
.54851 .94476 m
.55099 .95189 L
s
.631 1 0 r
.9373 .87799 m
.93749 .87946 L
s
.9373 .87799 m
.93365 .88069 L
s
0 1 .694 r
.63862 .23046 m
.63519 .22898 L
s
.63519 .22898 m
.63562 .22149 L
s
.63519 .22898 m
.63045 .22627 L
s
.064 1 0 r
.57427 .40864 m
.5726 .41375 L
s
.56772 .4093 m
.5726 .41375 L
s
.56772 .4093 m
.57427 .40864 L
s
.498 1 0 r
.61158 .78614 m
.60465 .76748 L
s
.631 1 0 r
.93365 .88069 m
.93767 .88303 L
s
.93365 .88069 m
.93749 .87946 L
s
.95282 .87979 m
.93365 .88069 L
s
0 .934 1 r
.74674 .21873 m
.70858 .22205 L
s
0 1 .248 r
.91173 .69758 m
.9188 .70072 L
s
.91173 .69758 m
.91853 .69478 L
s
1 .667 0 r
.95797 1.06369 m
.95866 1.06555 L
s
.95961 1.06309 m
.95797 1.06369 L
s
.95797 1.06369 m
.9582 1.06405 L
s
.96007 1.06459 m
.95797 1.06369 L
s
.9638 1.06686 m
.95797 1.06369 L
s
0 .975 1 r
.89219 .51432 m
.90181 .51819 L
s
.89219 .51432 m
.90151 .51006 L
s
0 .324 1 r
.88643 .32532 m
.88669 .33539 L
s
.87504 .33084 m
.88669 .33539 L
s
.275 1 0 r
.25961 .49105 m
.25658 .48969 L
s
.25658 .48969 m
.25964 .48526 L
s
.2634 .48958 m
.25961 .49105 L
s
.25964 .48526 m
.2634 .48958 L
s
0 1 .924 r
.19804 .67016 m
.19165 .66689 L
s
.19165 .66689 m
.19926 .66054 L
s
1 0 .85 r
.208 1.06951 m
.23902 1.00941 L
s
.46 1 0 r
.3432 .50193 m
.33673 .48334 L
s
0 .975 1 r
.90151 .51006 m
.90181 .51819 L
s
1 .667 0 r
.95866 1.06555 m
.96007 1.06459 L
s
.96007 1.06459 m
.95961 1.06309 L
s
0 .324 1 r
.87504 .33084 m
.88643 .32532 L
s
0 1 .924 r
.19926 .66054 m
.19804 .67016 L
s
0 1 .248 r
.91853 .69478 m
.9188 .70072 L
s
.498 1 0 r
.60692 .77001 m
.60871 .77064 L
s
.60337 .7718 m
.60692 .77001 L
s
.60692 .77001 m
.60465 .76748 L
s
0 1 .694 r
.63562 .22149 m
.63906 .22295 L
s
.63562 .22149 m
.63045 .22627 L
s
.631 1 0 r
.93749 .87946 m
.93767 .88303 L
s
1 .667 0 r
.9582 1.06405 m
.95866 1.06555 L
s
0 1 .514 r
.27484 .66495 m
.28019 .66729 L
s
.27029 .66612 m
.27484 .66495 L
s
.27484 .66495 m
.27634 .6602 L
s
1 .667 0 r
.95961 1.06309 m
.9582 1.06405 L
s
0 .023 1 r
.22127 .84592 m
.21598 .84783 L
s
.21792 .8346 m
.22127 .84592 L
s
0 1 .456 r
.54851 .94476 m
.54823 .95283 L
s
.54221 .95034 m
.54851 .94476 L
s
.416 1 0 r
.58498 .58829 m
.58756 .59304 L
s
.58498 .58829 m
.59024 .58949 L
s
0 1 .234 r
.65181 .41124 m
.64957 .40966 L
s
.64957 .40966 m
.65071 .40359 L
s
.64957 .40966 m
.64556 .40685 L
s
.747 1 0 r
.32407 .31108 m
.32248 .31002 L
s
.32248 .31002 m
.32461 .30721 L
s
.32248 .31002 m
.32202 .30729 L
s
.32461 .30721 m
.32619 .30827 L
s
.32461 .30721 m
.32202 .30729 L
s
.416 1 0 r
.59024 .58949 m
.58756 .59304 L
s
.275 1 0 r
.25964 .48526 m
.25961 .49105 L
s
0 1 .456 r
.54823 .95283 m
.54221 .95034 L
s
.498 1 0 r
.60514 .77244 m
.60337 .7718 L
s
.60337 .7718 m
.60465 .76748 L
s
.272 1 0 r
.68435 .5954 m
.66306 .58748 L
s
1 0 .85 r
.22952 1.01613 m
.2415 1.02364 L
s
.22404 1.01931 m
.22952 1.01613 L
s
.22952 1.01613 m
.23902 1.00941 L
s
0 .54 1 r
.28035 .87901 m
.29546 .83574 L
s
.548 1 0 r
.4157 .31081 m
.39919 .30368 L
s
.078 1 0 r
.62464 .95118 m
.62933 .95257 L
s
.62214 .95168 m
.62464 .95118 L
s
.62464 .95118 m
.62672 .94694 L
s
0 1 .234 r
.65071 .40359 m
.65296 .40517 L
s
.65071 .40359 m
.64556 .40685 L
s
.498 1 0 r
.60465 .76748 m
.60514 .77244 L
s
.60465 .76748 m
.60871 .77064 L
s
0 1 .514 r
.28019 .66729 m
.27565 .66847 L
s
.27634 .6602 m
.28019 .66729 L
s
.747 1 0 r
.32619 .30827 m
.32407 .31108 L
s
.32202 .30729 m
.32407 .31108 L
s
.32202 .30729 m
.32619 .30827 L
s
.498 1 0 r
.60871 .77064 m
.60514 .77244 L
s
0 1 .694 r
.63906 .22295 m
.63862 .23046 L
s
.63045 .22627 m
.63862 .23046 L
s
.272 1 0 r
.66694 .59195 m
.66577 .59057 L
s
.66577 .59057 m
.66771 .58619 L
s
.66577 .59057 m
.66306 .58748 L
s
.078 1 0 r
.62182 .97287 m
.62672 .94694 L
s
0 1 .569 r
.75728 .40424 m
.72387 .40438 L
s
0 .54 1 r
.29072 .84163 m
.29878 .84572 L
s
.28607 .84313 m
.29072 .84163 L
s
.29072 .84163 m
.29546 .83574 L
s
.46 1 0 r
.33873 .48563 m
.34087 .48658 L
s
.33518 .48757 m
.33873 .48563 L
s
.33873 .48563 m
.33673 .48334 L
s
1 0 .85 r
.2415 1.02364 m
.23608 1.02686 L
s
.23902 1.00941 m
.2415 1.02364 L
s
.078 1 0 r
.62933 .95257 m
.62685 .95308 L
s
.62672 .94694 m
.62933 .95257 L
s
0 1 .694 r
.63045 .22627 m
.63906 .22295 L
s
0 1 .138 r
.35286 .6881 m
.35384 .65986 L
s
.272 1 0 r
.66771 .58619 m
.66888 .58756 L
s
.66771 .58619 m
.66306 .58748 L
s
0 1 .514 r
.27565 .66847 m
.27029 .66612 L
s
.27029 .66612 m
.27634 .6602 L
s
0 .934 1 r
.7181 .22644 m
.71423 .2249 L
s
.71423 .2249 m
.71439 .21634 L
s
.71423 .2249 m
.70858 .22205 L
s
.46 1 0 r
.33731 .48852 m
.33518 .48757 L
s
.33518 .48757 m
.33673 .48334 L
s
0 .023 1 r
.21792 .8346 m
.21598 .84783 L
s
.20682 .84268 m
.21792 .8346 L
s
0 1 .234 r
.65296 .40517 m
.65181 .41124 L
s
.64556 .40685 m
.65181 .41124 L
s
.078 1 0 r
.62672 .94694 m
.62685 .95308 L
s
.62214 .95168 m
.62672 .94694 L
s
0 1 .234 r
.64556 .40685 m
.65296 .40517 L
s
0 1 .514 r
.27634 .6602 m
.27565 .66847 L
s
.078 1 0 r
.62685 .95308 m
.62214 .95168 L
s
.667 1 0 r
.69476 .78191 m
.68296 .76822 L
s
0 .555 1 r
.83036 .21266 m
.78723 .2178 L
s
0 .023 1 r
.21598 .84783 m
.20682 .84268 L
s
0 .54 1 r
.29878 .84572 m
.29415 .84723 L
s
.29546 .83574 m
.29878 .84572 L
s
.667 1 0 r
.68644 .76939 m
.68705 .77008 L
s
.6836 .77184 m
.68644 .76939 L
s
.68644 .76939 m
.68296 .76822 L
s
.68421 .77253 m
.6836 .77184 L
s
.6836 .77184 m
.68296 .76822 L
s
.46 1 0 r
.34087 .48658 m
.33731 .48852 L
s
.33673 .48334 m
.34087 .48658 L
s
.548 0 1 r
.28988 1.0662 m
.31702 1.01195 L
s
.532 1 0 r
.42553 .49677 m
.41426 .48142 L
s
0 1 .138 r
.35371 .66418 m
.35791 .66567 L
s
.34937 .66538 m
.35371 .66418 L
s
.35371 .66418 m
.35384 .65986 L
s
.272 1 0 r
.66306 .58748 m
.66694 .59195 L
s
.66306 .58748 m
.66888 .58756 L
s
0 1 .569 r
.73154 .40874 m
.72898 .40702 L
s
.72898 .40702 m
.72961 .39997 L
s
.72898 .40702 m
.72387 .40438 L
s
.272 1 0 r
.66888 .58756 m
.66694 .59195 L
s
0 .934 1 r
.71439 .21634 m
.71827 .21786 L
s
.71439 .21634 m
.70858 .22205 L
s
.548 1 0 r
.40243 .30751 m
.40083 .30641 L
s
.40083 .30641 m
.40258 .30272 L
s
.40083 .30641 m
.39919 .30368 L
s
1 .77 0 r
.15612 .21144 m
.15345 .20499 L
s
.46 1 0 r
.33673 .48334 m
.33731 .48852 L
s
.548 0 1 r
.30834 1.01834 m
.31915 1.02474 L
s
.30398 1.02092 m
.30834 1.01834 L
s
.30834 1.01834 m
.31702 1.01195 L
s
.548 1 0 r
.40258 .30272 m
.40418 .3038 L
s
.40258 .30272 m
.39919 .30368 L
s
.563 1 0 r
.70508 .95286 m
.70813 .95316 L
s
.7024 .95313 m
.70508 .95286 L
s
.70508 .95286 m
.70528 .94912 L
s
.022 1 0 r
.76785 .59054 m
.74157 .58666 L
s
.667 1 0 r
.68296 .76822 m
.68421 .77253 L
s
.68296 .76822 m
.68705 .77008 L
s
0 1 .569 r
.72961 .39997 m
.73218 .40167 L
s
.72961 .39997 m
.72387 .40438 L
s
0 1 .956 r
.36256 .87508 m
.37337 .83689 L
s
.275 1 0 r
.49836 .30502 m
.47685 .30005 L
s
.022 1 0 r
.74689 .59089 m
.7456 .58928 L
s
.7456 .58928 m
.74679 .58399 L
s
.7456 .58928 m
.74157 .58666 L
s
.667 1 0 r
.68705 .77008 m
.68421 .77253 L
s
.548 0 1 r
.31915 1.02474 m
.31482 1.02735 L
s
.31702 1.01195 m
.31915 1.02474 L
s
0 1 .138 r
.35791 .66567 m
.35357 .66688 L
s
.35384 .65986 m
.35791 .66567 L
s
0 1 .956 r
.36979 .84247 m
.37673 .84551 L
s
.36566 .84359 m
.36979 .84247 L
s
.36979 .84247 m
.37337 .83689 L
s
.548 1 0 r
.40418 .3038 m
.40243 .30751 L
s
.39919 .30368 m
.40243 .30751 L
s
0 1 .138 r
.35357 .66688 m
.34937 .66538 L
s
.34937 .66538 m
.35384 .65986 L
s
.563 1 0 r
.70528 .94912 m
.70546 .95343 L
s
.70528 .94912 m
.70813 .95316 L
s
.7024 .95313 m
.70528 .94912 L
s
.70521 .96924 m
.70528 .94912 L
s
0 .54 1 r
.29546 .83574 m
.29415 .84723 L
s
.28607 .84313 m
.29546 .83574 L
s
.563 1 0 r
.70813 .95316 m
.70546 .95343 L
s
.70546 .95343 m
.7024 .95313 L
s
.548 1 0 r
.39919 .30368 m
.40418 .3038 L
s
.022 1 0 r
.74679 .58399 m
.74808 .5856 L
s
.74679 .58399 m
.74157 .58666 L
s
.532 1 0 r
.41738 .48277 m
.41882 .48361 L
s
.41422 .48538 m
.41738 .48277 L
s
.41738 .48277 m
.41426 .48142 L
s
1 0 .85 r
.23902 1.00941 m
.23608 1.02686 L
s
.22404 1.01931 m
.23902 1.00941 L
s
0 1 .929 r
.84111 .39875 m
.80268 .40189 L
s
0 .54 1 r
.29415 .84723 m
.28607 .84313 L
s
0 .934 1 r
.71827 .21786 m
.7181 .22644 L
s
.70858 .22205 m
.7181 .22644 L
s
.532 1 0 r
.41566 .48623 m
.41422 .48538 L
s
.41422 .48538 m
.41426 .48142 L
s
0 1 .138 r
.35384 .65986 m
.35357 .66688 L
s
.184 1 0 r
.4354 .68354 m
.43174 .65952 L
s
0 .934 1 r
.70858 .22205 m
.71827 .21786 L
s
0 .555 1 r
.79814 .22241 m
.79376 .22078 L
s
.79376 .22078 m
.79367 .21114 L
s
.79376 .22078 m
.78723 .2178 L
s
.636 1 0 r
.76417 .77287 m
.76406 .7718 L
s
.76406 .7718 m
.7659 .76854 L
s
.76406 .7718 m
.76168 .76896 L
s
.589 1 0 r
.16541 .39765 m
.16569 .37959 L
s
0 1 .569 r
.72387 .40438 m
.73154 .40874 L
s
.72387 .40438 m
.73218 .40167 L
s
.73218 .40167 m
.73154 .40874 L
s
0 1 .956 r
.37673 .84551 m
.37262 .84664 L
s
.37337 .83689 m
.37673 .84551 L
s
.636 1 0 r
.7659 .76854 m
.76602 .7696 L
s
.7659 .76854 m
.76168 .76896 L
s
1 .77 0 r
.15409 .20504 m
.15549 .20617 L
s
.15249 .2064 m
.15409 .20504 L
s
.15409 .20504 m
.15345 .20499 L
s
1 0 .85 r
.23608 1.02686 m
.22404 1.01931 L
s
.022 1 0 r
.74157 .58666 m
.74689 .59089 L
s
.74157 .58666 m
.74808 .5856 L
s
.636 1 0 r
.77848 .77766 m
.76168 .76896 L
s
0 .17 1 r
.91453 .20654 m
.86642 .21352 L
s
.184 1 0 r
.4331 .6632 m
.43601 .66403 L
s
.42893 .66465 m
.4331 .6632 L
s
.4331 .6632 m
.43174 .65952 L
s
0 1 .929 r
.81181 .40623 m
.80885 .40438 L
s
.80885 .40438 m
.80897 .39631 L
s
.80885 .40438 m
.80268 .40189 L
s
1 .77 0 r
.15388 .20753 m
.15249 .2064 L
s
.15249 .2064 m
.15345 .20499 L
s
0 .048 1 r
.38758 1.02055 m
.39719 1.02585 L
s
.38423 1.02252 m
.38758 1.02055 L
s
.38758 1.02055 m
.39534 1.01449 L
s
1 .77 0 r
.15549 .20617 m
.15388 .20753 L
s
.15345 .20499 m
.15549 .20617 L
s
.532 1 0 r
.41882 .48361 m
.41566 .48623 L
s
.41426 .48142 m
.41882 .48361 L
s
.022 1 0 r
.74808 .5856 m
.74689 .59089 L
s
0 .048 1 r
.37231 1.06288 m
.39534 1.01449 L
s
.532 1 0 r
.41426 .48142 m
.41566 .48623 L
s
.275 1 0 r
.48136 .30396 m
.47962 .30279 L
s
.47962 .30279 m
.48098 .29814 L
s
.47962 .30279 m
.47685 .30005 L
s
.474 1 0 r
.5084 .49158 m
.49224 .47948 L
s
1 .77 0 r
.15345 .20499 m
.15388 .20753 L
s
.636 1 0 r
.76168 .76896 m
.76417 .77287 L
s
.76168 .76896 m
.76602 .7696 L
s
0 .555 1 r
.79367 .21114 m
.79805 .21273 L
s
.79367 .21114 m
.78723 .2178 L
s
1 .865 0 r
.23813 .20531 m
.23038 .2002 L
s
.929 1 0 r
.78376 .95452 m
.78374 .95478 L
s
.78374 .95478 m
.78661 .95381 L
s
.78374 .95478 m
.7842 .95131 L
s
.78661 .95381 m
.78663 .95355 L
s
.78661 .95381 m
.7842 .95131 L
s
.275 1 0 r
.48098 .29814 m
.48272 .2993 L
s
.48098 .29814 m
.47685 .30005 L
s
.636 1 0 r
.76602 .7696 m
.76417 .77287 L
s
0 .048 1 r
.39719 1.02585 m
.39388 1.02784 L
s
.39534 1.01449 m
.39719 1.02585 L
s
.929 1 0 r
.7842 .95131 m
.78376 .95452 L
s
.7842 .95131 m
.78663 .95355 L
s
.78915 .96559 m
.7842 .95131 L
s
0 1 .299 r
.82737 .58985 m
.82584 .58801 L
s
.82584 .58801 m
.82626 .58177 L
s
.82584 .58801 m
.82053 .58584 L
s
.548 0 1 r
.31702 1.01195 m
.31482 1.02735 L
s
.30398 1.02092 m
.31702 1.01195 L
s
0 1 .929 r
.80897 .39631 m
.81193 .39814 L
s
.80897 .39631 m
.80268 .40189 L
s
0 1 .956 r
.37337 .83689 m
.37262 .84664 L
s
.36566 .84359 m
.37337 .83689 L
s
.184 1 0 r
.43184 .66547 m
.42893 .66465 L
s
.42893 .66465 m
.43174 .65952 L
s
0 1 .299 r
.85191 .58565 m
.82053 .58584 L
s
0 1 .956 r
.37262 .84664 m
.36566 .84359 L
s
0 1 .471 r
.44939 .84329 m
.45514 .84527 L
s
.4456 .84408 m
.44939 .84329 L
s
.44939 .84329 m
.45164 .83805 L
s
.44532 .87113 m
.45164 .83805 L
s
.589 1 0 r
.16583 .38206 m
.16848 .38336 L
s
.16279 .38306 m
.16583 .38206 L
s
.16583 .38206 m
.16569 .37959 L
s
0 1 .044 r
.58155 .2992 m
.55502 .2964 L
s
.184 1 0 r
.43601 .66403 m
.43184 .66547 L
s
.43174 .65952 m
.43601 .66403 L
s
0 1 .299 r
.82626 .58177 m
.82779 .5836 L
s
.82626 .58177 m
.82053 .58584 L
s
0 1 .282 r
.17474 .58468 m
.18033 .5548 L
s
.929 1 0 r
.78663 .95355 m
.78376 .95452 L
s
.184 1 0 r
.43174 .65952 m
.43184 .66547 L
s
.275 1 0 r
.48272 .2993 m
.48136 .30396 L
s
.47685 .30005 m
.48136 .30396 L
s
.474 1 0 r
.4947 .4841 m
.49364 .48314 L
s
.49364 .48314 m
.49626 .47971 L
s
.49364 .48314 m
.49224 .47948 L
s
.49626 .47971 m
.49732 .48066 L
s
.49626 .47971 m
.49224 .47948 L
s
.548 0 1 r
.31482 1.02735 m
.30398 1.02092 L
s
.418 1 0 r
.84483 .77327 m
.84474 .77177 L
s
.84474 .77177 m
.84553 .76761 L
s
.84474 .77177 m
.84079 .7697 L
s
.275 1 0 r
.47685 .30005 m
.48272 .2993 L
s
0 .694 1 r
.9255 .39323 m
.88197 .3994 L
s
.589 1 0 r
.16848 .38336 m
.16543 .38436 L
s
.16569 .37959 m
.16848 .38336 L
s
.16543 .38436 m
.16279 .38306 L
s
.16279 .38306 m
.16569 .37959 L
s
0 .17 1 r
.87873 .21835 m
.87378 .21665 L
s
.87378 .21665 m
.87346 .2059 L
s
.87378 .21665 m
.86642 .21352 L
s
.418 1 0 r
.84553 .76761 m
.84562 .7691 L
s
.84553 .76761 m
.84079 .7697 L
s
0 .555 1 r
.79805 .21273 m
.79814 .22241 L
s
.78723 .2178 m
.79814 .22241 L
s
.416 1 0 r
.51848 .67895 m
.51004 .65918 L
s
0 1 .471 r
.45514 .84527 m
.45136 .84607 L
s
.45164 .83805 m
.45514 .84527 L
s
0 1 .929 r
.80268 .40189 m
.81181 .40623 L
s
.80268 .40189 m
.81193 .39814 L
s
0 .555 1 r
.78723 .2178 m
.79805 .21273 L
s
0 .635 1 r
.46724 1.02278 m
.47565 1.02697 L
s
.4648 1.02413 m
.46724 1.02278 L
s
.46724 1.02278 m
.47398 1.01705 L
s
0 1 .299 r
.82053 .58584 m
.82737 .58985 L
s
.82053 .58584 m
.82779 .5836 L
s
.747 1 0 r
.24763 .39212 m
.24306 .37651 L
s
0 1 .929 r
.81193 .39814 m
.81181 .40623 L
s
.418 1 0 r
.84079 .7697 m
.84483 .77327 L
s
.84079 .7697 m
.84562 .7691 L
s
.86275 .77337 m
.84079 .7697 L
s
0 .694 1 r
.8926 .40371 m
.88919 .40173 L
s
.88919 .40173 m
.88881 .39262 L
s
.88919 .40173 m
.88197 .3994 L
s
.589 1 0 r
.16569 .37959 m
.16543 .38436 L
s
0 .048 1 r
.39534 1.01449 m
.39388 1.02784 L
s
.38423 1.02252 m
.39534 1.01449 L
s
0 1 .282 r
.17888 .5593 m
.18374 .56145 L
s
.17467 .56013 m
.17888 .5593 L
s
.17888 .5593 m
.18033 .5548 L
s
1 .969 0 r
.8642 .95658 m
.86566 .95589 L
s
.86566 .95589 m
.8668 .95381 L
s
.86566 .95589 m
.86347 .95352 L
s
.416 1 0 r
.51287 .6619 m
.51445 .6624 L
s
.50903 .66388 m
.51287 .6619 L
s
.51287 .6619 m
.51004 .65918 L
s
1 .865 0 r
.23195 .20271 m
.23059 .2018 L
s
.23059 .2018 m
.23192 .19974 L
s
.23059 .2018 m
.23038 .2002 L
s
.23192 .19974 m
.23328 .20064 L
s
.23192 .19974 m
.23038 .2002 L
s
0 1 .299 r
.82779 .5836 m
.82737 .58985 L
s
.474 1 0 r
.49224 .47948 m
.4947 .4841 L
s
.49224 .47948 m
.49732 .48066 L
s
1 .969 0 r
.86347 .95352 m
.8642 .95658 L
s
.8668 .95381 m
.86347 .95352 L
s
.86347 .95352 m
.86534 .9545 L
s
.87364 .96191 m
.86347 .95352 L
s
0 1 .044 r
.56083 .30043 m
.55888 .29916 L
s
.55888 .29916 m
.55985 .2935 L
s
.55888 .29916 m
.55502 .2964 L
s
.474 1 0 r
.49732 .48066 m
.4947 .4841 L
s
0 1 .471 r
.45164 .83805 m
.45136 .84607 L
s
.4456 .84408 m
.45164 .83805 L
s
0 .635 1 r
.47565 1.02697 m
.47325 1.02834 L
s
.47398 1.01705 m
.47565 1.02697 L
s
0 1 .471 r
.45136 .84607 m
.4456 .84408 L
s
1 .969 0 r
.8668 .95381 m
.86534 .9545 L
s
.416 1 0 r
.5106 .66438 m
.50903 .66388 L
s
.50903 .66388 m
.51004 .65918 L
s
.418 1 0 r
.84562 .7691 m
.84483 .77327 L
s
0 .635 1 r
.45527 1.05953 m
.47398 1.01705 L
s
.301 1 0 r
.59181 .48636 m
.57068 .47753 L
s
0 1 .665 r
.90835 .58881 m
.90651 .58674 L
s
.90651 .58674 m
.90616 .57952 L
s
.90651 .58674 m
.89993 .58502 L
s
1 .865 0 r
.23328 .20064 m
.23195 .20271 L
s
.23038 .2002 m
.23195 .20271 L
s
.23038 .2002 m
.23328 .20064 L
s
0 .17 1 r
.87346 .2059 m
.87841 .20757 L
s
.87346 .2059 m
.86642 .21352 L
s
1 .969 0 r
.86534 .9545 m
.8642 .95658 L
s
0 1 .044 r
.55985 .2935 m
.5618 .29475 L
s
.55985 .2935 m
.55502 .2964 L
s
0 .731 1 r
.18411 .77252 m
.19739 .73068 L
s
.898 1 0 r
.32069 .19915 m
.30782 .19536 L
s
0 .694 1 r
.88881 .39262 m
.89222 .39458 L
s
.88881 .39262 m
.88197 .3994 L
s
0 .048 1 r
.39388 1.02784 m
.38423 1.02252 L
s
0 1 .021 r
.52962 .84402 m
.53398 .84497 L
s
.5259 .84463 m
.52962 .84402 L
s
.52962 .84402 m
.53028 .83921 L
s
0 1 .282 r
.18374 .56145 m
.17954 .56229 L
s
.18033 .5548 m
.18374 .56145 L
s
0 1 .665 r
.93651 .58074 m
.89993 .58502 L
s
.90616 .57952 m
.90801 .58158 L
s
.90616 .57952 m
.89993 .58502 L
s
.416 1 0 r
.51004 .65918 m
.5106 .66438 L
s
.51004 .65918 m
.51445 .6624 L
s
.075 1 0 r
.92601 .77368 m
.92576 .77179 L
s
.92576 .77179 m
.92551 .76666 L
s
.92576 .77179 m
.92031 .77045 L
s
.416 1 0 r
.51445 .6624 m
.5106 .66438 L
s
.747 1 0 r
.24452 .37851 m
.24636 .37931 L
s
.24159 .37997 m
.24452 .37851 L
s
.24452 .37851 m
.24306 .37651 L
s
.301 1 0 r
.57439 .48205 m
.57342 .48089 L
s
.57342 .48089 m
.57544 .47655 L
s
.57342 .48089 m
.57068 .47753 L
s
0 1 .021 r
.52861 .86714 m
.53028 .83921 L
s
0 1 .39 r
.6653 .29334 m
.63368 .29272 L
s
0 .731 1 r
.1934 .73668 m
.20093 .74035 L
s
.18851 .73779 m
.1934 .73668 L
s
.1934 .73668 m
.19739 .73068 L
s
.301 1 0 r
.57544 .47655 m
.57641 .47771 L
s
.57544 .47655 m
.57068 .47753 L
s
0 1 .282 r
.17954 .56229 m
.17467 .56013 L
s
.17467 .56013 m
.18033 .5548 L
s
.042 1 0 r
.25718 .57975 m
.25815 .55336 L
s
.075 1 0 r
.92551 .76666 m
.92575 .76855 L
s
.92551 .76666 m
.92031 .77045 L
s
0 .635 1 r
.47398 1.01705 m
.47325 1.02834 L
s
.4648 1.02413 m
.47398 1.01705 L
s
0 1 .044 r
.5618 .29475 m
.56083 .30043 L
s
.55502 .2964 m
.56083 .30043 L
s
.747 1 0 r
.24343 .38077 m
.24159 .37997 L
s
.24159 .37997 m
.24306 .37651 L
s
0 1 .044 r
.55502 .2964 m
.5618 .29475 L
s
0 1 .282 r
.18033 .5548 m
.17954 .56229 L
s
0 1 .794 r
.54732 1.02502 m
.55454 1.0281 L
s
.54569 1.02575 m
.54732 1.02502 L
s
.54732 1.02502 m
.55295 1.01962 L
s
0 1 .021 r
.53398 .84497 m
.53027 .84558 L
s
.53028 .83921 m
.53398 .84497 L
s
.8 1 0 r
.94563 .9585 m
.94702 .95701 L
s
.94702 .95701 m
.94679 .95396 L
s
.94702 .95701 m
.9431 .95573 L
s
.9431 .95573 m
.94563 .9585 L
s
.94679 .95396 m
.9431 .95573 L
s
.9431 .95573 m
.9454 .95545 L
s
.95869 .95821 m
.9431 .95573 L
s
.075 1 0 r
.92031 .77045 m
.92601 .77368 L
s
.92031 .77045 m
.92575 .76855 L
s
.94758 .76906 m
.92031 .77045 L
s
.747 1 0 r
.24636 .37931 m
.24343 .38077 L
s
.24306 .37651 m
.24636 .37931 L
s
0 1 .665 r
.89993 .58502 m
.90835 .58881 L
s
.89993 .58502 m
.90801 .58158 L
s
0 1 .021 r
.53027 .84558 m
.5259 .84463 L
s
.5259 .84463 m
.53028 .83921 L
s
.53028 .83921 m
.53027 .84558 L
s
.519 1 0 r
.60211 .67433 m
.58877 .65884 L
s
0 .694 1 r
.88197 .3994 m
.8926 .40371 L
s
.88197 .3994 m
.89222 .39458 L
s
.8 1 0 r
.94679 .95396 m
.9454 .95545 L
s
0 .731 1 r
.20093 .74035 m
.19606 .74148 L
s
.19739 .73068 m
.20093 .74035 L
s
0 .17 1 r
.87841 .20757 m
.87873 .21835 L
s
.86642 .21352 m
.87873 .21835 L
s
0 1 .794 r
.55454 1.0281 m
.55293 1.02883 L
s
.55295 1.01962 m
.55454 1.0281 L
s
.747 1 0 r
.24306 .37651 m
.24343 .38077 L
s
.042 1 0 r
.2581 .55754 m
.26191 .55883 L
s
.25399 .55847 m
.2581 .55754 L
s
.2581 .55754 m
.25815 .55336 L
s
.519 1 0 r
.59276 .66026 m
.59331 .66087 L
s
.58957 .66301 m
.59276 .66026 L
s
.59276 .66026 m
.58877 .65884 L
s
.59011 .66362 m
.58957 .66301 L
s
.58957 .66301 m
.58877 .65884 L
s
0 .17 1 r
.86642 .21352 m
.87841 .20757 L
s
.362 0 1 r
.19352 .96118 m
.2169 .9073 L
s
.778 1 0 r
.3304 .38656 m
.32089 .37342 L
s
0 .694 1 r
.89222 .39458 m
.8926 .40371 L
s
.301 1 0 r
.57068 .47753 m
.57439 .48205 L
s
.57068 .47753 m
.57641 .47771 L
s
.898 1 0 r
.3106 .19802 m
.30917 .19718 L
s
.30917 .19718 m
.3102 .19423 L
s
.30917 .19718 m
.30782 .19536 L
s
0 .635 1 r
.47325 1.02834 m
.4648 1.02413 L
s
0 1 .39 r
.64084 .29688 m
.63861 .29551 L
s
.63861 .29551 m
.63921 .28881 L
s
.63861 .29551 m
.63368 .29272 L
s
0 1 .665 r
.90801 .58158 m
.90835 .58881 L
s
.301 1 0 r
.57641 .47771 m
.57439 .48205 L
s
.075 1 0 r
.92575 .76855 m
.92601 .77368 L
s
.898 1 0 r
.3102 .19423 m
.31163 .19506 L
s
.3102 .19423 m
.30782 .19536 L
s
.8 1 0 r
.9454 .95545 m
.94563 .9585 L
s
.362 0 1 r
.20961 .91422 m
.21998 .91998 L
s
.20442 .91623 m
.20961 .91422 L
s
.20961 .91422 m
.2169 .9073 L
s
0 1 .794 r
.53879 1.05616 m
.55295 1.01962 L
s
.042 1 0 r
.67577 .4811 m
.64958 .47557 L
s
.366 1 0 r
.61063 .84449 m
.6131 .84457 L
s
.60674 .84529 m
.61063 .84449 L
s
.61063 .84449 m
.60929 .84038 L
s
0 1 .39 r
.63921 .28881 m
.64144 .29017 L
s
.63921 .28881 m
.63368 .29272 L
s
.898 1 0 r
.31163 .19506 m
.3106 .19802 L
s
.30782 .19536 m
.3106 .19802 L
s
.519 1 0 r
.58877 .65884 m
.59011 .66362 L
s
.58877 .65884 m
.59331 .66087 L
s
0 1 .794 r
.55295 1.01962 m
.55293 1.02883 L
s
.54569 1.02575 m
.55295 1.01962 L
s
0 1 .825 r
.26676 .7682 m
.27567 .73079 L
s
.589 1 0 r
.40379 .19294 m
.38577 .1905 L
s
.898 1 0 r
.30782 .19536 m
.31163 .19506 L
s
.042 1 0 r
.26191 .55883 m
.25781 .55976 L
s
.25815 .55336 m
.26191 .55883 L
s
.65465 .48002 m
.6536 .47863 L
s
.6536 .47863 m
.655 .47334 L
s
.6536 .47863 m
.64958 .47557 L
s
.25781 .55976 m
.25399 .55847 L
s
.25399 .55847 m
.25815 .55336 L
s
.519 1 0 r
.59331 .66087 m
.59011 .66362 L
s
0 1 .825 r
.27288 .73655 m
.27937 .73919 L
s
.26839 .73739 m
.27288 .73655 L
s
.27288 .73655 m
.27567 .73079 L
s
0 .731 1 r
.19739 .73068 m
.19606 .74148 L
s
.18851 .73779 m
.19739 .73068 L
s
.362 0 1 r
.21998 .91998 m
.21483 .92202 L
s
.2169 .9073 m
.21998 .91998 L
s
.778 1 0 r
.32354 .37465 m
.32473 .37529 L
s
.32088 .37682 m
.32354 .37465 L
s
.32354 .37465 m
.32089 .37342 L
s
.366 1 0 r
.60921 .84536 m
.60674 .84529 L
s
.60674 .84529 m
.60929 .84038 L
s
0 .731 1 r
.19606 .74148 m
.18851 .73779 L
s
.042 1 0 r
.655 .47334 m
.65606 .47471 L
s
.655 .47334 m
.64958 .47557 L
s
.366 1 0 r
.61246 .86313 m
.60929 .84038 L
s
.778 1 0 r
.32206 .37746 m
.32088 .37682 L
s
.32088 .37682 m
.32089 .37342 L
s
0 1 .753 r
.7496 .28744 m
.71285 .28902 L
s
.042 1 0 r
.25815 .55336 m
.25781 .55976 L
s
0 1 .248 r
.62782 1.02727 m
.63387 1.02925 L
s
.62687 1.02735 m
.62782 1.02727 L
s
.62782 1.02727 m
.63225 1.02219 L
s
.366 1 0 r
.60929 .84038 m
.60921 .84536 L
s
.60929 .84038 m
.6131 .84457 L
s
0 1 .794 r
.55293 1.02883 m
.54569 1.02575 L
s
.304 1 0 r
.34016 .57479 m
.33639 .55191 L
s
.366 1 0 r
.6131 .84457 m
.60921 .84536 L
s
0 1 .39 r
.64144 .29017 m
.64084 .29688 L
s
.63368 .29272 m
.64084 .29688 L
s
.63368 .29272 m
.64144 .29017 L
s
0 1 .248 r
.63387 1.02925 m
.63293 1.02933 L
s
.63225 1.02219 m
.63387 1.02925 L
s
.463 1 0 r
.67045 .66303 m
.6704 .66206 L
s
.6704 .66206 m
.67272 .65844 L
s
.6704 .66206 m
.66791 .65849 L
s
0 1 .825 r
.27937 .73919 m
.27489 .74003 L
s
.27567 .73079 m
.27937 .73919 L
s
.778 1 0 r
.32473 .37529 m
.32206 .37746 L
s
.32089 .37342 m
.32473 .37529 L
s
.463 1 0 r
.67272 .65844 m
.67278 .6594 L
s
.67272 .65844 m
.66791 .65849 L
s
.778 1 0 r
.32089 .37342 m
.32206 .37746 L
s
.042 1 0 r
.64958 .47557 m
.65465 .48002 L
s
.64958 .47557 m
.65606 .47471 L
s
.304 1 0 r
.33786 .55556 m
.34046 .55618 L
s
.33383 .55682 m
.33786 .55556 L
s
.33786 .55556 m
.33639 .55191 L
s
.463 1 0 r
.68629 .66968 m
.66791 .65849 L
s
.589 1 0 r
.38978 .1934 m
.38823 .19254 L
s
.38823 .19254 m
.38898 .18859 L
s
.38823 .19254 m
.38577 .1905 L
s
0 1 .753 r
.72138 .29333 m
.71882 .29184 L
s
.71882 .29184 m
.71906 .28408 L
s
.71882 .29184 m
.71285 .28902 L
s
0 1 .248 r
.63225 1.02219 m
.63293 1.02933 L
s
.62687 1.02735 m
.63225 1.02219 L
s
.62285 1.05276 m
.63225 1.02219 L
s
0 .177 1 r
.28928 .91553 m
.29858 .92019 L
s
.28496 .91701 m
.28928 .91553 L
s
.28928 .91553 m
.29564 .90886 L
s
.042 1 0 r
.65606 .47471 m
.65465 .48002 L
s
0 .177 1 r
.27638 .95747 m
.29564 .90886 L
s
.673 1 0 r
.41371 .38096 m
.3992 .37031 L
s
.589 1 0 r
.38898 .18859 m
.39053 .18944 L
s
.38898 .18859 m
.38577 .1905 L
s
.463 1 0 r
.66791 .65849 m
.67045 .66303 L
s
.66791 .65849 m
.67278 .6594 L
s
.636 1 0 r
.69204 .84428 m
.6921 .84419 L
s
.68852 .84592 m
.69204 .84428 L
s
.69204 .84428 m
.68867 .84155 L
s
.68857 .84583 m
.68852 .84592 L
s
.68852 .84592 m
.68867 .84155 L
s
.304 1 0 r
.33643 .55744 m
.33383 .55682 L
s
.33383 .55682 m
.33639 .55191 L
s
0 1 .753 r
.71906 .28408 m
.72162 .28555 L
s
.71906 .28408 m
.71285 .28902 L
s
0 1 .825 r
.27567 .73079 m
.27489 .74003 L
s
.26839 .73739 m
.27567 .73079 L
s
.362 0 1 r
.2169 .9073 m
.21483 .92202 L
s
.20442 .91623 m
.2169 .9073 L
s
0 1 .274 r
.73545 .47798 m
.7342 .47638 L
s
.7342 .47638 m
.73499 .4701 L
s
.7342 .47638 m
.72894 .4736 L
s
.76029 .47581 m
.72894 .4736 L
s
0 1 .825 r
.27489 .74003 m
.26839 .73739 L
s
.463 1 0 r
.67278 .6594 m
.67045 .66303 L
s
0 1 .248 r
.63293 1.02933 m
.62687 1.02735 L
s
0 .177 1 r
.29858 .92019 m
.29429 .92169 L
s
.29564 .90886 m
.29858 .92019 L
s
.589 1 0 r
.39053 .18944 m
.38978 .1934 L
s
.38577 .1905 m
.38978 .1934 L
s
0 1 .408 r
.35294 .73637 m
.35826 .73797 L
s
.34864 .73702 m
.35294 .73637 L
s
.35294 .73637 m
.35433 .7309 L
s
.304 1 0 r
.34046 .55618 m
.33643 .55744 L
s
.33639 .55191 m
.34046 .55618 L
s
.636 1 0 r
.68867 .84155 m
.68857 .84583 L
s
.68867 .84155 m
.6921 .84419 L
s
.69686 .8591 m
.68867 .84155 L
s
0 1 .408 r
.34995 .76385 m
.35433 .7309 L
s
.245 1 0 r
.48744 .1867 m
.46423 .18561 L
s
.589 1 0 r
.38577 .1905 m
.39053 .18944 L
s
.246 1 0 r
.70876 1.02954 m
.71368 1.03043 L
s
.70832 1.02894 m
.70876 1.02954 L
s
.70876 1.02954 m
.71188 1.02478 L
s
.304 1 0 r
.33639 .55191 m
.33643 .55744 L
s
.673 1 0 r
.40141 .37433 m
.40056 .37361 L
s
.40056 .37361 m
.40281 .37056 L
s
.40056 .37361 m
.3992 .37031 L
s
0 1 .274 r
.73499 .4701 m
.73624 .47169 L
s
.73499 .4701 m
.72894 .4736 L
s
.673 1 0 r
.40281 .37056 m
.40366 .37128 L
s
.40281 .37056 m
.3992 .37031 L
s
.362 0 1 r
.21483 .92202 m
.20442 .91623 L
s
.246 1 0 r
.71368 1.03043 m
.71325 1.02983 L
s
.71188 1.02478 m
.71368 1.03043 L
s
.266 1 0 r
.75145 .66249 m
.75148 .66111 L
s
.75148 .66111 m
.75291 .65655 L
s
.75148 .66111 m
.74747 .65815 L
s
0 .873 1 r
.83445 .2815 m
.79253 .28529 L
s
.636 1 0 r
.6921 .84419 m
.68857 .84583 L
s
.246 1 0 r
.71188 1.02478 m
.71325 1.02983 L
s
.70832 1.02894 m
.71188 1.02478 L
s
.70747 1.04935 m
.71188 1.02478 L
s
.474 1 0 r
.42368 .5698 m
.41507 .55046 L
s
0 1 .753 r
.71285 .28902 m
.72138 .29333 L
s
.71285 .28902 m
.72162 .28555 L
s
.266 1 0 r
.75291 .65655 m
.75288 .65792 L
s
.75291 .65655 m
.74747 .65815 L
s
0 1 .408 r
.35826 .73797 m
.35397 .73863 L
s
.35433 .7309 m
.35826 .73797 L
s
0 1 .753 r
.72162 .28555 m
.72138 .29333 L
s
1 .865 0 r
.15032 .28031 m
.14916 .26944 L
s
0 .703 1 r
.36942 .91685 m
.37763 .9204 L
s
.36582 .9178 m
.36942 .91685 L
s
.36942 .91685 m
.37472 .91042 L
s
0 1 .274 r
.72894 .4736 m
.73545 .47798 L
s
.72894 .4736 m
.73624 .47169 L
s
.673 1 0 r
.3992 .37031 m
.40141 .37433 L
s
.3992 .37031 m
.40366 .37128 L
s
.40366 .37128 m
.40141 .37433 L
s
.474 1 0 r
.41801 .55322 m
.41935 .55354 L
s
.41423 .55513 m
.41801 .55322 L
s
.41801 .55322 m
.41507 .55046 L
s
0 .873 1 r
.80247 .28976 m
.7995 .28816 L
s
.7995 .28816 m
.7994 .27932 L
s
.7995 .28816 m
.79253 .28529 L
s
.245 1 0 r
.46949 .18878 m
.46778 .18787 L
s
.46778 .18787 m
.46827 .18287 L
s
.46778 .18787 m
.46423 .18561 L
s
0 .177 1 r
.29564 .90886 m
.29429 .92169 L
s
.28496 .91701 m
.29564 .90886 L
s
.712 1 0 r
.76939 .84682 m
.77063 .84621 L
s
.77063 .84621 m
.77283 .84354 L
s
.77063 .84621 m
.76843 .84272 L
s
.266 1 0 r
.74747 .65815 m
.75145 .66249 L
s
.74747 .65815 m
.75288 .65792 L
s
.77103 .665 m
.74747 .65815 L
s
0 1 .274 r
.73624 .47169 m
.73545 .47798 L
s
.246 1 0 r
.71325 1.02983 m
.70832 1.02894 L
s
0 1 .408 r
.35397 .73863 m
.34864 .73702 L
s
.34864 .73702 m
.35433 .7309 L
s
.35433 .7309 m
.35397 .73863 L
s
.474 1 0 r
.41557 .55545 m
.41423 .55513 L
s
.41423 .55513 m
.41507 .55046 L
s
0 .703 1 r
.35979 .95375 m
.37472 .91042 L
s
.46 1 0 r
.49758 .37532 m
.47798 .36718 L
s
.245 1 0 r
.46827 .18287 m
.46999 .18378 L
s
.46827 .18287 m
.46423 .18561 L
s
.712 1 0 r
.77283 .84354 m
.77158 .84415 L
s
.77283 .84354 m
.76843 .84272 L
s
.76843 .84272 m
.76939 .84682 L
s
.76843 .84272 m
.77158 .84415 L
s
.78182 .85504 m
.76843 .84272 L
s
0 1 .626 r
.81677 .47595 m
.81524 .47413 L
s
.81524 .47413 m
.81543 .46683 L
s
.81524 .47413 m
.80877 .47161 L
s
.266 1 0 r
.75288 .65792 m
.75145 .66249 L
s
0 .703 1 r
.37763 .9204 m
.37405 .92136 L
s
.37472 .91042 m
.37763 .9204 L
s
0 .177 1 r
.29429 .92169 m
.28496 .91701 L
s
0 .873 1 r
.7994 .27932 m
.80237 .2809 L
s
.7994 .27932 m
.79253 .28529 L
s
.631 1 0 r
.79213 1.03201 m
.79479 1.03096 L
s
.78923 1.03119 m
.79213 1.03201 L
s
.79185 1.02738 m
.79213 1.03201 L
s
0 1 .033 r
.43365 .73605 m
.43756 .73669 L
s
.42932 .73672 m
.43365 .73605 L
s
.43365 .73605 m
.43338 .731 L
s
.631 1 0 r
.79189 1.03014 m
.79185 1.02738 L
s
.79185 1.02738 m
.78923 1.03119 L
s
.79479 1.03096 m
.79185 1.02738 L
s
.79266 1.04591 m
.79185 1.02738 L
s
.474 1 0 r
.41507 .55046 m
.41557 .55545 L
s
.41507 .55046 m
.41935 .55354 L
s
0 1 .626 r
.84537 .47048 m
.80877 .47161 L
s
1 .865 0 r
.14961 .27078 m
.15115 .2716 L
s
.14765 .27163 m
.14961 .27078 L
s
.14961 .27078 m
.14916 .26944 L
s
.712 1 0 r
.77158 .84415 m
.76939 .84682 L
s
.474 1 0 r
.41935 .55354 m
.41557 .55545 L
s
.46 1 0 r
.4814 .37127 m
.48064 .37037 L
s
.48064 .37037 m
.48242 .36635 L
s
.48064 .37037 m
.47798 .36718 L
s
0 1 .626 r
.81543 .46683 m
.81696 .46863 L
s
.81543 .46683 m
.80877 .47161 L
s
0 1 .033 r
.4337 .75948 m
.43338 .731 L
s
.245 1 0 r
.46999 .18378 m
.46949 .18878 L
s
.46423 .18561 m
.46949 .18878 L
s
0 1 .116 r
.57164 .18041 m
.54321 .18068 L
s
0 1 .033 r
.83299 .66194 m
.83291 .66018 L
s
.83291 .66018 m
.83346 .65465 L
s
.83291 .66018 m
.82745 .6578 L
s
.245 1 0 r
.46423 .18561 m
.46999 .18378 L
s
.46 1 0 r
.48242 .36635 m
.48319 .36725 L
s
.48242 .36635 m
.47798 .36718 L
s
.631 1 0 r
.79189 1.03014 m
.78923 1.03119 L
s
1 .865 0 r
.14918 .27245 m
.14765 .27163 L
s
.14765 .27163 m
.14916 .26944 L
s
.15115 .2716 m
.14918 .27245 L
s
.14916 .26944 m
.15115 .2716 L
s
.322 1 0 r
.15974 .46941 m
.16215 .44655 L
s
.631 1 0 r
.79479 1.03096 m
.79189 1.03014 L
s
0 1 .033 r
.83346 .65465 m
.83354 .6564 L
s
.83346 .65465 m
.82745 .6578 L
s
0 .703 1 r
.37472 .91042 m
.37405 .92136 L
s
.36582 .9178 m
.37472 .91042 L
s
1 .865 0 r
.14916 .26944 m
.14918 .27245 L
s
0 .491 1 r
.91987 .27552 m
.87272 .28155 L
s
0 1 .79 r
.45006 .91819 m
.45715 .9206 L
s
.44698 .9186 m
.45006 .91819 L
s
.45006 .91819 m
.45415 .912 L
s
0 1 .033 r
.43323 .73736 m
.42932 .73672 L
s
.42932 .73672 m
.43338 .731 L
s
.43756 .73669 m
.43323 .73736 L
s
.43338 .731 m
.43756 .73669 L
s
.563 1 0 r
.85115 .84781 m
.85259 .84645 L
s
.85259 .84645 m
.85349 .84281 L
s
.85259 .84645 m
.84857 .84391 L
s
0 .873 1 r
.79253 .28529 m
.80247 .28976 L
s
.79253 .28529 m
.80237 .2809 L
s
0 1 .626 r
.80877 .47161 m
.81677 .47595 L
s
.80877 .47161 m
.81696 .46863 L
s
.519 1 0 r
.50777 .56478 m
.49418 .549 L
s
0 1 .033 r
.82745 .6578 m
.83299 .66194 L
s
.82745 .6578 m
.83354 .6564 L
s
.85633 .66029 m
.82745 .6578 L
s
.43338 .731 m
.43323 .73736 L
s
.46 1 0 r
.47798 .36718 m
.4814 .37127 L
s
.47798 .36718 m
.48319 .36725 L
s
.322 1 0 r
.16166 .45023 m
.16509 .45149 L
s
.15825 .45077 m
.16166 .45023 L
s
.16166 .45023 m
.16215 .44655 L
s
0 .491 1 r
.88412 .28617 m
.88067 .28445 L
s
.88067 .28445 m
.88024 .27452 L
s
.88067 .28445 m
.87272 .28155 L
s
0 .873 1 r
.80237 .2809 m
.80247 .28976 L
s
.46 1 0 r
.48319 .36725 m
.4814 .37127 L
s
.519 1 0 r
.4983 .55055 m
.49871 .55099 L
s
.49509 .55332 m
.4983 .55055 L
s
.4983 .55055 m
.49418 .549 L
s
.49549 .55377 m
.49509 .55332 L
s
.49509 .55332 m
.49418 .549 L
s
.563 1 0 r
.84857 .84391 m
.85115 .84781 L
s
.85349 .84281 m
.84857 .84391 L
s
.84857 .84391 m
.85205 .84417 L
s
.86735 .85095 m
.84857 .84391 L
s
0 .703 1 r
.37405 .92136 m
.36582 .9178 L
s
1 .841 0 r
.23353 .27432 m
.22728 .26514 L
s
0 1 .116 r
.54975 .18416 m
.54782 .18317 L
s
.54782 .18317 m
.54808 .1771 L
s
.54782 .18317 m
.54321 .18068 L
s
.563 1 0 r
.85349 .84281 m
.85205 .84417 L
s
.8 1 0 r
.87215 1.02999 m
.87194 1.0341 L
s
.87485 1.03084 m
.87215 1.02999 L
s
.87215 1.02999 m
.87163 1.03197 L
s
.87516 1.03298 m
.87215 1.02999 L
s
.87841 1.04245 m
.87215 1.02999 L
s
0 1 .626 r
.81696 .46863 m
.81677 .47595 L
s
0 1 .79 r
.45715 .9206 m
.45409 .92102 L
s
.45415 .912 m
.45715 .9206 L
s
0 .999 1 r
.89861 .4739 m
.89674 .47188 L
s
.89674 .47188 m
.89632 .46354 L
s
.89674 .47188 m
.88907 .46961 L
s
0 1 .033 r
.83354 .6564 m
.83299 .66194 L
s
0 1 .116 r
.54808 .1771 m
.55001 .17808 L
s
.54808 .1771 m
.54321 .18068 L
s
.8 1 0 r
.87194 1.0341 m
.87516 1.03298 L
s
.87516 1.03298 m
.87485 1.03084 L
s
0 1 .79 r
.44376 .94999 m
.45415 .912 L
s
.322 1 0 r
.16509 .45149 m
.16168 .45203 L
s
.16215 .44655 m
.16509 .45149 L
s
.176 1 0 r
.582 .36964 m
.55725 .36403 L
s
.8 1 0 r
.87163 1.03197 m
.87194 1.0341 L
s
.563 1 0 r
.85205 .84417 m
.85115 .84781 L
s
.272 1 0 r
.51505 .73538 m
.51707 .73531 L
s
.51064 .7365 m
.51505 .73538 L
s
.51505 .73538 m
.51282 .73111 L
s
.519 1 0 r
.49418 .549 m
.49549 .55377 L
s
.49418 .549 m
.49871 .55099 L
s
0 .491 1 r
.88024 .27452 m
.88369 .27621 L
s
.88024 .27452 m
.87272 .28155 L
s
0 1 .609 r
.16919 .65935 m
.17758 .62432 L
s
0 1 .395 r
.91503 .6614 m
.91475 .65928 L
s
.91475 .65928 m
.91442 .65275 L
s
.91475 .65928 m
.90786 .65745 L
s
.322 1 0 r
.16168 .45203 m
.15825 .45077 L
s
.15825 .45077 m
.16215 .44655 L
s
.176 1 0 r
.56196 .36821 m
.56113 .36712 L
s
.56113 .36712 m
.56245 .3621 L
s
.56113 .36712 m
.55725 .36403 L
s
0 .999 1 r
.89632 .46354 m
.8982 .46554 L
s
.89632 .46354 m
.88907 .46961 L
s
0 1 .79 r
.45415 .912 m
.45409 .92102 L
s
.44698 .9186 m
.45415 .912 L
s
.519 1 0 r
.49871 .55099 m
.49549 .55377 L
s
1 .841 0 r
.22898 .26598 m
.22994 .26649 L
s
.22713 .26747 m
.22898 .26598 L
s
.22898 .26598 m
.22728 .26514 L
s
0 1 .609 r
.1751 .62987 m
.18106 .63227 L
s
.17074 .6304 m
.1751 .62987 L
s
.1751 .62987 m
.17758 .62432 L
s
.322 1 0 r
.16215 .44655 m
.16168 .45203 L
s
.8 1 0 r
.87485 1.03084 m
.87163 1.03197 L
s
0 .999 1 r
.93101 .46511 m
.88907 .46961 L
s
1 .841 0 r
.22809 .26798 m
.22713 .26747 L
s
.22713 .26747 m
.22728 .26514 L
s
.272 1 0 r
.51266 .73644 m
.51064 .7365 L
s
.51064 .7365 m
.51282 .73111 L
s
.176 1 0 r
.56245 .3621 m
.56328 .36319 L
s
.56245 .3621 m
.55725 .36403 L
s
0 1 .395 r
.91442 .65275 m
.9147 .65484 L
s
.91442 .65275 m
.90786 .65745 L
s
.272 1 0 r
.518 .75507 m
.51282 .73111 L
s
0 1 .488 r
.6564 .17408 m
.62273 .17572 L
s
.246 1 0 r
.93341 .84876 m
.93476 .84678 L
s
.93476 .84678 m
.93449 .84213 L
s
.93476 .84678 m
.9291 .84509 L
s
0 1 .116 r
.55001 .17808 m
.54975 .18416 L
s
.54321 .18068 m
.54975 .18416 L
s
.54321 .18068 m
.55001 .17808 L
s
0 1 .316 r
.53129 .91952 m
.53718 .92075 L
s
.5284 .91945 m
.53129 .91952 L
s
.53129 .91952 m
.53392 .91358 L
s
0 1 .79 r
.45409 .92102 m
.44698 .9186 L
s
1 .841 0 r
.22994 .26649 m
.22809 .26798 L
s
.22728 .26514 m
.22994 .26649 L
s
.548 1 0 r
.24316 .46404 m
.24072 .44396 L
s
.272 1 0 r
.51282 .73111 m
.51266 .73644 L
s
.51282 .73111 m
.51707 .73531 L
s
.246 1 0 r
.9291 .84509 m
.93341 .84876 L
s
.93449 .84213 m
.9291 .84509 L
s
.9291 .84509 m
.93315 .8441 L
s
.95344 .84683 m
.9291 .84509 L
s
.667 1 0 r
.95278 1.03261 m
.95419 1.03641 L
s
.95613 1.03135 m
.95278 1.03261 L
s
.95278 1.03261 m
.95324 1.03331 L
s
.95708 1.03444 m
.95278 1.03261 L
s
.96473 1.03896 m
.95278 1.03261 L
s
1 .841 0 r
.22728 .26514 m
.22809 .26798 L
s
0 1 .395 r
.90786 .65745 m
.91503 .6614 L
s
.90786 .65745 m
.9147 .65484 L
s
.9422 .65555 m
.90786 .65745 L
s
.246 1 0 r
.93449 .84213 m
.93315 .8441 L
s
.272 1 0 r
.51707 .73531 m
.51266 .73644 L
s
0 .999 1 r
.88907 .46961 m
.89861 .4739 L
s
.88907 .46961 m
.8982 .46554 L
s
.427 1 0 r
.57619 .55222 m
.57624 .55143 L
s
.57624 .55143 m
.57873 .54772 L
s
.57624 .55143 m
.57372 .54753 L
s
0 1 .609 r
.18106 .63227 m
.17671 .63281 L
s
.17758 .62432 m
.18106 .63227 L
s
.176 1 0 r
.55725 .36403 m
.56196 .36821 L
s
.55725 .36403 m
.56328 .36319 L
s
0 .491 1 r
.87272 .28155 m
.88412 .28617 L
s
.87272 .28155 m
.88369 .27621 L
s
.548 1 0 r
.24178 .44729 m
.24411 .44779 L
s
.23831 .44817 m
.24178 .44729 L
s
.24178 .44729 m
.24072 .44396 L
s
.427 1 0 r
.57873 .54772 m
.57868 .5485 L
s
.57873 .54772 m
.57372 .54753 L
s
.59241 .55972 m
.57372 .54753 L
s
.667 1 0 r
.95419 1.03641 m
.95708 1.03444 L
s
.95708 1.03444 m
.95613 1.03135 L
s
0 1 .488 r
.63057 .17951 m
.62835 .17844 L
s
.62835 .17844 m
.62839 .17127 L
s
.62835 .17844 m
.62273 .17572 L
s
.176 1 0 r
.56328 .36319 m
.56196 .36821 L
s
0 1 .316 r
.53718 .92075 m
.53431 .92069 L
s
.53392 .91358 m
.53718 .92075 L
s
0 .366 1 r
.19015 .80967 m
.1989 .81384 L
s
.18531 .81072 m
.19015 .80967 L
s
.19015 .80967 m
.19548 .80279 L
s
.17869 .85013 m
.19548 .80279 L
s
0 .491 1 r
.88369 .27621 m
.88412 .28617 L
s
1 .991 0 r
.31728 .2683 m
.30589 .26081 L
s
0 .999 1 r
.8982 .46554 m
.89861 .4739 L
s
.667 1 0 r
.95324 1.03331 m
.95419 1.03641 L
s
0 1 .395 r
.9147 .65484 m
.91503 .6614 L
s
.667 1 0 r
.95613 1.03135 m
.95324 1.03331 L
s
.246 1 0 r
.93315 .8441 m
.93341 .84876 L
s
0 1 .316 r
.53392 .91358 m
.53431 .92069 L
s
.5284 .91945 m
.53392 .91358 L
s
.52828 .94621 m
.53392 .91358 L
s
.427 1 0 r
.57372 .54753 m
.57619 .55222 L
s
.57372 .54753 m
.57868 .5485 L
s
.548 1 0 r
.24064 .44867 m
.23831 .44817 L
s
.23831 .44817 m
.24072 .44396 L
s
0 1 .609 r
.17758 .62432 m
.17671 .63281 L
s
.17074 .6304 m
.17758 .62432 L
s
0 1 .488 r
.62839 .17127 m
.63061 .17233 L
s
.62839 .17127 m
.62273 .17572 L
s
0 1 .609 r
.17671 .63281 m
.17074 .6304 L
s
.463 1 0 r
.59665 .73411 m
.59666 .73403 L
s
.59273 .73617 m
.59665 .73411 L
s
.59665 .73411 m
.59265 .73122 L
s
.59274 .73609 m
.59273 .73617 L
s
.59273 .73617 m
.59265 .73122 L
s
.548 1 0 r
.24411 .44779 m
.24064 .44867 L
s
.24072 .44396 m
.24411 .44779 L
s
0 1 .151 r
.66699 .36393 m
.63699 .36086 L
s
.64307 .36515 m
.64208 .36386 L
s
.64208 .36386 m
.64293 .35781 L
s
.64208 .36386 m
.63699 .36086 L
s
.427 1 0 r
.57868 .5485 m
.57619 .55222 L
s
0 1 .316 r
.53431 .92069 m
.5284 .91945 L
s
.548 1 0 r
.24072 .44396 m
.24064 .44867 L
s
0 1 .248 r
.25555 .6287 m
.26042 .63006 L
s
.25128 .62913 m
.25555 .6287 L
s
.25555 .6287 m
.25661 .62333 L
s
.25283 .6546 m
.25661 .62333 L
s
0 .366 1 r
.1989 .81384 m
.19409 .81491 L
s
.19548 .80279 m
.1989 .81384 L
s
1 .991 0 r
.30773 .26377 m
.30705 .26325 L
s
.30705 .26325 m
.30862 .26085 L
s
.30705 .26325 m
.30589 .26081 L
s
.30862 .26085 m
.30929 .26138 L
s
.30862 .26085 m
.30589 .26081 L
s
.463 1 0 r
.59265 .73122 m
.59274 .73609 L
s
.59265 .73122 m
.59666 .73403 L
s
.60286 .75064 m
.59265 .73122 L
s
.102 1 0 r
.6135 .92081 m
.61776 .92074 L
s
.61006 .92048 m
.6135 .92081 L
s
.6135 .92081 m
.61405 .91517 L
s
0 1 .151 r
.64293 .35781 m
.64392 .35908 L
s
.64293 .35781 m
.63699 .36086 L
s
.761 0 1 r
.20697 .98966 m
.21863 .99611 L
s
.20198 .9919 m
.20697 .98966 L
s
.20697 .98966 m
.21586 .98204 L
s
0 1 .865 r
.74173 .1677 m
.70277 .17073 L
s
.22 1 0 r
.65753 .55069 m
.6577 .54953 L
s
.6577 .54953 m
.65945 .54484 L
s
.6577 .54953 m
.65371 .54605 L
s
0 1 .488 r
.62273 .17572 m
.63057 .17951 L
s
.62273 .17572 m
.63061 .17233 L
s
.63061 .17233 m
.63057 .17951 L
s
1 .991 0 r
.30929 .26138 m
.30773 .26377 L
s
.30589 .26081 m
.30773 .26377 L
s
.761 0 1 r
.18823 1.04175 m
.21586 .98204 L
s
1 .991 0 r
.30589 .26081 m
.30929 .26138 L
s
.673 1 0 r
.32713 .45863 m
.31974 .44135 L
s
.463 1 0 r
.59666 .73403 m
.59274 .73609 L
s
0 1 .248 r
.26042 .63006 m
.25616 .6305 L
s
.25661 .62333 m
.26042 .63006 L
s
.102 1 0 r
.61405 .91517 m
.61433 .92041 L
s
.61405 .91517 m
.61776 .92074 L
s
.61006 .92048 m
.61405 .91517 L
s
.61337 .94241 m
.61405 .91517 L
s
.22 1 0 r
.65945 .54484 m
.65928 .546 L
s
.65945 .54484 m
.65371 .54605 L
s
0 1 .151 r
.63699 .36086 m
.64307 .36515 L
s
.63699 .36086 m
.64392 .35908 L
s
.102 1 0 r
.61776 .92074 m
.61433 .92041 L
s
.673 1 0 r
.32234 .44395 m
.32346 .44409 L
s
.31898 .44553 m
.32234 .44395 L
s
.32234 .44395 m
.31974 .44135 L
s
0 .833 1 r
.27075 .81004 m
.27849 .8131 L
s
.26646 .81066 m
.27075 .81004 L
s
.27075 .81004 m
.27497 .80333 L
s
0 1 .865 r
.71194 .17485 m
.70937 .17368 L
s
.70937 .17368 m
.70923 .1654 L
s
.70937 .17368 m
.70277 .17073 L
s
.761 0 1 r
.21863 .99611 m
.21369 .99839 L
s
.21586 .98204 m
.21863 .99611 L
s
.102 1 0 r
.61433 .92041 m
.61006 .92048 L
s
0 .366 1 r
.19548 .80279 m
.19409 .81491 L
s
.18531 .81072 m
.19548 .80279 L
s
0 1 .151 r
.64392 .35908 m
.64307 .36515 L
s
.22 1 0 r
.67762 .55463 m
.65371 .54605 L
s
0 1 .248 r
.25616 .6305 m
.25128 .62913 L
s
.25128 .62913 m
.25661 .62333 L
s
.25661 .62333 m
.25616 .6305 L
s
.673 1 0 r
.3201 .44567 m
.31898 .44553 L
s
.31898 .44553 m
.31974 .44135 L
s
.22 1 0 r
.65371 .54605 m
.65753 .55069 L
s
.65371 .54605 m
.65928 .546 L
s
.498 1 0 r
.67399 .7361 m
.67512 .73559 L
s
.67512 .73559 m
.67793 .73249 L
s
.67512 .73559 m
.67288 .73133 L
s
0 .833 1 r
.26254 .84601 m
.27497 .80333 L
s
.747 1 0 r
.4016 .26223 m
.38499 .25646 L
s
0 .366 1 r
.19409 .81491 m
.18531 .81072 L
s
.498 1 0 r
.67793 .73249 m
.6768 .733 L
s
.67793 .73249 m
.67288 .73133 L
s
0 1 .504 r
.72471 .36207 m
.72349 .3606 L
s
.72349 .3606 m
.72388 .35349 L
s
.72349 .3606 m
.71722 .35767 L
s
0 1 .865 r
.70923 .1654 m
.7118 .16655 L
s
.70923 .1654 m
.70277 .17073 L
s
.22 1 0 r
.65928 .546 m
.65753 .55069 L
s
.498 1 0 r
.67288 .73133 m
.67399 .7361 L
s
.67288 .73133 m
.6768 .733 L
s
.6883 .74618 m
.67288 .73133 L
s
.673 1 0 r
.31974 .44135 m
.3201 .44567 L
s
.31974 .44135 m
.32346 .44409 L
s
0 .833 1 r
.27849 .8131 m
.27423 .81372 L
s
.27497 .80333 m
.27849 .8131 L
s
.064 1 0 r
.3367 .62735 m
.34019 .62776 L
s
.3323 .62793 m
.3367 .62735 L
s
.3367 .62735 m
.33605 .62235 L
s
.673 1 0 r
.32346 .44409 m
.3201 .44567 L
s
0 1 .504 r
.75254 .35818 m
.71722 .35767 L
s
.747 1 0 r
.388 .25964 m
.3874 .25899 L
s
.3874 .25899 m
.38864 .25559 L
s
.3874 .25899 m
.38499 .25646 L
s
.418 1 0 r
.69305 .92108 m
.69331 .92207 L
s
.69331 .92207 m
.69779 .92115 L
s
.69331 .92207 m
.69453 .91676 L
s
.064 1 0 r
.33702 .64982 m
.33605 .62235 L
s
0 1 .504 r
.72388 .35349 m
.72511 .35494 L
s
.72388 .35349 m
.71722 .35767 L
s
.418 1 0 r
.69779 .92115 m
.69754 .92016 L
s
.69779 .92115 m
.69453 .91676 L
s
.207 0 1 r
.28776 .99141 m
.29833 .99673 L
s
.28387 .993 m
.28776 .99141 L
s
.28776 .99141 m
.29582 .984 L
s
.747 1 0 r
.38864 .25559 m
.38924 .25624 L
s
.38864 .25559 m
.38499 .25646 L
s
0 1 .067 r
.73943 .54916 m
.73953 .54764 L
s
.73953 .54764 m
.74055 .54194 L
s
.73953 .54764 m
.73414 .54456 L
s
.418 1 0 r
.69453 .91676 m
.69305 .92108 L
s
.69453 .91676 m
.69754 .92016 L
s
.69903 .93858 m
.69453 .91676 L
s
.498 1 0 r
.6768 .733 m
.67399 .7361 L
s
0 .753 1 r
.82763 .16129 m
.78335 .1657 L
s
0 .833 1 r
.27497 .80333 m
.27423 .81372 L
s
.26646 .81066 m
.27497 .80333 L
s
0 1 .067 r
.74055 .54194 m
.74044 .54345 L
s
.74055 .54194 m
.73414 .54456 L
s
.747 1 0 r
.38499 .25646 m
.388 .25964 L
s
.38499 .25646 m
.38924 .25624 L
s
.064 1 0 r
.33579 .62835 m
.3323 .62793 L
s
.3323 .62793 m
.33605 .62235 L
s
0 1 .865 r
.70277 .17073 m
.71194 .17485 L
s
.70277 .17073 m
.7118 .16655 L
s
.207 0 1 r
.29833 .99673 m
.29449 .99834 L
s
.29582 .984 m
.29833 .99673 L
s
.747 1 0 r
.38924 .25624 m
.388 .25964 L
s
0 1 .725 r
.35192 .81041 m
.35857 .81232 L
s
.34794 .81062 m
.35192 .81041 L
s
.35192 .81041 m
.35483 .80387 L
s
.064 1 0 r
.34019 .62776 m
.33579 .62835 L
s
.33605 .62235 m
.34019 .62776 L
s
.761 0 1 r
.21586 .98204 m
.21369 .99839 L
s
.20198 .9919 m
.21586 .98204 L
s
.207 0 1 r
.2723 1.03827 m
.29582 .984 L
s
.667 1 0 r
.41167 .45319 m
.39921 .43872 L
s
0 1 .504 r
.71722 .35767 m
.72471 .36207 L
s
.71722 .35767 m
.72511 .35494 L
s
0 1 .865 r
.7118 .16655 m
.71194 .17485 L
s
.064 1 0 r
.33605 .62235 m
.33579 .62835 L
s
.366 1 0 r
.7561 .73612 m
.75754 .73494 L
s
.75754 .73494 m
.75923 .73085 L
s
.75754 .73494 m
.75351 .73144 L
s
0 .833 1 r
.27423 .81372 m
.26646 .81066 L
s
.667 1 0 r
.40305 .44024 m
.40329 .44048 L
s
.40013 .44276 m
.40305 .44024 L
s
.40305 .44024 m
.39921 .43872 L
s
.40036 .44301 m
.40013 .44276 L
s
.40013 .44276 m
.39921 .43872 L
s
1 .385 0 r
.13485 .16 m
.13345 .15661 L
s
0 .753 1 r
.79388 .17016 m
.7909 .16889 L
s
.7909 .16889 m
.79058 .15948 L
s
.7909 .16889 m
.78335 .1657 L
s
0 1 .067 r
.73414 .54456 m
.73943 .54916 L
s
.73414 .54456 m
.74044 .54345 L
s
.7634 .5495 m
.73414 .54456 L
s
.418 1 0 r
.69754 .92016 m
.69305 .92108 L
s
0 1 .504 r
.72511 .35494 m
.72471 .36207 L
s
.366 1 0 r
.75923 .73085 m
.75778 .73203 L
s
.75923 .73085 m
.75351 .73144 L
s
.75351 .73144 m
.7561 .73612 L
s
.75351 .73144 m
.75778 .73203 L
s
.77431 .74168 m
.75351 .73144 L
s
0 1 .873 r
.80689 .35898 m
.80536 .35732 L
s
.80536 .35732 m
.80532 .34913 L
s
.80536 .35732 m
.79795 .35447 L
s
0 1 .725 r
.34696 .84186 m
.35483 .80387 L
s
.427 1 0 r
.48649 .25612 m
.4646 .25208 L
s
0 1 .725 r
.35857 .81232 m
.3546 .81254 L
s
.35483 .80387 m
.35857 .81232 L
s
.563 1 0 r
.77479 .92311 m
.77787 .92269 L
s
.77787 .92269 m
.77988 .92014 L
s
.77787 .92269 m
.77536 .91836 L
s
0 1 .067 r
.74044 .54345 m
.73943 .54916 L
s
.667 1 0 r
.39921 .43872 m
.40036 .44301 L
s
.39921 .43872 m
.40329 .44048 L
s
.761 0 1 r
.21369 .99839 m
.20198 .9919 L
s
.563 1 0 r
.77536 .91836 m
.77479 .92311 L
s
.77988 .92014 m
.77536 .91836 L
s
.77536 .91836 m
.7768 .92056 L
s
.78526 .93473 m
.77536 .91836 L
s
0 .753 1 r
.79058 .15948 m
.79357 .16072 L
s
.79058 .15948 m
.78335 .1657 L
s
.301 1 0 r
.41847 .6256 m
.42016 .62539 L
s
.41399 .62679 m
.41847 .6256 L
s
.41847 .6256 m
.4159 .62136 L
s
0 .333 1 r
.36896 .99317 m
.37847 .99735 L
s
.36607 .9941 m
.36896 .99317 L
s
.36896 .99317 m
.37611 .98597 L
s
.427 1 0 r
.46885 .25552 m
.46821 .25472 L
s
.46821 .25472 m
.46911 .25027 L
s
.46821 .25472 m
.4646 .25208 L
s
1 .385 0 r
.13379 .15665 m
.1345 .15723 L
s
.13296 .15735 m
.13379 .15665 L
s
.13379 .15665 m
.13345 .15661 L
s
.667 1 0 r
.40329 .44048 m
.40036 .44301 L
s
.366 1 0 r
.75778 .73203 m
.7561 .73612 L
s
1 .385 0 r
.13368 .15792 m
.13296 .15735 L
s
.13296 .15735 m
.13345 .15661 L
s
0 1 .407 r
.82184 .54761 m
.82177 .54576 L
s
.82177 .54576 m
.82208 .53903 L
s
.82177 .54576 m
.81501 .54306 L
s
1 .385 0 r
.1345 .15723 m
.13368 .15792 L
s
.13345 .15661 m
.1345 .15723 L
s
0 1 .873 r
.80532 .34913 m
.80684 .35076 L
s
.80532 .34913 m
.79795 .35447 L
s
1 .385 0 r
.13345 .15661 m
.13368 .15792 L
s
0 1 .873 r
.83867 .35239 m
.79795 .35447 L
s
.207 0 1 r
.29582 .984 m
.29449 .99834 L
s
.28387 .993 m
.29582 .984 L
s
0 1 .725 r
.35483 .80387 m
.3546 .81254 L
s
.34794 .81062 m
.35483 .80387 L
s
.427 1 0 r
.46911 .25027 m
.46976 .25106 L
s
.46911 .25027 m
.4646 .25208 L
s
.563 1 0 r
.77988 .92014 m
.7768 .92056 L
s
.301 1 0 r
.41568 .62658 m
.41399 .62679 L
s
.41399 .62679 m
.4159 .62136 L
s
.563 1 0 r
.7768 .92056 m
.77479 .92311 L
s
.301 1 0 r
.42178 .64501 m
.4159 .62136 L
s
0 .333 1 r
.37847 .99735 m
.37561 .9983 L
s
.37611 .98597 m
.37847 .99735 L
s
0 1 .725 r
.3546 .81254 m
.34794 .81062 L
s
0 1 .407 r
.82208 .53903 m
.82214 .54087 L
s
.82208 .53903 m
.81501 .54306 L
s
.898 1 0 r
.14435 .35123 m
.14475 .33568 L
s
0 1 .32 r
.4338 .81073 m
.43915 .81145 L
s
.42973 .81068 m
.4338 .81073 L
s
.4338 .81073 m
.43506 .80441 L
s
.102 1 0 r
.83876 .73611 m
.84019 .73433 L
s
.84019 .73433 m
.84085 .72923 L
s
.84019 .73433 m
.83454 .73155 L
s
.301 1 0 r
.4159 .62136 m
.41568 .62658 L
s
.4159 .62136 m
.42016 .62539 L
s
.427 1 0 r
.4646 .25208 m
.46885 .25552 L
s
.4646 .25208 m
.46976 .25106 L
s
.532 1 0 r
.48141 .44046 m
.4816 .43989 L
s
.4816 .43989 m
.48393 .43637 L
s
.4816 .43989 m
.47914 .43609 L
s
0 .369 1 r
.91411 .15483 m
.86447 .16064 L
s
.301 1 0 r
.42016 .62539 m
.41568 .62658 L
s
0 1 .873 r
.79795 .35447 m
.80689 .35898 L
s
.79795 .35447 m
.80684 .35076 L
s
.427 1 0 r
.46976 .25106 m
.46885 .25552 L
s
0 1 .407 r
.81501 .54306 m
.82184 .54761 L
s
.81501 .54306 m
.82214 .54087 L
s
.84976 .54434 m
.81501 .54306 L
s
.898 1 0 r
.14484 .33833 m
.14696 .33892 L
s
.14239 .33867 m
.14484 .33833 L
s
.14484 .33833 m
.14475 .33568 L
s
0 .753 1 r
.78335 .1657 m
.79388 .17016 L
s
.78335 .1657 m
.79357 .16072 L
s
.207 0 1 r
.29449 .99834 m
.28387 .993 L
s
.102 1 0 r
.83454 .73155 m
.83876 .73611 L
s
.84085 .72923 m
.83454 .73155 L
s
.83454 .73155 m
.83941 .731 L
s
.86089 .73716 m
.83454 .73155 L
s
.532 1 0 r
.48393 .43637 m
.48375 .43693 L
s
.48393 .43637 m
.47914 .43609 L
s
0 .333 1 r
.35694 1.03475 m
.37611 .98597 L
s
.102 1 0 r
.84085 .72923 m
.83941 .731 L
s
.532 1 0 r
.49678 .44771 m
.47914 .43609 L
s
0 .369 1 r
.8764 .16543 m
.87293 .16407 L
s
.87293 .16407 m
.87246 .15353 L
s
.87293 .16407 m
.86447 .16064 L
s
.487 1 0 r
.85655 .91997 m
.85783 .92466 L
s
.86146 .91961 m
.85655 .91997 L
s
.85655 .91997 m
.85838 .92112 L
s
.86091 .92315 m
.85655 .91997 L
s
.87208 .93084 m
.85655 .91997 L
s
0 .753 1 r
.79357 .16072 m
.79388 .17016 L
s
.487 1 0 r
.85783 .92466 m
.86091 .92315 L
s
.86091 .92315 m
.86146 .91961 L
s
1 .546 0 r
.21906 .15354 m
.21234 .15103 L
s
0 .747 1 r
.8896 .35586 m
.88771 .35403 L
s
.88771 .35403 m
.88724 .34476 L
s
.88771 .35403 m
.87917 .35124 L
s
.898 1 0 r
.14696 .33892 m
.14451 .33926 L
s
.14475 .33568 m
.14696 .33892 L
s
0 1 .873 r
.80684 .35076 m
.80689 .35898 L
s
0 .333 1 r
.37611 .98597 m
.37561 .9983 L
s
.36607 .9941 m
.37611 .98597 L
s
0 1 .32 r
.43915 .81145 m
.43508 .81141 L
s
.43506 .80441 m
.43915 .81145 L
s
.898 1 0 r
.14451 .33926 m
.14239 .33867 L
s
.14239 .33867 m
.14475 .33568 L
s
.532 1 0 r
.47914 .43609 m
.48141 .44046 L
s
.47914 .43609 m
.48375 .43693 L
s
0 .849 1 r
.4506 .99494 m
.45904 .99799 L
s
.44857 .9952 m
.4506 .99494 L
s
.4506 .99494 m
.45673 .98795 L
s
0 1 .407 r
.82214 .54087 m
.82184 .54761 L
s
0 1 .32 r
.43506 .80441 m
.43508 .81141 L
s
.42973 .81068 m
.43506 .80441 L
s
.43194 .83768 m
.43506 .80441 L
s
.898 1 0 r
.14475 .33568 m
.14451 .33926 L
s
0 1 .78 r
.90475 .54605 m
.90445 .5439 L
s
.90445 .5439 m
.90405 .53612 L
s
.90445 .5439 m
.89634 .54156 L
s
.102 1 0 r
.83941 .731 m
.83876 .73611 L
s
.487 1 0 r
.86146 .91961 m
.85838 .92112 L
s
.078 1 0 r
.57194 .24997 m
.5447 .24768 L
s
.427 1 0 r
.5004 .6233 m
.5003 .62312 L
s
.4964 .62552 m
.5004 .6233 L
s
.5004 .6233 m
.49616 .62036 L
s
.4963 .62534 m
.4964 .62552 L
s
.4964 .62552 m
.49616 .62036 L
s
.078 1 0 r
.55025 .25138 m
.54948 .25043 L
s
.54948 .25043 m
.55007 .2449 L
s
.54948 .25043 m
.5447 .24768 L
s
.532 1 0 r
.48375 .43693 m
.48141 .44046 L
s
.487 1 0 r
.85838 .92112 m
.85783 .92466 L
s
0 1 .32 r
.43508 .81141 m
.42973 .81068 L
s
0 .369 1 r
.87246 .15353 m
.87593 .15485 L
s
.87246 .15353 m
.86447 .16064 L
s
1 .546 0 r
.21369 .15246 m
.21309 .15208 L
s
.21309 .15208 m
.21367 .1506 L
s
.21309 .15208 m
.21234 .15103 L
s
.008 1 0 r
.15723 .52026 m
.16166 .52159 L
s
.15352 .52038 m
.15723 .52026 L
s
.15723 .52026 m
.15852 .51539 L
s
.1539 .54331 m
.15852 .51539 L
s
0 .849 1 r
.45904 .99799 m
.45704 .99825 L
s
.45673 .98795 m
.45904 .99799 L
s
1 .546 0 r
.21367 .1506 m
.21428 .15098 L
s
.21367 .1506 m
.21234 .15103 L
s
0 .747 1 r
.88724 .34476 m
.88914 .34656 L
s
.88724 .34476 m
.87917 .35124 L
s
.078 1 0 r
.55007 .2449 m
.55084 .24583 L
s
.55007 .2449 m
.5447 .24768 L
s
0 1 .248 r
.92189 .73606 m
.9232 .73377 L
s
.9232 .73377 m
.92287 .72764 L
s
.9232 .73377 m
.91598 .73166 L
s
1 .546 0 r
.21428 .15098 m
.21369 .15246 L
s
.21234 .15103 m
.21369 .15246 L
s
0 .747 1 r
.92538 .34656 m
.87917 .35124 L
s
0 1 .78 r
.90405 .53612 m
.90436 .53825 L
s
.90405 .53612 m
.89634 .54156 L
s
.427 1 0 r
.49616 .62036 m
.4963 .62534 L
s
.49616 .62036 m
.5003 .62312 L
s
.50712 .64016 m
.49616 .62036 L
s
1 .546 0 r
.21234 .15103 m
.21428 .15098 L
s
0 .333 1 r
.37561 .9983 m
.36607 .9941 L
s
.022 1 0 r
.51676 .81081 m
.52003 .81036 L
s
.51203 .81095 m
.51676 .81081 L
s
.51676 .81081 m
.51566 .80496 L
s
.218 1 0 r
.9381 .92158 m
.94117 .92609 L
s
.94354 .91921 m
.9381 .92158 L
s
.9381 .92158 m
.9406 .92153 L
s
.94412 .92377 m
.9381 .92158 L
s
.95949 .92694 m
.9381 .92158 L
s
0 1 .248 r
.91598 .73166 m
.92189 .73606 L
s
.92287 .72764 m
.91598 .73166 L
s
.91598 .73166 m
.92156 .72992 L
s
.94807 .73261 m
.91598 .73166 L
s
.298 1 0 r
.56309 .43792 m
.56341 .43701 L
s
.56341 .43701 m
.56515 .43246 L
s
.56341 .43701 m
.55953 .43343 L
s
.008 1 0 r
.16166 .52159 m
.15796 .52171 L
s
.15852 .51539 m
.16166 .52159 L
s
0 1 .248 r
.92287 .72764 m
.92156 .72992 L
s
1 .991 0 r
.22878 .34539 m
.22409 .33188 L
s
0 1 .78 r
.89634 .54156 m
.90475 .54605 L
s
.89634 .54156 m
.90436 .53825 L
s
.9367 .53915 m
.89634 .54156 L
s
0 .849 1 r
.45673 .98795 m
.45704 .99825 L
s
.44857 .9952 m
.45673 .98795 L
s
.44215 1.03122 m
.45673 .98795 L
s
.218 1 0 r
.94117 .92609 m
.94412 .92377 L
s
.94412 .92377 m
.94354 .91921 L
s
.078 1 0 r
.5447 .24768 m
.55025 .25138 L
s
.5447 .24768 m
.55084 .24583 L
s
.427 1 0 r
.5003 .62312 m
.4963 .62534 L
s
0 .747 1 r
.87917 .35124 m
.8896 .35586 L
s
.87917 .35124 m
.88914 .34656 L
s
.298 1 0 r
.56515 .43246 m
.56483 .43336 L
s
.56515 .43246 m
.55953 .43343 L
s
1 .991 0 r
.22583 .33408 m
.22681 .33411 L
s
.22326 .33506 m
.22583 .33408 L
s
.22583 .33408 m
.22409 .33188 L
s
.078 1 0 r
.55084 .24583 m
.55025 .25138 L
s
0 .369 1 r
.86447 .16064 m
.8764 .16543 L
s
.86447 .16064 m
.87593 .15485 L
s
0 1 .959 r
.17113 .70237 m
.17829 .70512 L
s
.16671 .70268 m
.17113 .70237 L
s
.17113 .70237 m
.17476 .69579 L
s
.022 1 0 r
.51566 .80496 m
.5153 .8105 L
s
.51566 .80496 m
.52003 .81036 L
s
.51203 .81095 m
.51566 .80496 L
s
.5175 .83347 m
.51566 .80496 L
s
.008 1 0 r
.15852 .51539 m
.15796 .52171 L
s
.15352 .52038 m
.15852 .51539 L
s
.022 1 0 r
.5153 .8105 m
.51203 .81095 L
s
.008 1 0 r
.15796 .52171 m
.15352 .52038 L
s
.218 1 0 r
.94354 .91921 m
.9406 .92153 L
s
.298 1 0 r
.58246 .4422 m
.55953 .43343 L
s
1 .991 0 r
.22423 .33509 m
.22326 .33506 L
s
.22326 .33506 m
.22409 .33188 L
s
0 1 .67 r
.53266 .99672 m
.54007 .99865 L
s
.53136 .99628 m
.53266 .99672 L
s
.53266 .99672 m
.53767 .98993 L
s
.298 1 0 r
.55953 .43343 m
.56309 .43792 L
s
.55953 .43343 m
.56483 .43336 L
s
0 1 .959 r
.16348 .73626 m
.17476 .69579 L
s
0 .369 1 r
.87593 .15485 m
.8764 .16543 L
s
.022 1 0 r
.52003 .81036 m
.5153 .8105 L
s
1 .865 0 r
.30383 .14703 m
.29174 .14541 L
s
.416 1 0 r
.57798 .62437 m
.5791 .62401 L
s
.5791 .62401 m
.58217 .62072 L
s
.5791 .62401 m
.57684 .61936 L
s
0 .747 1 r
.88914 .34656 m
.8896 .35586 L
s
0 1 .78 r
.90436 .53825 m
.90475 .54605 L
s
.218 1 0 r
.9406 .92153 m
.94117 .92609 L
s
1 .991 0 r
.22409 .33188 m
.22423 .33509 L
s
.22409 .33188 m
.22681 .33411 L
s
.22681 .33411 m
.22423 .33509 L
s
0 1 .248 r
.92156 .72992 m
.92189 .73606 L
s
0 1 .67 r
.54007 .99865 m
.5388 .99821 L
s
.53767 .98993 m
.54007 .99865 L
s
0 .849 1 r
.45704 .99825 m
.44857 .9952 L
s
.416 1 0 r
.58217 .62072 m
.58105 .62107 L
s
.58217 .62072 m
.57684 .61936 L
s
0 1 .286 r
.63219 .24722 m
.63124 .24613 L
s
.63124 .24613 m
.63153 .23949 L
s
.63124 .24613 m
.62532 .24324 L
s
.298 1 0 r
.56483 .43336 m
.56309 .43792 L
s
0 1 .959 r
.17829 .70512 m
.17388 .70543 L
s
.17476 .69579 m
.17829 .70512 L
s
.275 1 0 r
.23875 .51794 m
.24193 .51826 L
s
.2348 .51823 m
.23875 .51794 L
s
.23875 .51794 m
.23832 .51327 L
s
1 .865 0 r
.29425 .14719 m
.2937 .14678 L
s
.2937 .14678 m
.29407 .14428 L
s
.2937 .14678 m
.29174 .14541 L
s
0 1 .286 r
.65797 .24378 m
.62532 .24324 L
s
.416 1 0 r
.57684 .61936 m
.57798 .62437 L
s
.57684 .61936 m
.58105 .62107 L
s
.59303 .63528 m
.57684 .61936 L
s
0 1 .67 r
.53767 .98993 m
.5388 .99821 L
s
.53136 .99628 m
.53767 .98993 L
s
.52793 1.02766 m
.53767 .98993 L
s
1 .865 0 r
.29407 .14428 m
.29462 .14469 L
s
.29407 .14428 m
.29174 .14541 L
s
.275 1 0 r
.23854 .53811 m
.23832 .51327 L
s
0 1 .286 r
.63153 .23949 m
.63248 .24056 L
s
.63153 .23949 m
.62532 .24324 L
s
.014 0 1 r
.18675 .88467 m
.19679 .8894 L
s
.18203 .88577 m
.18675 .88467 L
s
.18675 .88467 m
.19351 .87694 L
s
.266 1 0 r
.59543 .81054 m
.59579 .8114 L
s
.59579 .8114 m
.60063 .80995 L
s
.59579 .8114 m
.59664 .80551 L
s
.60063 .80995 m
.60029 .80909 L
s
.60063 .80995 m
.59664 .80551 L
s
0 1 0 r
.64533 .43535 m
.64562 .43413 L
s
.64562 .43413 m
.64678 .42853 L
s
.64562 .43413 m
.64039 .43076 L
s
1 .865 0 r
.29462 .14469 m
.29425 .14719 L
s
.29174 .14541 m
.29425 .14719 L
s
.29174 .14541 m
.29462 .14469 L
s
.416 1 0 r
.58105 .62107 m
.57798 .62437 L
s
.266 1 0 r
.59664 .80551 m
.59543 .81054 L
s
.59664 .80551 m
.60029 .80909 L
s
.60364 .82924 m
.59664 .80551 L
s
0 1 .959 r
.17476 .69579 m
.17388 .70543 L
s
.16671 .70268 m
.17476 .69579 L
s
.275 1 0 r
.24193 .51826 m
.23799 .51855 L
s
.23832 .51327 m
.24193 .51826 L
s
.23799 .51855 m
.2348 .51823 L
s
.2348 .51823 m
.23832 .51327 L
s
0 1 0 r
.64678 .42853 m
.64649 .42975 L
s
.64678 .42853 m
.64039 .43076 L
s
.275 1 0 r
.23832 .51327 m
.23799 .51855 L
s
0 1 .286 r
.62532 .24324 m
.63219 .24722 L
s
.62532 .24324 m
.63248 .24056 L
s
.014 0 1 r
.17311 .93007 m
.19351 .87694 L
s
.963 1 0 r
.31378 .33952 m
.30391 .32806 L
s
0 1 .575 r
.25277 .70175 m
.25888 .70335 L
s
.24851 .70176 m
.25277 .70175 L
s
.25277 .70175 m
.25504 .69526 L
s
0 1 .248 r
.61515 .99851 m
.62161 .99934 L
s
.61441 .99734 m
.61515 .99851 L
s
.61515 .99851 m
.61894 .99193 L
s
0 1 .959 r
.17388 .70543 m
.16671 .70268 L
s
0 1 .67 r
.5388 .99821 m
.53136 .99628 L
s
.014 0 1 r
.19679 .8894 m
.19211 .89052 L
s
.19351 .87694 m
.19679 .8894 L
s
.963 1 0 r
.30699 .32932 m
.30707 .3294 L
s
.3047 .3313 m
.30699 .32932 L
s
.30699 .32932 m
.30391 .32806 L
s
.30477 .33137 m
.3047 .3313 L
s
.3047 .3313 m
.30391 .32806 L
s
.272 1 0 r
.66046 .6234 m
.66193 .62243 L
s
.66193 .62243 m
.66404 .61811 L
s
.66193 .62243 m
.65794 .61835 L
s
0 1 .248 r
.62161 .99934 m
.62088 .99816 L
s
.61894 .99193 m
.62161 .99934 L
s
0 1 .286 r
.63248 .24056 m
.63219 .24722 L
s
0 1 0 r
.64039 .43076 m
.64533 .43535 L
s
.64039 .43076 m
.64649 .42975 L
s
.66872 .43664 m
.64039 .43076 L
s
0 1 .248 r
.61894 .99193 m
.62088 .99816 L
s
.61441 .99734 m
.61894 .99193 L
s
.6143 1.02407 m
.61894 .99193 L
s
.266 1 0 r
.60029 .80909 m
.59543 .81054 L
s
.963 1 0 r
.30391 .32806 m
.30477 .33137 L
s
.30391 .32806 m
.30707 .3294 L
s
.272 1 0 r
.66404 .61811 m
.66257 .61907 L
s
.66404 .61811 m
.65794 .61835 L
s
0 1 .575 r
.24835 .7317 m
.25504 .69526 L
s
.776 1 0 r
.38918 .14047 m
.37166 .13976 L
s
0 1 .659 r
.71468 .24303 m
.71349 .24179 L
s
.71349 .24179 m
.71349 .23404 L
s
.71349 .24179 m
.70645 .23878 L
s
.272 1 0 r
.65794 .61835 m
.66046 .6234 L
s
.65794 .61835 m
.66257 .61907 L
s
.67952 .63037 m
.65794 .61835 L
s
.963 1 0 r
.30707 .3294 m
.30477 .33137 L
s
0 1 0 r
.64649 .42975 m
.64533 .43535 L
s
0 1 .575 r
.25888 .70335 m
.25463 .70336 L
s
.25504 .69526 m
.25888 .70335 L
s
.366 1 0 r
.67757 .81135 m
.68019 .81121 L
s
.68019 .81121 m
.68333 .80831 L
s
.68019 .81121 m
.67798 .80606 L
s
.46 1 0 r
.32095 .51519 m
.3224 .51482 L
s
.3168 .51616 m
.32095 .51519 L
s
.32095 .51519 m
.31856 .51114 L
s
.776 1 0 r
.37536 .14195 m
.37481 .14145 L
s
.37481 .14145 m
.37498 .13786 L
s
.37481 .14145 m
.37166 .13976 L
s
0 .468 1 r
.26847 .88551 m
.27754 .88909 L
s
.26454 .88602 m
.26847 .88551 L
s
.26847 .88551 m
.27426 .8779 L
s
.776 1 0 r
.37498 .13786 m
.37553 .13835 L
s
.37498 .13786 m
.37166 .13976 L
s
.366 1 0 r
.67798 .80606 m
.67757 .81135 L
s
.68333 .80831 m
.67798 .80606 L
s
.67798 .80606 m
.68071 .80844 L
s
.69036 .82498 m
.67798 .80606 L
s
0 1 .659 r
.74459 .23755 m
.70645 .23878 L
s
.71349 .23404 m
.71469 .23526 L
s
.71349 .23404 m
.70645 .23878 L
s
0 1 .338 r
.7281 .43277 m
.72826 .43125 L
s
.72826 .43125 m
.72887 .42459 L
s
.72826 .43125 m
.72171 .42808 L
s
0 1 .575 r
.25504 .69526 m
.25463 .70336 L
s
.24851 .70176 m
.25504 .69526 L
s
.272 1 0 r
.66257 .61907 m
.66046 .6234 L
s
.014 0 1 r
.19351 .87694 m
.19211 .89052 L
s
.18203 .88577 m
.19351 .87694 L
s
.46 1 0 r
.31825 .51579 m
.3168 .51616 L
s
.3168 .51616 m
.31856 .51114 L
s
.366 1 0 r
.68333 .80831 m
.68071 .80844 L
s
.46 1 0 r
.32377 .53287 m
.31856 .51114 L
s
0 1 .248 r
.62088 .99816 m
.61441 .99734 L
s
.075 1 0 r
.70097 1.0006 m
.70466 .99905 L
s
.6967 .99938 m
.70097 1.0006 L
s
.70053 .99393 m
.70097 1.0006 L
s
0 1 .575 r
.25463 .70336 m
.24851 .70176 L
s
.776 1 0 r
.37166 .13976 m
.37536 .14195 L
s
.37166 .13976 m
.37553 .13835 L
s
.46 1 0 r
.31856 .51114 m
.31825 .51579 L
s
.31856 .51114 m
.3224 .51482 L
s
.776 1 0 r
.37553 .13835 m
.37536 .14195 L
s
.075 1 0 r
.70039 .99783 m
.70053 .99393 L
s
.70053 .99393 m
.6967 .99938 L
s
.70466 .99905 m
.70053 .99393 L
s
.70126 1.02046 m
.70053 .99393 L
s
0 1 .338 r
.72887 .42459 m
.72871 .42609 L
s
.72887 .42459 m
.72171 .42808 L
s
0 1 .234 r
.33518 .70104 m
.33996 .70145 L
s
.33068 .70095 m
.33518 .70104 L
s
.33518 .70104 m
.3357 .69472 L
s
0 .468 1 r
.27754 .88909 m
.27363 .88962 L
s
.27426 .8779 m
.27754 .88909 L
s
.366 1 0 r
.68071 .80844 m
.67757 .81135 L
s
.022 1 0 r
.7435 .62239 m
.74503 .62088 L
s
.74503 .62088 m
.74626 .61552 L
s
.74503 .62088 m
.73946 .61734 L
s
.46 1 0 r
.3224 .51482 m
.31825 .51579 L
s
.778 1 0 r
.38615 .32779 m
.38647 .32743 L
s
.38647 .32743 m
.38831 .32439 L
s
.38647 .32743 m
.3842 .32421 L
s
0 1 .659 r
.70645 .23878 m
.71468 .24303 L
s
.70645 .23878 m
.71469 .23526 L
s
.014 0 1 r
.19211 .89052 m
.18203 .88577 L
s
.778 1 0 r
.38831 .32439 m
.388 .32474 L
s
.38831 .32439 m
.3842 .32421 L
s
0 .468 1 r
.2582 .92615 m
.27426 .8779 L
s
.778 1 0 r
.39935 .3336 m
.3842 .32421 L
s
0 1 .338 r
.72171 .42808 m
.7281 .43277 L
s
.72171 .42808 m
.72871 .42609 L
s
.75557 .43105 m
.72171 .42808 L
s
.075 1 0 r
.70039 .99783 m
.6967 .99938 L
s
.022 1 0 r
.74626 .61552 m
.74473 .61703 L
s
.74626 .61552 m
.73946 .61734 L
s
.73946 .61734 m
.7435 .62239 L
s
.73946 .61734 m
.74473 .61703 L
s
.7666 .62543 m
.73946 .61734 L
s
.075 1 0 r
.70466 .99905 m
.70039 .99783 L
s
0 1 .659 r
.71469 .23526 m
.71468 .24303 L
s
.778 1 0 r
.3842 .32421 m
.38615 .32779 L
s
.3842 .32421 m
.388 .32474 L
s
.298 1 0 r
.76094 .81198 m
.76398 .81081 L
s
.76398 .81081 m
.76564 .80685 L
s
.76398 .81081 m
.75971 .80661 L
s
0 .961 1 r
.79774 .23882 m
.79622 .23743 L
s
.79622 .23743 m
.79596 .22856 L
s
.79622 .23743 m
.78811 .23428 L
s
.298 1 0 r
.75971 .80661 m
.76094 .81198 L
s
.76564 .80685 m
.75971 .80661 L
s
.75971 .80661 m
.7626 .80801 L
s
.77768 .82068 m
.75971 .80661 L
s
0 .468 1 r
.27426 .8779 m
.27363 .88962 L
s
.26454 .88602 m
.27426 .8779 L
s
0 1 .234 r
.33996 .70145 m
.33546 .70136 L
s
.3357 .69472 m
.33996 .70145 L
s
.778 1 0 r
.388 .32474 m
.38615 .32779 L
s
0 .925 1 r
.3507 .88636 m
.35878 .88877 L
s
.34733 .88629 m
.3507 .88636 L
s
.3507 .88636 m
.35535 .87886 L
s
0 1 .338 r
.72871 .42609 m
.7281 .43277 L
s
0 1 .234 r
.3357 .69472 m
.33546 .70136 L
s
.33068 .70095 m
.3357 .69472 L
s
.3338 .7271 m
.3357 .69472 L
s
.404 1 0 r
.47511 .13387 m
.45211 .13407 L
s
.45702 .13669 m
.45641 .13609 L
s
.45641 .13609 m
.45642 .13137 L
s
.45641 .13609 m
.45211 .13407 L
s
.532 1 0 r
.4033 .51184 m
.40306 .5115 L
s
.39953 .51393 m
.4033 .51184 L
s
.4033 .51184 m
.39923 .509 L
s
.39928 .5136 m
.39953 .51393 L
s
.39953 .51393 m
.39923 .509 L
s
0 1 .234 r
.33546 .70136 m
.33068 .70095 L
s
.246 1 0 r
.78246 .99594 m
.78143 1.00212 L
s
.78602 .99807 m
.78246 .99594 L
s
.78246 .99594 m
.78102 .99931 L
s
.78643 1.00088 m
.78246 .99594 L
s
.78881 1.01683 m
.78246 .99594 L
s
0 1 .7 r
.81139 .43016 m
.81135 .42837 L
s
.81135 .42837 m
.81142 .42063 L
s
.81135 .42837 m
.80351 .42538 L
s
.298 1 0 r
.76564 .80685 m
.7626 .80801 L
s
.022 1 0 r
.74473 .61703 m
.7435 .62239 L
s
.404 1 0 r
.45642 .13137 m
.45702 .13196 L
s
.45642 .13137 m
.45211 .13407 L
s
0 .961 1 r
.79596 .22856 m
.79748 .22991 L
s
.79596 .22856 m
.78811 .23428 L
s
.246 1 0 r
.78143 1.00212 m
.78643 1.00088 L
s
.78643 1.00088 m
.78602 .99807 L
s
0 .961 1 r
.83179 .23127 m
.78811 .23428 L
s
.246 1 0 r
.78102 .99931 m
.78143 1.00212 L
s
.298 1 0 r
.7626 .80801 m
.76094 .81198 L
s
.532 1 0 r
.39923 .509 m
.39928 .5136 L
s
.39923 .509 m
.40306 .5115 L
s
.40957 .5276 m
.39923 .509 L
s
0 .468 1 r
.27363 .88962 m
.26454 .88602 L
s
0 .925 1 r
.35878 .88877 m
.35542 .8887 L
s
.35535 .87886 m
.35878 .88877 L
s
0 1 .299 r
.82704 .62134 m
.82849 .61935 L
s
.82849 .61935 m
.8289 .61295 L
s
.82849 .61935 m
.82142 .61632 L
s
0 1 .7 r
.81142 .42063 m
.81146 .42239 L
s
.81142 .42063 m
.80351 .42538 L
s
.042 1 0 r
.41861 .69998 m
.42123 .69933 L
s
.41351 .70035 m
.41861 .69998 L
s
.41861 .69998 m
.41675 .69419 L
s
.404 1 0 r
.45211 .13407 m
.45702 .13669 L
s
.45211 .13407 m
.45702 .13196 L
s
.504 1 0 r
.46816 .32418 m
.4686 .32353 L
s
.4686 .32353 m
.47 .31941 L
s
.4686 .32353 m
.46497 .32034 L
s
1 .546 0 r
.12858 .23002 m
.12816 .22209 L
s
.404 1 0 r
.45702 .13196 m
.45702 .13669 L
s
.532 1 0 r
.40306 .5115 m
.39928 .5136 L
s
1 .546 0 r
.12842 .2235 m
.12938 .22367 L
s
.12711 .22369 m
.12842 .2235 L
s
.12842 .2235 m
.12816 .22209 L
s
0 1 .7 r
.80351 .42538 m
.81139 .43016 L
s
.80351 .42538 m
.81146 .42239 L
s
.84301 .42542 m
.80351 .42538 L
s
.504 1 0 r
.47 .31941 m
.46956 .32006 L
s
.47 .31941 m
.46497 .32034 L
s
0 1 .299 r
.8289 .61295 m
.82745 .61493 L
s
.8289 .61295 m
.82142 .61632 L
s
0 .961 1 r
.78811 .23428 m
.79774 .23882 L
s
.78811 .23428 m
.79748 .22991 L
s
0 1 .299 r
.82142 .61632 m
.82704 .62134 L
s
.82142 .61632 m
.82745 .61493 L
s
.85427 .62045 m
.82142 .61632 L
s
0 .925 1 r
.35535 .87886 m
.35542 .8887 L
s
.34733 .88629 m
.35535 .87886 L
s
.34388 .92221 m
.35535 .87886 L
s
.078 1 0 r
.84477 .81247 m
.8478 .8105 L
s
.8478 .8105 m
.84833 .80552 L
s
.8478 .8105 m
.84182 .80716 L
s
.84182 .80716 m
.84477 .81247 L
s
.84833 .80552 m
.84182 .80716 L
s
.84182 .80716 m
.8453 .80749 L
s
.86559 .81636 m
.84182 .80716 L
s
1 .546 0 r
.12807 .22385 m
.12711 .22369 L
s
.12711 .22369 m
.12816 .22209 L
s
.12938 .22367 m
.12807 .22385 L
s
.12816 .22209 m
.12938 .22367 L
s
.246 1 0 r
.78602 .99807 m
.78102 .99931 L
s
.042 1 0 r
.41612 .6997 m
.41351 .70035 L
s
.41351 .70035 m
.41675 .69419 L
s
.504 1 0 r
.48551 .32764 m
.46497 .32034 L
s
.218 1 0 r
.86473 .99796 m
.86524 1.00394 L
s
.86908 .99803 m
.86473 .99796 L
s
.86473 .99796 m
.86447 1.00019 L
s
.86985 1.00178 m
.86473 .99796 L
s
.87696 1.01317 m
.86473 .99796 L
s
1 .546 0 r
.12816 .22209 m
.12807 .22385 L
s
.042 1 0 r
.41675 .69419 m
.41612 .6997 L
s
.41675 .69419 m
.42123 .69933 L
s
.41983 .72248 m
.41675 .69419 L
s
.504 1 0 r
.46497 .32034 m
.46816 .32418 L
s
.46497 .32034 m
.46956 .32006 L
s
0 1 .657 r
.43355 .88724 m
.44057 .8884 L
s
.43035 .88661 m
.43355 .88724 L
s
.43355 .88724 m
.4368 .87983 L
s
0 .578 1 r
.88136 .23458 m
.87945 .23305 L
s
.87945 .23305 m
.87895 .22304 L
s
.87945 .23305 m
.87028 .22976 L
s
0 .961 1 r
.79748 .22991 m
.79774 .23882 L
s
.474 1 0 r
.48138 .51163 m
.48256 .51146 L
s
.48256 .51146 m
.48553 .50823 L
s
.48256 .51146 m
.48033 .50684 L
s
.078 1 0 r
.84833 .80552 m
.8453 .80749 L
s
.504 1 0 r
.46956 .32006 m
.46816 .32418 L
s
.042 1 0 r
.42123 .69933 m
.41612 .6997 L
s
0 .925 1 r
.35542 .8887 m
.34733 .88629 L
s
0 1 .7 r
.81146 .42239 m
.81139 .43016 L
s
0 .921 1 r
.89521 .42753 m
.8949 .42549 L
s
.8949 .42549 m
.89445 .41665 L
s
.8949 .42549 m
.88579 .42267 L
s
.218 1 0 r
.86524 1.00394 m
.86985 1.00178 L
s
.86985 1.00178 m
.86908 .99803 L
s
.026 1 0 r
.53924 .1314 m
.53851 .1307 L
s
.53851 .1307 m
.53837 .12484 L
s
.53851 .1307 m
.53309 .12834 L
s
.474 1 0 r
.48553 .50823 m
.48435 .50839 L
s
.48553 .50823 m
.48033 .50684 L
s
0 1 .299 r
.82745 .61493 m
.82704 .62134 L
s
.589 1 0 r
.13977 .40775 m
.14277 .40823 L
s
.13686 .40759 m
.13977 .40775 L
s
.13977 .40775 m
.14022 .40381 L
s
.026 1 0 r
.56162 .12723 m
.53309 .12834 L
s
.218 1 0 r
.86447 1.00019 m
.86524 1.00394 L
s
.078 1 0 r
.8453 .80749 m
.84477 .81247 L
s
.474 1 0 r
.48033 .50684 m
.48138 .51163 L
s
.48033 .50684 m
.48435 .50839 L
s
.49595 .52229 m
.48033 .50684 L
s
0 1 .657 r
.44057 .8884 m
.43738 .88777 L
s
.4368 .87983 m
.44057 .8884 L
s
0 1 .665 r
.91106 .62028 m
.91237 .61786 L
s
.91237 .61786 m
.91198 .61038 L
s
.91237 .61786 m
.9038 .6153 L
s
0 .578 1 r
.87895 .22304 m
.88085 .22453 L
s
.87895 .22304 m
.87028 .22976 L
s
.026 1 0 r
.53837 .12484 m
.5391 .12553 L
s
.53837 .12484 m
.53309 .12834 L
s
.589 1 0 r
.1382 .42429 m
.14022 .40381 L
s
0 .921 1 r
.89445 .41665 m
.89476 .41867 L
s
.89445 .41665 m
.88579 .42267 L
s
0 1 .657 r
.4368 .87983 m
.43738 .88777 L
s
.43035 .88661 m
.4368 .87983 L
s
.43014 .91825 m
.4368 .87983 L
s
.218 1 0 r
.86908 .99803 m
.86447 1.00019 L
s
0 .578 1 r
.91959 .22496 m
.87028 .22976 L
s
.589 1 0 r
.14277 .40823 m
.13986 .40807 L
s
.14022 .40381 m
.14277 .40823 L
s
.181 1 0 r
.55073 .32055 m
.55117 .31963 L
s
.55117 .31963 m
.55215 .31442 L
s
.55117 .31963 m
.54624 .31644 L
s
.22 1 0 r
.49713 .6989 m
.49761 .69978 L
s
.49761 .69978 m
.50256 .69805 L
s
.49761 .69978 m
.4982 .69364 L
s
.50256 .69805 m
.50209 .69717 L
s
.50256 .69805 m
.4982 .69364 L
s
0 1 0 r
.94733 .99999 m
.94949 1.00577 L
s
.95248 .99798 m
.94733 .99999 L
s
.94733 .99999 m
.94802 1.00098 L
s
.95394 1.00277 m
.94733 .99999 L
s
.96572 1.00949 m
.94733 .99999 L
s
0 1 .248 r
.92431 .80772 m
.92902 .81292 L
s
.93146 .80423 m
.92431 .80772 L
s
.92431 .80772 m
.92851 .80688 L
s
.93196 .81027 m
.92431 .80772 L
s
.95411 .81201 m
.92431 .80772 L
s
.92902 .81292 m
.93196 .81027 L
s
.93196 .81027 m
.93146 .80423 L
s
.474 1 0 r
.48435 .50839 m
.48138 .51163 L
s
0 1 .665 r
.91198 .61038 m
.91067 .61279 L
s
.91198 .61038 m
.9038 .6153 L
s
.9038 .6153 m
.91106 .62028 L
s
.9038 .6153 m
.91067 .61279 L
s
.94255 .61543 m
.9038 .6153 L
s
.589 1 0 r
.14022 .40381 m
.13986 .40807 L
s
.13686 .40759 m
.14022 .40381 L
s
.13986 .40807 m
.13686 .40759 L
s
.026 1 0 r
.53309 .12834 m
.53924 .1314 L
s
.53309 .12834 m
.5391 .12553 L
s
0 .921 1 r
.88579 .42267 m
.89521 .42753 L
s
.88579 .42267 m
.89476 .41867 L
s
.93105 .41975 m
.88579 .42267 L
s
.181 1 0 r
.55215 .31442 m
.55171 .31533 L
s
.55215 .31442 m
.54624 .31644 L
s
.22 1 0 r
.4982 .69364 m
.49713 .6989 L
s
.4982 .69364 m
.50209 .69717 L
s
.50645 .71783 m
.4982 .69364 L
s
1 .593 0 r
.21403 .22369 m
.20829 .21702 L
s
.21011 .2178 m
.21009 .21777 L
s
.20879 .21894 m
.21011 .2178 L
s
.21011 .2178 m
.20829 .21702 L
s
.20877 .21891 m
.20879 .21894 L
s
.20879 .21894 m
.20829 .21702 L
s
0 .578 1 r
.87028 .22976 m
.88136 .23458 L
s
.87028 .22976 m
.88085 .22453 L
s
0 1 .334 r
.15255 .59222 m
.15815 .59374 L
s
.14864 .59197 m
.15255 .59222 L
s
.15255 .59222 m
.15478 .5862 L
s
0 1 .299 r
.51751 .88811 m
.523 .8878 L
s
.51353 .88715 m
.51751 .88811 L
s
.51751 .88811 m
.51859 .8808 L
s
0 1 .657 r
.43738 .88777 m
.43035 .88661 L
s
.026 1 0 r
.5391 .12553 m
.53924 .1314 L
s
0 1 .248 r
.93146 .80423 m
.92851 .80688 L
s
0 1 0 r
.94949 1.00577 m
.95394 1.00277 L
s
.95394 1.00277 m
.95248 .99798 L
s
.181 1 0 r
.54624 .31644 m
.55073 .32055 L
s
.54624 .31644 m
.55171 .31533 L
s
.57225 .32164 m
.54624 .31644 L
s
1 .593 0 r
.20829 .21702 m
.20877 .21891 L
s
.20829 .21702 m
.21009 .21777 L
s
.301 1 0 r
.56423 .50964 m
.56576 .50892 L
s
.56576 .50892 m
.56795 .50461 L
s
.56576 .50892 m
.56188 .50468 L
s
1 .593 0 r
.21009 .21777 m
.20877 .21891 L
s
0 1 .334 r
.14788 .61945 m
.15478 .5862 L
s
.301 1 0 r
.56795 .50461 m
.56641 .50533 L
s
.56795 .50461 m
.56188 .50468 L
s
0 1 0 r
.94802 1.00098 m
.94949 1.00577 L
s
0 .578 1 r
.88085 .22453 m
.88136 .23458 L
s
.181 1 0 r
.55171 .31533 m
.55073 .32055 L
s
0 1 .334 r
.15815 .59374 m
.15424 .59349 L
s
.15478 .5862 m
.15815 .59374 L
s
0 1 0 r
.95248 .99798 m
.94802 1.00098 L
s
.22 1 0 r
.50209 .69717 m
.49713 .6989 L
s
0 1 .355 r
.62203 .12608 m
.62111 .12527 L
s
.62111 .12527 m
.62084 .11826 L
s
.62111 .12527 m
.61461 .12258 L
s
0 1 .299 r
.51859 .8808 m
.51903 .88684 L
s
.51859 .8808 m
.523 .8878 L
s
.51353 .88715 m
.51859 .8808 L
s
.51699 .91425 m
.51859 .8808 L
s
0 .921 1 r
.89476 .41867 m
.89521 .42753 L
s
0 1 .248 r
.92851 .80688 m
.92902 .81292 L
s
0 1 .665 r
.91067 .61279 m
.91106 .62028 L
s
.301 1 0 r
.56188 .50468 m
.56423 .50964 L
s
.56188 .50468 m
.56641 .50533 L
s
.58293 .51695 m
.56188 .50468 L
s
.747 1 0 r
.22244 .40411 m
.22383 .40368 L
s
.21903 .40456 m
.22244 .40411 L
s
.22244 .40411 m
.22082 .4005 L
s
0 1 .299 r
.523 .8878 m
.51903 .88684 L
s
.272 1 0 r
.57977 .69864 m
.58216 .69869 L
s
.58216 .69869 m
.58574 .69556 L
s
.58216 .69869 m
.58004 .6931 L
s
0 1 .355 r
.64873 .12054 m
.61461 .12258 L
s
0 .674 1 r
.16698 .77689 m
.17541 .78007 L
s
.16258 .77706 m
.16698 .77689 L
s
.16698 .77689 m
.17186 .76932 L
s
0 1 .355 r
.62084 .11826 m
.62177 .11906 L
s
.62084 .11826 m
.61461 .12258 L
s
0 1 .334 r
.15478 .5862 m
.15424 .59349 L
s
.14864 .59197 m
.15478 .5862 L
s
0 1 .299 r
.51903 .88684 m
.51353 .88715 L
s
.747 1 0 r
.22043 .40413 m
.21903 .40456 L
s
.21903 .40456 m
.22082 .4005 L
s
0 1 .169 r
.63383 .31688 m
.63419 .31572 L
s
.63419 .31572 m
.63478 .30941 L
s
.63419 .31572 m
.62799 .31252 L
s
.747 1 0 r
.22389 .41862 m
.22082 .4005 L
s
.301 1 0 r
.56641 .50533 m
.56423 .50964 L
s
.272 1 0 r
.58004 .6931 m
.57977 .69864 L
s
.58574 .69556 m
.58004 .6931 L
s
.58004 .6931 m
.58336 .6955 L
s
.59366 .71314 m
.58004 .6931 L
s
0 1 .334 r
.15424 .59349 m
.14864 .59197 L
s
.272 1 0 r
.58574 .69556 m
.58336 .6955 L
s
.747 1 0 r
.22082 .4005 m
.22043 .40413 L
s
.22082 .4005 m
.22383 .40368 L
s
.22383 .40368 m
.22043 .40413 L
s
0 1 .169 r
.63478 .30941 m
.63442 .31055 L
s
.63478 .30941 m
.62799 .31252 L
s
0 1 .044 r
.23539 .59052 m
.23974 .59082 L
s
.23114 .59022 m
.23539 .59052 L
s
.23539 .59052 m
.23585 .58454 L
s
1 .841 0 r
.29046 .21424 m
.29083 .21402 L
s
.29083 .21402 m
.29185 .21177 L
s
.29083 .21402 m
.28892 .21192 L
s
0 1 .355 r
.61461 .12258 m
.62203 .12608 L
s
.61461 .12258 m
.62177 .11906 L
s
0 .674 1 r
.17541 .78007 m
.17104 .78025 L
s
.17186 .76932 m
.17541 .78007 L
s
0 1 .033 r
.5982 .88703 m
.59879 .88873 L
s
.59879 .88873 m
.60473 .88786 L
s
.59879 .88873 m
.60073 .88177 L
s
1 .841 0 r
.29185 .21177 m
.29148 .21198 L
s
.29185 .21177 m
.28892 .21192 L
s
.042 1 0 r
.64764 .5076 m
.64927 .50639 L
s
.64927 .50639 m
.65074 .50102 L
s
.64927 .50639 m
.64388 .5025 L
s
0 1 .033 r
.60473 .88786 m
.60415 .88615 L
s
.60473 .88786 m
.60073 .88177 L
s
0 .674 1 r
.15759 .8155 m
.17186 .76932 L
s
0 1 .033 r
.60073 .88177 m
.5982 .88703 L
s
.60073 .88177 m
.60415 .88615 L
s
.60444 .91023 m
.60073 .88177 L
s
1 .841 0 r
.30008 .21732 m
.28892 .21192 L
s
.272 1 0 r
.58336 .6955 m
.57977 .69864 L
s
0 1 .169 r
.62799 .31252 m
.63383 .31688 L
s
.62799 .31252 m
.63442 .31055 L
s
.6596 .31561 m
.62799 .31252 L
s
1 .841 0 r
.28892 .21192 m
.29046 .21424 L
s
.28892 .21192 m
.29148 .21198 L
s
0 1 .355 r
.62177 .11906 m
.62203 .12608 L
s
.405 0 1 r
.18321 .96178 m
.19459 .96713 L
s
.17869 .96303 m
.18321 .96178 L
s
.18321 .96178 m
.19148 .95323 L
s
1 .841 0 r
.29148 .21198 m
.29046 .21424 L
s
.042 1 0 r
.65074 .50102 m
.64912 .50222 L
s
.65074 .50102 m
.64388 .5025 L
s
.64388 .5025 m
.64764 .5076 L
s
.64388 .5025 m
.64912 .50222 L
s
.67051 .51157 m
.64388 .5025 L
s
0 1 .738 r
.7054 .12073 m
.70422 .11981 L
s
.70422 .11981 m
.70385 .11164 L
s
.70422 .11981 m
.69667 .11677 L
s
0 1 .044 r
.23974 .59082 m
.23549 .59052 L
s
.23585 .58454 m
.23974 .59082 L
s
.186 1 0 r
.66348 .69827 m
.66643 .6974 L
s
.66643 .6974 m
.66874 .69317 L
s
.66643 .6974 m
.66228 .69255 L
s
0 1 .169 r
.63442 .31055 m
.63383 .31688 L
s
0 .674 1 r
.17186 .76932 m
.17104 .78025 L
s
.16258 .77706 m
.17186 .76932 L
s
0 1 .044 r
.23379 .61443 m
.23585 .58454 L
s
.23585 .58454 m
.23549 .59052 L
s
.23114 .59022 m
.23585 .58454 L
s
0 1 .927 r
.24976 .77678 m
.25724 .77875 L
s
.2457 .77646 m
.24976 .77678 L
s
.24976 .77678 m
.25341 .76922 L
s
.778 1 0 r
.30532 .39972 m
.30495 .39922 L
s
.30211 .4014 m
.30532 .39972 L
s
.30532 .39972 m
.30187 .39716 L
s
.30174 .40091 m
.30211 .4014 L
s
.30211 .4014 m
.30187 .39716 L
s
0 1 .044 r
.23549 .59052 m
.23114 .59022 L
s
.186 1 0 r
.66228 .69255 m
.66348 .69827 L
s
.66874 .69317 m
.66228 .69255 L
s
.66228 .69255 m
.66579 .69403 L
s
.68148 .70842 m
.66228 .69255 L
s
.405 0 1 r
.19459 .96713 m
.19011 .96841 L
s
.19148 .95323 m
.19459 .96713 L
s
0 1 .535 r
.71748 .31318 m
.71769 .3118 L
s
.71769 .3118 m
.7179 .30437 L
s
.71769 .3118 m
.71023 .30858 L
s
0 1 .033 r
.60415 .88615 m
.5982 .88703 L
s
0 1 .738 r
.70385 .11164 m
.70503 .11253 L
s
.70385 .11164 m
.69667 .11677 L
s
.042 1 0 r
.64912 .50222 m
.64764 .5076 L
s
.186 1 0 r
.66874 .69317 m
.66579 .69403 L
s
.778 1 0 r
.30187 .39716 m
.30174 .40091 L
s
.30187 .39716 m
.30495 .39922 L
s
.31016 .4129 m
.30187 .39716 L
s
0 1 .738 r
.73643 .1138 m
.69667 .11677 L
s
0 .674 1 r
.17104 .78025 m
.16258 .77706 L
s
.102 1 0 r
.68148 .88908 m
.6862 .88886 L
s
.6862 .88886 m
.68865 .88575 L
s
.6862 .88886 m
.68322 .88275 L
s
.68322 .88275 m
.68148 .88908 L
s
.68865 .88575 m
.68322 .88275 L
s
.68322 .88275 m
.68393 .88596 L
s
.69249 .90618 m
.68322 .88275 L
s
.405 0 1 r
.16735 1.01244 m
.19148 .95323 L
s
0 1 .927 r
.25724 .77875 m
.25321 .77844 L
s
.25341 .76922 m
.25724 .77875 L
s
0 1 .535 r
.7179 .30437 m
.71769 .30573 L
s
.7179 .30437 m
.71023 .30858 L
s
.176 1 0 r
.31926 .58843 m
.32151 .58764 L
s
.31435 .58871 m
.31926 .58843 L
s
.31926 .58843 m
.31734 .58288 L
s
.186 1 0 r
.66579 .69403 m
.66348 .69827 L
s
0 1 .274 r
.73158 .50552 m
.73317 .50388 L
s
.73317 .50388 m
.73398 .49743 L
s
.73317 .50388 m
.72632 .50031 L
s
.83 1 0 r
.37278 .20952 m
.37327 .20909 L
s
.37327 .20909 m
.374 .20571 L
s
.37327 .20909 m
.37006 .20679 L
s
.778 1 0 r
.30495 .39922 m
.30174 .40091 L
s
.83 1 0 r
.374 .20571 m
.37351 .20614 L
s
.374 .20571 m
.37006 .20679 L
s
0 1 .738 r
.69667 .11677 m
.7054 .12073 L
s
.69667 .11677 m
.70503 .11253 L
s
0 .088 1 r
.26607 .96305 m
.27649 .96725 L
s
.26261 .96359 m
.26607 .96305 L
s
.26607 .96305 m
.27353 .95459 L
s
.102 1 0 r
.68393 .88596 m
.68148 .88908 L
s
0 1 .535 r
.71023 .30858 m
.71748 .31318 L
s
.71023 .30858 m
.71769 .30573 L
s
.74754 .30953 m
.71023 .30858 L
s
0 1 .927 r
.25341 .76922 m
.25321 .77844 L
s
.2457 .77646 m
.25341 .76922 L
s
.24374 .81114 m
.25341 .76922 L
s
0 1 .274 r
.73398 .49743 m
.73238 .49906 L
s
.73398 .49743 m
.72632 .50031 L
s
.83 1 0 r
.37006 .20679 m
.37278 .20952 L
s
.37006 .20679 m
.37351 .20614 L
s
.38671 .21091 m
.37006 .20679 L
s
.102 1 0 r
.68865 .88575 m
.68393 .88596 L
s
0 1 .274 r
.72632 .50031 m
.73158 .50552 L
s
.72632 .50031 m
.73238 .49906 L
s
.75869 .50615 m
.72632 .50031 L
s
.176 1 0 r
.31659 .58792 m
.31435 .58871 L
s
.31435 .58871 m
.31734 .58288 L
s
0 1 .021 r
.74773 .69779 m
.75079 .69616 L
s
.75079 .69616 m
.75207 .69087 L
s
.75079 .69616 m
.74493 .69201 L
s
.405 0 1 r
.19148 .95323 m
.19011 .96841 L
s
.17869 .96303 m
.19148 .95323 L
s
.176 1 0 r
.31734 .58288 m
.31659 .58792 L
s
.31734 .58288 m
.32151 .58764 L
s
.3203 .60938 m
.31734 .58288 L
s
0 1 .738 r
.70503 .11253 m
.7054 .12073 L
s
.83 1 0 r
.37351 .20614 m
.37278 .20952 L
s
0 1 .021 r
.74493 .69201 m
.74773 .69779 L
s
.75207 .69087 m
.74493 .69201 L
s
.74493 .69201 m
.74901 .6925 L
s
.7699 .70367 m
.74493 .69201 L
s
0 1 .569 r
.33329 .77665 m
.33963 .77733 L
s
.32909 .77596 m
.33329 .77665 L
s
.33329 .77665 m
.33534 .76913 L
s
0 .088 1 r
.27649 .96725 m
.27308 .9678 L
s
.27353 .95459 m
.27649 .96725 L
s
0 .878 1 r
.78936 .11534 m
.78785 .11431 L
s
.78785 .11431 m
.78739 .10497 L
s
.78785 .11431 m
.77927 .11093 L
s
.673 1 0 r
.38421 .39792 m
.38548 .39793 L
s
.38548 .39793 m
.38801 .39503 L
s
.38548 .39793 m
.38339 .39381 L
s
0 1 .927 r
.25321 .77844 m
.2457 .77646 L
s
.176 1 0 r
.32151 .58764 m
.31659 .58792 L
s
0 1 .535 r
.71769 .30573 m
.71748 .31318 L
s
.078 1 0 r
.76607 .88373 m
.76623 .8902 L
s
.77192 .88457 m
.76607 .88373 L
s
.76607 .88373 m
.76714 .88607 L
s
.771 .8887 m
.76607 .88373 L
s
.78115 .90211 m
.76607 .88373 L
s
.673 1 0 r
.38801 .39503 m
.38675 .39502 L
s
.38801 .39503 m
.38339 .39381 L
s
0 1 .021 r
.75207 .69087 m
.74901 .6925 L
s
0 1 .911 r
.80168 .30946 m
.80166 .30786 L
s
.80166 .30786 m
.80151 .2993 L
s
.80166 .30786 m
.79298 .30462 L
s
.078 1 0 r
.76623 .8902 m
.771 .8887 L
s
.771 .8887 m
.77192 .88457 L
s
.673 1 0 r
.38339 .39381 m
.38421 .39792 L
s
.38339 .39381 m
.38675 .39502 L
s
.39703 .40715 m
.38339 .39381 L
s
0 1 .274 r
.73238 .49906 m
.73158 .50552 L
s
0 .878 1 r
.78739 .10497 m
.78889 .10596 L
s
.78739 .10497 m
.77927 .11093 L
s
.405 0 1 r
.19011 .96841 m
.17869 .96303 L
s
0 1 .626 r
.81602 .50341 m
.81751 .50138 L
s
.81751 .50138 m
.81767 .49384 L
s
.81751 .50138 m
.80922 .49811 L
s
0 1 .021 r
.74901 .6925 m
.74773 .69779 L
s
0 1 .569 r
.33963 .77733 m
.33544 .77663 L
s
.33534 .76913 m
.33963 .77733 L
s
0 .878 1 r
.82474 .10702 m
.77927 .11093 L
s
0 1 .911 r
.80151 .2993 m
.80152 .30087 L
s
.80151 .2993 m
.79298 .30462 L
s
.673 1 0 r
.38675 .39502 m
.38421 .39792 L
s
.078 1 0 r
.76714 .88607 m
.76623 .8902 L
s
.473 1 0 r
.45565 .20476 m
.45618 .20413 L
s
.45618 .20413 m
.45665 .19962 L
s
.45618 .20413 m
.4517 .20162 L
s
0 1 .569 r
.33534 .76913 m
.33544 .77663 L
s
.32909 .77596 m
.33534 .76913 L
s
.33047 .80675 m
.33534 .76913 L
s
0 .088 1 r
.27353 .95459 m
.27308 .9678 L
s
.26261 .96359 m
.27353 .95459 L
s
.25373 1.00875 m
.27353 .95459 L
s
0 .552 1 r
.34936 .96434 m
.35886 .96737 L
s
.34684 .96415 m
.34936 .96434 L
s
.34936 .96434 m
.35589 .95596 L
s
.298 1 0 r
.39818 .58619 m
.3988 .58718 L
s
.3988 .58718 m
.40355 .58544 L
s
.3988 .58718 m
.39924 .58121 L
s
.40355 .58544 m
.40294 .58445 L
s
.40355 .58544 m
.39924 .58121 L
s
.078 1 0 r
.77192 .88457 m
.76714 .88607 L
s
0 1 .316 r
.83244 .69724 m
.83547 .69497 L
s
.83547 .69497 m
.83584 .68863 L
s
.83547 .69497 m
.82798 .69145 L
s
.473 1 0 r
.45665 .19962 m
.45612 .20024 L
s
.45665 .19962 m
.4517 .20162 L
s
0 1 .626 r
.81767 .49384 m
.81619 .49585 L
s
.81767 .49384 m
.80922 .49811 L
s
1 0 0 r
.01 w
.11239 .10566 Mdot
0 1 .626 r
.5 Mabswid
.80922 .49811 m
.81602 .50341 L
s
.80922 .49811 m
.81619 .49585 L
s
.84748 .50069 m
.80922 .49811 L
s
0 1 .911 r
.79298 .30462 m
.80168 .30946 L
s
.79298 .30462 m
.80152 .30087 L
s
.83609 .3034 m
.79298 .30462 L
s
.298 1 0 r
.39924 .58121 m
.39818 .58619 L
s
.39924 .58121 m
.40294 .58445 L
s
.4074 .60429 m
.39924 .58121 L
s
0 1 .316 r
.82798 .69145 m
.83244 .69724 L
s
.83584 .68863 m
.82798 .69145 L
s
.82798 .69145 m
.83281 .69089 L
s
.85893 .69889 m
.82798 .69145 L
s
0 .878 1 r
.77927 .11093 m
.78936 .11534 L
s
.77927 .11093 m
.78889 .10596 L
s
0 1 .569 r
.33544 .77663 m
.32909 .77596 L
s
0 .552 1 r
.35886 .96737 m
.35637 .96719 L
s
.35589 .95596 m
.35886 .96737 L
s
0 1 .099 r
.84928 .88472 m
.8512 .89115 L
s
.85576 .88356 m
.84928 .88472 L
s
.84928 .88472 m
.85112 .88601 L
s
.85584 .8887 m
.84928 .88472 L
s
.87043 .898 m
.84928 .88472 L
s
.473 1 0 r
.4517 .20162 m
.45565 .20476 L
s
.4517 .20162 m
.45612 .20024 L
s
.47395 .20445 m
.4517 .20162 L
s
0 1 .274 r
.41815 .77638 m
.42244 .77556 L
s
.41289 .77579 m
.41815 .77638 L
s
.41815 .77638 m
.41763 .76903 L
s
.46 1 0 r
.46743 .39488 m
.46902 .39438 L
s
.46902 .39438 m
.47094 .39037 L
s
.46902 .39438 m
.46536 .39044 L
s
0 1 .316 r
.83584 .68863 m
.83281 .69089 L
s
0 1 .099 r
.8512 .89115 m
.85584 .8887 L
s
.85584 .8887 m
.85576 .88356 L
s
0 .493 1 r
.87391 .10991 m
.872 .10878 L
s
.872 .10878 m
.87146 .09825 L
s
.872 .10878 m
.86243 .10505 L
s
.473 1 0 r
.45612 .20024 m
.45565 .20476 L
s
0 .088 1 r
.27308 .9678 m
.26261 .96359 L
s
0 .878 1 r
.78889 .10596 m
.78936 .11534 L
s
.46 1 0 r
.47094 .39037 m
.46935 .39086 L
s
.47094 .39037 m
.46536 .39044 L
s
0 .707 1 r
.88643 .30571 m
.88612 .30391 L
s
.88612 .30391 m
.88562 .29421 L
s
.88612 .30391 m
.87624 .30063 L
s
.298 1 0 r
.40294 .58445 m
.39818 .58619 L
s
0 .552 1 r
.35589 .95596 m
.35637 .96719 L
s
.34684 .96415 m
.35589 .95596 L
s
.3407 1.00503 m
.35589 .95596 L
s
0 1 .911 r
.80152 .30087 m
.80168 .30946 L
s
.46 1 0 r
.46536 .39044 m
.46743 .39488 L
s
.46536 .39044 m
.46935 .39086 L
s
.4845 .40135 m
.46536 .39044 L
s
1 .865 0 r
.12272 .29224 m
.12443 .2921 L
s
.12075 .2919 m
.12272 .29224 L
s
.12272 .29224 m
.12271 .28945 L
s
0 1 .274 r
.41763 .76903 m
.41718 .77497 L
s
.41763 .76903 m
.42244 .77556 L
s
.41289 .77579 m
.41763 .76903 L
s
.41781 .80233 m
.41763 .76903 L
s
0 1 .626 r
.81619 .49585 m
.81602 .50341 L
s
0 .999 1 r
.90097 .50127 m
.90228 .49889 L
s
.90228 .49889 m
.90183 .49025 L
s
.90228 .49889 m
.89257 .49589 L
s
0 1 .316 r
.83281 .69089 m
.83244 .69724 L
s
0 1 .099 r
.85576 .88356 m
.85112 .88601 L
s
.85112 .88601 m
.8512 .89115 L
s
.301 1 0 r
.4813 .58491 m
.48362 .58514 L
s
.48362 .58514 m
.48721 .58198 L
s
.48362 .58514 m
.48156 .57952 L
s
0 .975 1 r
.43307 .96563 m
.44169 .96752 L
s
.43134 .96468 m
.43307 .96563 L
s
.43307 .96563 m
.43858 .95733 L
s
0 .493 1 r
.87146 .09825 m
.87337 .09935 L
s
.87146 .09825 m
.86243 .10505 L
s
0 1 .274 r
.41718 .77497 m
.41289 .77579 L
s
1 .865 0 r
.12443 .2921 m
.12246 .29175 L
s
.12271 .28945 m
.12443 .2921 L
s
.12271 .28945 m
.12246 .29175 L
s
.12075 .2919 m
.12271 .28945 L
s
.12211 .30218 m
.12271 .28945 L
s
.12246 .29175 m
.12075 .2919 L
s
0 1 .274 r
.42244 .77556 m
.41718 .77497 L
s
.46 1 0 r
.46935 .39086 m
.46743 .39488 L
s
0 .707 1 r
.88562 .29421 m
.88592 .29598 L
s
.88562 .29421 m
.87624 .30063 L
s
.103 1 0 r
.53907 .19997 m
.53958 .19916 L
s
.53958 .19916 m
.53981 .1935 L
s
.53958 .19916 m
.53386 .19642 L
s
0 1 .67 r
.91761 .69667 m
.92055 .69383 L
s
.92055 .69383 m
.92004 .6864 L
s
.92055 .69383 m
.91144 .6909 L
s
0 1 .396 r
.93285 .88571 m
.93654 .89206 L
s
.94006 .8826 m
.93285 .88571 L
s
.93285 .88571 m
.9355 .88584 L
s
.94109 .88881 m
.93285 .88571 L
s
.96033 .89387 m
.93285 .88571 L
s
0 1 .67 r
.91144 .6909 m
.91761 .69667 L
s
.92004 .6864 m
.91144 .6909 L
s
.91144 .6909 m
.91709 .68922 L
s
.94858 .69407 m
.91144 .6909 L
s
.301 1 0 r
.48156 .57952 m
.4813 .58491 L
s
.48721 .58198 m
.48156 .57952 L
s
.48156 .57952 m
.4849 .58174 L
s
.49511 .59916 m
.48156 .57952 L
s
.48721 .58198 m
.4849 .58174 L
s
0 .999 1 r
.90183 .49025 m
.90052 .49261 L
s
.90183 .49025 m
.89257 .49589 L
s
0 .493 1 r
.91366 .10019 m
.86243 .10505 L
s
0 .975 1 r
.44169 .96752 m
.43998 .96658 L
s
.43858 .95733 m
.44169 .96752 L
s
0 .999 1 r
.89257 .49589 m
.90097 .50127 L
s
.89257 .49589 m
.90052 .49261 L
s
.93689 .4952 m
.89257 .49589 L
s
.103 1 0 r
.53981 .1935 m
.5393 .19429 L
s
.53981 .1935 m
.53386 .19642 L
s
1 .385 0 r
.1944 .09982 m
.19464 .09969 L
s
.19464 .09969 m
.1945 .09853 L
s
.19464 .09969 m
.19334 .09926 L
s
.1945 .09853 m
.19426 .09866 L
s
.1945 .09853 m
.19334 .09926 L
s
0 .707 1 r
.87624 .30063 m
.88643 .30571 L
s
.87624 .30063 m
.88592 .29598 L
s
.92525 .29724 m
.87624 .30063 L
s
0 1 .396 r
.93654 .89206 m
.94109 .88881 L
s
.94109 .88881 m
.94006 .8826 L
s
.245 1 0 r
.13441 .47912 m
.13851 .4796 L
s
.13112 .47848 m
.13441 .47912 L
s
.13441 .47912 m
.13555 .4739 L
s
0 .552 1 r
.35637 .96719 m
.34684 .96415 L
s
1 .385 0 r
.19334 .09926 m
.1944 .09982 L
s
.19334 .09926 m
.19426 .09866 L
s
.19891 .09882 m
.19334 .09926 L
s
0 1 .67 r
.92004 .6864 m
.91709 .68922 L
s
0 .975 1 r
.43858 .95733 m
.43998 .96658 L
s
.43134 .96468 m
.43858 .95733 L
s
.42828 1.00129 m
.43858 .95733 L
s
1 .385 0 r
.19426 .09866 m
.1944 .09982 L
s
.103 1 0 r
.53386 .19642 m
.53907 .19997 L
s
.53386 .19642 m
.5393 .19429 L
s
.56178 .19795 m
.53386 .19642 L
s
.176 1 0 r
.55122 .39176 m
.55292 .39084 L
s
.55292 .39084 m
.55429 .38573 L
s
.55292 .39084 m
.54781 .38705 L
s
0 .493 1 r
.86243 .10505 m
.87391 .10991 L
s
.86243 .10505 m
.87337 .09935 L
s
0 1 .067 r
.49798 .77453 m
.49875 .77615 L
s
.49875 .77615 m
.50478 .77488 L
s
.49875 .77615 m
.50029 .76893 L
s
.50478 .77488 m
.50402 .77325 L
s
.50478 .77488 m
.50029 .76893 L
s
.301 1 0 r
.4849 .58174 m
.4813 .58491 L
s
0 1 .067 r
.50029 .76893 m
.49798 .77453 L
s
.50029 .76893 m
.50402 .77325 L
s
.50576 .79789 m
.50029 .76893 L
s
.245 1 0 r
.13851 .4796 m
.13522 .47896 L
s
.13555 .4739 m
.13851 .4796 L
s
0 1 .396 r
.94006 .8826 m
.9355 .88584 L
s
.176 1 0 r
.55429 .38573 m
.55258 .38664 L
s
.55429 .38573 m
.54781 .38705 L
s
.54781 .38705 m
.55122 .39176 L
s
.54781 .38705 m
.55258 .38664 L
s
.57258 .39552 m
.54781 .38705 L
s
.103 1 0 r
.5393 .19429 m
.53907 .19997 L
s
.245 1 0 r
.13555 .4739 m
.13522 .47896 L
s
.13112 .47848 m
.13555 .4739 L
s
.13187 .4996 m
.13555 .4739 L
s
0 .493 1 r
.87337 .09935 m
.87391 .10991 L
s
0 1 .396 r
.9355 .88584 m
.93654 .89206 L
s
0 1 .665 r
.51722 .96693 m
.52504 .9677 L
s
.51608 .96519 m
.51722 .96693 L
s
.51722 .96693 m
.52159 .95871 L
s
.184 1 0 r
.5654 .58351 m
.5683 .58291 L
s
.5683 .58291 m
.57081 .5786 L
s
.5683 .58291 m
.56429 .57783 L
s
0 .707 1 r
.88592 .29598 m
.88643 .30571 L
s
0 1 .67 r
.91709 .68922 m
.91761 .69667 L
s
0 .999 1 r
.90052 .49261 m
.90097 .50127 L
s
1 .841 0 r
.20644 .28692 m
.20601 .2863 L
s
.20413 .28792 m
.20644 .28692 L
s
.20644 .28692 m
.20413 .28489 L
s
.2037 .2873 m
.20413 .28792 L
s
.20413 .28792 m
.20413 .28489 L
s
.245 1 0 r
.13522 .47896 m
.13112 .47848 L
s
0 1 .694 r
.14765 .66621 m
.15451 .668 L
s
.14365 .66566 m
.14765 .66621 L
s
.14765 .66621 m
.15093 .65906 L
s
1 .841 0 r
.20413 .28489 m
.2037 .2873 L
s
.20413 .28489 m
.20601 .2863 L
s
.20885 .296 m
.20413 .28489 L
s
0 1 .665 r
.52504 .9677 m
.52393 .96597 L
s
.52159 .95871 m
.52504 .9677 L
s
.184 1 0 r
.56429 .57783 m
.5654 .58351 L
s
.57081 .5786 m
.56429 .57783 L
s
.56429 .57783 m
.56792 .5792 L
s
.58342 .594 m
.56429 .57783 L
s
0 .975 1 r
.43998 .96658 m
.43134 .96468 L
s
0 1 .274 r
.62306 .19514 m
.62347 .19416 L
s
.62347 .19416 m
.62348 .18734 L
s
.62347 .19416 m
.61653 .19119 L
s
0 1 .665 r
.52159 .95871 m
.52393 .96597 L
s
.51608 .96519 m
.52159 .95871 L
s
.51646 .99753 m
.52159 .95871 L
s
.176 1 0 r
.55258 .38664 m
.55122 .39176 L
s
.184 1 0 r
.57081 .5786 m
.56792 .5792 L
s
1 .841 0 r
.20601 .2863 m
.2037 .2873 L
s
0 1 .067 r
.50402 .77325 m
.49798 .77453 L
s
.022 1 0 r
.58163 .77523 m
.58573 .77549 L
s
.58573 .77549 m
.5894 .77222 L
s
.58573 .77549 m
.58333 .76883 L
s
1 .77 0 r
.27697 .09393 m
.27739 .09368 L
s
.27739 .09368 m
.27713 .09136 L
s
.27739 .09368 m
.27481 .09282 L
s
0 1 .694 r
.15451 .668 m
.15051 .66746 L
s
.15093 .65906 m
.15451 .668 L
s
0 1 .274 r
.62348 .18734 m
.62307 .1883 L
s
.62348 .18734 m
.61653 .19119 L
s
.427 1 0 r
.21872 .47614 m
.22093 .47534 L
s
.21452 .476 m
.21872 .47614 L
s
.21872 .47614 m
.21745 .47107 L
s
.022 1 0 r
.58333 .76883 m
.58163 .77523 L
s
.5894 .77222 m
.58333 .76883 L
s
.58333 .76883 m
.5853 .77196 L
s
.59432 .79341 m
.58333 .76883 L
s
1 .77 0 r
.27713 .09136 m
.27671 .09161 L
s
.27713 .09136 m
.27481 .09282 L
s
0 1 .151 r
.63553 .38859 m
.63724 .38731 L
s
.63724 .38731 m
.63811 .38109 L
s
.63724 .38731 m
.63072 .38364 L
s
.184 1 0 r
.56792 .5792 m
.5654 .58351 L
s
1 .77 0 r
.27481 .09282 m
.27697 .09393 L
s
.27481 .09282 m
.27671 .09161 L
s
.28602 .09194 m
.27481 .09282 L
s
0 1 .274 r
.61653 .19119 m
.62306 .19514 L
s
.61653 .19119 m
.62307 .1883 L
s
.65023 .1914 m
.61653 .19119 L
s
1 .77 0 r
.27671 .09161 m
.27697 .09393 L
s
0 .295 1 r
.16265 .85352 m
.17242 .85719 L
s
.15836 .85365 m
.16265 .85352 L
s
.16265 .85352 m
.16887 .84498 L
s
0 1 .694 r
.14167 .69793 m
.15093 .65906 L
s
.15093 .65906 m
.15051 .66746 L
s
.14365 .66566 m
.15093 .65906 L
s
0 1 .395 r
.60552 .9686 m
.61005 .96657 L
s
.59994 .96701 m
.60552 .9686 L
s
.60493 .9601 m
.60552 .9686 L
s
.022 1 0 r
.5894 .77222 m
.5853 .77196 L
s
0 1 .151 r
.63811 .38109 m
.63639 .38236 L
s
.63811 .38109 m
.63072 .38364 L
s
.427 1 0 r
.21674 .47519 m
.21452 .476 L
s
.21452 .476 m
.21745 .47107 L
s
.21745 .47107 m
.21674 .47519 L
s
.21745 .47107 m
.22093 .47534 L
s
.21885 .4941 m
.21745 .47107 L
s
0 1 .151 r
.63072 .38364 m
.63553 .38859 L
s
.63072 .38364 m
.63639 .38236 L
s
.66127 .38965 m
.63072 .38364 L
s
0 1 .395 r
.60447 .96497 m
.60493 .9601 L
s
.60493 .9601 m
.59994 .96701 L
s
.61005 .96657 m
.60493 .9601 L
s
.60526 .99374 m
.60493 .9601 L
s
0 1 .033 r
.65006 .582 m
.65313 .58071 L
s
.65313 .58071 m
.65477 .57532 L
s
.65313 .58071 m
.64746 .57613 L
s
.022 1 0 r
.5853 .77196 m
.58163 .77523 L
s
0 1 .665 r
.52393 .96597 m
.51608 .96519 L
s
.427 1 0 r
.22093 .47534 m
.21674 .47519 L
s
1 .991 0 r
.28654 .28329 m
.28786 .28339 L
s
.28786 .28339 m
.28958 .28109 L
s
.28786 .28339 m
.28603 .2803 L
s
0 1 .39 r
.23171 .66508 m
.23745 .66555 L
s
.22741 .66425 m
.23171 .66508 L
s
.23171 .66508 m
.23331 .65785 L
s
0 1 .274 r
.62307 .1883 m
.62306 .19514 L
s
0 1 .694 r
.15051 .66746 m
.14365 .66566 L
s
0 1 .033 r
.64746 .57613 m
.65006 .582 L
s
.65477 .57532 m
.64746 .57613 L
s
.64746 .57613 m
.65171 .57661 L
s
.67235 .58881 m
.64746 .57613 L
s
0 .295 1 r
.17242 .85719 m
.16817 .85734 L
s
.16887 .84498 m
.17242 .85719 L
s
1 .991 0 r
.28958 .28109 m
.28826 .28099 L
s
.28958 .28109 m
.28603 .2803 L
s
.28603 .2803 m
.28654 .28329 L
s
.28603 .2803 m
.28826 .28099 L
s
.29621 .28979 m
.28603 .2803 L
s
0 1 .033 r
.65477 .57532 m
.65171 .57661 L
s
0 1 .654 r
.70761 .19027 m
.70785 .18914 L
s
.70785 .18914 m
.70767 .18115 L
s
.70785 .18914 m
.69973 .18593 L
s
0 1 .395 r
.60447 .96497 m
.59994 .96701 L
s
0 1 .021 r
.66675 .77546 m
.67139 .77444 L
s
.67139 .77444 m
.67341 .77003 L
s
.67139 .77444 m
.66675 .76873 L
s
0 1 .151 r
.63639 .38236 m
.63553 .38859 L
s
0 1 .021 r
.66675 .76873 m
.66675 .77546 L
s
.67341 .77003 m
.66675 .76873 L
s
.66675 .76873 m
.66877 .77104 L
s
.68349 .7889 m
.66675 .76873 L
s
1 .991 0 r
.28826 .28099 m
.28654 .28329 L
s
0 1 .395 r
.61005 .96657 m
.60447 .96497 L
s
0 1 .39 r
.23745 .66555 m
.23316 .66471 L
s
.23331 .65785 m
.23745 .66555 L
s
0 1 .504 r
.72036 .38539 m
.72202 .38378 L
s
.72202 .38378 m
.72241 .37644 L
s
.72202 .38378 m
.71411 .38021 L
s
.845 1 0 r
.36012 .08801 m
.36065 .08764 L
s
.36065 .08764 m
.36028 .08414 L
s
.36065 .08764 m
.35681 .08634 L
s
0 1 .654 r
.70767 .18115 m
.70742 .18227 L
s
.70767 .18115 m
.69973 .18593 L
s
0 1 .033 r
.65171 .57661 m
.65006 .582 L
s
0 .295 1 r
.15152 .89718 m
.16887 .84498 L
s
0 1 .39 r
.23331 .65785 m
.23316 .66471 L
s
.22741 .66425 m
.23331 .65785 L
s
.22889 .69311 m
.23331 .65785 L
s
0 1 .248 r
.6886 .96149 m
.68682 .96954 L
s
.69281 .96473 m
.6886 .96149 L
s
.6886 .96149 m
.68617 .96608 L
s
.69344 .9682 m
.6886 .96149 L
s
.69468 .98992 m
.6886 .96149 L
s
.504 1 0 r
.29862 .47245 m
.29935 .47358 L
s
.29935 .47358 m
.3036 .47211 L
s
.29935 .47358 m
.29978 .46822 L
s
.3036 .47211 m
.30287 .47098 L
s
.3036 .47211 m
.29978 .46822 L
s
0 .295 1 r
.16887 .84498 m
.16817 .85734 L
s
.15836 .85365 m
.16887 .84498 L
s
.845 1 0 r
.36028 .08414 m
.35975 .0845 L
s
.36028 .08414 m
.35681 .08634 L
s
0 .705 1 r
.24656 .85387 m
.25547 .85633 L
s
.2429 .85336 m
.24656 .85387 L
s
.24656 .85387 m
.25175 .84531 L
s
0 1 .021 r
.67341 .77003 m
.66877 .77104 L
s
.845 1 0 r
.35681 .08634 m
.36012 .08801 L
s
.35681 .08634 m
.35975 .0845 L
s
.37374 .085 m
.35681 .08634 L
s
0 1 .021 r
.66877 .77104 m
.66675 .77546 L
s
.504 1 0 r
.29978 .46822 m
.29862 .47245 L
s
.29978 .46822 m
.30287 .47098 L
s
.30644 .48856 m
.29978 .46822 L
s
0 1 .654 r
.69973 .18593 m
.70761 .19027 L
s
.69973 .18593 m
.70742 .18227 L
s
.73929 .18481 m
.69973 .18593 L
s
0 1 .248 r
.68682 .96954 m
.69344 .9682 L
s
.68617 .96608 m
.68682 .96954 L
s
.69344 .9682 m
.69281 .96473 L
s
0 1 .504 r
.72241 .37644 m
.72075 .37803 L
s
.72241 .37644 m
.71411 .38021 L
s
0 1 .39 r
.23316 .66471 m
.22741 .66425 L
s
0 1 .32 r
.7352 .58042 m
.7383 .57854 L
s
.7383 .57854 m
.73918 .57208 L
s
.7383 .57854 m
.73105 .57443 L
s
0 1 .504 r
.71411 .38021 m
.72036 .38539 L
s
.71411 .38021 m
.72075 .37803 L
s
.75058 .38373 m
.71411 .38021 L
s
.845 1 0 r
.35975 .0845 m
.36012 .08801 L
s
0 1 .32 r
.73105 .57443 m
.7352 .58042 L
s
.73918 .57208 m
.73105 .57443 L
s
.73105 .57443 m
.73608 .57394 L
s
.76191 .58358 m
.73105 .57443 L
s
0 1 .151 r
.31712 .66372 m
.32072 .6627 L
s
.31171 .66321 m
.31712 .66372 L
s
.31712 .66372 m
.31609 .65664 L
s
0 .705 1 r
.25547 .85633 m
.25184 .85583 L
s
.25175 .84531 m
.25547 .85633 L
s
.747 1 0 r
.37012 .27913 m
.37172 .27879 L
s
.37172 .27879 m
.37299 .27536 L
s
.37172 .27879 m
.36841 .27567 L
s
0 1 .189 r
.75054 .76863 m
.75225 .77546 L
s
.75787 .76805 m
.75054 .76863 L
s
.75054 .76863 m
.75319 .77 L
s
.75693 .7735 m
.75054 .76863 L
s
.7733 .78435 m
.75054 .76863 L
s
0 .295 1 r
.16817 .85734 m
.15836 .85365 L
s
0 1 .32 r
.73918 .57208 m
.73608 .57394 L
s
0 1 .189 r
.75225 .77546 m
.75693 .7735 L
s
.75693 .7735 m
.75787 .76805 L
s
.504 1 0 r
.30287 .47098 m
.29862 .47245 L
s
.747 1 0 r
.37299 .27536 m
.3714 .27569 L
s
.37299 .27536 m
.36841 .27567 L
s
.36841 .27567 m
.37012 .27913 L
s
.36841 .27567 m
.3714 .27569 L
s
.38417 .28353 m
.36841 .27567 L
s
0 1 .654 r
.70742 .18227 m
.70761 .19027 L
s
0 .963 1 r
.79273 .18537 m
.79274 .18408 L
s
.79274 .18408 m
.79237 .17492 L
s
.79274 .18408 m
.78346 .18063 L
s
0 1 .248 r
.7726 .96288 m
.77228 .97086 L
s
.77774 .96411 m
.7726 .96288 L
s
.7726 .96288 m
.77144 .96642 L
s
.77857 .96855 m
.7726 .96288 L
s
.78474 .98607 m
.7726 .96288 L
s
0 .705 1 r
.25175 .84531 m
.25184 .85583 L
s
.2429 .85336 m
.25175 .84531 L
s
.23898 .89304 m
.25175 .84531 L
s
0 1 .504 r
.72075 .37803 m
.72036 .38539 L
s
0 1 .151 r
.31609 .65664 m
.3153 .66218 L
s
.31609 .65664 m
.32072 .6627 L
s
.31171 .66321 m
.31609 .65664 L
s
.31672 .68825 m
.31609 .65664 L
s
.747 1 0 r
.3714 .27569 m
.37012 .27913 L
s
0 1 .248 r
.69281 .96473 m
.68617 .96608 L
s
0 1 .873 r
.80573 .38216 m
.80726 .38025 L
s
.80726 .38025 m
.80719 .37177 L
s
.80726 .38025 m
.79799 .37676 L
s
0 1 .151 r
.3153 .66218 m
.31171 .66321 L
s
.46 1 0 r
.38219 .47016 m
.38453 .47055 L
s
.38453 .47055 m
.38773 .46758 L
s
.38453 .47055 m
.38255 .46535 L
s
0 1 .32 r
.73608 .57394 m
.7352 .58042 L
s
0 1 .929 r
.33109 .85425 m
.3391 .85543 L
s
.32766 .8531 m
.33109 .85425 L
s
.33109 .85425 m
.33497 .84564 L
s
.46 1 0 r
.44384 .08205 m
.44441 .08156 L
s
.44441 .08156 m
.44396 .07687 L
s
.44441 .08156 m
.43935 .07982 L
s
0 1 .189 r
.75787 .76805 m
.75319 .77 L
s
0 1 .248 r
.77228 .97086 m
.77857 .96855 L
s
.77857 .96855 m
.77774 .96411 L
s
0 .963 1 r
.79237 .17492 m
.79236 .17619 L
s
.79237 .17492 m
.78346 .18063 L
s
0 1 .151 r
.32072 .6627 m
.3153 .66218 L
s
0 1 .189 r
.75319 .77 m
.75225 .77546 L
s
0 1 .248 r
.77144 .96642 m
.77228 .97086 L
s
.46 1 0 r
.38255 .46535 m
.38219 .47016 L
s
.38773 .46758 m
.38255 .46535 L
s
.38255 .46535 m
.38539 .46719 L
s
.39464 .48298 m
.38255 .46535 L
s
0 1 .657 r
.82083 .57881 m
.82389 .57641 L
s
.82389 .57641 m
.82405 .56885 L
s
.82389 .57641 m
.81507 .57271 L
s
.46 1 0 r
.38773 .46758 m
.38539 .46719 L
s
.44396 .07687 m
.44339 .07735 L
s
.44396 .07687 m
.43935 .07982 L
s
0 1 .873 r
.80719 .37177 m
.80566 .37367 L
s
.80719 .37177 m
.79799 .37676 L
s
0 .705 1 r
.25184 .85583 m
.2429 .85336 L
s
0 1 .873 r
.79799 .37676 m
.80573 .38216 L
s
.79799 .37676 m
.80566 .37367 L
s
.84051 .37777 m
.79799 .37676 L
s
0 1 .657 r
.81507 .57271 m
.82083 .57881 L
s
.82405 .56885 m
.81507 .57271 L
s
.81507 .57271 m
.82098 .57122 L
s
.85209 .57831 m
.81507 .57271 L
s
.46 1 0 r
.43935 .07982 m
.44384 .08205 L
s
.43935 .07982 m
.44339 .07735 L
s
.46208 .07802 m
.43935 .07982 L
s
0 .963 1 r
.78346 .18063 m
.79273 .18537 L
s
.78346 .18063 m
.79236 .17619 L
s
.82898 .17817 m
.78346 .18063 L
s
0 1 .456 r
.83472 .76853 m
.83815 .7754 L
s
.84281 .76613 m
.83472 .76853 L
s
.83472 .76853 m
.83816 .76887 L
s
.84279 .77265 m
.83472 .76853 L
s
.86373 .77978 m
.83472 .76853 L
s
0 1 .929 r
.3391 .85543 m
.33569 .85428 L
s
.33497 .84564 m
.3391 .85543 L
s
0 1 .396 r
.85693 .96428 m
.85818 .97218 L
s
.86302 .96349 m
.85693 .96428 L
s
.85693 .96428 m
.85688 .9667 L
s
.86431 .96897 m
.85693 .96428 L
s
.87543 .9822 m
.85693 .96428 L
s
0 1 .456 r
.83815 .7754 m
.84279 .77265 L
s
.84279 .77265 m
.84281 .76613 L
s
.427 1 0 r
.45424 .27489 m
.45598 .27421 L
s
.45598 .27421 m
.45689 .26964 L
s
.45598 .27421 m
.45128 .27103 L
s
.46 1 0 r
.38539 .46719 m
.38219 .47016 L
s
0 1 .657 r
.82405 .56885 m
.82098 .57122 L
s
0 1 .929 r
.33497 .84564 m
.33569 .85428 L
s
.32766 .8531 m
.33497 .84564 L
s
.32705 .88887 m
.33497 .84564 L
s
0 1 0 r
.39704 .66087 m
.39796 .66254 L
s
.39796 .66254 m
.40382 .66113 L
s
.39796 .66254 m
.39925 .65543 L
s
.40382 .66113 m
.4029 .65946 L
s
.40382 .66113 m
.39925 .65543 L
s
.46 1 0 r
.44339 .07735 m
.44384 .08205 L
s
0 1 .248 r
.77774 .96411 m
.77144 .96642 L
s
.427 1 0 r
.45689 .26964 m
.45515 .27031 L
s
.45689 .26964 m
.45128 .27103 L
s
0 1 0 r
.39925 .65543 m
.39704 .66087 L
s
.39925 .65543 m
.4029 .65946 L
s
.40516 .68336 m
.39925 .65543 L
s
.427 1 0 r
.45128 .27103 m
.45424 .27489 L
s
.45128 .27103 m
.45515 .27031 L
s
.47275 .27722 m
.45128 .27103 L
s
0 .579 1 r
.87843 .18044 m
.87814 .179 L
s
.87814 .179 m
.8776 .16866 L
s
.87814 .179 m
.86772 .1753 L
s
1 .385 0 r
.10615 .17364 m
.10674 .17307 L
s
.10514 .1732 m
.10615 .17364 L
s
.10603 .17221 m
.10615 .17364 L
s
.10572 .17263 m
.10603 .17221 L
s
.10603 .17221 m
.10514 .1732 L
s
.10674 .17307 m
.10603 .17221 L
s
.10558 .17684 m
.10603 .17221 L
s
0 1 .396 r
.85818 .97218 m
.86431 .96897 L
s
.86431 .96897 m
.86302 .96349 L
s
0 .963 1 r
.79236 .17619 m
.79273 .18537 L
s
0 1 .456 r
.84281 .76613 m
.83816 .76887 L
s
0 1 .626 r
.41675 .85468 m
.42344 .85428 L
s
.4125 .85308 m
.41675 .85468 L
s
.41675 .85468 m
.41853 .84596 L
s
1 .385 0 r
.10572 .17263 m
.10514 .1732 L
s
0 .747 1 r
.89164 .37891 m
.89297 .37671 L
s
.89297 .37671 m
.89246 .36709 L
s
.89297 .37671 m
.88234 .37329 L
s
1 .385 0 r
.10674 .17307 m
.10572 .17263 L
s
.304 1 0 r
.4667 .4677 m
.46957 .46733 L
s
.46957 .46733 m
.47188 .46318 L
s
.46957 .46733 m
.46576 .46247 L
s
0 1 .873 r
.80566 .37367 m
.80573 .38216 L
s
0 1 .657 r
.82098 .57122 m
.82083 .57881 L
s
.427 1 0 r
.45515 .27031 m
.45424 .27489 L
s
0 1 .929 r
.33569 .85428 m
.32766 .8531 L
s
0 .975 1 r
.90694 .57716 m
.90991 .5743 L
s
.90991 .5743 m
.90936 .56562 L
s
.90991 .5743 m
.89953 .57098 L
s
0 1 .456 r
.83816 .76887 m
.83815 .7754 L
s
0 1 .396 r
.85688 .9667 m
.85818 .97218 L
s
.304 1 0 r
.46576 .46247 m
.4667 .4677 L
s
.47188 .46318 m
.46576 .46247 L
s
.46576 .46247 m
.46902 .46355 L
s
.48346 .47736 m
.46576 .46247 L
s
.075 1 0 r
.52813 .07604 m
.52868 .07544 L
s
.52868 .07544 m
.52817 .06956 L
s
.52868 .07544 m
.52244 .07325 L
s
0 1 .667 r
.9416 .96569 m
.94454 .97351 L
s
.94863 .96286 m
.9416 .96569 L
s
.9416 .96569 m
.94253 .96692 L
s
.95063 .96945 m
.9416 .96569 L
s
.96676 .9783 m
.9416 .96569 L
s
0 .579 1 r
.8776 .16866 m
.87789 .17006 L
s
.8776 .16866 m
.86772 .1753 L
s
0 1 .794 r
.91928 .76843 m
.92446 .7753 L
s
.92819 .76424 m
.91928 .76843 L
s
.91928 .76843 m
.92358 .76766 L
s
.92906 .77186 m
.91928 .76843 L
s
.95481 .77517 m
.91928 .76843 L
s
.304 1 0 r
.47188 .46318 m
.46902 .46355 L
s
0 .975 1 r
.89953 .57098 m
.90694 .57716 L
s
.90936 .56562 m
.89953 .57098 L
s
.89953 .57098 m
.90639 .56846 L
s
.94291 .573 m
.89953 .57098 L
s
0 .747 1 r
.89246 .36709 m
.89113 .36926 L
s
.89246 .36709 m
.88234 .37329 L
s
0 1 .626 r
.41853 .84596 m
.4192 .85268 L
s
.41853 .84596 m
.42344 .85428 L
s
.4125 .85308 m
.41853 .84596 L
s
.41573 .88467 m
.41853 .84596 L
s
0 1 0 r
.4029 .65946 m
.39704 .66087 L
s
0 1 .794 r
.92446 .7753 m
.92906 .77186 L
s
.92906 .77186 m
.92819 .76424 L
s
0 1 .396 r
.86302 .96349 m
.85688 .9667 L
s
.075 1 0 r
.52817 .06956 m
.52762 .07015 L
s
.52817 .06956 m
.52244 .07325 L
s
0 .747 1 r
.88234 .37329 m
.89164 .37891 L
s
.88234 .37329 m
.89113 .36926 L
s
.93108 .37177 m
.88234 .37329 L
s
.042 1 0 r
.48122 .66044 m
.48499 .66095 L
s
.48499 .66095 m
.48895 .65763 L
s
.48499 .66095 m
.48281 .65421 L
s
.776 1 0 r
.11669 .36295 m
.11941 .36263 L
s
.11413 .36205 m
.11669 .36295 L
s
.11669 .36295 m
.11711 .35878 L
s
0 1 .626 r
.42344 .85428 m
.4192 .85268 L
s
0 .975 1 r
.90936 .56562 m
.90639 .56846 L
s
0 .579 1 r
.86772 .1753 m
.87843 .18044 L
s
.86772 .1753 m
.87789 .17006 L
s
.9193 .17149 m
.86772 .1753 L
s
.078 1 0 r
.53891 .27059 m
.5407 .26963 L
s
.5407 .26963 m
.54128 .26392 L
s
.5407 .26963 m
.53465 .26635 L
s
.304 1 0 r
.46902 .46355 m
.4667 .4677 L
s
.075 1 0 r
.52244 .07325 m
.52813 .07604 L
s
.52244 .07325 m
.52762 .07015 L
s
.55104 .07099 m
.52244 .07325 L
s
.042 1 0 r
.48281 .65421 m
.48122 .66044 L
s
.48895 .65763 m
.48281 .65421 L
s
.48281 .65421 m
.48518 .65711 L
s
.49423 .67843 m
.48281 .65421 L
s
0 1 .667 r
.94454 .97351 m
.95063 .96945 L
s
.95063 .96945 m
.94863 .96286 L
s
.776 1 0 r
.11711 .35878 m
.11686 .36172 L
s
.11711 .35878 m
.11941 .36263 L
s
.11413 .36205 m
.11711 .35878 L
s
.11543 .37658 m
.11711 .35878 L
s
.11941 .36263 m
.11686 .36172 L
s
0 1 .794 r
.92819 .76424 m
.92358 .76766 L
s
.078 1 0 r
.54128 .26392 m
.53949 .26487 L
s
.54128 .26392 m
.53465 .26635 L
s
0 1 .626 r
.4192 .85268 m
.4125 .85308 L
s
.042 1 0 r
.48895 .65763 m
.48518 .65711 L
s
.078 1 0 r
.53465 .26635 m
.53891 .27059 L
s
.53465 .26635 m
.53949 .26487 L
s
.56195 .27088 m
.53465 .26635 L
s
.776 1 0 r
.11686 .36172 m
.11413 .36205 L
s
.075 1 0 r
.52762 .07015 m
.52813 .07604 L
s
.064 1 0 r
.55176 .46512 m
.55482 .46412 L
s
.55482 .46412 m
.55645 .45887 L
s
.55482 .46412 m
.54942 .45958 L
s
1 .546 0 r
.18848 .16787 m
.18971 .16779 L
s
.18971 .16779 m
.19014 .16631 L
s
.18971 .16779 m
.18828 .16633 L
s
.18828 .16633 m
.18848 .16787 L
s
.19014 .16631 m
.18828 .16633 L
s
.18828 .16633 m
.18891 .16639 L
s
.19342 .17015 m
.18828 .16633 L
s
0 1 .407 r
.49886 .85232 m
.49985 .8547 L
s
.49985 .8547 m
.50706 .85387 L
s
.49985 .8547 m
.50244 .84629 L
s
.042 1 0 r
.48518 .65711 m
.48122 .66044 L
s
0 1 .116 r
.12877 .55252 m
.1341 .55312 L
s
.12523 .55143 m
.12877 .55252 L
s
.12877 .55252 m
.13075 .54604 L
s
1 .546 0 r
.19014 .16631 m
.18891 .16639 L
s
0 1 .667 r
.94253 .96692 m
.94454 .97351 L
s
0 1 .407 r
.50706 .85387 m
.50608 .85148 L
s
.50706 .85387 m
.50244 .84629 L
s
.50244 .84629 m
.49886 .85232 L
s
.50244 .84629 m
.50608 .85148 L
s
.50505 .88045 m
.50244 .84629 L
s
0 1 .667 r
.94863 .96286 m
.94253 .96692 L
s
0 1 .794 r
.92358 .76766 m
.92446 .7753 L
s
.064 1 0 r
.54942 .45958 m
.55176 .46512 L
s
.55645 .45887 m
.54942 .45958 L
s
.54942 .45958 m
.55338 .45986 L
s
.57291 .4717 m
.54942 .45958 L
s
1 .546 0 r
.18891 .16639 m
.18848 .16787 L
s
0 .579 1 r
.87789 .17006 m
.87843 .18044 L
s
0 .975 1 r
.90639 .56846 m
.90694 .57716 L
s
0 .747 1 r
.89113 .36926 m
.89164 .37891 L
s
.078 1 0 r
.53949 .26487 m
.53891 .27059 L
s
.064 1 0 r
.55645 .45887 m
.55338 .45986 L
s
0 1 .309 r
.61302 .06999 m
.61347 .06928 L
s
.61347 .06928 m
.61291 .0622 L
s
.61347 .06928 m
.60606 .06664 L
s
0 1 .033 r
.5667 .65966 m
.57116 .65901 L
s
.57116 .65901 m
.57367 .65447 L
s
.57116 .65901 m
.56677 .65298 L
s
0 1 .116 r
.1341 .55312 m
.13057 .55204 L
s
.13075 .54604 m
.1341 .55312 L
s
0 1 .033 r
.56677 .65298 m
.5667 .65966 L
s
.57367 .65447 m
.56677 .65298 L
s
.56677 .65298 m
.56921 .65511 L
s
.58393 .67347 m
.56677 .65298 L
s
0 1 .309 r
.61291 .0622 m
.61246 .06289 L
s
.61291 .0622 m
.60606 .06664 L
s
0 1 .116 r
.13075 .54604 m
.13057 .55204 L
s
.12523 .55143 m
.13075 .54604 L
s
.12533 .57725 m
.13075 .54604 L
s
0 1 .286 r
.62412 .26626 m
.62591 .26504 L
s
.62591 .26504 m
.62617 .25818 L
s
.62591 .26504 m
.61851 .26165 L
s
.064 1 0 r
.55338 .45986 m
.55176 .46512 L
s
.83 1 0 r
.19849 .35771 m
.19926 .35898 L
s
.19926 .35898 m
.20267 .35804 L
s
.19926 .35898 m
.19985 .35471 L
s
.20267 .35804 m
.2019 .35678 L
s
.20267 .35804 m
.19985 .35471 L
s
.19985 .35471 m
.19849 .35771 L
s
.19985 .35471 m
.2019 .35678 L
s
.20351 .37057 m
.19985 .35471 L
s
0 .934 1 r
.14253 .74231 m
.15073 .74447 L
s
.13853 .74154 m
.14253 .74231 L
s
.14253 .74231 m
.14697 .73405 L
s
0 1 .309 r
.60606 .06664 m
.61302 .06999 L
s
.60606 .06664 m
.61246 .06289 L
s
.64062 .06391 m
.60606 .06664 L
s
0 1 .033 r
.57367 .65447 m
.56921 .65511 L
s
0 1 .299 r
.58398 .85443 m
.59031 .85429 L
s
.59031 .85429 m
.59274 .85058 L
s
.59031 .85429 m
.58671 .84663 L
s
0 1 .116 r
.13057 .55204 m
.12523 .55143 L
s
0 1 .299 r
.58671 .84663 m
.58398 .85443 L
s
.59274 .85058 m
.58671 .84663 L
s
.58671 .84663 m
.58639 .85071 L
s
.59499 .87619 m
.58671 .84663 L
s
0 1 .286 r
.62617 .25818 m
.62439 .25938 L
s
.62617 .25818 m
.61851 .26165 L
s
0 1 .407 r
.50608 .85148 m
.49886 .85232 L
s
0 1 .286 r
.61851 .26165 m
.62412 .26626 L
s
.61851 .26165 m
.62439 .25938 L
s
.65178 .26448 m
.61851 .26165 L
s
0 1 .234 r
.63731 .46246 m
.64046 .46096 L
s
.64046 .46096 m
.64149 .4546 L
s
.64046 .46096 m
.63353 .45667 L
s
0 1 .033 r
.56921 .65511 m
.5667 .65966 L
s
1 .865 0 r
.27234 .16246 m
.2738 .16213 L
s
.2738 .16213 m
.27408 .15956 L
s
.2738 .16213 m
.27105 .16041 L
s
.83 1 0 r
.2019 .35678 m
.19849 .35771 L
s
.078 1 0 r
.21459 .55023 m
.21802 .54923 L
s
.20981 .54941 m
.21459 .55023 L
s
.21459 .55023 m
.21398 .54368 L
s
0 1 .234 r
.63353 .45667 m
.63731 .46246 L
s
.64149 .4546 m
.63353 .45667 L
s
.63353 .45667 m
.63834 .45609 L
s
.66299 .46601 m
.63353 .45667 L
s
1 .865 0 r
.27105 .16041 m
.27234 .16246 L
s
.27408 .15956 m
.27105 .16041 L
s
.27105 .16041 m
.27262 .15989 L
s
.28188 .1634 m
.27105 .16041 L
s
0 .934 1 r
.15073 .74447 m
.14674 .74371 L
s
.14697 .73405 m
.15073 .74447 L
s
0 1 .309 r
.61246 .06289 m
.61302 .06999 L
s
1 .865 0 r
.27408 .15956 m
.27262 .15989 L
s
0 1 .299 r
.58639 .85071 m
.58398 .85443 L
s
0 1 .234 r
.64149 .4546 m
.63834 .45609 L
s
0 1 .211 r
.65266 .65866 m
.65729 .65712 L
s
.65729 .65712 m
.6588 .6515 L
s
.65729 .65712 m
.65113 .65175 L
s
1 .865 0 r
.27262 .15989 m
.27234 .16246 L
s
0 1 .211 r
.65113 .65175 m
.65266 .65866 L
s
.6588 .6515 m
.65113 .65175 L
s
.65113 .65175 m
.65418 .65303 L
s
.67426 .66848 m
.65113 .65175 L
s
0 1 .694 r
.6985 .0639 m
.69878 .06309 L
s
.69878 .06309 m
.6982 .05479 L
s
.69878 .06309 m
.69024 .05998 L
s
0 1 .286 r
.62439 .25938 m
.62412 .26626 L
s
0 .934 1 r
.14697 .73405 m
.14674 .74371 L
s
.13853 .74154 m
.14697 .73405 L
s
.13528 .77886 m
.14697 .73405 L
s
.092 0 1 r
.15815 .93237 m
.16931 .93659 L
s
.15405 .93256 m
.15815 .93237 L
s
.15815 .93237 m
.1658 .92288 L
s
.078 1 0 r
.21398 .54368 m
.21324 .54841 L
s
.21398 .54368 m
.21802 .54923 L
s
.20981 .54941 m
.21398 .54368 L
s
.21365 .57194 m
.21398 .54368 L
s
0 1 .299 r
.59274 .85058 m
.58639 .85071 L
s
.078 1 0 r
.21324 .54841 m
.20981 .54941 L
s
.747 1 0 r
.2825 .35447 m
.2849 .35489 L
s
.2849 .35489 m
.28725 .35231 L
s
.2849 .35489 m
.28305 .35062 L
s
0 1 .316 r
.67133 .84696 m
.67051 .85506 L
s
.67781 .84876 m
.67133 .84696 L
s
.67133 .84696 m
.67141 .8503 L
s
.67689 .85352 m
.67133 .84696 L
s
.68558 .8719 m
.67133 .84696 L
s
0 1 .659 r
.70988 .26189 m
.71159 .26044 L
s
.71159 .26044 m
.71157 .2524 L
s
.71159 .26044 m
.70288 .25692 L
s
.078 1 0 r
.21802 .54923 m
.21324 .54841 L
s
0 1 .234 r
.63834 .45609 m
.63731 .46246 L
s
0 1 .753 r
.22773 .74171 m
.235 .74251 L
s
.22365 .74042 m
.22773 .74171 L
s
.22773 .74171 m
.2307 .73329 L
s
0 1 .694 r
.6982 .05479 m
.69792 .05558 L
s
.6982 .05479 m
.69024 .05998 L
s
.747 1 0 r
.28305 .35062 m
.2825 .35447 L
s
.28725 .35231 m
.28305 .35062 L
s
.28305 .35062 m
.28485 .35189 L
s
.29221 .36452 m
.28305 .35062 L
s
0 1 .316 r
.67051 .85506 m
.67689 .85352 L
s
.67689 .85352 m
.67781 .84876 L
s
0 1 .211 r
.6588 .6515 m
.65418 .65303 L
s
.747 1 0 r
.28725 .35231 m
.28485 .35189 L
s
.092 0 1 r
.16931 .93659 m
.16525 .9368 L
s
.1658 .92288 m
.16931 .93659 L
s
0 1 .569 r
.72337 .45976 m
.72653 .45781 L
s
.72653 .45781 m
.727 .45033 L
s
.72653 .45781 m
.7181 .45374 L
s
0 1 .211 r
.65418 .65303 m
.65266 .65866 L
s
0 .934 1 r
.14674 .74371 m
.13853 .74154 L
s
0 1 .659 r
.71157 .2524 m
.70986 .25383 L
s
.71157 .2524 m
.70288 .25692 L
s
0 1 .694 r
.69024 .05998 m
.6985 .0639 L
s
.69024 .05998 m
.69792 .05558 L
s
.73083 .05678 m
.69024 .05998 L
s
0 1 .659 r
.70288 .25692 m
.70988 .26189 L
s
.70288 .25692 m
.70986 .25383 L
s
.74224 .25805 m
.70288 .25692 L
s
.747 1 0 r
.28485 .35189 m
.2825 .35447 L
s
0 1 .316 r
.67141 .8503 m
.67051 .85506 L
s
0 1 .569 r
.7181 .45374 m
.72337 .45976 L
s
.727 .45033 m
.7181 .45374 L
s
.7181 .45374 m
.72384 .45226 L
s
.75371 .46027 m
.7181 .45374 L
s
.776 1 0 r
.35677 .15702 m
.35841 .15648 L
s
.35841 .15648 m
.35852 .15276 L
s
.35841 .15648 m
.35432 .15446 L
s
0 1 .753 r
.235 .74251 m
.23094 .74122 L
s
.2307 .73329 m
.235 .74251 L
s
0 1 .471 r
.7359 .65051 m
.73904 .65757 L
s
.74442 .6486 m
.7359 .65051 L
s
.7359 .65051 m
.73973 .65086 L
s
.74372 .6553 m
.7359 .65051 L
s
.76523 .66344 m
.7359 .65051 L
s
.73904 .65757 m
.74372 .6553 L
s
.74372 .6553 m
.74442 .6486 L
s
.181 1 0 r
.2954 .5461 m
.29645 .54787 L
s
.29645 .54787 m
.30183 .54659 L
s
.29645 .54787 m
.29762 .5413 L
s
.776 1 0 r
.35432 .15446 m
.35677 .15702 L
s
.35852 .15276 m
.35432 .15446 L
s
.35432 .15446 m
.35688 .15329 L
s
.37096 .15661 m
.35432 .15446 L
s
0 1 .753 r
.2307 .73329 m
.23094 .74122 L
s
.22365 .74042 m
.2307 .73329 L
s
.22384 .77425 m
.2307 .73329 L
s
.181 1 0 r
.30183 .54659 m
.30079 .54481 L
s
.30183 .54659 m
.29762 .5413 L
s
0 1 .569 r
.727 .45033 m
.72384 .45226 L
s
.776 1 0 r
.35852 .15276 m
.35688 .15329 L
s
.181 1 0 r
.29762 .5413 m
.2954 .5461 L
s
.29762 .5413 m
.30079 .54481 L
s
.3026 .56659 m
.29762 .5413 L
s
0 .324 1 r
.2432 .93314 m
.25357 .93618 L
s
.2401 .93256 m
.2432 .93314 L
s
.2432 .93314 m
.25003 .92361 L
s
0 1 .456 r
.7563 .84729 m
.75719 .85549 L
s
.76354 .84714 m
.7563 .84729 L
s
.7563 .84729 m
.75724 .8497 L
s
.76348 .85293 m
.7563 .84729 L
s
.7768 .86758 m
.7563 .84729 L
s
0 1 .316 r
.67781 .84876 m
.67141 .8503 L
s
.092 0 1 r
.1658 .92288 m
.16525 .9368 L
s
.15405 .93256 m
.1658 .92288 L
s
.14527 .98142 m
.1658 .92288 L
s
0 1 .694 r
.69792 .05558 m
.6985 .0639 L
s
0 .921 1 r
.78457 .05777 m
.78461 .05686 L
s
.78461 .05686 m
.78404 .04734 L
s
.78461 .05686 m
.77498 .05329 L
s
.776 1 0 r
.35688 .15329 m
.35677 .15702 L
s
0 1 .659 r
.70986 .25383 m
.70988 .26189 L
s
0 1 .456 r
.75719 .85549 m
.76348 .85293 L
s
.76348 .85293 m
.76354 .84714 L
s
.548 1 0 r
.36742 .35088 m
.37023 .35062 L
s
.37023 .35062 m
.37192 .34688 L
s
.37023 .35062 m
.36671 .3465 L
s
0 1 .504 r
.31434 .74107 m
.31987 .74016 L
s
.30902 .73967 m
.31434 .74107 L
s
.31434 .74107 m
.3148 .73252 L
s
0 .961 1 r
.7962 .25749 m
.79777 .25581 L
s
.79777 .25581 m
.79748 .2466 L
s
.79777 .25581 m
.78775 .25216 L
s
0 1 .471 r
.74442 .6486 m
.73973 .65086 L
s
0 .324 1 r
.25357 .93618 m
.2505 .93561 L
s
.25003 .92361 m
.25357 .93618 L
s
0 1 .753 r
.23094 .74122 m
.22365 .74042 L
s
.548 1 0 r
.36671 .3465 m
.36742 .35088 L
s
.37192 .34688 m
.36671 .3465 L
s
.36671 .3465 m
.36911 .34714 L
s
.38154 .35843 m
.36671 .3465 L
s
0 1 .569 r
.72384 .45226 m
.72337 .45976 L
s
0 1 .929 r
.80994 .45702 m
.81305 .45467 L
s
.81305 .45467 m
.81299 .44605 L
s
.81305 .45467 m
.80312 .4508 L
s
0 .921 1 r
.78404 .04734 m
.784 .04822 L
s
.78404 .04734 m
.77498 .05329 L
s
.548 1 0 r
.37192 .34688 m
.36911 .34714 L
s
0 1 .471 r
.73973 .65086 m
.73904 .65757 L
s
.181 1 0 r
.30079 .54481 m
.2954 .5461 L
s
0 1 .456 r
.75724 .8497 m
.75719 .85549 L
s
0 .961 1 r
.79748 .2466 m
.79591 .24825 L
s
.79748 .2466 m
.78775 .25216 L
s
0 1 .504 r
.3148 .73252 m
.31455 .73876 L
s
.3148 .73252 m
.31987 .74016 L
s
.30902 .73967 m
.3148 .73252 L
s
.31303 .7696 m
.3148 .73252 L
s
0 1 .929 r
.80312 .4508 m
.80994 .45702 L
s
.81299 .44605 m
.80312 .4508 L
s
.80312 .4508 m
.80987 .44838 L
s
.84507 .45449 m
.80312 .4508 L
s
.092 0 1 r
.16525 .9368 m
.15405 .93256 L
s
0 .324 1 r
.25003 .92361 m
.2505 .93561 L
s
.2401 .93256 m
.25003 .92361 L
s
.23407 .97752 m
.25003 .92361 L
s
0 1 .79 r
.82107 .64927 m
.82587 .65644 L
s
.83048 .64572 m
.82107 .64927 L
s
.82107 .64927 m
.8258 .64862 L
s
.83055 .65353 m
.82107 .64927 L
s
.85685 .65838 m
.82107 .64927 L
s
.548 1 0 r
.36911 .34714 m
.36742 .35088 L
s
0 .961 1 r
.78775 .25216 m
.7962 .25749 L
s
.78775 .25216 m
.79591 .24825 L
s
.83335 .25156 m
.78775 .25216 L
s
.176 1 0 r
.38012 .54465 m
.38378 .5453 L
s
.38378 .5453 m
.38744 .54206 L
s
.38378 .5453 m
.38169 .53891 L
s
0 1 .79 r
.82587 .65644 m
.83055 .65353 L
s
.83055 .65353 m
.83048 .64572 L
s
0 1 .699 r
.84163 .84763 m
.84423 .85587 L
s
.84975 .84557 m
.84163 .84763 L
s
.84163 .84763 m
.84349 .84899 L
s
.85048 .85244 m
.84163 .84763 L
s
.86869 .86323 m
.84163 .84763 L
s
0 .921 1 r
.77498 .05329 m
.78457 .05777 L
s
.77498 .05329 m
.784 .04822 L
s
.82168 .04959 m
.77498 .05329 L
s
0 1 .456 r
.76354 .84714 m
.75724 .8497 L
s
.404 1 0 r
.44175 .15153 m
.44353 .15082 L
s
.44353 .15082 m
.44349 .14593 L
s
.44353 .15082 m
.43812 .14847 L
s
0 1 .504 r
.31987 .74016 m
.31455 .73876 L
s
0 1 .929 r
.81299 .44605 m
.80987 .44838 L
s
.176 1 0 r
.38169 .53891 m
.38012 .54465 L
s
.38744 .54206 m
.38169 .53891 L
s
.38169 .53891 m
.38378 .5414 L
s
.39218 .5612 m
.38169 .53891 L
s
0 .694 1 r
.32868 .93393 m
.33832 .93579 L
s
.32642 .93253 m
.32868 .93393 L
s
.32868 .93393 m
.33458 .92435 L
s
.404 1 0 r
.43812 .14847 m
.44175 .15153 L
s
.44349 .14593 m
.43812 .14847 L
s
.43812 .14847 m
.44171 .14663 L
s
.46068 .14978 m
.43812 .14847 L
s
0 1 .504 r
.31455 .73876 m
.30902 .73967 L
s
.404 1 0 r
.44349 .14593 m
.44171 .14663 L
s
0 1 .699 r
.84423 .85587 m
.85048 .85244 L
s
.85048 .85244 m
.84975 .84557 L
s
.176 1 0 r
.38744 .54206 m
.38378 .5414 L
s
0 .694 1 r
.33832 .93579 m
.33609 .9344 L
s
.33458 .92435 m
.33832 .93579 L
s
0 1 .79 r
.83048 .64572 m
.8258 .64862 L
s
.275 1 0 r
.45285 .34715 m
.45586 .34638 L
s
.45586 .34638 m
.45709 .34153 L
s
.45586 .34638 m
.45085 .34236 L
s
0 .536 1 r
.87126 .0516 m
.87098 .05059 L
s
.87098 .05059 m
.87043 .03984 L
s
.87098 .05059 m
.86028 .04654 L
s
0 .578 1 r
.88309 .25305 m
.88445 .25116 L
s
.88445 .25116 m
.8839 .24077 L
s
.88445 .25116 m
.87314 .24737 L
s
0 .921 1 r
.784 .04822 m
.78457 .05777 L
s
.176 1 0 r
.38378 .5414 m
.38012 .54465 L
s
0 1 .338 r
.39586 .73773 m
.39706 .74009 L
s
.39706 .74009 m
.40408 .73899 L
s
.39706 .74009 m
.39926 .73175 L
s
.404 1 0 r
.44171 .14663 m
.44175 .15153 L
s
.275 1 0 r
.45085 .34236 m
.45285 .34715 L
s
.45709 .34153 m
.45085 .34236 L
s
.45085 .34236 m
.45407 .34229 L
s
.47151 .35229 m
.45085 .34236 L
s
0 .694 1 r
.33458 .92435 m
.33609 .9344 L
s
.32642 .93253 m
.33458 .92435 L
s
.32351 .97358 m
.33458 .92435 L
s
0 .961 1 r
.79591 .24825 m
.7962 .25749 L
s
0 1 .338 r
.40408 .73899 m
.40291 .73663 L
s
.40408 .73899 m
.39926 .73175 L
s
0 .324 1 r
.2505 .93561 m
.2401 .93256 L
s
0 .694 1 r
.89703 .45426 m
.90003 .45152 L
s
.90003 .45152 m
.89945 .44175 L
s
.90003 .45152 m
.8886 .44784 L
s
0 1 .338 r
.39926 .73175 m
.39586 .73773 L
s
.39926 .73175 m
.40291 .73663 L
s
.40286 .76493 m
.39926 .73175 L
s
0 1 .929 r
.80987 .44838 m
.80994 .45702 L
s
0 .978 1 r
.92732 .84796 m
.93169 .85623 L
s
.93637 .84401 m
.92732 .84796 L
s
.92732 .84796 m
.93012 .84822 L
s
.93793 .85201 m
.92732 .84796 L
s
.96123 .85885 m
.92732 .84796 L
s
.275 1 0 r
.45709 .34153 m
.45407 .34229 L
s
0 1 .79 r
.8258 .64862 m
.82587 .65644 L
s
0 1 .699 r
.84349 .84899 m
.84423 .85587 L
s
0 .849 1 r
.90666 .64802 m
.91317 .65528 L
s
.917 .64284 m
.90666 .64802 L
s
.90666 .64802 m
.91234 .64632 L
s
.91782 .65178 m
.90666 .64802 L
s
.94913 .65327 m
.90666 .64802 L
s
0 1 .699 r
.84975 .84557 m
.84349 .84899 L
s
0 .849 1 r
.91317 .65528 m
.91782 .65178 L
s
.91782 .65178 m
.917 .64284 L
s
0 .536 1 r
.87043 .03984 m
.8707 .0408 L
s
.87043 .03984 m
.86028 .04654 L
s
0 .694 1 r
.8886 .44784 m
.89703 .45426 L
s
.89945 .44175 m
.8886 .44784 L
s
.8886 .44784 m
.89644 .44446 L
s
.93709 .44867 m
.8886 .44784 L
s
.064 1 0 r
.46602 .54278 m
.47034 .54239 L
s
.47034 .54239 m
.47278 .53791 L
s
.47034 .54239 m
.46617 .53651 L
s
0 .578 1 r
.8839 .24077 m
.88254 .24262 L
s
.8839 .24077 m
.87314 .24737 L
s
1 .77 0 r
.09973 .2436 m
.10092 .2425 L
s
.09767 .24274 m
.09973 .2436 L
s
.09947 .24072 m
.09973 .2436 L
s
.064 1 0 r
.46617 .53651 m
.46602 .54278 L
s
.47278 .53791 m
.46617 .53651 L
s
.46617 .53651 m
.46847 .5383 L
s
.48239 .55577 m
.46617 .53651 L
s
0 .578 1 r
.87314 .24737 m
.88309 .25305 L
s
.87314 .24737 m
.88254 .24262 L
s
.92511 .24503 m
.87314 .24737 L
s
1 .77 0 r
.09885 .24164 m
.09947 .24072 L
s
.09947 .24072 m
.09767 .24274 L
s
.10092 .2425 m
.09947 .24072 L
s
.09856 .25027 m
.09947 .24072 L
s
.275 1 0 r
.45407 .34229 m
.45285 .34715 L
s
0 .999 1 r
.41459 .93471 m
.42358 .93544 L
s
.41298 .93247 m
.41459 .93471 L
s
.41459 .93471 m
.41946 .92509 L
s
0 .694 1 r
.89945 .44175 m
.89644 .44446 L
s
.026 1 0 r
.52731 .14601 m
.52915 .14513 L
s
.52915 .14513 m
.52897 .13905 L
s
.52915 .14513 m
.52243 .14244 L
s
0 .978 1 r
.93169 .85623 m
.93793 .85201 L
s
.93793 .85201 m
.93637 .84401 L
s
1 .77 0 r
.09885 .24164 m
.09767 .24274 L
s
0 .536 1 r
.86028 .04654 m
.87126 .0516 L
s
.86028 .04654 m
.8707 .0408 L
s
.91318 .04236 m
.86028 .04654 L
s
1 .77 0 r
.10092 .2425 m
.09885 .24164 L
s
0 .999 1 r
.42358 .93544 m
.422 .93319 L
s
.41946 .92509 m
.42358 .93544 L
s
0 .849 1 r
.917 .64284 m
.91234 .64632 L
s
0 .999 1 r
.41946 .92509 m
.422 .93319 L
s
.41298 .93247 m
.41946 .92509 L
s
.41359 .96962 m
.41946 .92509 L
s
.026 1 0 r
.52897 .13905 m
.52712 .13992 L
s
.52897 .13905 m
.52243 .14244 L
s
.064 1 0 r
.47278 .53791 m
.46847 .5383 L
s
.026 1 0 r
.52243 .14244 m
.52731 .14601 L
s
.52243 .14244 m
.52712 .13992 L
s
.55103 .14289 m
.52243 .14244 L
s
0 1 .274 r
.48129 .73844 m
.48696 .7389 L
s
.48696 .7389 m
.49059 .73515 L
s
.48696 .7389 m
.4841 .73098 L
s
0 .694 1 r
.33609 .9344 m
.32642 .93253 L
s
0 1 .338 r
.40291 .73663 m
.39586 .73773 L
s
0 1 .044 r
.53879 .34336 m
.54194 .34218 L
s
.54194 .34218 m
.54275 .33619 L
s
.54194 .34218 m
.53546 .3382 L
s
.064 1 0 r
.46847 .5383 m
.46602 .54278 L
s
0 1 .274 r
.4841 .73098 m
.48129 .73844 L
s
.49059 .73515 m
.4841 .73098 L
s
.4841 .73098 m
.48491 .73469 L
s
.49333 .76021 m
.4841 .73098 L
s
0 .978 1 r
.93637 .84401 m
.93012 .84822 L
s
.404 1 0 r
.11033 .4357 m
.11424 .43532 L
s
.10732 .43424 m
.11033 .4357 L
s
.11033 .4357 m
.11134 .43015 L
s
0 1 .044 r
.53546 .3382 m
.53879 .34336 L
s
.54275 .33619 m
.53546 .3382 L
s
.53546 .3382 m
.5396 .33736 L
s
.56212 .34611 m
.53546 .3382 L
s
0 .978 1 r
.93012 .84822 m
.93169 .85623 L
s
0 1 .044 r
.54275 .33619 m
.5396 .33736 L
s
0 .849 1 r
.91234 .64632 m
.91317 .65528 L
s
.026 1 0 r
.52712 .13992 m
.52731 .14601 L
s
0 .694 1 r
.89644 .44446 m
.89703 .45426 L
s
0 .536 1 r
.8707 .0408 m
.87126 .0516 L
s
0 1 .78 r
.50541 .93596 m
.51058 .93347 L
s
.4986 .93401 m
.50541 .93596 L
s
.50466 .92583 m
.50541 .93596 L
s
0 .578 1 r
.88254 .24262 m
.88309 .25305 L
s
.404 1 0 r
.11134 .43015 m
.11124 .43386 L
s
.11134 .43015 m
.11424 .43532 L
s
.10732 .43424 m
.11134 .43015 L
s
.10855 .45333 m
.11134 .43015 L
s
0 1 .138 r
.5524 .54071 m
.55694 .53952 L
s
.55694 .53952 m
.55858 .53394 L
s
.55694 .53952 m
.55108 .5341 L
s
.404 1 0 r
.11424 .43532 m
.11124 .43386 L
s
0 1 .274 r
.48491 .73469 m
.48129 .73844 L
s
0 1 .138 r
.55108 .5341 m
.5524 .54071 L
s
.55858 .53394 m
.55108 .5341 L
s
.55108 .5341 m
.55404 .53512 L
s
.57325 .5503 m
.55108 .5341 L
s
0 1 .274 r
.49059 .73515 m
.48491 .73469 L
s
0 1 .78 r
.50376 .93152 m
.50466 .92583 L
s
.50466 .92583 m
.4986 .93401 L
s
.51058 .93347 m
.50466 .92583 L
s
.50431 .96563 m
.50466 .92583 L
s
1 .865 0 r
.18245 .23805 m
.18485 .23807 L
s
.18485 .23807 m
.18558 .23599 L
s
.18485 .23807 m
.18308 .23535 L
s
.18308 .23535 m
.18245 .23805 L
s
.18558 .23599 m
.18308 .23535 L
s
.18308 .23535 m
.18318 .23596 L
s
.18776 .24373 m
.18308 .23535 L
s
.404 1 0 r
.11124 .43386 m
.10732 .43424 L
s
0 1 .044 r
.5396 .33736 m
.53879 .34336 L
s
0 1 .355 r
.61344 .14045 m
.61528 .13942 L
s
.61528 .13942 m
.61497 .13214 L
s
.61528 .13942 m
.60728 .13638 L
s
0 .999 1 r
.422 .93319 m
.41298 .93247 L
s
0 1 .488 r
.12287 .62804 m
.12953 .62886 L
s
.11919 .62657 m
.12287 .62804 L
s
.12287 .62804 m
.12581 .62032 L
s
1 .865 0 r
.18318 .23596 m
.18245 .23805 L
s
0 1 .32 r
.56932 .7302 m
.56828 .73818 L
s
.57637 .73227 m
.56932 .7302 L
s
.56932 .7302 m
.57019 .73324 L
s
.57446 .7372 m
.56932 .7302 L
s
.58444 .75547 m
.56932 .7302 L
s
1 .865 0 r
.18558 .23599 m
.18318 .23596 L
s
0 1 .138 r
.55858 .53394 m
.55404 .53512 L
s
0 1 .32 r
.56828 .73818 m
.57446 .7372 L
s
.57446 .7372 m
.57637 .73227 L
s
0 1 .78 r
.50376 .93152 m
.4986 .93401 L
s
0 1 .355 r
.61497 .13214 m
.61313 .13316 L
s
.61497 .13214 m
.60728 .13638 L
s
0 1 .39 r
.62526 .33952 m
.62847 .33798 L
s
.62847 .33798 m
.6289 .33085 L
s
.62847 .33798 m
.62054 .33401 L
s
0 1 .355 r
.60728 .13638 m
.61344 .14045 L
s
.60728 .13638 m
.61313 .13316 L
s
.64203 .13595 m
.60728 .13638 L
s
0 1 .138 r
.55404 .53512 m
.5524 .54071 L
s
0 1 .78 r
.51058 .93347 m
.50376 .93152 L
s
0 1 .488 r
.12953 .62886 m
.12586 .62739 L
s
.12581 .62032 m
.12953 .62886 L
s
0 1 .39 r
.62054 .33401 m
.62526 .33952 L
s
.6289 .33085 m
.62054 .33401 L
s
.62054 .33401 m
.62568 .33237 L
s
.65337 .33989 m
.62054 .33401 L
s
0 1 .665 r
.59018 .92658 m
.58772 .9363 L
s
.59483 .93076 m
.59018 .92658 L
s
.59018 .92658 m
.58674 .93221 L
s
.5958 .93486 m
.59018 .92658 L
s
.59569 .96161 m
.59018 .92658 L
s
.473 1 0 r
.19311 .43024 m
.1942 .43214 L
s
.1942 .43214 m
.19879 .43126 L
s
.1942 .43214 m
.19544 .42657 L
s
0 1 .488 r
.12581 .62032 m
.12586 .62739 L
s
.11919 .62657 m
.12581 .62032 L
s
.11859 .65736 m
.12581 .62032 L
s
.473 1 0 r
.19879 .43126 m
.1977 .42935 L
s
.19879 .43126 m
.19544 .42657 L
s
0 1 .32 r
.57019 .73324 m
.56828 .73818 L
s
0 1 .39 r
.6289 .33085 m
.62568 .33237 L
s
0 1 .408 r
.63924 .53855 m
.64389 .5367 L
s
.64389 .5367 m
.64487 .53002 L
s
.64389 .5367 m
.63642 .53167 L
s
.473 1 0 r
.19544 .42657 m
.19311 .43024 L
s
.19544 .42657 m
.1977 .42935 L
s
.198 .4475 m
.19544 .42657 L
s
0 1 .408 r
.63642 .53167 m
.63924 .53855 L
s
.64487 .53002 m
.63642 .53167 L
s
.63642 .53167 m
.64021 .53185 L
s
.66477 .5448 m
.63642 .53167 L
s
0 1 .665 r
.58772 .9363 m
.5958 .93486 L
s
.58674 .93221 m
.58772 .9363 L
s
.5958 .93486 m
.59483 .93076 L
s
0 1 .32 r
.57637 .73227 m
.57019 .73324 L
s
0 .555 1 r
.13721 .82064 m
.1468 .82322 L
s
.1333 .81974 m
.13721 .82064 L
s
.13721 .82064 m
.1429 .81128 L
s
0 1 .355 r
.61313 .13316 m
.61344 .14045 L
s
0 1 .471 r
.65491 .72942 m
.65554 .73765 L
s
.66274 .72964 m
.65491 .72942 L
s
.65491 .72942 m
.65649 .73164 L
s
.66179 .73564 m
.65491 .72942 L
s
.67622 .75069 m
.65491 .72942 L
s
.898 1 0 r
.26764 .23312 m
.27026 .23273 L
s
.27026 .23273 m
.27087 .22965 L
s
.27026 .23273 m
.26717 .22995 L
s
.26717 .22995 m
.26764 .23312 L
s
.27087 .22965 m
.26717 .22995 L
s
.26717 .22995 m
.26825 .23003 L
s
.2776 .23714 m
.26717 .22995 L
s
0 1 .488 r
.12586 .62739 m
.11919 .62657 L
s
0 1 .286 r
.20999 .62641 m
.21501 .62545 L
s
.20497 .62488 m
.20999 .62641 L
s
.20999 .62641 m
.21041 .61841 L
s
0 1 .471 r
.65554 .73765 m
.66179 .73564 L
s
.66179 .73564 m
.66274 .72964 L
s
0 1 .738 r
.70016 .13486 m
.70192 .13367 L
s
.70192 .13367 m
.70151 .12518 L
s
.70192 .13367 m
.69265 .13027 L
s
0 1 .408 r
.64487 .53002 m
.64021 .53185 L
s
0 1 .39 r
.62568 .33237 m
.62526 .33952 L
s
0 .555 1 r
.1468 .82322 m
.14291 .82233 L
s
.1429 .81128 m
.1468 .82322 L
s
.473 1 0 r
.1977 .42935 m
.19311 .43024 L
s
.898 1 0 r
.27087 .22965 m
.26825 .23003 L
s
0 1 .67 r
.67603 .92732 m
.67495 .9371 L
s
.68175 .92954 m
.67603 .92732 L
s
.67603 .92732 m
.6739 .93199 L
s
.68279 .93465 m
.67603 .92732 L
s
.68772 .95756 m
.67603 .92732 L
s
.898 1 0 r
.26825 .23003 m
.26764 .23312 L
s
0 1 .753 r
.71226 .33565 m
.71549 .33378 L
s
.71549 .33378 m
.71555 .32548 L
s
.71549 .33378 m
.70611 .3298 L
s
0 1 .408 r
.64021 .53185 m
.63924 .53855 L
s
0 1 .738 r
.70151 .12518 m
.69974 .12635 L
s
.70151 .12518 m
.69265 .13027 L
s
0 1 .286 r
.21041 .61841 m
.20999 .62392 L
s
.21041 .61841 m
.21501 .62545 L
s
.20497 .62488 m
.21041 .61841 L
s
.20829 .65225 m
.21041 .61841 L
s
0 1 .738 r
.69265 .13027 m
.70016 .13486 L
s
.69265 .13027 m
.69974 .12635 L
s
.73369 .12897 m
.69265 .13027 L
s
.427 1 0 r
.27838 .42789 m
.28207 .42852 L
s
.28207 .42852 m
.28482 .42549 L
s
.28207 .42852 m
.27998 .42297 L
s
0 .555 1 r
.1429 .81128 m
.14291 .82233 L
s
.1333 .81974 m
.1429 .81128 L
s
.12867 .86236 m
.1429 .81128 L
s
0 1 .753 r
.70611 .3298 m
.71226 .33565 L
s
.71555 .32548 m
.70611 .3298 L
s
.70611 .3298 m
.71232 .32733 L
s
.74529 .33362 m
.70611 .3298 L
s
0 1 .471 r
.65649 .73164 m
.65554 .73765 L
s
0 1 .67 r
.67495 .9371 m
.68279 .93465 L
s
.68279 .93465 m
.68175 .92954 L
s
0 1 .725 r
.72655 .53635 m
.73127 .53393 L
s
.73127 .53393 m
.73163 .52611 L
s
.73127 .53393 m
.72219 .52924 L
s
0 1 .665 r
.59483 .93076 m
.58674 .93221 L
s
0 1 .286 r
.21501 .62545 m
.20999 .62392 L
s
0 1 .725 r
.72219 .52924 m
.72655 .53635 L
s
.73163 .52611 m
.72219 .52924 L
s
.72219 .52924 m
.7269 .52852 L
s
.75694 .53925 m
.72219 .52924 L
s
.427 1 0 r
.27998 .42297 m
.27838 .42789 L
s
.28482 .42549 m
.27998 .42297 L
s
.27998 .42297 m
.28113 .42485 L
s
.28809 .44163 m
.27998 .42297 L
s
0 1 .471 r
.66274 .72964 m
.65649 .73164 L
s
0 1 .67 r
.6739 .93199 m
.67495 .9371 L
s
0 1 .753 r
.71555 .32548 m
.71232 .32733 L
s
0 .873 1 r
.22349 .82049 m
.23235 .82177 L
s
.21992 .81888 m
.22349 .82049 L
s
.22349 .82049 m
.22801 .81095 L
s
0 1 .286 r
.20999 .62392 m
.20497 .62488 L
s
0 1 .709 r
.74088 .72864 m
.74317 .73703 L
s
.74962 .72709 m
.74088 .72864 L
s
.74088 .72864 m
.74333 .72993 L
s
.74945 .73418 m
.74088 .72864 L
s
.76866 .74587 m
.74088 .72864 L
s
.427 1 0 r
.28482 .42549 m
.28113 .42485 L
s
0 1 .794 r
.76221 .92808 m
.76262 .9379 L
s
.76902 .92831 m
.76221 .92808 L
s
.76221 .92808 m
.76126 .93171 L
s
.77037 .9345 m
.76221 .92808 L
s
.78043 .95349 m
.76221 .92808 L
s
0 1 .709 r
.74317 .73703 m
.74945 .73418 L
s
.74945 .73418 m
.74962 .72709 L
s
.427 1 0 r
.28113 .42485 m
.27838 .42789 L
s
.589 1 0 r
.35338 .22815 m
.35623 .22745 L
s
.35623 .22745 m
.35666 .22327 L
s
.35623 .22745 m
.35176 .22452 L
s
0 1 .725 r
.73163 .52611 m
.7269 .52852 L
s
.589 1 0 r
.35176 .22452 m
.35338 .22815 L
s
.35666 .22327 m
.35176 .22452 L
s
.35176 .22452 m
.3538 .22397 L
s
.36809 .23051 m
.35176 .22452 L
s
0 .873 1 r
.23235 .82177 m
.2288 .82016 L
s
.22801 .81095 m
.23235 .82177 L
s
0 1 .738 r
.69974 .12635 m
.70016 .13486 L
s
0 .878 1 r
.78746 .12923 m
.78908 .12789 L
s
.78908 .12789 m
.78857 .11817 L
s
.78908 .12789 m
.77856 .12413 L
s
0 .555 1 r
.14291 .82233 m
.1333 .81974 L
s
0 1 .169 r
.29209 .62194 m
.29344 .62435 L
s
.29344 .62435 m
.3 .62325 L
s
.29344 .62435 m
.29541 .6165 L
s
.3 .62325 m
.29867 .62084 L
s
.3 .62325 m
.29541 .6165 L
s
0 .873 1 r
.22801 .81095 m
.2288 .82016 L
s
.21992 .81888 m
.22801 .81095 L
s
.21862 .85798 m
.22801 .81095 L
s
.589 1 0 r
.35666 .22327 m
.3538 .22397 L
s
0 1 .753 r
.71232 .32733 m
.71226 .33565 L
s
0 1 .169 r
.29541 .6165 m
.29209 .62194 L
s
.29541 .6165 m
.29867 .62084 L
s
.29863 .6471 m
.29541 .6165 L
s
0 .873 1 r
.79981 .33175 m
.80298 .32957 L
s
.80298 .32957 m
.80269 .32009 L
s
.80298 .32957 m
.79216 .32557 L
s
0 1 .67 r
.68175 .92954 m
.6739 .93199 L
s
0 1 .794 r
.76262 .9379 m
.77037 .9345 L
s
.77037 .9345 m
.76902 .92831 L
s
0 1 .725 r
.7269 .52852 m
.72655 .53635 L
s
.589 1 0 r
.3538 .22397 m
.35338 .22815 L
s
0 1 .709 r
.74962 .72709 m
.74333 .72993 L
s
.275 1 0 r
.36471 .42486 m
.36888 .42456 L
s
.36888 .42456 m
.37075 .42035 L
s
.36888 .42456 m
.36497 .41934 L
s
0 .925 1 r
.81435 .53411 m
.81909 .53117 L
s
.81909 .53117 m
.81886 .52221 L
s
.81909 .53117 m
.80839 .52679 L
s
0 1 .709 r
.74333 .72993 m
.74317 .73703 L
s
0 .878 1 r
.78857 .11817 m
.78695 .11948 L
s
.78857 .11817 m
.77856 .12413 L
s
0 .925 1 r
.80839 .52679 m
.81435 .53411 L
s
.81886 .52221 m
.80839 .52679 L
s
.80839 .52679 m
.81411 .52513 L
s
.84979 .53367 m
.80839 .52679 L
s
0 .873 1 r
.79216 .32557 m
.79981 .33175 L
s
.80269 .32009 m
.79216 .32557 L
s
.79216 .32557 m
.79951 .32224 L
s
.83786 .3273 m
.79216 .32557 L
s
0 .987 1 r
.82724 .72785 m
.83121 .73637 L
s
.83695 .72456 m
.82724 .72785 L
s
.82724 .72785 m
.83062 .72815 L
s
.83753 .73277 m
.82724 .72785 L
s
.86176 .74102 m
.82724 .72785 L
s
.275 1 0 r
.36497 .41934 m
.36471 .42486 L
s
.37075 .42035 m
.36497 .41934 L
s
.36497 .41934 m
.36657 .42065 L
s
.37883 .43572 m
.36497 .41934 L
s
0 1 .794 r
.76126 .93171 m
.76262 .9379 L
s
0 1 .873 r
.31083 .82043 m
.31865 .82011 L
s
.30659 .81822 m
.31083 .82043 L
s
.31083 .82043 m
.31347 .81061 L
s
0 .878 1 r
.77856 .12413 m
.78746 .12923 L
s
.77856 .12413 m
.78695 .11948 L
s
.826 .12193 m
.77856 .12413 L
s
0 .978 1 r
.84872 .92883 m
.85075 .93871 L
s
.85662 .92708 m
.84872 .92883 L
s
.84872 .92883 m
.84885 .93138 L
s
.8585 .93441 m
.84872 .92883 L
s
.8738 .94938 m
.84872 .92883 L
s
0 .873 1 r
.80269 .32009 m
.79951 .32224 L
s
0 .987 1 r
.83121 .73637 m
.83753 .73277 L
s
.83753 .73277 m
.83695 .72456 L
s
.275 1 0 r
.37075 .42035 m
.36657 .42065 L
s
0 .873 1 r
.2288 .82016 m
.21992 .81888 L
s
0 .925 1 r
.81886 .52221 m
.81411 .52513 L
s
0 1 .873 r
.31347 .81061 m
.31442 .8179 L
s
.31347 .81061 m
.31865 .82011 L
s
.30659 .81822 m
.31347 .81061 L
s
.30922 .85356 m
.31347 .81061 L
s
.275 1 0 r
.36657 .42065 m
.36471 .42486 L
s
0 1 .169 r
.29867 .62084 m
.29209 .62194 L
s
0 1 .151 r
.37808 .62152 m
.38338 .62222 L
s
.38338 .62222 m
.38704 .61852 L
s
.38338 .62222 m
.3808 .61458 L
s
.245 1 0 r
.43967 .22315 m
.44272 .22218 L
s
.44272 .22218 m
.44294 .21685 L
s
.44272 .22218 m
.43685 .21905 L
s
0 1 .794 r
.76902 .92831 m
.76126 .93171 L
s
0 1 .873 r
.31865 .82011 m
.31442 .8179 L
s
0 1 .151 r
.3808 .61458 m
.37808 .62152 L
s
.38704 .61852 m
.3808 .61458 L
s
.3808 .61458 m
.38173 .61781 L
s
.38963 .64192 m
.3808 .61458 L
s
.245 1 0 r
.43685 .21905 m
.43967 .22315 L
s
.44294 .21685 m
.43685 .21905 L
s
.43685 .21905 m
.43989 .21782 L
s
.45923 .22383 m
.43685 .21905 L
s
0 .978 1 r
.85075 .93871 m
.8585 .93441 L
s
.8585 .93441 m
.85662 .92708 L
s
0 .493 1 r
.87535 .12355 m
.87675 .12207 L
s
.87675 .12207 m
.87618 .11113 L
s
.87675 .12207 m
.86502 .11795 L
s
0 .491 1 r
.88791 .32782 m
.89096 .32534 L
s
.89096 .32534 m
.89033 .31467 L
s
.89096 .32534 m
.87871 .32131 L
s
.245 1 0 r
.44294 .21685 m
.43989 .21782 L
s
0 .667 1 r
.93557 .92959 m
.93932 .93952 L
s
.94457 .92584 m
.93557 .92959 L
s
.93557 .92959 m
.93673 .931 L
s
.94714 .93435 m
.93557 .92959 L
s
.96786 .94524 m
.93557 .92959 L
s
0 .987 1 r
.83695 .72456 m
.83062 .72815 L
s
0 .878 1 r
.78695 .11948 m
.78746 .12923 L
s
0 .635 1 r
.91398 .72706 m
.91971 .7357 L
s
.9247 .72203 m
.91398 .72706 L
s
.91398 .72706 m
.91835 .72631 L
s
.92605 .7314 m
.91398 .72706 L
s
.95555 .73614 m
.91398 .72706 L
s
0 .873 1 r
.79951 .32224 m
.79981 .33175 L
s
0 .552 1 r
.90265 .53184 m
.90736 .52842 L
s
.90736 .52842 m
.90654 .51829 L
s
.90736 .52842 m
.89503 .52433 L
s
.89503 .52433 m
.90265 .53184 L
s
.90654 .51829 m
.89503 .52433 L
s
.89503 .52433 m
.90183 .52169 L
s
.9433 .52804 m
.89503 .52433 L
s
0 .925 1 r
.81411 .52513 m
.81435 .53411 L
s
.042 1 0 r
.45149 .42164 m
.4559 .42068 L
s
.4559 .42068 m
.45721 .41536 L
s
.4559 .42068 m
.4504 .4157 L
s
0 .987 1 r
.83062 .72815 m
.83121 .73637 L
s
0 .978 1 r
.84885 .93138 m
.85075 .93871 L
s
0 1 .151 r
.38704 .61852 m
.38173 .61781 L
s
.042 1 0 r
.4504 .4157 m
.45149 .42164 L
s
.45721 .41536 m
.4504 .4157 L
s
.4504 .4157 m
.4528 .41632 L
s
.47023 .42977 m
.4504 .4157 L
s
0 1 .151 r
.38173 .61781 m
.37808 .62152 L
s
0 .491 1 r
.87871 .32131 m
.88791 .32782 L
s
.89033 .31467 m
.87871 .32131 L
s
.87871 .32131 m
.88728 .31711 L
s
.93111 .32094 m
.87871 .32131 L
s
.245 1 0 r
.43989 .21782 m
.43967 .22315 L
s
0 1 .873 r
.31442 .8179 m
.30659 .81822 L
s
0 .635 1 r
.91971 .7357 m
.92605 .7314 L
s
.92605 .7314 m
.9247 .72203 L
s
0 1 .7 r
.39466 .81687 m
.39609 .8199 L
s
.39609 .8199 m
.40436 .81912 L
s
.39609 .8199 m
.39928 .81027 L
s
0 .493 1 r
.87618 .11113 m
.87478 .11257 L
s
.87618 .11113 m
.86502 .11795 L
s
0 1 .7 r
.39928 .81027 m
.39466 .81687 L
s
.40436 .81912 m
.39928 .81027 L
s
.39928 .81027 m
.40295 .81609 L
s
.40048 .84911 m
.39928 .81027 L
s
.40436 .81912 m
.40295 .81609 L
s
0 .493 1 r
.86502 .11795 m
.87535 .12355 L
s
.86502 .11795 m
.87478 .11257 L
s
.91898 .11484 m
.86502 .11795 L
s
0 .491 1 r
.89033 .31467 m
.88728 .31711 L
s
0 .978 1 r
.85662 .92708 m
.84885 .93138 L
s
.042 1 0 r
.45721 .41536 m
.4528 .41632 L
s
0 .552 1 r
.90654 .51829 m
.90183 .52169 L
s
0 .667 1 r
.93932 .93952 m
.94714 .93435 L
s
.94714 .93435 m
.94457 .92584 L
s
0 1 .234 r
.46548 .62021 m
.47139 .61959 L
s
.47139 .61959 m
.47355 .61464 L
s
.47139 .61959 m
.46659 .61264 L
s
.46659 .61264 m
.46548 .62021 L
s
.47355 .61464 m
.46659 .61264 L
s
.46659 .61264 m
.46763 .61526 L
s
.48129 .6367 m
.46659 .61264 L
s
.042 1 0 r
.4528 .41632 m
.45149 .42164 L
s
0 1 .116 r
.52652 .21813 m
.52971 .2169 L
s
.52971 .2169 m
.52974 .2104 L
s
.52971 .2169 m
.52243 .21356 L
s
0 .635 1 r
.9247 .72203 m
.91835 .72631 L
s
.845 1 0 r
.09313 .31565 m
.09492 .31404 L
s
.08997 .31439 m
.09313 .31565 L
s
.09273 .31127 m
.09313 .31565 L
s
0 1 .116 r
.52243 .21356 m
.52652 .21813 L
s
.52974 .2104 m
.52243 .21356 L
s
.52243 .21356 m
.52654 .21161 L
s
.55103 .2171 m
.52243 .21356 L
s
.845 1 0 r
.09176 .31278 m
.09273 .31127 L
s
.09273 .31127 m
.08997 .31439 L
s
.09492 .31404 m
.09273 .31127 L
s
.09131 .32604 m
.09273 .31127 L
s
0 1 .116 r
.52974 .2104 m
.52654 .21161 L
s
0 .667 1 r
.93673 .931 m
.93932 .93952 L
s
0 1 .626 r
.48543 .80993 m
.48194 .81908 L
s
.49169 .81456 m
.48543 .80993 L
s
.48543 .80993 m
.48385 .81477 L
s
.48977 .81887 m
.48543 .80993 L
s
.49239 .84463 m
.48543 .80993 L
s
.845 1 0 r
.09176 .31278 m
.08997 .31439 L
s
0 1 .234 r
.46763 .61526 m
.46548 .62021 L
s
0 1 .248 r
.53875 .41835 m
.54333 .41684 L
s
.54333 .41684 m
.54417 .4104 L
s
.54333 .41684 m
.53629 .41204 L
s
0 1 .626 r
.48194 .81908 m
.48977 .81887 L
s
.48977 .81887 m
.49169 .81456 L
s
0 .667 1 r
.94457 .92584 m
.93673 .931 L
s
0 1 .248 r
.53629 .41204 m
.53875 .41835 L
s
.54417 .4104 m
.53629 .41204 L
s
.53629 .41204 m
.53959 .4119 L
s
.56229 .42377 m
.53629 .41204 L
s
0 .635 1 r
.91835 .72631 m
.91971 .7357 L
s
0 1 .234 r
.47355 .61464 m
.46763 .61526 L
s
.845 1 0 r
.09492 .31404 m
.09176 .31278 L
s
0 .552 1 r
.90183 .52169 m
.90265 .53184 L
s
0 .491 1 r
.88728 .31711 m
.88791 .32782 L
s
0 .493 1 r
.87478 .11257 m
.87535 .12355 L
s
0 1 .7 r
.40295 .81609 m
.39466 .81687 L
s
0 1 .116 r
.52654 .21161 m
.52652 .21813 L
s
0 1 .626 r
.48385 .81477 m
.48194 .81908 L
s
0 1 .408 r
.55279 .6107 m
.55322 .61863 L
s
.56062 .61101 m
.55279 .6107 L
s
.55279 .6107 m
.55452 .61258 L
s
.55932 .61705 m
.55279 .6107 L
s
.57361 .63144 m
.55279 .6107 L
s
.026 1 0 r
.10366 .51058 m
.10888 .51026 L
s
.10034 .5086 m
.10366 .51058 L
s
.10366 .51058 m
.1054 .50367 L
s
0 1 .248 r
.54417 .4104 m
.53959 .4119 L
s
0 1 .408 r
.55322 .61863 m
.55932 .61705 L
s
.55932 .61705 m
.56062 .61101 L
s
0 1 .488 r
.61393 .21306 m
.61721 .2116 L
s
.61721 .2116 m
.61704 .20391 L
s
.61721 .2116 m
.60852 .20803 L
s
0 1 .248 r
.53959 .4119 m
.53875 .41835 L
s
.026 1 0 r
.1054 .50367 m
.10557 .50827 L
s
.1054 .50367 m
.10888 .51026 L
s
.10034 .5086 m
.1054 .50367 L
s
.10145 .53255 m
.1054 .50367 L
s
.10888 .51026 m
.10557 .50827 L
s
0 1 .657 r
.57193 .80959 m
.57031 .81915 L
s
.57874 .81213 m
.57193 .80959 L
s
.57193 .80959 m
.57088 .81377 L
s
.57815 .81751 m
.57193 .80959 L
s
.58498 .84011 m
.57193 .80959 L
s
.776 1 0 r
.17772 .3064 m
.17633 .31041 L
s
.18079 .30768 m
.17772 .3064 L
s
.17772 .3064 m
.17711 .30765 L
s
.18001 .31044 m
.17772 .3064 L
s
.18192 .31967 m
.17772 .3064 L
s
.17633 .31041 m
.18001 .31044 L
s
.18001 .31044 m
.18079 .30768 L
s
0 1 .488 r
.60852 .20803 m
.61393 .21306 L
s
.61704 .20391 m
.60852 .20803 L
s
.60852 .20803 m
.61376 .20535 L
s
.64349 .21032 m
.60852 .20803 L
s
0 1 .626 r
.49169 .81456 m
.48385 .81477 L
s
0 1 .657 r
.57031 .81915 m
.57815 .81751 L
s
.57815 .81751 m
.57874 .81213 L
s
0 1 .575 r
.62651 .41501 m
.63122 .41303 L
s
.63122 .41303 m
.63162 .40544 L
s
.63122 .41303 m
.62263 .40836 L
s
0 1 .408 r
.55452 .61258 m
.55322 .61863 L
s
0 1 .488 r
.61704 .20391 m
.61376 .20535 L
s
0 1 .408 r
.56062 .61101 m
.55452 .61258 L
s
0 1 .575 r
.62263 .40836 m
.62651 .41501 L
s
.63162 .40544 m
.62263 .40836 L
s
.62263 .40836 m
.62691 .40741 L
s
.65502 .41772 m
.62263 .40836 L
s
.776 1 0 r
.17711 .30765 m
.17633 .31041 L
s
0 1 .865 r
.11672 .70579 m
.12478 .7069 L
s
.11301 .70401 m
.11672 .70579 L
s
.11672 .70579 m
.12071 .69684 L
s
.026 1 0 r
.10557 .50827 m
.10034 .5086 L
s
.776 1 0 r
.18079 .30768 m
.17711 .30765 L
s
0 1 .657 r
.57088 .81377 m
.57031 .81915 L
s
0 1 .654 r
.63938 .60875 m
.64136 .61695 L
s
.64821 .60745 m
.63938 .60875 L
s
.63938 .60875 m
.64198 .60979 L
s
.64758 .6146 m
.63938 .60875 L
s
.6666 .62614 m
.63938 .60875 L
s
.64136 .61695 m
.64758 .6146 L
s
.64758 .6146 m
.64821 .60745 L
s
0 1 .575 r
.63162 .40544 m
.62691 .40741 L
s
0 1 .865 r
.12478 .7069 m
.12109 .70513 L
s
.12071 .69684 m
.12478 .7069 L
s
0 1 .79 r
.65879 .80925 m
.65879 .81903 L
s
.66651 .80989 m
.65879 .80925 L
s
.65879 .80925 m
.65868 .81258 L
s
.6666 .81634 m
.65879 .80925 L
s
.67824 .83556 m
.65879 .80925 L
s
.103 1 0 r
.18757 .50497 m
.18899 .50749 L
s
.18899 .50749 m
.19479 .50665 L
s
.18899 .50749 m
.1909 .50056 L
s
0 1 .488 r
.61376 .20535 m
.61393 .21306 L
s
.103 1 0 r
.19479 .50665 m
.19339 .50413 L
s
.19479 .50665 m
.1909 .50056 L
s
.1909 .50056 m
.18757 .50497 L
s
.1909 .50056 m
.19339 .50413 L
s
.19231 .52691 m
.1909 .50056 L
s
0 1 .865 r
.12071 .69684 m
.12109 .70513 L
s
.11301 .70401 m
.12071 .69684 L
s
.11163 .74005 m
.12071 .69684 L
s
.70191 .20797 m
.7052 .20629 L
s
.7052 .20629 m
.70486 .19738 L
s
.7052 .20629 m
.69513 .20247 L
s
0 1 .657 r
.57874 .81213 m
.57088 .81377 L
s
0 1 .575 r
.62691 .40741 m
.62651 .41501 L
s
0 1 .79 r
.65879 .81903 m
.6666 .81634 L
s
.6666 .81634 m
.66651 .80989 L
s
0 .17 1 r
.13168 .9013 m
.14271 .90435 L
s
.12794 .90037 m
.13168 .9013 L
s
.13168 .9013 m
.13869 .89085 L
s
.589 1 0 r
.26319 .30151 m
.26289 .30596 L
s
.26748 .30174 m
.26319 .30151 L
s
.26319 .30151 m
.26358 .30223 L
s
.26678 .30547 m
.26319 .30151 L
s
.27319 .31325 m
.26319 .30151 L
s
.26289 .30596 m
.26678 .30547 L
s
.26678 .30547 m
.26748 .30174 L
s
0 1 .654 r
.64821 .60745 m
.64198 .60979 L
s
0 1 .865 r
.69513 .20247 m
.70191 .20797 L
s
.70486 .19738 m
.69513 .20247 L
s
.69513 .20247 m
.70156 .19904 L
s
.73663 .20349 m
.69513 .20247 L
s
0 1 .927 r
.71478 .41164 m
.71957 .40922 L
s
.71957 .40922 m
.71956 .40047 L
s
.71957 .40922 m
.70943 .40466 L
s
0 1 .654 r
.64198 .60979 m
.64136 .61695 L
s
0 1 .927 r
.70943 .40466 m
.71478 .41164 L
s
.71956 .40047 m
.70943 .40466 L
s
.70943 .40466 m
.71476 .40286 L
s
.74843 .41164 m
.70943 .40466 L
s
0 1 .659 r
.20489 .70473 m
.21176 .70409 L
s
.20012 .70252 m
.20489 .70473 L
s
.20489 .70473 m
.20674 .69538 L
s
0 1 .865 r
.70486 .19738 m
.70156 .19904 L
s
0 1 .956 r
.72638 .60679 m
.72994 .61523 L
s
.73627 .60391 m
.72638 .60679 L
s
.72638 .60679 m
.72994 .60693 L
s
.73626 .61219 m
.72638 .60679 L
s
.76028 .6208 m
.72638 .60679 L
s
0 .17 1 r
.14271 .90435 m
.13901 .90344 L
s
.13869 .89085 m
.14271 .90435 L
s
0 1 .79 r
.65868 .81258 m
.65879 .81903 L
s
.589 1 0 r
.26358 .30223 m
.26289 .30596 L
s
.26748 .30174 m
.26358 .30223 L
s
0 1 .865 r
.12109 .70513 m
.11301 .70401 L
s
.103 1 0 r
.19339 .50413 m
.18757 .50497 L
s
0 .987 1 r
.746 .8089 m
.74763 .81886 L
s
.75475 .80768 m
.746 .8089 L
s
.746 .8089 m
.74688 .81129 L
s
.75548 .81525 m
.746 .8089 L
s
.77219 .83098 m
.746 .8089 L
s
0 1 .956 r
.72994 .61523 m
.73626 .61219 L
s
.73626 .61219 m
.73627 .60391 L
s
0 1 .659 r
.20674 .69538 m
.207 .70188 L
s
.20674 .69538 m
.21176 .70409 L
s
.20012 .70252 m
.20674 .69538 L
s
.20275 .73516 m
.20674 .69538 L
s
.078 1 0 r
.27424 .50365 m
.27943 .5043 L
s
.27943 .5043 m
.28221 .5007 L
s
.27943 .5043 m
.27683 .49744 L
s
0 1 .927 r
.71956 .40047 m
.71476 .40286 L
s
.078 1 0 r
.27683 .49744 m
.27424 .50365 L
s
.28221 .5007 m
.27683 .49744 L
s
.27683 .49744 m
.27702 .50005 L
s
.28384 .52124 m
.27683 .49744 L
s
0 1 .659 r
.21176 .70409 m
.207 .70188 L
s
0 1 .79 r
.66651 .80989 m
.65868 .81258 L
s
0 .17 1 r
.13869 .89085 m
.13901 .90344 L
s
.12794 .90037 m
.13869 .89085 L
s
.12186 .94856 m
.13869 .89085 L
s
0 .987 1 r
.74763 .81886 m
.75548 .81525 L
s
.75548 .81525 m
.75475 .80768 L
s
0 .491 1 r
.21905 .90155 m
.22949 .90341 L
s
.21619 .89975 m
.21905 .90155 L
s
.21905 .90155 m
.22524 .89092 L
s
0 1 .865 r
.70156 .19904 m
.70191 .20797 L
s
0 .753 1 r
.79046 .20284 m
.7937 .20094 L
s
.7937 .20094 m
.79319 .19081 L
s
.7937 .20094 m
.78224 .19687 L
s
0 1 .956 r
.73627 .60391 m
.72994 .60693 L
s
.322 1 0 r
.34913 .29659 m
.34997 .30149 L
s
.35465 .29576 m
.34913 .29659 L
s
.34913 .29659 m
.3505 .29669 L
s
.35412 .30055 m
.34913 .29659 L
s
.36513 .30679 m
.34913 .29659 L
s
.34997 .30149 m
.35412 .30055 L
s
.35412 .30055 m
.35465 .29576 L
s
.078 1 0 r
.27702 .50005 m
.27424 .50365 L
s
0 1 .927 r
.71476 .40286 m
.71478 .41164 L
s
.078 1 0 r
.28221 .5007 m
.27702 .50005 L
s
0 .705 1 r
.80359 .40824 m
.80841 .40542 L
s
.80841 .40542 m
.80798 .39547 L
s
.80841 .40542 m
.79669 .40095 L
s
0 1 .659 r
.207 .70188 m
.20012 .70252 L
s
0 .703 1 r
.8138 .60482 m
.819 .61348 L
s
.82477 .60036 m
.8138 .60482 L
s
.8138 .60482 m
.81837 .60401 L
s
.8254 .60982 m
.8138 .60482 L
s
.85465 .61542 m
.8138 .60482 L
s
0 .705 1 r
.79669 .40095 m
.80359 .40824 L
s
.80798 .39547 m
.79669 .40095 L
s
.79669 .40095 m
.80315 .39827 L
s
.84252 .40551 m
.79669 .40095 L
s
0 .694 1 r
.83357 .80856 m
.83688 .81866 L
s
.84341 .80549 m
.83357 .80856 L
s
.83357 .80856 m
.83546 .80993 L
s
.84481 .81422 m
.83357 .80856 L
s
.86684 .82637 m
.83357 .80856 L
s
0 .491 1 r
.22949 .90341 m
.22667 .90161 L
s
.22524 .89092 m
.22949 .90341 L
s
0 1 .956 r
.72994 .60693 m
.72994 .61523 L
s
0 .753 1 r
.78224 .19687 m
.79046 .20284 L
s
.79319 .19081 m
.78224 .19687 L
s
.78224 .19687 m
.78995 .19268 L
s
.83045 .19661 m
.78224 .19687 L
s
0 1 .535 r
.28868 .70008 m
.29031 .70311 L
s
.29031 .70311 m
.29813 .70219 L
s
.29031 .70311 m
.29313 .69391 L
s
0 .987 1 r
.74688 .81129 m
.74763 .81886 L
s
0 .703 1 r
.819 .61348 m
.8254 .60982 L
s
.8254 .60982 m
.82477 .60036 L
s
0 1 .535 r
.29313 .69391 m
.28868 .70008 L
s
.29813 .70219 m
.29313 .69391 L
s
.29313 .69391 m
.29652 .69916 L
s
.29454 .73023 m
.29313 .69391 L
s
.29813 .70219 m
.29652 .69916 L
s
0 .753 1 r
.79319 .19081 m
.78995 .19268 L
s
0 .491 1 r
.22524 .89092 m
.22667 .90161 L
s
.21619 .89975 m
.22524 .89092 L
s
.21324 .94441 m
.22524 .89092 L
s
.322 1 0 r
.35465 .29576 m
.3505 .29669 L
s
0 .987 1 r
.75475 .80768 m
.74688 .81129 L
s
.322 1 0 r
.3505 .29669 m
.34997 .30149 L
s
0 1 .044 r
.36206 .50116 m
.3677 .50066 L
s
.3677 .50066 m
.36941 .49588 L
s
.3677 .50066 m
.36317 .4943 L
s
0 .17 1 r
.13901 .90344 m
.12794 .90037 L
s
0 1 .044 r
.36317 .4943 m
.36206 .50116 L
s
.36941 .49588 m
.36317 .4943 L
s
.36317 .4943 m
.36376 .49637 L
s
.37604 .51552 m
.36317 .4943 L
s
0 .705 1 r
.80798 .39547 m
.80315 .39827 L
s
0 .694 1 r
.83688 .81866 m
.84481 .81422 L
s
.84481 .81422 m
.84341 .80549 L
s
0 .747 1 r
.30684 .90181 m
.31679 .90249 L
s
.30469 .89909 m
.30684 .90181 L
s
.30684 .90181 m
.31211 .891 L
s
0 .703 1 r
.82477 .60036 m
.81837 .60401 L
s
0 .346 1 r
.9215 .80821 m
.92659 .81846 L
s
.93246 .80329 m
.9215 .80821 L
s
.9215 .80821 m
.92443 .80852 L
s
.9346 .81322 m
.9215 .80821 L
s
.96218 .82172 m
.9215 .80821 L
s
0 .369 1 r
.8796 .19768 m
.88271 .19557 L
s
.88271 .19557 m
.88205 .18421 L
s
.88271 .19557 m
.86988 .19124 L
s
0 .333 1 r
.90162 .60284 m
.90854 .61171 L
s
.91373 .59681 m
.90162 .60284 L
s
.90162 .60284 m
.90728 .60104 L
s
.91498 .60746 m
.90162 .60284 L
s
.94971 .61001 m
.90162 .60284 L
s
0 1 .044 r
.36376 .49637 m
.36206 .50116 L
s
0 .747 1 r
.31679 .90249 m
.31467 .89978 L
s
.31211 .891 m
.31679 .90249 L
s
.008 1 0 r
.43554 .29165 m
.4376 .29698 L
s
.4423 .28975 m
.43554 .29165 L
s
.43554 .29165 m
.43791 .29105 L
s
.442 .29567 m
.43554 .29165 L
s
.45773 .30028 m
.43554 .29165 L
s
.4376 .29698 m
.442 .29567 L
s
.442 .29567 m
.4423 .28975 L
s
0 .324 1 r
.89293 .40481 m
.89771 .40161 L
s
.89771 .40161 m
.89688 .39046 L
s
.89771 .40161 m
.88442 .39721 L
s
0 1 .504 r
.37627 .70093 m
.38349 .7013 L
s
.38349 .7013 m
.38634 .697 L
s
.38349 .7013 m
.37989 .69244 L
s
0 .747 1 r
.31211 .891 m
.31467 .89978 L
s
.30469 .89909 m
.31211 .891 L
s
.30529 .94024 m
.31211 .891 L
s
0 1 .044 r
.36941 .49588 m
.36376 .49637 L
s
0 .753 1 r
.78995 .19268 m
.79046 .20284 L
s
0 .324 1 r
.88442 .39721 m
.89293 .40481 L
s
.89688 .39046 m
.88442 .39721 L
s
.88442 .39721 m
.89209 .39363 L
s
.93731 .39933 m
.88442 .39721 L
s
0 1 .504 r
.37989 .69244 m
.37627 .70093 L
s
.38634 .697 m
.37989 .69244 L
s
.37989 .69244 m
.37911 .69662 L
s
.387 .72527 m
.37989 .69244 L
s
0 .705 1 r
.80315 .39827 m
.80359 .40824 L
s
0 .333 1 r
.90854 .61171 m
.91498 .60746 L
s
.91498 .60746 m
.91373 .59681 L
s
0 .703 1 r
.81837 .60401 m
.819 .61348 L
s
0 1 .535 r
.29652 .69916 m
.28868 .70008 L
s
0 .694 1 r
.83546 .80993 m
.83688 .81866 L
s
.84341 .80549 m
.83546 .80993 L
s
0 .369 1 r
.86988 .19124 m
.8796 .19768 L
s
.88205 .18421 m
.86988 .19124 L
s
.86988 .19124 m
.87893 .18628 L
s
.92496 .18969 m
.86988 .19124 L
s
0 .491 1 r
.22667 .90161 m
.21619 .89975 L
s
.008 1 0 r
.4423 .28975 m
.43791 .29105 L
s
0 .369 1 r
.88205 .18421 m
.87893 .18628 L
s
0 .346 1 r
.92659 .81846 m
.9346 .81322 L
s
.9346 .81322 m
.93246 .80329 L
s
0 1 .248 r
.44995 .49114 m
.45022 .49843 L
s
.45721 .49125 m
.44995 .49114 L
s
.44995 .49114 m
.45134 .49255 L
s
.45609 .49713 m
.44995 .49114 L
s
.46891 .50976 m
.44995 .49114 L
s
.45022 .49843 m
.45609 .49713 L
s
.45609 .49713 m
.45721 .49125 L
s
0 1 .504 r
.37911 .69662 m
.37627 .70093 L
s
0 .921 1 r
.4002 .9026 m
.40582 .89969 L
s
.39226 .90032 m
.4002 .9026 L
s
.39929 .89107 m
.4002 .9026 L
s
0 .324 1 r
.89688 .39046 m
.89209 .39363 L
s
.008 1 0 r
.43791 .29105 m
.4376 .29698 L
s
0 .921 1 r
.39787 .8974 m
.39929 .89107 L
s
.39929 .89107 m
.39226 .90032 L
s
.40582 .89969 m
.39929 .89107 L
s
.39802 .93604 m
.39929 .89107 L
s
0 .333 1 r
.91373 .59681 m
.90728 .60104 L
s
0 1 .504 r
.38634 .697 m
.37911 .69662 L
s
0 1 .569 r
.46703 .69096 m
.46519 .70006 L
s
.47408 .69349 m
.46703 .69096 L
s
.46703 .69096 m
.46651 .69459 L
s
.47274 .69896 m
.46703 .69096 L
s
.48014 .72026 m
.46703 .69096 L
s
.46519 .70006 m
.47274 .69896 L
s
.47274 .69896 m
.47408 .69349 L
s
0 1 .248 r
.45134 .49255 m
.45022 .49843 L
s
0 .346 1 r
.93246 .80329 m
.92443 .80852 L
s
0 1 .248 r
.45721 .49125 m
.45134 .49255 L
s
0 1 .334 r
.52577 .29245 m
.53038 .29079 L
s
.53038 .29079 m
.53045 .2837 L
s
.53038 .29079 m
.52243 .28667 L
s
.52243 .28667 m
.52577 .29245 L
s
.53045 .2837 m
.52243 .28667 L
s
.52243 .28667 m
.52584 .28535 L
s
.55102 .29372 m
.52243 .28667 L
s
0 .747 1 r
.31467 .89978 m
.30469 .89909 L
s
0 .346 1 r
.92443 .80852 m
.92659 .81846 L
s
0 .333 1 r
.90728 .60104 m
.90854 .61171 L
s
0 .921 1 r
.39787 .8974 m
.39226 .90032 L
s
0 .324 1 r
.89209 .39363 m
.89293 .40481 L
s
0 .369 1 r
.87893 .18628 m
.8796 .19768 L
s
0 1 .514 r
.53714 .48797 m
.53882 .49563 L
s
.54553 .48666 m
.53714 .48797 L
s
.53714 .48797 m
.53945 .48862 L
s
.54489 .49367 m
.53714 .48797 L
s
.56247 .50396 m
.53714 .48797 L
s
0 1 .569 r
.46651 .69459 m
.46519 .70006 L
s
.46 1 0 r
.08632 .38987 m
.08874 .38778 L
s
.08204 .38824 m
.08632 .38987 L
s
.08578 .38396 m
.08632 .38987 L
s
0 .999 1 r
.4868 .89115 m
.48375 .90232 L
s
.49169 .8961 m
.4868 .89115 L
s
.4868 .89115 m
.48234 .89764 L
s
.49308 .90079 m
.4868 .89115 L
s
.49143 .9318 m
.4868 .89115 L
s
0 1 .334 r
.53045 .2837 m
.52584 .28535 L
s
0 1 .514 r
.53882 .49563 m
.54489 .49367 L
s
.54489 .49367 m
.54553 .48666 L
s
0 .921 1 r
.40582 .89969 m
.39787 .8974 L
s
.46 1 0 r
.08446 .38615 m
.08578 .38396 L
s
.08578 .38396 m
.08204 .38824 L
s
.08874 .38778 m
.08578 .38396 L
s
.08383 .40428 m
.08578 .38396 L
s
0 .999 1 r
.48375 .90232 m
.49308 .90079 L
s
.48234 .89764 m
.48375 .90232 L
s
.49308 .90079 m
.49169 .8961 L
s
0 1 .725 r
.55454 .68947 m
.55427 .69893 L
s
.56252 .69022 m
.55454 .68947 L
s
.55454 .68947 m
.55484 .69236 L
s
.56193 .69679 m
.55454 .68947 L
s
.57397 .71523 m
.55454 .68947 L
s
0 1 .334 r
.52584 .28535 m
.52577 .29245 L
s
0 1 .569 r
.47408 .69349 m
.46651 .69459 L
s
.46 1 0 r
.08446 .38615 m
.08204 .38824 L
s
.08874 .38778 m
.08446 .38615 L
s
0 1 .725 r
.55427 .69893 m
.56193 .69679 L
s
.56193 .69679 m
.56252 .69022 L
s
0 1 .514 r
.54553 .48666 m
.53945 .48862 L
s
0 1 .694 r
.6145 .28789 m
.61926 .28591 L
s
.61926 .28591 m
.61909 .27762 L
s
.61926 .28591 m
.60981 .28167 L
s
.60981 .28167 m
.6145 .28789 L
s
.61909 .27762 m
.60981 .28167 L
s
.60981 .28167 m
.61432 .27959 L
s
.645 .28712 m
.60981 .28167 L
s
0 1 .514 r
.53945 .48862 m
.53882 .49563 L
s
0 .975 1 r
.57463 .89123 m
.57286 .90258 L
s
.58072 .89424 m
.57463 .89123 L
s
.57463 .89123 m
.57148 .89682 L
s
.58208 .90001 m
.57463 .89123 L
s
.58553 .92754 m
.57463 .89123 L
s
0 1 .355 r
.09668 .5877 m
.1033 .58752 L
s
.09319 .58524 m
.09668 .5877 L
s
.09668 .5877 m
.09928 .57942 L
s
0 1 .825 r
.62477 .48479 m
.6279 .49279 L
s
.63432 .48208 m
.62477 .48479 L
s
.62477 .48479 m
.62807 .48461 L
s
.63415 .49024 m
.62477 .48479 L
s
.65672 .49811 m
.62477 .48479 L
s
0 1 .725 r
.55484 .69236 m
.55427 .69893 L
s
0 1 .825 r
.6279 .49279 m
.63415 .49024 L
s
.63415 .49024 m
.63432 .48208 L
s
0 1 .355 r
.09928 .57942 m
.09982 .58506 L
s
.09928 .57942 m
.1033 .58752 L
s
.09319 .58524 m
.09928 .57942 L
s
.09411 .61435 m
.09928 .57942 L
s
.1033 .58752 m
.09982 .58506 L
s
.404 1 0 r
.17221 .37959 m
.17014 .38504 L
s
.17575 .38151 m
.17221 .37959 L
s
.17221 .37959 m
.17073 .38159 L
s
.17515 .38495 m
.17221 .37959 L
s
.17589 .39809 m
.17221 .37959 L
s
0 1 .694 r
.61909 .27762 m
.61432 .27959 L
s
.404 1 0 r
.17014 .38504 m
.17515 .38495 L
s
.17515 .38495 m
.17575 .38151 L
s
0 .975 1 r
.57286 .90258 m
.58208 .90001 L
s
.58208 .90001 m
.58072 .89424 L
s
0 1 .956 r
.64243 .68798 m
.64372 .69772 L
s
.65147 .68702 m
.64243 .68798 L
s
.64243 .68798 m
.64367 .69002 L
s
.6515 .69471 m
.64243 .68798 L
s
.6685 .71015 m
.64243 .68798 L
s
0 .975 1 r
.57148 .89682 m
.57286 .90258 L
s
0 1 .725 r
.56252 .69022 m
.55484 .69236 L
s
0 .999 1 r
.49169 .8961 m
.48234 .89764 L
s
.404 1 0 r
.17073 .38159 m
.17014 .38504 L
s
0 1 .956 r
.64372 .69772 m
.6515 .69471 L
s
.6515 .69471 m
.65147 .68702 L
s
0 .849 1 r
.66278 .8913 m
.66242 .90284 L
s
.67009 .89238 m
.66278 .8913 L
s
.66278 .8913 m
.66083 .89595 L
s
.67166 .89928 m
.66278 .8913 L
s
.68034 .92324 m
.66278 .8913 L
s
0 .753 1 r
.11032 .78588 m
.11984 .78734 L
s
.10668 .78388 m
.11032 .78588 L
s
.11032 .78588 m
.11546 .7757 L
s
0 1 .694 r
.61432 .27959 m
.6145 .28789 L
s
0 1 .825 r
.63432 .48208 m
.62807 .48461 L
s
.404 1 0 r
.17575 .38151 m
.17073 .38159 L
s
0 1 .355 r
.09982 .58506 m
.09319 .58524 L
s
0 .934 1 r
.70378 .2833 m
.70865 .28101 L
s
.70865 .28101 m
.70823 .27151 L
s
.70865 .28101 m
.69767 .27664 L
s
.69767 .27664 m
.70378 .2833 L
s
.70823 .27151 m
.69767 .27664 L
s
.69767 .27664 m
.70336 .27377 L
s
.73968 .28046 m
.69767 .27664 L
s
0 1 .825 r
.62807 .48461 m
.6279 .49279 L
s
0 .753 1 r
.11984 .78734 m
.11623 .78534 L
s
.11546 .7757 m
.11984 .78734 L
s
0 1 .274 r
.18187 .58202 m
.1836 .58512 L
s
.1836 .58512 m
.19067 .58433 L
s
.1836 .58512 m
.18623 .57678 L
s
0 .833 1 r
.71284 .48159 m
.71748 .48991 L
s
.72358 .47748 m
.71284 .48159 L
s
.71284 .48159 m
.71718 .48055 L
s
.72387 .48683 m
.71284 .48159 L
s
.75168 .49223 m
.71284 .48159 L
s
0 1 .274 r
.18623 .57678 m
.18187 .58202 L
s
.19067 .58433 m
.18623 .57678 L
s
.18623 .57678 m
.18895 .58123 L
s
.18644 .60892 m
.18623 .57678 L
s
.19067 .58433 m
.18895 .58123 L
s
0 .849 1 r
.66242 .90284 m
.67166 .89928 L
s
.67166 .89928 m
.67009 .89238 L
s
0 .753 1 r
.7307 .68648 m
.73359 .69647 L
s
.74088 .68383 m
.7307 .68648 L
s
.7307 .68648 m
.73294 .68761 L
s
.74151 .69268 m
.7307 .68648 L
s
.76373 .70504 m
.7307 .68648 L
s
0 .833 1 r
.71748 .48991 m
.72387 .48683 L
s
.72387 .48683 m
.72358 .47748 L
s
0 1 .956 r
.64367 .69002 m
.64372 .69772 L
s
0 .753 1 r
.11546 .7757 m
.11623 .78534 L
s
.10668 .78388 m
.11546 .7757 L
s
.10444 .82544 m
.11546 .7757 L
s
.245 1 0 r
.25909 .3752 m
.25809 .38108 L
s
.26388 .37595 m
.25909 .3752 L
s
.25909 .3752 m
.25864 .37665 L
s
.26332 .38037 m
.25909 .3752 L
s
.26863 .39186 m
.25909 .3752 L
s
0 .975 1 r
.58072 .89424 m
.57148 .89682 L
s
0 .635 1 r
.75126 .89138 m
.75243 .90311 L
s
.75981 .89052 m
.75126 .89138 L
s
.75126 .89138 m
.75045 .89503 L
s
.76177 .8986 m
.75126 .89138 L
s
.77585 .91891 m
.75126 .89138 L
s
0 .849 1 r
.66083 .89595 m
.66242 .90284 L
s
0 1 .956 r
.65147 .68702 m
.64367 .69002 L
s
.245 1 0 r
.25809 .38108 m
.26332 .38037 L
s
.26332 .38037 m
.26388 .37595 L
s
0 .934 1 r
.70823 .27151 m
.70336 .27377 L
s
0 .753 1 r
.73359 .69647 m
.74151 .69268 L
s
.74151 .69268 m
.74088 .68383 L
s
0 .961 1 r
.19935 .78526 m
.20816 .78519 L
s
.19537 .7825 m
.19935 .78526 L
s
.19935 .78526 m
.20295 .77466 L
s
.245 1 0 r
.25864 .37665 m
.25809 .38108 L
s
0 .833 1 r
.72358 .47748 m
.71718 .48055 L
s
.245 1 0 r
.26388 .37595 m
.25864 .37665 L
s
0 1 .286 r
.27018 .58186 m
.27701 .58228 L
s
.27701 .58228 m
.27932 .57804 L
s
.27701 .58228 m
.27358 .57412 L
s
0 .555 1 r
.79362 .27868 m
.79852 .27609 L
s
.79852 .27609 m
.79788 .26536 L
s
.79852 .27609 m
.78603 .27158 L
s
0 1 .274 r
.18895 .58123 m
.18187 .58202 L
s
0 .934 1 r
.70336 .27377 m
.70378 .2833 L
s
0 .635 1 r
.75243 .90311 m
.76177 .8986 L
s
.76177 .8986 m
.75981 .89052 L
s
0 .961 1 r
.20295 .77466 m
.2042 .78242 L
s
.20295 .77466 m
.20816 .78519 L
s
.19537 .7825 m
.20295 .77466 L
s
.19703 .82078 m
.20295 .77466 L
s
0 1 .286 r
.27358 .57412 m
.27018 .58186 L
s
.27932 .57804 m
.27358 .57412 L
s
.27358 .57412 m
.27247 .57762 L
s
.27945 .60346 m
.27358 .57412 L
s
0 .468 1 r
.80134 .47837 m
.80758 .48702 L
s
.81331 .47287 m
.80134 .47837 L
s
.80134 .47837 m
.80681 .47644 L
s
.81407 .48342 m
.80134 .47837 L
s
.84734 .4863 m
.80134 .47837 L
s
0 .418 1 r
.81936 .68497 m
.82392 .69521 L
s
.83072 .68063 m
.81936 .68497 L
s
.81936 .68497 m
.82265 .68514 L
s
.83197 .69069 m
.81936 .68497 L
s
.85968 .69989 m
.81936 .68497 L
s
0 .961 1 r
.20816 .78519 m
.2042 .78242 L
s
0 .849 1 r
.67009 .89238 m
.66083 .89595 L
s
0 .555 1 r
.78603 .27158 m
.79362 .27868 L
s
.79788 .26536 m
.78603 .27158 L
s
.78603 .27158 m
.79297 .26792 L
s
.83506 .27376 m
.78603 .27158 L
s
0 .753 1 r
.11623 .78534 m
.10668 .78388 L
s
0 .346 1 r
.84007 .89146 m
.8429 .90337 L
s
.84987 .88864 m
.84007 .89146 L
s
.84007 .89146 m
.84036 .89406 L
s
.85238 .89795 m
.84007 .89146 L
s
.87208 .91454 m
.84007 .89146 L
s
0 .833 1 r
.71718 .48055 m
.71748 .48991 L
s
0 .468 1 r
.80758 .48702 m
.81407 .48342 L
s
.81407 .48342 m
.81331 .47287 L
s
0 .753 1 r
.74088 .68383 m
.73294 .68761 L
s
.73294 .68761 m
.73359 .69647 L
s
.008 1 0 r
.34641 .37078 m
.34657 .37709 L
s
.35248 .37035 m
.34641 .37078 L
s
.34641 .37078 m
.34697 .3716 L
s
.35208 .37584 m
.34641 .37078 L
s
.36206 .38559 m
.34641 .37078 L
s
0 .635 1 r
.75045 .89503 m
.75243 .90311 L
s
.008 1 0 r
.34657 .37709 m
.35208 .37584 L
s
.35208 .37584 m
.35248 .37035 L
s
0 1 .286 r
.27247 .57762 m
.27018 .58186 L
s
0 .418 1 r
.82392 .69521 m
.83197 .69069 L
s
.83197 .69069 m
.83072 .68063 L
s
0 .555 1 r
.79788 .26536 m
.79297 .26792 L
s
0 1 .911 r
.28516 .78062 m
.28708 .78423 L
s
.28708 .78423 m
.29619 .78352 L
s
.28708 .78423 m
.29078 .77363 L
s
0 1 .286 r
.27932 .57804 m
.27247 .57762 L
s
0 1 .911 r
.29078 .77363 m
.28516 .78062 L
s
.29619 .78352 m
.29078 .77363 L
s
.29078 .77363 m
.2943 .7799 L
s
.29031 .81609 m
.29078 .77363 L
s
0 .468 1 r
.81331 .47287 m
.80681 .47644 L
s
0 0 1 r
.92921 .89153 m
.93382 .90364 L
s
.94029 .88676 m
.92921 .89153 L
s
.92921 .89153 m
.93061 .89306 L
s
.94347 .89733 m
.92921 .89153 L
s
.96903 .91015 m
.92921 .89153 L
s
0 .346 1 r
.8429 .90337 m
.85238 .89795 L
s
.85238 .89795 m
.84987 .88864 L
s
0 .635 1 r
.75981 .89052 m
.75045 .89503 L
s
0 1 .911 r
.29619 .78352 m
.2943 .7799 L
s
0 .961 1 r
.2042 .78242 m
.19537 .7825 L
s
.008 1 0 r
.34697 .3716 m
.34657 .37709 L
s
0 .048 1 r
.9084 .68346 m
.91472 .69393 L
s
.92099 .67743 m
.9084 .68346 L
s
.9084 .68346 m
.9128 .68263 L
s
.92289 .68871 m
.9084 .68346 L
s
.95634 .6947 m
.9084 .68346 L
s
0 1 .39 r
.36133 .57145 m
.3595 .57984 L
s
.36786 .57359 m
.36133 .57145 L
s
.36133 .57145 m
.36068 .57445 L
s
.36666 .57897 m
.36133 .57145 L
s
.37315 .59795 m
.36133 .57145 L
s
.008 1 0 r
.35248 .37035 m
.34697 .3716 L
s
0 1 .39 r
.3595 .57984 m
.36666 .57897 L
s
.36666 .57897 m
.36786 .57359 L
s
0 .088 1 r
.89029 .47514 m
.89819 .4841 L
s
.90351 .46824 m
.89029 .47514 L
s
.89029 .47514 m
.89696 .47228 L
s
.90472 .48002 m
.89029 .47514 L
s
.94371 .48032 m
.89029 .47514 L
s
0 .17 1 r
.88403 .27403 m
.88889 .27116 L
s
.88889 .27116 m
.88803 .25918 L
s
.88889 .27116 m
.87488 .2665 L
s
0 .418 1 r
.83072 .68063 m
.82265 .68514 L
s
0 .088 1 r
.89819 .4841 m
.90472 .48002 L
s
.90472 .48002 m
.90351 .46824 L
s
0 .17 1 r
.87488 .2665 m
.88403 .27403 L
s
.88803 .25918 m
.87488 .2665 L
s
.87488 .2665 m
.88316 .26201 L
s
.93115 .267 m
.87488 .2665 L
s
0 .555 1 r
.79297 .26792 m
.79362 .27868 L
s
0 .468 1 r
.80681 .47644 m
.80758 .48702 L
s
0 .418 1 r
.82265 .68514 m
.82392 .69521 L
s
0 .346 1 r
.84036 .89406 m
.8429 .90337 L
s
0 1 .282 r
.43419 .36634 m
.43557 .37308 L
s
.44155 .36473 m
.43419 .36634 L
s
.43419 .36634 m
.43575 .36646 L
s
.44137 .37134 m
.43419 .36634 L
s
.45619 .37926 m
.43419 .36634 L
s
0 .048 1 r
.91472 .69393 m
.92289 .68871 L
s
.92289 .68871 m
.92099 .67743 L
s
0 1 .39 r
.36068 .57445 m
.3595 .57984 L
s
0 1 .282 r
.43557 .37308 m
.44137 .37134 L
s
.44137 .37134 m
.44155 .36473 L
s
0 1 .873 r
.37895 .77259 m
.37499 .78295 L
s
.38504 .77763 m
.37895 .77259 L
s
.37895 .77259 m
.37594 .77807 L
s
.38407 .7825 m
.37895 .77259 L
s
.38429 .81137 m
.37895 .77259 L
s
0 .346 1 r
.84987 .88864 m
.84036 .89406 L
s
0 1 .873 r
.37499 .78295 m
.38407 .7825 L
s
.38407 .7825 m
.38504 .77763 L
s
0 .17 1 r
.88803 .25918 m
.88316 .26201 L
s
0 0 1 r
.93382 .90364 m
.94347 .89733 L
s
.94347 .89733 m
.94029 .88676 L
s
0 1 .39 r
.36786 .57359 m
.36068 .57445 L
s
0 .088 1 r
.90351 .46824 m
.89696 .47228 L
s
0 1 .575 r
.44947 .56877 m
.44906 .57759 L
s
.45707 .56932 m
.44947 .56877 L
s
.44947 .56877 m
.44969 .57109 L
s
.45643 .57582 m
.44947 .56877 L
s
.46755 .5924 m
.44947 .56877 L
s
0 1 .873 r
.37594 .77807 m
.37499 .78295 L
s
0 1 .911 r
.2943 .7799 m
.28516 .78062 L
s
0 1 .575 r
.44906 .57759 m
.45643 .57582 L
s
.45643 .57582 m
.45707 .56932 L
s
0 1 .282 r
.44155 .36473 m
.43575 .36646 L
s
0 .048 1 r
.92099 .67743 m
.9128 .68263 L
s
0 1 .282 r
.43575 .36646 m
.43557 .37308 L
s
0 1 .929 r
.46747 .77155 m
.46522 .78239 L
s
.47429 .7746 m
.46747 .77155 L
s
.46747 .77155 m
.46518 .77642 L
s
.47431 .78057 m
.46747 .77155 L
s
.47896 .80661 m
.46747 .77155 L
s
0 0 1 r
.93061 .89306 m
.93382 .90364 L
s
0 1 .609 r
.52243 .36187 m
.5251 .36905 L
s
.5311 .35907 m
.52243 .36187 L
s
.52243 .36187 m
.52502 .36125 L
s
.53117 .36686 m
.52243 .36187 L
s
.55102 .37289 m
.52243 .36187 L
s
0 0 1 r
.94029 .88676 m
.93061 .89306 L
s
0 .048 1 r
.9128 .68263 m
.91472 .69393 L
s
0 .088 1 r
.89696 .47228 m
.89819 .4841 L
s
0 1 .575 r
.44969 .57109 m
.44906 .57759 L
s
0 .17 1 r
.88316 .26201 m
.88403 .27403 L
s
0 1 .609 r
.5251 .36905 m
.53117 .36686 L
s
.53117 .36686 m
.5311 .35907 L
s
0 1 .929 r
.46522 .78239 m
.47431 .78057 L
s
.47431 .78057 m
.47429 .7746 L
s
0 1 .873 r
.38504 .77763 m
.37594 .77807 L
s
0 1 .575 r
.45707 .56932 m
.44969 .57109 L
s
0 1 .825 r
.53803 .56608 m
.53903 .57528 L
s
.54679 .5651 m
.53803 .56608 L
s
.53803 .56608 m
.53919 .56763 L
s
.54661 .57273 m
.53803 .56608 L
s
.56266 .58682 m
.53803 .56608 L
s
0 1 .929 r
.46518 .77642 m
.46522 .78239 L
s
0 1 .825 r
.53903 .57528 m
.54661 .57273 L
s
.54661 .57273 m
.54679 .5651 L
s
0 1 .609 r
.5311 .35907 m
.52502 .36125 L
s
0 .925 1 r
.55634 .7705 m
.55558 .78167 L
s
.56424 .77172 m
.55634 .7705 L
s
.55634 .7705 m
.55505 .77459 L
s
.56475 .7788 m
.55634 .7705 L
s
.57435 .80181 m
.55634 .7705 L
s
.075 1 0 r
.0793 .46637 m
.08236 .46384 L
s
.07386 .46439 m
.0793 .46637 L
s
.07861 .45889 m
.0793 .46637 L
s
0 1 .609 r
.52502 .36125 m
.5251 .36905 L
s
.075 1 0 r
.07692 .46185 m
.07861 .45889 L
s
.07861 .45889 m
.07386 .46439 L
s
.08236 .46384 m
.07861 .45889 L
s
.0761 .48511 m
.07861 .45889 L
s
0 1 .959 r
.61112 .35739 m
.61518 .36499 L
s
.62112 .35339 m
.61112 .35739 L
s
.61112 .35739 m
.61481 .35598 L
s
.62147 .36239 m
.61112 .35739 L
s
.64656 .36647 m
.61112 .35739 L
s
0 .925 1 r
.55558 .78167 m
.56475 .7788 L
s
.56475 .7788 m
.56424 .77172 L
s
0 1 .959 r
.61518 .36499 m
.62147 .36239 L
s
.62147 .36239 m
.62112 .35339 L
s
0 1 .825 r
.53919 .56763 m
.53903 .57528 L
s
0 1 .929 r
.47429 .7746 m
.46518 .77642 L
s
0 .876 1 r
.62698 .56337 m
.62946 .57292 L
s
.63697 .56087 m
.62698 .56337 L
s
.62698 .56337 m
.62915 .5641 L
s
.63726 .56969 m
.62698 .56337 L
s
.65848 .58119 m
.62698 .56337 L
s
.075 1 0 r
.07692 .46185 m
.07386 .46439 L
s
0 1 .825 r
.54679 .5651 m
.53919 .56763 L
s
.075 1 0 r
.08236 .46384 m
.07692 .46185 L
s
0 .925 1 r
.55505 .77459 m
.55558 .78167 L
s
0 .703 1 r
.64556 .76945 m
.64632 .78092 L
s
.65465 .76886 m
.64556 .76945 L
s
.64556 .76945 m
.64532 .77266 L
s
.65564 .77711 m
.64556 .76945 L
s
.67046 .79698 m
.64556 .76945 L
s
0 .876 1 r
.62946 .57292 m
.63726 .56969 L
s
.63726 .56969 m
.63697 .56087 L
s
0 1 .738 r
.08941 .66716 m
.09749 .66721 L
s
.08586 .66428 m
.08941 .66716 L
s
.08941 .66716 m
.09297 .65751 L
s
0 1 .959 r
.62112 .35339 m
.61481 .35598 L
s
.026 1 0 r
.16652 .455 m
.16386 .462 L
s
.17044 .4576 m
.16652 .455 L
s
.16652 .455 m
.16405 .4579 L
s
.17023 .4617 m
.16652 .455 L
s
.16966 .47912 m
.16652 .455 L
s
0 1 .738 r
.09297 .65751 m
.09397 .66433 L
s
.09297 .65751 m
.09749 .66721 L
s
.08586 .66428 m
.09297 .65751 L
s
.08653 .69886 m
.09297 .65751 L
s
.09749 .66721 m
.09397 .66433 L
s
.026 1 0 r
.16386 .462 m
.17023 .4617 L
s
.17023 .4617 m
.17044 .4576 L
s
0 .703 1 r
.64632 .78092 m
.65564 .77711 L
s
.65564 .77711 m
.65465 .76886 L
s
0 .925 1 r
.56424 .77172 m
.55505 .77459 L
s
0 1 .959 r
.61481 .35598 m
.61518 .36499 L
s
0 .674 1 r
.70028 .35288 m
.70579 .36091 L
s
.71163 .34767 m
.70028 .35288 L
s
.70028 .35288 m
.70514 .35066 L
s
.71227 .3579 m
.70028 .35288 L
s
.74282 .36001 m
.70028 .35288 L
s
.026 1 0 r
.16405 .4579 m
.16386 .462 L
s
0 .54 1 r
.71635 .56065 m
.72037 .57055 L
s
.72761 .55664 m
.71635 .56065 L
s
.71635 .56065 m
.71959 .5605 L
s
.72838 .56667 m
.71635 .56065 L
s
.75503 .57551 m
.71635 .56065 L
s
0 .674 1 r
.70579 .36091 m
.71227 .3579 L
s
.71227 .3579 m
.71163 .34767 L
s
0 .876 1 r
.63697 .56087 m
.62915 .5641 L
s
.62915 .5641 m
.62946 .57292 L
s
0 .418 1 r
.73514 .7684 m
.73749 .78015 L
s
.74548 .766 m
.73514 .7684 L
s
.73514 .7684 m
.73595 .77067 L
s
.747 .77547 m
.73514 .7684 L
s
.7673 .79211 m
.73514 .7684 L
s
0 .369 1 r
.10368 .86843 m
.11469 .87028 L
s
.10019 .86629 m
.10368 .86843 L
s
.10368 .86843 m
.11005 .857 L
s
0 .703 1 r
.64532 .77266 m
.64632 .78092 L
s
0 .54 1 r
.72037 .57055 m
.72838 .56667 L
s
.72838 .56667 m
.72761 .55664 L
s
.026 1 0 r
.17044 .4576 m
.16405 .4579 L
s
0 1 .654 r
.17598 .66148 m
.17805 .66512 L
s
.17805 .66512 m
.18642 .6644 L
s
.17805 .66512 m
.18142 .65532 L
s
0 .369 1 r
.11469 .87028 m
.11125 .86815 L
s
.11005 .857 m
.11469 .87028 L
s
0 1 .654 r
.18142 .65532 m
.17598 .66148 L
s
.18642 .6644 m
.18142 .65532 L
s
.18142 .65532 m
.18437 .66076 L
s
.18037 .69366 m
.18142 .65532 L
s
0 1 .738 r
.09397 .66433 m
.08586 .66428 L
s
0 .674 1 r
.71163 .34767 m
.70514 .35066 L
s
0 1 .654 r
.18642 .6644 m
.18437 .66076 L
s
0 1 .116 r
.25486 .45109 m
.25325 .45853 L
s
.26007 .4524 m
.25486 .45109 L
s
.25486 .45109 m
.25345 .45342 L
s
.25986 .45751 m
.25486 .45109 L
s
.26393 .47309 m
.25486 .45109 L
s
0 .418 1 r
.73749 .78015 m
.747 .77547 L
s
.747 .77547 m
.74548 .766 L
s
0 .703 1 r
.65465 .76886 m
.64532 .77266 L
s
0 .369 1 r
.11005 .857 m
.11125 .86815 L
s
.10019 .86629 m
.11005 .857 L
s
.09702 .91367 m
.11005 .857 L
s
0 1 .116 r
.25325 .45853 m
.25986 .45751 L
s
.25986 .45751 m
.26007 .4524 L
s
0 .177 1 r
.80612 .55792 m
.81178 .56815 L
s
.8187 .5524 m
.80612 .55792 L
s
.80612 .55792 m
.8105 .55686 L
s
.81997 .56366 m
.80612 .55792 L
s
.85231 .5698 m
.80612 .55792 L
s
0 .083 1 r
.82507 .76734 m
.82912 .77936 L
s
.83671 .76314 m
.82507 .76734 L
s
.82507 .76734 m
.82698 .76863 L
s
.83882 .77386 m
.82507 .76734 L
s
.86487 .7872 m
.82507 .76734 L
s
0 .295 1 r
.78991 .34835 m
.79695 .35681 L
s
.80262 .34193 m
.78991 .34835 L
s
.78991 .34835 m
.79601 .3453 L
s
.80354 .35341 m
.78991 .34835 L
s
.83981 .35349 m
.78991 .34835 L
s
0 .54 1 r
.72761 .55664 m
.71959 .5605 L
s
0 .295 1 r
.79695 .35681 m
.80354 .35341 L
s
.80354 .35341 m
.80262 .34193 L
s
0 .674 1 r
.70514 .35066 m
.70579 .36091 L
s
0 1 .116 r
.25345 .45342 m
.25325 .45853 L
s
0 .578 1 r
.19349 .86813 m
.20417 .86879 L
s
.19075 .86501 m
.19349 .86813 L
s
.19349 .86813 m
.19905 .85638 L
s
0 .54 1 r
.71959 .5605 m
.72037 .57055 L
s
0 .177 1 r
.81178 .56815 m
.81997 .56366 L
s
.81997 .56366 m
.8187 .5524 L
s
0 .418 1 r
.73595 .77067 m
.73749 .78015 L
s
0 1 .659 r
.27024 .65312 m
.2663 .6626 L
s
.27603 .65765 m
.27024 .65312 L
s
.27024 .65312 m
.26752 .65775 L
s
.27479 .6625 m
.27024 .65312 L
s
.27491 .68842 m
.27024 .65312 L
s
.2663 .6626 m
.27479 .6625 L
s
.27479 .6625 m
.27603 .65765 L
s
0 .578 1 r
.20417 .86879 m
.20147 .86567 L
s
.19905 .85638 m
.20417 .86879 L
s
0 1 .116 r
.26007 .4524 m
.25345 .45342 L
s
0 .578 1 r
.19905 .85638 m
.20147 .86567 L
s
.19075 .86501 m
.19905 .85638 L
s
.19112 .90927 m
.19905 .85638 L
s
0 .418 1 r
.74548 .766 m
.73595 .77067 L
s
0 .083 1 r
.82912 .77936 m
.83882 .77386 L
s
.83882 .77386 m
.83671 .76314 L
s
0 1 .334 r
.34362 .44717 m
.34316 .45504 L
s
.35015 .44717 m
.34362 .44717 L
s
.34362 .44717 m
.34322 .44883 L
s
.35007 .45337 m
.34362 .44717 L
s
.3589 .46702 m
.34362 .44717 L
s
0 1 .654 r
.18437 .66076 m
.17598 .66148 L
s
0 .295 1 r
.80262 .34193 m
.79601 .3453 L
s
.289 0 1 r
.91535 .76627 m
.92121 .77857 L
s
.92833 .76027 m
.91535 .76627 L
s
.91535 .76627 m
.91841 .76656 L
s
.93109 .77227 m
.91535 .76627 L
s
.96319 .78225 m
.91535 .76627 L
s
0 1 .659 r
.26752 .65775 m
.2663 .6626 L
s
0 1 .334 r
.34316 .45504 m
.35007 .45337 L
s
.35007 .45337 m
.35015 .44717 L
s
.207 0 1 r
.89631 .55518 m
.9037 .56573 L
s
.91023 .54813 m
.89631 .55518 L
s
.89631 .55518 m
.9019 .55318 L
s
.91201 .56066 m
.89631 .55518 L
s
.95033 .56404 m
.89631 .55518 L
s
0 .369 1 r
.11125 .86815 m
.10019 .86629 L
s
0 .707 1 r
.28942 .86844 m
.29529 .86515 L
s
.28047 .86586 m
.28942 .86844 L
s
.28836 .85576 m
.28942 .86844 L
s
.092 0 1 r
.88001 .34379 m
.88866 .35268 L
s
.89409 .33615 m
.88001 .34379 L
s
.88001 .34379 m
.88744 .33989 L
s
.89531 .3489 m
.88001 .34379 L
s
.93754 .34692 m
.88001 .34379 L
s
0 .177 1 r
.8187 .5524 m
.8105 .55686 L
s
.092 0 1 r
.88866 .35268 m
.89531 .3489 L
s
.89531 .3489 m
.89409 .33615 L
s
0 .707 1 r
.28633 .86256 m
.28836 .85576 L
s
.28836 .85576 m
.28047 .86586 L
s
.29529 .86515 m
.28836 .85576 L
s
.28594 .90483 m
.28836 .85576 L
s
.207 0 1 r
.9037 .56573 m
.91201 .56066 L
s
.91201 .56066 m
.91023 .54813 L
s
0 1 .334 r
.34322 .44883 m
.34316 .45504 L
s
0 1 .753 r
.35943 .6509 m
.35707 .66098 L
s
.36605 .65361 m
.35943 .6509 L
s
.35943 .6509 m
.35737 .65501 L
s
.36573 .65958 m
.35943 .6509 L
s
.37016 .68315 m
.35943 .6509 L
s
0 .295 1 r
.79601 .3453 m
.79695 .35681 L
s
0 .177 1 r
.8105 .55686 m
.81178 .56815 L
s
0 .083 1 r
.82698 .76863 m
.82912 .77936 L
s
.83671 .76314 m
.82698 .76863 L
s
0 1 .659 r
.27603 .65765 m
.26752 .65775 L
s
0 1 .753 r
.35707 .66098 m
.36573 .65958 L
s
.36573 .65958 m
.36605 .65361 L
s
.289 0 1 r
.92121 .77857 m
.93109 .77227 L
s
.93109 .77227 m
.92833 .76027 L
s
0 1 .334 r
.35015 .44717 m
.34322 .44883 L
s
0 1 .609 r
.43281 .44322 m
.43357 .45153 L
s
.44068 .44192 m
.43281 .44322 L
s
.43281 .44322 m
.43343 .44417 L
s
.44082 .44927 m
.43281 .44322 L
s
.45459 .46089 m
.43281 .44322 L
s
0 .578 1 r
.20147 .86567 m
.19075 .86501 L
s
0 1 .753 r
.35737 .65501 m
.35707 .66098 L
s
.092 0 1 r
.89409 .33615 m
.88744 .33989 L
s
0 .707 1 r
.28633 .86256 m
.28047 .86586 L
s
0 1 .609 r
.43357 .45153 m
.44082 .44927 L
s
.44082 .44927 m
.44068 .44192 L
s
0 .747 1 r
.37799 .85514 m
.37443 .86753 L
s
.38294 .86067 m
.37799 .85514 L
s
.37799 .85514 m
.37253 .8623 L
s
.38481 .86591 m
.37799 .85514 L
s
.38148 .90036 m
.37799 .85514 L
s
.207 0 1 r
.91023 .54813 m
.9019 .55318 L
s
0 .707 1 r
.29529 .86515 m
.28633 .86256 L
s
0 1 .927 r
.44899 .64868 m
.44802 .6592 L
s
.45676 .64971 m
.44899 .64868 L
s
.44899 .64868 m
.44788 .65209 L
s
.45688 .65681 m
.44899 .64868 L
s
.46614 .67783 m
.44899 .64868 L
s
0 .747 1 r
.37443 .86753 m
.38481 .86591 L
s
.37253 .8623 m
.37443 .86753 L
s
.38481 .86591 m
.38294 .86067 L
s
.289 0 1 r
.92833 .76027 m
.91841 .76656 L
s
0 1 .753 r
.36605 .65361 m
.35737 .65501 L
s
0 1 .927 r
.44802 .6592 m
.45688 .65681 L
s
.45688 .65681 m
.45676 .64971 L
s
0 1 .609 r
.43343 .44417 m
.43357 .45153 L
s
.289 0 1 r
.91841 .76656 m
.92121 .77857 L
s
.207 0 1 r
.9019 .55318 m
.9037 .56573 L
s
.092 0 1 r
.88744 .33989 m
.88866 .35268 L
s
0 1 .609 r
.44068 .44192 m
.43343 .44417 L
s
0 1 .924 r
.52243 .43926 m
.52451 .448 L
s
.53167 .43664 m
.52243 .43926 L
s
.52243 .43926 m
.52409 .43944 L
s
.53207 .44519 m
.52243 .43926 L
s
.55102 .45473 m
.52243 .43926 L
s
0 .694 1 r
.46793 .85452 m
.46557 .86723 L
s
.47419 .85816 m
.46793 .85452 L
s
.46793 .85452 m
.46375 .86086 L
s
.47598 .86454 m
.46793 .85452 L
s
.47774 .89586 m
.46793 .85452 L
s
0 1 .927 r
.44788 .65209 m
.44802 .6592 L
s
0 1 .924 r
.52451 .448 m
.53207 .44519 L
s
.53207 .44519 m
.53167 .43664 L
s
0 .833 1 r
.53893 .64645 m
.53938 .65736 L
s
.54795 .64583 m
.53893 .64645 L
s
.53893 .64645 m
.53883 .64907 L
s
.54848 .65412 m
.53893 .64645 L
s
.56285 .67247 m
.53893 .64645 L
s
0 .694 1 r
.46557 .86723 m
.47598 .86454 L
s
.47598 .86454 m
.47419 .85816 L
s
.46375 .86086 m
.46557 .86723 L
s
0 1 .927 r
.45676 .64971 m
.44788 .65209 L
s
0 .833 1 r
.53938 .65736 m
.54848 .65412 L
s
.54848 .65412 m
.54795 .64583 L
s
0 .552 1 r
.5582 .85389 m
.55715 .86693 L
s
.5658 .85564 m
.5582 .85389 L
s
.5582 .85389 m
.55522 .85936 L
s
.5677 .86321 m
.5582 .85389 L
s
.57474 .89132 m
.5582 .85389 L
s
0 .747 1 r
.38294 .86067 m
.37253 .8623 L
s
0 1 .924 r
.53167 .43664 m
.52409 .43944 L
s
0 .731 1 r
.61248 .43527 m
.61597 .44446 L
s
.62312 .43133 m
.61248 .43527 L
s
.61248 .43527 m
.61524 .43465 L
s
.62383 .44112 m
.61248 .43527 L
s
.64817 .44851 m
.61248 .43527 L
s
0 1 .924 r
.52409 .43944 m
.52451 .448 L
s
0 .54 1 r
.62925 .64421 m
.63119 .65549 L
s
.63958 .64196 m
.62925 .64421 L
s
.62925 .64421 m
.63019 .64598 L
s
.64056 .65146 m
.62925 .64421 L
s
.6603 .66707 m
.62925 .64421 L
s
0 1 .309 r
.07206 .54525 m
.07579 .54231 L
s
.06542 .54295 m
.07206 .54525 L
s
.07122 .53617 m
.07206 .54525 L
s
0 .731 1 r
.61597 .44446 m
.62383 .44112 L
s
.62383 .44112 m
.62312 .43133 L
s
0 .833 1 r
.53883 .64907 m
.53938 .65736 L
s
0 .552 1 r
.55715 .86693 m
.5677 .86321 L
s
.5677 .86321 m
.5658 .85564 L
s
0 1 .309 r
.06914 .54 m
.07122 .53617 L
s
.07122 .53617 m
.06542 .54295 L
s
.07579 .54231 m
.07122 .53617 L
s
.06811 .56865 m
.07122 .53617 L
s
0 .333 1 r
.64879 .85327 m
.64918 .86662 L
s
.65776 .8531 m
.64879 .85327 L
s
.64879 .85327 m
.64695 .85781 L
s
.65995 .86192 m
.64879 .85327 L
s
.67249 .88675 m
.64879 .85327 L
s
0 .552 1 r
.55522 .85936 m
.55715 .86693 L
s
0 .833 1 r
.54795 .64583 m
.53883 .64907 L
s
0 .54 1 r
.63119 .65549 m
.64056 .65146 L
s
.64056 .65146 m
.63958 .64196 L
s
0 .694 1 r
.47419 .85816 m
.46375 .86086 L
s
0 1 .309 r
.06914 .54 m
.06542 .54295 L
s
0 .366 1 r
.70297 .43127 m
.70795 .44089 L
s
.71502 .426 m
.70297 .43127 L
s
.70297 .43127 m
.70689 .42982 L
s
.71607 .43704 m
.70297 .43127 L
s
.74608 .44225 m
.70297 .43127 L
s
0 .731 1 r
.62312 .43133 m
.61524 .43465 L
s
0 1 .309 r
.07579 .54231 m
.06914 .54 L
s
0 .206 1 r
.71995 .64196 m
.72346 .65361 L
s
.73164 .63807 m
.71995 .64196 L
s
.71995 .64196 m
.72198 .64284 L
s
.7331 .64883 m
.71995 .64196 L
s
.7585 .66163 m
.71995 .64196 L
s
0 .878 1 r
.08184 .74908 m
.09145 .74941 L
s
.07835 .74587 m
.08184 .74908 L
s
.08184 .74908 m
.08645 .73806 L
s
0 .731 1 r
.61524 .43465 m
.61597 .44446 L
s
0 .333 1 r
.64918 .86662 m
.65995 .86192 L
s
.65995 .86192 m
.65776 .8531 L
s
0 .048 1 r
.7397 .85263 m
.74166 .86632 L
s
.75007 .85056 m
.7397 .85263 L
s
.7397 .85263 m
.739 .85622 L
s
.7527 .86067 m
.7397 .85263 L
s
.77098 .88214 m
.7397 .85263 L
s
0 .366 1 r
.70795 .44089 m
.71607 .43704 L
s
.71607 .43704 m
.71502 .426 L
s
0 1 .355 r
.16066 .53274 m
.15749 .54139 L
s
.16486 .53608 m
.16066 .53274 L
s
.16066 .53274 m
.1571 .53668 L
s
.16523 .54079 m
.16066 .53274 L
s
.16322 .56288 m
.16066 .53274 L
s
0 .54 1 r
.63019 .64598 m
.63119 .65549 L
s
0 1 .355 r
.15749 .54139 m
.16523 .54079 L
s
.16523 .54079 m
.16486 .53608 L
s
0 .878 1 r
.09145 .74941 m
.08799 .7462 L
s
.08645 .73806 m
.09145 .74941 L
s
.08645 .73806 m
.08799 .7462 L
s
.07835 .74587 m
.08645 .73806 L
s
.0787 .78622 m
.08645 .73806 L
s
0 .552 1 r
.5658 .85564 m
.55522 .85936 L
s
0 .333 1 r
.64695 .85781 m
.64918 .86662 L
s
0 .54 1 r
.63958 .64196 m
.63019 .64598 L
s
0 1 .355 r
.1571 .53668 m
.15749 .54139 L
s
0 .206 1 r
.72346 .65361 m
.7331 .64883 L
s
.7331 .64883 m
.73164 .63807 L
s
.159 0 1 r
.81103 .6397 m
.81622 .65171 L
s
.82413 .63417 m
.81103 .6397 L
s
.81103 .6397 m
.81422 .63965 L
s
.82611 .64621 m
.81103 .6397 L
s
.85745 .65615 m
.81103 .6397 L
s
.014 0 1 r
.7939 .42725 m
.80047 .4373 L
s
.8074 .42064 m
.7939 .42725 L
s
.7939 .42725 m
.79907 .42494 L
s
.80878 .43296 m
.7939 .42725 L
s
.84473 .43594 m
.7939 .42725 L
s
.289 0 1 r
.83094 .852 m
.8346 .86601 L
s
.84273 .84801 m
.83094 .852 L
s
.83094 .852 m
.83138 .85459 L
s
.84592 .85943 m
.83094 .852 L
s
.87024 .8775 m
.83094 .852 L
s
0 .366 1 r
.71502 .426 m
.70689 .42982 L
s
0 .048 1 r
.74166 .86632 m
.7527 .86067 L
s
.7527 .86067 m
.75007 .85056 L
s
0 .963 1 r
.1699 .74349 m
.17232 .74762 L
s
.17232 .74762 m
.18204 .74697 L
s
.17232 .74762 m
.17645 .7363 L
s
0 1 .488 r
.2505 .52931 m
.24837 .53841 L
s
.25604 .53122 m
.2505 .52931 L
s
.2505 .52931 m
.24802 .53264 L
s
.25637 .537 m
.2505 .52931 L
s
.25906 .55707 m
.2505 .52931 L
s
0 .963 1 r
.17645 .7363 m
.1699 .74349 L
s
.18204 .74697 m
.17645 .7363 L
s
.17645 .7363 m
.17965 .74284 L
s
.17409 .78126 m
.17645 .7363 L
s
0 .333 1 r
.65776 .8531 m
.64695 .85781 L
s
.014 0 1 r
.80047 .4373 m
.80878 .43296 L
s
.80878 .43296 m
.8074 .42064 L
s
0 .963 1 r
.18204 .74697 m
.17965 .74284 L
s
0 .366 1 r
.70689 .42982 m
.70795 .44089 L
s
0 1 .355 r
.16486 .53608 m
.1571 .53668 L
s
0 1 .488 r
.24837 .53841 m
.25637 .537 L
s
.25637 .537 m
.25604 .53122 L
s
0 .206 1 r
.72198 .64284 m
.72346 .65361 L
s
.73164 .63807 m
.72198 .64284 L
s
0 .878 1 r
.08799 .7462 m
.07835 .74587 L
s
.159 0 1 r
.81622 .65171 m
.82611 .64621 L
s
.82611 .64621 m
.82413 .63417 L
s
0 .048 1 r
.739 .85622 m
.74166 .86632 L
s
0 1 .488 r
.24802 .53264 m
.24837 .53841 L
s
.667 0 1 r
.9225 .85137 m
.92799 .8657 L
s
.93576 .84545 m
.9225 .85137 L
s
.9225 .85137 m
.92413 .85293 L
s
.93959 .85822 m
.9225 .85137 L
s
.97027 .87282 m
.9225 .85137 L
s
.548 0 1 r
.9025 .63743 m
.90948 .6498 L
s
.91703 .63026 m
.9025 .63743 L
s
.9025 .63743 m
.90692 .63643 L
s
.91956 .64361 m
.9025 .63743 L
s
.95718 .65063 m
.9025 .63743 L
s
.289 0 1 r
.8346 .86601 m
.84592 .85943 L
s
.84592 .85943 m
.84273 .84801 L
s
.405 0 1 r
.88528 .4232 m
.89352 .43368 L
s
.90025 .41525 m
.88528 .4232 L
s
.88528 .4232 m
.89178 .42002 L
s
.90197 .42887 m
.88528 .4232 L
s
.94415 .42958 m
.88528 .4232 L
s
0 .961 1 r
.26679 .73453 m
.26267 .74591 L
s
.27228 .73971 m
.26679 .73453 L
s
.26679 .73453 m
.26226 .74054 L
s
.27265 .74507 m
.26679 .73453 L
s
.27021 .77627 m
.26679 .73453 L
s
0 .048 1 r
.75007 .85056 m
.739 .85622 L
s
.014 0 1 r
.8074 .42064 m
.79907 .42494 L
s
0 1 .694 r
.34074 .52586 m
.33974 .53542 L
s
.34764 .52634 m
.34074 .52586 L
s
.34074 .52586 m
.33929 .52851 L
s
.34808 .53326 m
.34074 .52586 L
s
.35563 .55122 m
.34074 .52586 L
s
0 .961 1 r
.26267 .74591 m
.27265 .74507 L
s
.27265 .74507 m
.27228 .73971 L
s
.405 0 1 r
.89352 .43368 m
.90197 .42887 L
s
.90197 .42887 m
.90025 .41525 L
s
0 1 .488 r
.25604 .53122 m
.24802 .53264 L
s
0 .961 1 r
.26226 .74054 m
.26267 .74591 L
s
.159 0 1 r
.82413 .63417 m
.81422 .63965 L
s
0 1 .694 r
.33974 .53542 m
.34808 .53326 L
s
.34808 .53326 m
.34764 .52634 L
s
.548 0 1 r
.90948 .6498 m
.91956 .64361 L
s
.91956 .64361 m
.91703 .63026 L
s
0 .963 1 r
.17965 .74284 m
.1699 .74349 L
s
.014 0 1 r
.79907 .42494 m
.80047 .4373 L
s
.159 0 1 r
.81422 .63965 m
.81622 .65171 L
s
.289 0 1 r
.83138 .85459 m
.8346 .86601 L
s
.667 0 1 r
.92799 .8657 m
.93959 .85822 L
s
.93959 .85822 m
.93576 .84545 L
s
0 .873 1 r
.35747 .73276 m
.35476 .74466 L
s
.36399 .73609 m
.35747 .73276 L
s
.35747 .73276 m
.35388 .73816 L
s
.36484 .74259 m
.35747 .73276 L
s
.36707 .77125 m
.35747 .73276 L
s
0 1 .694 r
.33929 .52851 m
.33974 .53542 L
s
.289 0 1 r
.84273 .84801 m
.83138 .85459 L
s
0 1 .959 r
.43138 .52239 m
.43161 .53241 L
s
.43969 .52144 m
.43138 .52239 L
s
.43138 .52239 m
.43096 .52431 L
s
.44032 .52955 m
.43138 .52239 L
s
.45294 .54531 m
.43138 .52239 L
s
.405 0 1 r
.90025 .41525 m
.89178 .42002 L
s
0 .873 1 r
.35476 .74466 m
.36484 .74259 L
s
.36484 .74259 m
.36399 .73609 L
s
0 1 .694 r
.34764 .52634 m
.33929 .52851 L
s
0 .873 1 r
.35388 .73816 m
.35476 .74466 L
s
.548 0 1 r
.91703 .63026 m
.90692 .63643 L
s
0 .961 1 r
.27228 .73971 m
.26226 .74054 L
s
0 1 .959 r
.43161 .53241 m
.44032 .52955 L
s
.44032 .52955 m
.43969 .52144 L
s
0 .705 1 r
.44849 .73098 m
.44711 .74332 L
s
.45628 .73255 m
.44849 .73098 L
s
.44849 .73098 m
.44595 .73564 L
s
.45741 .74023 m
.44849 .73098 L
s
.46468 .76618 m
.44849 .73098 L
s
.667 0 1 r
.92413 .85293 m
.92799 .8657 L
s
.93576 .84545 m
.92413 .85293 L
s
.548 0 1 r
.90692 .63643 m
.90948 .6498 L
s
.405 0 1 r
.89178 .42002 m
.89352 .43368 L
s
0 1 .959 r
.43096 .52431 m
.43161 .53241 L
s
0 .731 1 r
.52242 .51891 m
.52399 .52939 L
s
.53216 .51652 m
.52242 .51891 L
s
.52242 .51891 m
.52305 .52004 L
s
.53308 .52586 m
.52242 .51891 L
s
.55101 .53937 m
.52242 .51891 L
s
0 .705 1 r
.44711 .74332 m
.45741 .74023 L
s
.45741 .74023 m
.45628 .73255 L
s
0 1 .959 r
.43969 .52144 m
.43096 .52431 L
s
0 .873 1 r
.36399 .73609 m
.35388 .73816 L
s
0 .705 1 r
.44595 .73564 m
.44711 .74332 L
s
0 .468 1 r
.53986 .72919 m
.53988 .74195 L
s
.54901 .72901 m
.53986 .72919 L
s
.53986 .72919 m
.53839 .73303 L
s
.55047 .73793 m
.53986 .72919 L
s
.56305 .76107 m
.53986 .72919 L
s
0 .731 1 r
.52399 .52939 m
.53308 .52586 L
s
.53308 .52586 m
.53216 .51652 L
s
0 .389 1 r
.61387 .51542 m
.61687 .52635 L
s
.62508 .51157 m
.61387 .51542 L
s
.61387 .51542 m
.61561 .51572 L
s
.62632 .52218 m
.61387 .51542 L
s
.64984 .53337 m
.61387 .51542 L
s
0 .468 1 r
.53988 .74195 m
.55047 .73793 L
s
.55047 .73793 m
.54901 .72901 L
s
0 .731 1 r
.52305 .52004 m
.52399 .52939 L
s
0 .705 1 r
.45628 .73255 m
.44595 .73564 L
s
0 .177 1 r
.63159 .7274 m
.63309 .74057 L
s
.64215 .72546 m
.63159 .7274 L
s
.63159 .7274 m
.6312 .73037 L
s
.64401 .73566 m
.63159 .7274 L
s
.66218 .75593 m
.63159 .7274 L
s
0 .731 1 r
.53216 .51652 m
.52305 .52004 L
s
0 .389 1 r
.61687 .52635 m
.62632 .52218 L
s
.62632 .52218 m
.62508 .51157 L
s
0 .468 1 r
.53839 .73303 m
.53988 .74195 L
s
0 1 .694 r
.0646 .62662 m
.069 .62332 L
s
.05671 .62404 m
.0646 .62662 L
s
.0636 .61589 m
.0646 .62662 L
s
0 .023 1 r
.70574 .5119 m
.71027 .52329 L
s
.71843 .5066 m
.70574 .5119 L
s
.70574 .5119 m
.70863 .51136 L
s
.72005 .51851 m
.70574 .5119 L
s
.74944 .52733 m
.70574 .5119 L
s
0 .177 1 r
.63309 .74057 m
.64401 .73566 L
s
.64401 .73566 m
.64215 .72546 L
s
0 1 .694 r
.0611 .62073 m
.0636 .61589 L
s
.0636 .61589 m
.05671 .62404 L
s
.069 .62332 m
.0636 .61589 L
s
.05985 .65506 m
.0636 .61589 L
s
.159 0 1 r
.72366 .72559 m
.72676 .73918 L
s
.73569 .7219 m
.72366 .72559 L
s
.72366 .72559 m
.72439 .72766 L
s
.73802 .73341 m
.72366 .72559 L
s
.76209 .75074 m
.72366 .72559 L
s
0 .468 1 r
.54901 .72901 m
.53839 .73303 L
s
0 .389 1 r
.61561 .51572 m
.61687 .52635 L
s
.62508 .51157 m
.61561 .51572 L
s
0 .023 1 r
.71027 .52329 m
.72005 .51851 L
s
.72005 .51851 m
.71843 .5066 L
s
0 .177 1 r
.6312 .73037 m
.63309 .74057 L
s
0 1 .694 r
.0611 .62073 m
.05671 .62404 L
s
.069 .62332 m
.0611 .62073 L
s
0 .493 1 r
.074 .83359 m
.08517 .83423 L
s
.07065 .83014 m
.074 .83359 L
s
.074 .83359 m
.07974 .82118 L
s
.159 0 1 r
.72676 .73918 m
.73802 .73341 L
s
.73802 .73341 m
.73569 .7219 L
s
0 1 .738 r
.15462 .61293 m
.15101 .6233 L
s
.159 .61708 m
.15462 .61293 L
s
.15462 .61293 m
.14988 .61804 L
s
.16011 .62234 m
.15462 .61293 L
s
.15656 .64952 m
.15462 .61293 L
s
.529 0 1 r
.81608 .72379 m
.8209 .73778 L
s
.82962 .71833 m
.81608 .72379 L
s
.81608 .72379 m
.818 .72491 L
s
.83248 .73118 m
.81608 .72379 L
s
.86278 .74551 m
.81608 .72379 L
s
.362 0 1 r
.79801 .50837 m
.80418 .52022 L
s
.81224 .50161 m
.79801 .50837 L
s
.79801 .50837 m
.80216 .50696 L
s
.81423 .51484 m
.79801 .50837 L
s
.84982 .52125 m
.79801 .50837 L
s
0 .177 1 r
.64215 .72546 m
.6312 .73037 L
s
0 1 .738 r
.15101 .6233 m
.16011 .62234 L
s
.16011 .62234 m
.159 .61708 L
s
0 .493 1 r
.08517 .83423 m
.08186 .83078 L
s
.07974 .82118 m
.08517 .83423 L
s
.07974 .82118 m
.08186 .83078 L
s
.07065 .83014 m
.07974 .82118 L
s
.0706 .87657 m
.07974 .82118 L
s
0 1 .738 r
.14988 .61804 m
.15101 .6233 L
s
0 .023 1 r
.71843 .5066 m
.70863 .51136 L
s
.362 0 1 r
.80418 .52022 m
.81423 .51484 L
s
.81423 .51484 m
.81224 .50161 L
s
0 .023 1 r
.70863 .51136 m
.71027 .52329 L
s
0 .579 1 r
.17254 .83338 m
.17846 .82977 L
s
.16272 .83055 m
.17254 .83338 L
s
.17133 .81983 m
.17254 .83338 L
s
.159 0 1 r
.72439 .72766 m
.72676 .73918 L
s
.926 0 1 r
.90886 .72197 m
.91552 .73637 L
s
.92394 .71474 m
.90886 .72197 L
s
.90886 .72197 m
.91204 .72213 L
s
.92739 .72896 m
.90886 .72197 L
s
.96426 .74024 m
.90886 .72197 L
s
0 1 .865 r
.24601 .60995 m
.24342 .62082 L
s
.25178 .61255 m
.24601 .60995 L
s
.24601 .60995 m
.24237 .61443 L
s
.25281 .61894 m
.24601 .60995 L
s
.25402 .64395 m
.24601 .60995 L
s
.529 0 1 r
.8209 .73778 m
.83248 .73118 L
s
.83248 .73118 m
.82962 .71833 L
s
.761 0 1 r
.8907 .50483 m
.89861 .51713 L
s
.90649 .49659 m
.8907 .50483 L
s
.8907 .50483 m
.89619 .50251 L
s
.90888 .51116 m
.8907 .50483 L
s
.95099 .51511 m
.8907 .50483 L
s
0 .579 1 r
.16863 .82693 m
.17133 .81983 L
s
.17133 .81983 m
.16272 .83055 L
s
.17846 .82977 m
.17133 .81983 L
s
.1676 .87188 m
.17133 .81983 L
s
.159 0 1 r
.73569 .7219 m
.72439 .72766 L
s
0 1 .865 r
.24342 .62082 m
.25281 .61894 L
s
.25281 .61894 m
.25178 .61255 L
s
0 1 .738 r
.159 .61708 m
.14988 .61804 L
s
0 1 .865 r
.24237 .61443 m
.24342 .62082 L
s
.362 0 1 r
.81224 .50161 m
.80216 .50696 L
s
.761 0 1 r
.89861 .51713 m
.90888 .51116 L
s
.90888 .51116 m
.90649 .49659 L
s
0 .493 1 r
.08186 .83078 m
.07065 .83014 L
s
0 .579 1 r
.16863 .82693 m
.16272 .83055 L
s
0 .578 1 r
.26323 .81848 m
.25927 .83183 L
s
.26805 .8244 m
.26323 .81848 L
s
.26323 .81848 m
.25683 .82611 L
s
.27046 .83013 m
.26323 .81848 L
s
.26536 .86716 m
.26323 .81848 L
s
0 .934 1 r
.33777 .60696 m
.33631 .61832 L
s
.34497 .608 m
.33777 .60696 L
s
.33777 .60696 m
.33518 .61074 L
s
.34607 .61559 m
.33777 .60696 L
s
.35224 .63833 m
.33777 .60696 L
s
.926 0 1 r
.91552 .73637 m
.92739 .72896 L
s
.92739 .72896 m
.92394 .71474 L
s
.362 0 1 r
.80216 .50696 m
.80418 .52022 L
s
.529 0 1 r
.818 .72491 m
.8209 .73778 L
s
.82962 .71833 m
.818 .72491 L
s
0 .579 1 r
.17846 .82977 m
.16863 .82693 L
s
0 .578 1 r
.25927 .83183 m
.27046 .83013 L
s
.25683 .82611 m
.25927 .83183 L
s
.27046 .83013 m
.26805 .8244 L
s
0 .934 1 r
.33631 .61832 m
.34607 .61559 L
s
.34607 .61559 m
.34497 .608 L
s
0 1 .865 r
.25178 .61255 m
.24237 .61443 L
s
0 .491 1 r
.35545 .81713 m
.35257 .83095 L
s
.36168 .8212 m
.35545 .81713 L
s
.35545 .81713 m
.35025 .82401 L
s
.36395 .82815 m
.35545 .81713 L
s
.36388 .8624 m
.35545 .81713 L
s
0 .934 1 r
.33518 .61074 m
.33631 .61832 L
s
.761 0 1 r
.90649 .49659 m
.89619 .50251 L
s
0 .674 1 r
.42991 .60396 m
.42969 .61582 L
s
.43857 .60344 m
.42991 .60396 L
s
.42991 .60396 m
.42836 .60698 L
s
.43987 .61227 m
.42991 .60396 L
s
.45124 .63267 m
.42991 .60396 L
s
.926 0 1 r
.92394 .71474 m
.91204 .72213 L
s
.91204 .72213 m
.91552 .73637 L
s
0 .491 1 r
.35257 .83095 m
.36395 .82815 L
s
.36395 .82815 m
.36168 .8212 L
s
.35025 .82401 m
.35257 .83095 L
s
.761 0 1 r
.89619 .50251 m
.89861 .51713 L
s
0 .674 1 r
.42969 .61582 m
.43987 .61227 L
s
.43987 .61227 m
.43857 .60344 L
s
0 .324 1 r
.44798 .81577 m
.44631 .83006 L
s
.45566 .81798 m
.44798 .81577 L
s
.44798 .81577 m
.44394 .82185 L
s
.45799 .8262 m
.44798 .81577 L
s
.46318 .8576 m
.44798 .81577 L
s
0 .934 1 r
.34497 .608 m
.33518 .61074 L
s
0 .578 1 r
.26805 .8244 m
.25683 .82611 L
s
0 .366 1 r
.52242 .60094 m
.52355 .6133 L
s
.53258 .59885 m
.52242 .60094 L
s
.52242 .60094 m
.52193 .60316 L
s
.53417 .60898 m
.52242 .60094 L
s
.55101 .62696 m
.52242 .60094 L
s
0 .674 1 r
.42836 .60698 m
.42969 .61582 L
s
0 .324 1 r
.44631 .83006 m
.45799 .8262 L
s
.45799 .8262 m
.45566 .81798 L
s
0 .088 1 r
.54082 .81441 m
.5405 .82916 L
s
.55 .81475 m
.54082 .81441 L
s
.54082 .81441 m
.53791 .81964 L
s
.55255 .82429 m
.54082 .81441 L
s
.56326 .85277 m
.54082 .81441 L
s
0 .324 1 r
.44394 .82185 m
.44631 .83006 L
s
0 .366 1 r
.52355 .6133 m
.53417 .60898 L
s
.53417 .60898 m
.53258 .59885 L
s
0 .674 1 r
.43857 .60344 m
.42836 .60698 L
s
0 .491 1 r
.36168 .8212 m
.35025 .82401 L
s
0 .023 1 r
.61531 .59792 m
.6179 .61076 L
s
.62701 .59424 m
.61531 .59792 L
s
.61531 .59792 m
.61593 .5993 L
s
.62895 .60569 m
.61531 .59792 L
s
.65157 .62121 m
.61531 .59792 L
s
.207 0 1 r
.63399 .81304 m
.63515 .82826 L
s
.64469 .81151 m
.63399 .81304 L
s
.63399 .81304 m
.6322 .81738 L
s
.6476 .8224 m
.63399 .81304 L
s
.66413 .8479 m
.63399 .81304 L
s
0 .088 1 r
.5405 .82916 m
.55255 .82429 L
s
.55255 .82429 m
.55 .81475 L
s
0 .366 1 r
.52193 .60316 m
.52355 .6133 L
s
0 .023 1 r
.6179 .61076 m
.62895 .60569 L
s
.62895 .60569 m
.62701 .59424 L
s
0 .088 1 r
.53791 .81964 m
.5405 .82916 L
s
0 .366 1 r
.53258 .59885 m
.52193 .60316 L
s
0 .324 1 r
.45566 .81798 m
.44394 .82185 L
s
.349 0 1 r
.70858 .59488 m
.71274 .60822 L
s
.72186 .58961 m
.70858 .59488 L
s
.70858 .59488 m
.71038 .5954 L
s
.72419 .60242 m
.70858 .59488 L
s
.75292 .61541 m
.70858 .59488 L
s
.548 0 1 r
.72747 .81167 m
.73025 .82736 L
s
.73975 .80826 m
.72747 .81167 L
s
.72747 .81167 m
.72684 .81509 L
s
.74312 .82053 m
.72747 .81167 L
s
.7658 .84298 m
.72747 .81167 L
s
.207 0 1 r
.63515 .82826 m
.6476 .8224 L
s
.6476 .8224 m
.64469 .81151 L
s
0 .921 1 r
.05689 .7106 m
.06198 .70699 L
s
.04772 .70778 m
.05689 .7106 L
s
.05573 .69819 m
.05689 .7106 L
s
0 .023 1 r
.61593 .5993 m
.6179 .61076 L
s
0 .088 1 r
.55 .81475 m
.53791 .81964 L
s
.349 0 1 r
.71274 .60822 m
.72419 .60242 L
s
.72419 .60242 m
.72186 .58961 L
s
0 .921 1 r
.05279 .70415 m
.05573 .69819 L
s
.05573 .69819 m
.04772 .70778 L
s
.06198 .70699 m
.05573 .69819 L
s
.0513 .74446 m
.05573 .69819 L
s
.207 0 1 r
.6322 .81738 m
.63515 .82826 L
s
0 .023 1 r
.62701 .59424 m
.61593 .5993 L
s
.741 0 1 r
.80223 .59183 m
.80809 .60566 L
s
.81713 .58496 m
.80223 .59183 L
s
.80223 .59183 m
.80529 .59145 L
s
.8199 .59915 m
.80223 .59183 L
s
.85509 .60956 m
.80223 .59183 L
s
.926 0 1 r
.82128 .81029 m
.82581 .82645 L
s
.83518 .80499 m
.82128 .81029 L
s
.82128 .81029 m
.82186 .81276 L
s
.83909 .81868 m
.82128 .81029 L
s
.86829 .83803 m
.82128 .81029 L
s
.548 0 1 r
.73025 .82736 m
.74312 .82053 L
s
.74312 .82053 m
.73975 .80826 L
s
0 .921 1 r
.05279 .70415 m
.04772 .70778 L
s
.207 0 1 r
.64469 .81151 m
.6322 .81738 L
s
0 .878 1 r
.14838 .69567 m
.14441 .70784 L
s
.15287 .70074 m
.14838 .69567 L
s
.14838 .69567 m
.1424 .7021 L
s
.15485 .70648 m
.14838 .69567 L
s
.14967 .73919 m
.14838 .69567 L
s
1 0 .667 r
.91541 .80891 m
.92183 .82554 L
s
.93097 .80171 m
.91541 .80891 L
s
.91541 .80891 m
.91727 .8104 L
s
.93548 .81684 m
.91541 .80891 L
s
.9716 .83304 m
.91541 .80891 L
s
0 .921 1 r
.06198 .70699 m
.05279 .70415 L
s
.741 0 1 r
.80809 .60566 m
.8199 .59915 L
s
.8199 .59915 m
.81713 .58496 L
s
.349 0 1 r
.71038 .5954 m
.71274 .60822 L
s
1 0 .85 r
.89627 .58876 m
.90394 .60309 L
s
.91283 .5803 m
.89627 .58876 L
s
.89627 .58876 m
.90068 .58748 L
s
.91605 .59587 m
.89627 .58876 L
s
.95807 .60367 m
.89627 .58876 L
s
.349 0 1 r
.72186 .58961 m
.71038 .5954 L
s
0 .878 1 r
.14441 .70784 m
.15485 .70648 L
s
.15485 .70648 m
.15287 .70074 L
s
.1424 .7021 m
.14441 .70784 L
s
.548 0 1 r
.72684 .81509 m
.73025 .82736 L
s
.926 0 1 r
.82581 .82645 m
.83909 .81868 L
s
.83909 .81868 m
.83518 .80499 L
s
0 .753 1 r
.24138 .69313 m
.2384 .70585 L
s
.24731 .69652 m
.24138 .69313 L
s
.24138 .69313 m
.23651 .6989 L
s
.24917 .70347 m
.24138 .69313 L
s
.24881 .73387 m
.24138 .69313 L
s
.548 0 1 r
.73975 .80826 m
.72684 .81509 L
s
1 0 .85 r
.90394 .60309 m
.91605 .59587 L
s
.91605 .59587 m
.91283 .5803 L
s
0 .753 1 r
.2384 .70585 m
.24917 .70347 L
s
.24917 .70347 m
.24731 .69652 L
s
.741 0 1 r
.81713 .58496 m
.80529 .59145 L
s
0 .753 1 r
.23651 .6989 m
.2384 .70585 L
s
.741 0 1 r
.80529 .59145 m
.80809 .60566 L
s
1 0 .667 r
.92183 .82554 m
.93548 .81684 L
s
.93548 .81684 m
.93097 .80171 L
s
.926 0 1 r
.82186 .81276 m
.82581 .82645 L
s
0 .555 1 r
.33472 .69058 m
.33286 .70385 L
s
.34213 .69228 m
.33472 .69058 L
s
.33472 .69058 m
.33091 .69563 L
s
.34404 .70051 m
.33472 .69058 L
s
.34874 .72851 m
.33472 .69058 L
s
0 .878 1 r
.15287 .70074 m
.1424 .7021 L
s
.926 0 1 r
.83518 .80499 m
.82186 .81276 L
s
0 .555 1 r
.33286 .70385 m
.34404 .70051 L
s
.34404 .70051 m
.34213 .69228 L
s
1 0 .85 r
.91283 .5803 m
.90068 .58748 L
s
0 .295 1 r
.4284 .68803 m
.42777 .70185 L
s
.43734 .68803 m
.4284 .68803 L
s
.4284 .68803 m
.42564 .69231 L
s
.43944 .69757 m
.4284 .68803 L
s
.44947 .72311 m
.4284 .68803 L
s
0 .555 1 r
.33091 .69563 m
.33286 .70385 L
s
1 0 .667 r
.91727 .8104 m
.92183 .82554 L
s
.93097 .80171 m
.91727 .8104 L
s
1 0 .85 r
.90068 .58748 m
.90394 .60309 L
s
0 .753 1 r
.24731 .69652 m
.23651 .6989 L
s
0 .295 1 r
.42777 .70185 m
.43944 .69757 L
s
.43944 .69757 m
.43734 .68803 L
s
.014 0 1 r
.52242 .68546 m
.52316 .69983 L
s
.53294 .68376 m
.52242 .68546 L
s
.52242 .68546 m
.52074 .68893 L
s
.53533 .69466 m
.52242 .68546 L
s
.551 .71766 m
.52242 .68546 L
s
0 .555 1 r
.34213 .69228 m
.33091 .69563 L
s
0 .295 1 r
.42564 .69231 m
.42777 .70185 L
s
.014 0 1 r
.52316 .69983 m
.53533 .69466 L
s
.53533 .69466 m
.53294 .68376 L
s
.362 0 1 r
.61679 .68288 m
.61903 .6978 L
s
.62893 .67947 m
.61679 .68288 L
s
.61679 .68288 m
.61623 .68551 L
s
.63169 .69176 m
.61679 .68288 L
s
.65335 .71217 m
.61679 .68288 L
s
0 .295 1 r
.43734 .68803 m
.42564 .69231 L
s
.014 0 1 r
.52074 .68893 m
.52316 .69983 L
s
.741 0 1 r
.71151 .6803 m
.71537 .69576 L
s
.72532 .67516 m
.71151 .6803 L
s
.71151 .6803 m
.71214 .68204 L
s
.72851 .68887 m
.71151 .6803 L
s
.75653 .70663 m
.71151 .6803 L
s
.362 0 1 r
.61903 .6978 m
.63169 .69176 L
s
.63169 .69176 m
.62893 .67947 L
s
.014 0 1 r
.53294 .68376 m
.52074 .68893 L
s
1 0 .857 r
.80658 .67771 m
.81219 .69372 L
s
.82211 .67084 m
.80658 .67771 L
s
.80658 .67771 m
.80848 .67855 L
s
.82577 .68599 m
.80658 .67771 L
s
.86055 .70106 m
.80658 .67771 L
s
.362 0 1 r
.61623 .68551 m
.61903 .6978 L
s
.741 0 1 r
.71537 .69576 m
.72851 .68887 L
s
.72851 .68887 m
.72532 .67516 L
s
0 .536 1 r
.04894 .79732 m
.05473 .79346 L
s
.03842 .7943 m
.04894 .79732 L
s
.0476 .7832 m
.04894 .79732 L
s
.362 0 1 r
.62893 .67947 m
.61623 .68551 L
s
0 .536 1 r
.0442 .79041 m
.0476 .7832 L
s
.0476 .7832 m
.03842 .7943 L
s
.05473 .79346 m
.0476 .7832 L
s
.04245 .83704 m
.0476 .7832 L
s
1 0 .436 r
.902 .6751 m
.9095 .69166 L
s
.91929 .6665 m
.902 .6751 L
s
.902 .6751 m
.90528 .67502 L
s
.92346 .68311 m
.902 .6751 L
s
.96541 .69543 m
.902 .6751 L
s
1 0 .857 r
.81219 .69372 m
.82577 .68599 L
s
.82577 .68599 m
.82211 .67084 L
s
.741 0 1 r
.71214 .68204 m
.71537 .69576 L
s
.72532 .67516 m
.71214 .68204 L
s
0 .493 1 r
.14194 .78109 m
.13767 .79512 L
s
.14647 .78721 m
.14194 .78109 L
s
.14194 .78109 m
.13466 .78899 L
s
.14943 .79335 m
.14194 .78109 L
s
.14253 .83204 m
.14194 .78109 L
s
0 .536 1 r
.0442 .79041 m
.03842 .7943 L
s
0 .493 1 r
.13767 .79512 m
.14943 .79335 L
s
.13466 .78899 m
.13767 .79512 L
s
0 .536 1 r
.05473 .79346 m
.0442 .79041 L
s
0 .493 1 r
.14943 .79335 m
.14647 .78721 L
s
1 0 .436 r
.9095 .69166 m
.92346 .68311 L
s
.92346 .68311 m
.91929 .6665 L
s
0 .369 1 r
.2366 .77897 m
.23329 .79363 L
s
.24261 .78328 m
.2366 .77897 L
s
.2366 .77897 m
.23043 .78619 L
s
.24543 .79072 m
.2366 .77897 L
s
.24341 .827 m
.2366 .77897 L
s
1 0 .857 r
.80848 .67855 m
.81219 .69372 L
s
.82211 .67084 m
.80848 .67855 L
s
0 .369 1 r
.23329 .79363 m
.24543 .79072 L
s
.24543 .79072 m
.24261 .78328 L
s
.23043 .78619 m
.23329 .79363 L
s
0 .17 1 r
.33156 .77684 m
.32936 .79212 L
s
.33912 .77933 m
.33156 .77684 L
s
.33156 .77684 m
.32647 .78333 L
s
.34197 .78813 m
.33156 .77684 L
s
.34511 .82192 m
.33156 .77684 L
s
1 0 .436 r
.91929 .6665 m
.90528 .67502 L
s
0 .493 1 r
.14647 .78721 m
.13466 .78899 L
s
1 0 .436 r
.90528 .67502 m
.9095 .69166 L
s
0 .17 1 r
.32936 .79212 m
.34197 .78813 L
s
.34197 .78813 m
.33912 .77933 L
s
.092 0 1 r
.42683 .77471 m
.42587 .79061 L
s
.436 .77536 m
.42683 .77471 L
s
.42683 .77471 m
.42281 .78042 L
s
.43901 .78557 m
.42683 .77471 L
s
.44764 .8168 m
.42683 .77471 L
s
0 .17 1 r
.32647 .78333 m
.32936 .79212 L
s
0 .369 1 r
.24261 .78328 m
.23043 .78619 L
s
.405 0 1 r
.52242 .77257 m
.52284 .78909 L
s
.53324 .77139 m
.52242 .77257 L
s
.52242 .77257 m
.51948 .77746 L
s
.53655 .78303 m
.52242 .77257 L
s
.551 .81164 m
.52242 .77257 L
s
.092 0 1 r
.42587 .79061 m
.43901 .78557 L
s
.43901 .78557 m
.436 .77536 L
s
.42281 .78042 m
.42587 .79061 L
s
.761 0 1 r
.61831 .77043 m
.62026 .78757 L
s
.63084 .76739 m
.61831 .77043 L
s
.61831 .77043 m
.61651 .77446 L
s
.63454 .78051 m
.61831 .77043 L
s
.65521 .80643 m
.61831 .77043 L
s
0 .17 1 r
.33912 .77933 m
.32647 .78333 L
s
.405 0 1 r
.52284 .78909 m
.53655 .78303 L
s
.53655 .78303 m
.53324 .77139 L
s
1 0 .85 r
.71453 .76828 m
.71814 .78604 L
s
.72882 .76338 m
.71453 .76828 L
s
.71453 .76828 m
.71393 .77142 L
s
.73298 .77799 m
.71453 .76828 L
s
.76027 .80118 m
.71453 .76828 L
s
.405 0 1 r
.51948 .77746 m
.52284 .78909 L
s
.092 0 1 r
.436 .77536 m
.42281 .78042 L
s
.761 0 1 r
.62026 .78757 m
.63454 .78051 L
s
.63454 .78051 m
.63084 .76739 L
s
1 0 .436 r
.81105 .76612 m
.81649 .7845 L
s
.82716 .75936 m
.81105 .76612 L
s
.81105 .76612 m
.81175 .76836 L
s
.83185 .77549 m
.81105 .76612 L
s
.8662 .79589 m
.81105 .76612 L
s
.405 0 1 r
.53324 .77139 m
.51948 .77746 L
s
.761 0 1 r
.61651 .77446 m
.62026 .78757 L
s
1 0 .85 r
.71814 .78604 m
.73298 .77799 L
s
.73298 .77799 m
.72882 .76338 L
s
1 0 0 r
.9079 .76395 m
.91529 .78295 L
s
.92588 .75532 m
.9079 .76395 L
s
.9079 .76395 m
.90999 .76526 L
s
.93113 .77298 m
.9079 .76395 L
s
.97301 .79056 m
.9079 .76395 L
s
.761 0 1 r
.63084 .76739 m
.61651 .77446 L
s
1 0 .436 r
.81649 .7845 m
.83185 .77549 L
s
.83185 .77549 m
.82716 .75936 L
s
1 0 .85 r
.71393 .77142 m
.71814 .78604 L
s
.72882 .76338 m
.71393 .77142 L
s
1 0 0 r
.91529 .78295 m
.93113 .77298 L
s
.93113 .77298 m
.92588 .75532 L
s
1 0 .436 r
.81175 .76836 m
.81649 .7845 L
s
.82716 .75936 m
.81175 .76836 L
s
1 0 0 r
.90999 .76526 m
.91529 .78295 L
s
.92588 .75532 m
.90999 .76526 L
s
0 g
.25 Mabswid
.08053 .06867 m
0 .84747 L
s
0 .84747 m
1 .79786 L
s
1 .79786 m
.93221 0 L
s
.93221 0 m
.08053 .06867 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[8]:=",
  ImageSize->{251.563, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003k000182000`400?l00000o`00003on`3oool0
0><0oooo1`00000A0?ooo`00e`3oool<000000H0oooo00<000000?ooo`3oool03`3oool00<X0oooo
3@00000B0?ooo`030000003oool0oooo00l0oooo002n0?ooo``000007`3oool00`000000oooo0?oo
o`0?0?ooo`00/@3oool=000002/0oooo00<000000?ooo`3oool03`3oool00:D0oooo3000000h0?oo
o`030000003oool0oooo00l0oooo002H0?ooo`d00000A03oool200000100oooo002<0?ooo``00000
D@3oool200000100oooo001o0?ooo`d00000G@3oool200000100oooo001b0?ooo`d00000JP3oool2
00000100oooo001V0?ooo``00000I`3oool20029o`<0oooo1`00ROl40?ooo`800000403oool005T0
oooo3@00001N0?ooo`03003[o`3oool0oooo0100oooo1`00ROl;0?ooo`800000403oool004d0oooo
3000001Z0?ooo`800>_o0`3oool6003[o`X0oooo0`00ROl>0?ooo`800000403oool00400oooo3@00
001Q0?ooo`03003o/@3oool0oooo0140oooo1P00jolB0?ooo`030029o`3oool0oooo00`0oooo0P00
000@0?ooo`00=03oool<000006d0oooo0P00ok430?ooo`H00?na2`3oool2003[ob@0oooo0P00000@
0?ooo`009`3oool=000006D0oooo00<00?m?0?ooo`3oool0403oool6003o/CL0oooo0P00000@0?oo
o`006`3oool<00000700oooo2P00odl=0?ooo`800?na>@3oool200000100oooo000D0?ooo`L00000
J@3oool00`0Co`00oooo0?ooo`0401?o00d0oooo0P00odm?0?ooo`800000403oool001@0oooo00<0
00000?ooo`3oool0J`3oool501?o0680oooo00<000000?ooo`0000003`3oool001@0oooo0P00001I
0?ooo`0307Go003oool0MOl00080MOl03`3oool201?o06@0oooo00<000000?ooo`0000003`3oool0
01@0oooo0P00001H0?ooo`<0MOl0N03oool00`000000oooo0000000?0?ooo`00503oool00`000000
oooo000000120?ooo`D0f?l0R`3oool00`000000oooo0000000?0?ooo`004`3oool010000000oooo
0?ooo`00000^0?ooo`030?o5003oool0oooo0180oooo00<0f?l00?ooo`3oool0S03oool00`000000
oooo0000000?0?ooo`004`3oool01@000000oooo0?ooo`3oool0000002`0oooo103oa@2Q0?ooo`03
0000003oool0000000l0oooo000C0?ooo`050000003oool0oooo0?ooo`000000603oool20?mR0:P0
oooo00<007ko0?ooo`3oool0303oool00`000000oooo0000000?0?ooo`004`3oool01@000000oooo
0?ooo`3oool0000001P0oooo00<0of800?ooo`3oool0YP3oool2001no`@0oooo1P00O_l40?ooo`03
0000003oool0000000l0oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3o002X0?ooo`04003Po`3oool0oooo0?ooo`H00>3o2@3oool7001no`X0oooo00<000000?ooo`00
00003`3oool001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?l00:H0oooo
1P00h?l@0?ooo`<007ko3@3oool00`000000oooo0000000?0?ooo`004`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo09@0oooo00@00?nl0?ooo`3oool0oooo1@00ok`;0?ooo`800>3o
4`3oool3001no`@0oooo1`00O_l20?ooo`030000003oool0000000l0oooo000C0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0O`3oool00`00oeX0oooo0?ooo`0@0?ooo`H00?nl4@3o
ool00`00h?l0oooo0?ooo`0@0?ooo`P007ko2@3oool00`000000oooo0000000?0?ooo`004`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo07d0oooo2P00oeX<0?ooo`800?nl4`3oool2
003Po`<0oooo1P00h?l:0?ooo`<007ko3@3oool010000000oooo0?ooo`00000>0?ooo`004`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo06T0oooo0P06o`000`3oool01_l000Ko0002
00Ko00d0oooo0P00oeXC0?ooo`03003o_03oool0oooo0140oooo1P00h?lB0?ooo`03001no`3oool0
oooo00/0oooo00@000000?ooo`3oool000003P3oool00180oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1X0?ooo`@01_l0903oool;003o_0`0oooo0P00h?lS0?ooo`040000003oool0
oooo000000h0oooo000B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0D`3oool7
06Oo00h0oooo0P06o`0A0?ooo`800?mJ4`3oool2003o_3T0oooo00@000000?ooo`3oool000003P3o
ool00180oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0o0?ooo`80a_l04`3oool0
0`1Wo`00oooo0?ooo`0?0?ooo`0300Ko003oool0oooo0140oooo2@00oeY80?ooo`040000003oool0
oooo000000h0oooo000B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0?P3oool5
0<Ko0200oooo2@06o`0>0?ooo`800?mJCP3oool010000000oooo0?ooo`00000>0?ooo`004P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo02X0oooo103og@0Q0?ooo`80Iol04`3oool2
00Ko06@0oooo00@000000?ooo`3oool000003P3oool00180oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0F0?ooo`030?n;003oool0oooo03D0oooo1`1Wo`1e0?ooo`040000003oool0
oooo000000h0oooo000B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05@3oool2
0?n;0240oooo0P36o`0D0?ooo`0306Oo003oool0oooo06T0oooo0P00G_l60?ooo`@005ko0`3oool0
10000000oooo0?ooo`00000>0?ooo`004P3oool00`000000oooo0?ooo`080?ooo`050000003oool0
oooo0?ooo`3oHP00=`3oool40<Ko07`0oooo2@00G_l70?ooo`040000003oool0oooo000000h0oooo
000B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool0of808@3oool20?oM0840oooo
00@00<3o0?ooo`3oool0oooo1P00`?l80?ooo`@005ko3@3oool010000000oooo0?ooo`00000>0?oo
o`004P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<0oh/00?ooo`3o
ool04`3oool20?oM06X0oooo0P00omdA0?ooo`H00<3o3`3oool3001No`d0oooo00@000000?ooo`3o
ool000003P3oool00140oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`80
oh/0O`3oool:003og@/0oooo0P00`?lD0?ooo`03002Do`3oool0oooo00/0oooo00D000000?ooo`3o
ool0oooo0000000=0?ooo`004@3oool00`000000oooo0?ooo`060?ooo`030?mR003oool0oooo0080
oooo00<000000?ooo`3oool0N`3oool2003oO080oooo1000og`<0?ooo`800?oM4`3oool00`00m_l0
oooo0?ooo`0A0?ooo`8009Co103oool7002Do`80oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`004@3oool00`000000oooo0?ooo`060?ooo`030?mR003oool0oooo0080oooo00<000000?ooo`3o
ool0I`3oool00`00oad0oooo0?ooo`0@0?ooo`D00?ml903oool2003fo`<0oooo1P00m_l90?ooo`L0
09Co2@3oool01@000000oooo0?ooo`3oool0000000d0oooo000A0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0DP3oool00`0no`00oooo0?ooo`0@0?ooo`P00?lM3@3oool00`00og`0
oooo0?ooo`0A0?ooo`03003oY`3oool0oooo0100oooo1P00m_lA0?ooo`8009Co303oool01@000000
oooo0?ooo`3oool0000000d0oooo000A0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0D@3oool703ko00h0oooo00<00?lM0?ooo`3oool08`3oool;003oY`/0oooo0P00m_lE0?ooo`80
05ko2`3oool01@000000oooo0?ooo`3oool0000000d0oooo000A0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0?03oool309Ko0180oooo00<0?_l00?ooo`3oool0903oool00`00odH0
oooo0?ooo`0A0?ooo`800?nW503oool00`00`?l0oooo0?ooo`0A0?ooo`@005ko0`3oool7001No`03
0?ooo`000000oooo0080oooo00<000000?ooo`3oool02`3oool00140oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0Y0?ooo`80iOl04P3oool00`2Fo`00oooo09Ko000209Ko0240oooo
00<06_l00?ooo`3oool0403oool9003oAR80oooo0P00`?lB0?ooo`P005ko203oool01@000000oooo
0?ooo`3oool0000000d0oooo000A0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
:@3oool20>Go03H0oooo200Jo`0>0?ooo`800?m64P3oool2003ogA<0oooo3@00`?l:0?ooo`<005ko
2`3oool01@000000oooo0?ooo`3oool0000000d0oooo000A0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0503oool20?oM01@0oooo0P3Uo`0P0?ooo`<0NOl04P3oool201[o02H0oooo
1@00omdB0?ooo`800<3o8P3oool01@000000oooo0?ooo`3oool0000000d0oooo000A0?ooo`030000
003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0?o5000C0?ooo`80omd0803oool20=Co01@0
oooo00<0NOl00?ooo`1io`000P1io`0R0?ooo`800?ml4`3oool3003og@80oooo1P00omdQ0?ooo`03
000[o`3oool0oooo00H0oooo0`00:ol30?ooo`050000003oool0oooo0?ooo`0000003@3oool00100
oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`3oa@0f0?ooo`@0e?l08`3oool00`00
oad0oooo0?ooo`0A0?ooo`X00?ml3@3oool00`00omd0oooo0?ooo`0W0?ooo`X002_o1P3oool01@00
0000oooo0?ooo`3oool0000000d0oooo000@0?ooo`030000003oool0oooo0100oooo00D000000?oo
o`3oool0oooo0?o5000P0?ooo`80omL0>03oool4003o7A<0oooo0P00og`[0?ooo`8008ko0`3oool6
002>o`P0oooo1000:ol<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool0
0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`030?nG003oool0oooo
01<0oooo0P3oe`0Q0?ooo`80?_l0503oool2003o7@030?ooo`00oad00?lM00<00?lM:03oool01000
kol0oooo0?ooo`3oool5003_o`T0oooo1P00S_l?0?ooo`<002_o303oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00X0oooo000@0?ooo`030000003oool0oooo00d0oooo00D0oh/00?oo
o`3oool0oooo0000000?0?ooo`030?nG003oool0oooo03H0oooo1@0no`0]0?ooo`800?na403oool6
003_o`l0oooo0P00S_lD0?ooo`03002Co`3oool0oooo00X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0:0?ooo`00403oool00`000000oooo0?ooo`0<0?ooo`80oh/00`3oool00`00
0000oooo0?ooo`0>0?ooo`030?nG003oool0oooo0200oooo0P2Fo`0D0?ooo`0403ko003oool0oooo
0?ooo`80?_l05`3oool00`00oeD0oooo0?ooo`0?0?ooo`X00?na2`3oool2003_obL0oooo0P00Tol4
0?ooo`H009?o0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo000@0?oo
o`030000003oool0oooo00d0oooo00<0oh/00?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?oo
o`80iOl0503oool509Ko02d0oooo2000oeD<0?ooo`<00?na9P3oool00`00m_l0oooo0?ooo`0@0?oo
o`L009?o203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo000@0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool06`3oool20>Go0380oooo0`02o`0A0?ooo`80
0?mE9@3oool00`00ojP0oooo0?ooo`0@0?ooo``00?Ko2P3oool2002Co``0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`00403oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00@0oooo0P3og@0F0?ooo`030>Go003oool0oooo01`0oooo0P1Bo`0A0?ooo`800_l0
00<0oooo00;o0002o`000P02o`0c0?ooo`X00?nX2`3oool2003fob40oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`00403oool00`000000oooo0?ooo`050?ooo`80olD0303o
ool00`000000oooo0?ooo`050?ooo`030?oM003oool0oooo01l0oooo0`2Fo`0A0?ooo`D0D_l0=@3o
ool00`00odT0oooo0?ooo`0A0?ooo`800?nX:@3oool00`00Tol0oooo0?ooo`090?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02P3oool000l0oooo00<000000?ooo`3oool01P3oool0
0`3oa@00oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<0omd00?ooo`3oool0303oool0
0`36o`00oooo0?ooo`0@0?ooo`80U_l0=P3oool201?o0140oooo2@00odTR0?ooo`03003fo`3oool0
oooo0140oooo0`00Tol30?ooo`L009?o00<0oooo0000003oool00`3oool00`000000oooo0?ooo`0:
0?ooo`003`3oool00`000000oooo0?ooo`060?ooo`030?o5003oool0oooo00`0oooo00D000000?oo
o`3oool0oooo0=So000A0?ooo`<0a_l04`3oool209Ko0200oooo00<0KOl00?ooo`3oool0403oool8
01?o00d0oooo0P00odTW0?ooo`800?Ko4P3oool7002Co`P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0:0?ooo`003`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0080f?l0503oool00`36o`00oooo0?ooo`0a0?ooo`<0KOl04P3oool00`0Co`00oooo0?ooo`0U0?oo
o`800?nX4P3oool<003fo`/0oooo0P00Tol;0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02P3oool000l0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0f?l0
03<0oooo0P2oo`0C0?ooo`0306go003oool0KOl00080KOl08P3oool00`00odT0oooo0?ooo`0A0?oo
o`X00?nX303oool2003foa<0oooo0P0G0?l60?ooo`<05`3o0`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo000?0?ooo`030000003oool0oooo01H0oooo00D000000?ooo`3o
ool0oooo0=So000O0?ooo`80ood04`3oool40;oo03D0oooo1@00odTB0?ooo`800?nX503oool3001;
o`@0oooo0`00Bol90?ooo`<05`3o0P00:ol401L0o`H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`003`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00`0
oooo0P3oe`0B0?ooo`<0ood0=P3oool401?o0180oooo0P00odT20?ooo`D00?m9403oool2002/oa00
oooo00<004_o002>o`00Bol01@00Bol;0?ooo`805`3o1`00:ol70?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02@3oool000l0oooo00<000000?ooo`3oool04`3oool01@3og@00oooo
0?ooo`3oool0000000h0oooo0P3oe`0E0?ooo`030?om003oool0oooo0200oooo00<0KOl00?ooo`3o
ool04@3oool201?o00030?ooo`0Co`004ol000804ol0503oool00`00ooD0oooo0?ooo`0>0?ooo`/0
0:co203oool3002>o`03001;o`3oool0oooo0100oooo00@05`3o000[o`00:ol002_o0`3oool8000[
o`D0oooo00<000000?ooo`3oool02@3oool000l0oooo00<000000?ooo`3oool04P3oool20?oM00<0
oooo00<000000?ooo`3oool03P3oool00`3oe`00oooo0?ooo`0d0?ooo`<0KOl06@3oool00`00oi/0
oooo0?ooo`0?0?ooo`X00?oe1`3oool2003_o`040?ooo`00[?l00:co002/o`h0oooo3P00S_l:0?oo
o`03001mo`00:ol002_o00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?oo
o`003`3oool00`000000oooo0?ooo`0C0?ooo`030?oM003oool0oooo0080oooo00<000000?ooo`3o
ool0;`3oool20;oo01H0oooo0`1]o`030?ooo`03003oB03oool0oooo00l0oooo2000oi/60?ooo`80
0?na103oool2003om@`0oooo1P00kol00`3oool00:co0?ooo`0>0?ooo`@008ko4P3oool3001mo`<0
oooo1P00OOl20?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool000l0oooo
00<000000?ooo`3oool04`3oool00`3og@00oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo
0P3oo@0C0?ooo`<0_ol02@3oool00`02o`00oooo0?ooo`0>0?ooo`<00?m84@3oool2003oV`T0oooo
1000ok450?ooo`03003om@3oool0oooo00/0oooo0`00kol20?ooo`H00>oo3P3oool2003Oo`80oooo
1P00gol80?ooo`L007go203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
000>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool00`3oe`00oooo0?oo
o`0A0?ooo`<0ood02`3oool00`0no`00oooo0?ooo`070?ooo`80_ol01P3oool200;o0140oooo1P00
odP20?ooo`<00?mE4`3oool7003o/A40oooo00D00>oo0?ooo`3oool0oooo003o`00A0?ooo`H00=oo
3`3oool3001mo`/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`003P3o
ool00`000000oooo0?ooo`0=0?ooo`030?oM003oool0oooo00X0oooo00<000000?ooo`3oool01@3o
ool00`3oe`00oooo0?ooo`0<0?ooo`0306Oo003oool0oooo00D0oooo00<0ood00?ooo`3oool01`3o
ool203ko0140oooo1@02o`020?ooo`0300;o003oool0oooo0140oooo1P00oeDA0?ooo`800?na103o
ool3003o/A00oooo2P00ol0;0?ooo`<00=oo7`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00T0oooo000>0?ooo`030000003oool0oooo00d0oooo0P3og@0<0?ooo`030000003oool0
oooo0080MOl00`3oool00`3oe`00oooo0?ooo`0:0?ooo`<0Iol04@3oool203ko01H0oooo0P02o`0D
0?ooo`03003oE@3oool0oooo0080oooo0`00oeD00`3oool00?l;0?ooo`0@0?ooo`T00?mS303oool2
003o`2P0oooo00<00;Co0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00T0oooo000>0?ooo`030000003oool0oooo00d0oooo00<0omd00?ooo`3oool02`3oool00`00
0000oooo0?ooo`0207Go00<0oooo00<0omL00?ooo`3oool02`3oool206Oo01<0oooo0P1Bo`0D0?oo
o`@00_l01`3oool00`16o`00oooo0?ooo`0@0?ooo`<00?l;4@3oool2003oHc/0oooo0P00]?l40?oo
o`H00;Co00<0oooo0000003oool0103oool00`000000oooo0?ooo`090?ooo`003P3oool00`000000
oooo0?ooo`0=0?ooo`030?oM003oool0oooo00/0oooo00<000000?ooo`3oool00P1eo`0@0?ooo`<0
U_l000<0Iol00?ooo`3oool0403oool305;o00X0oooo00<0S?l00?ooo`3oool02P3oool200;o00@0
oooo0`16o`0B0?ooo`03003o2`3oool00?l;00<00?l;=P3oool00`00onT0oooo0?ooo`0@0?ooo`L0
0;Co0P3oool206L0o`<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`00
3P3oool00`000000oooo0?ooo`0K0?ooo`050<Ko00000000oooo0?ooo`1eo`00403oool209Ko01L0
oooo0P1Bo`080?ooo`80S?l04P3oool00`16o`00oooo04Ko000204Ko03H0oooo00<00?n80?ooo`3o
ool0403oool<003oj@T0oooo0P1W0?l2002do`030?ooo`1W0?l0I`3o0080I`3o1@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo000>0?ooo`030000003oool0oooo01/0oooo
0P36o`0?0?ooo`030=Co003oool0oooo00<0oooo00<0U_l00?ooo`3oool02P3oool20;oo0180oooo
00<0S?l00?ooo`2<o`000P2<o`0e0?ooo`800?l[4@3oool;003oR0/0oooo0P00onT200<0o`80oooo
1@030?l80?ooo`H0I`3o2@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo
000>0?ooo`030000003oool0oooo00D0oooo0P3Ho`0B0?ooo`050<Ko003oool0a_l00?ooo`000000
3P3oool20=Co00D0oooo00<0U_l00?ooo`3oool02P3oool20;oo03L0oooo00<0;_l00?ooo`3oool0
403oool4003o:`030?ooo`00^ol0oooo00h0oooo0P00ohP4001Mo`030?ooo`00GOl005go00<005go
2@3oool600<0o`d0oooo0P1W0?l0103oool0I`3o0?ooo`00OOl90?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0203oool000h0oooo00<000000?ooo`3oool01P3oool00`3Ho`00oooo
0?ooo`0?0?ooo`<0a_l000<0oooo0<Ko000000003`3oool00`3Do`00oooo0?ooo`0B0?ooo`030;oo
003oool0oooo0380oooo100^o`040?ooo`03003ok03oool0oooo00/0oooo00<00?l[0?ooo`3oool0
1@00ob/4002ko`X0oooo1@00GOl?0?ooo`800`3o4P3oool0101W0?l007go001mo`00OOl90?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool000h0oooo00<000000?ooo`3oool0
1@3oool00`3Ho`00oooo0?ooo`0A0?ooo`050<Ko003oool0oooo0<Ko00000000403oool00`3Do`00
oooo0?ooo`0b0?ooo`80POl01`3oool00`00oi/0oooo0?ooo`090?ooo`80;_l000<0oooo02ko000^
o`000P0^o`000`3oool00?o/0?ooo`0>0?ooo`D00;_o3`3oool2001Moa40oooo0P00golB0?ooo`h0
07go1P3oool00`000000oooo0?ooo`080?ooo`003@3oool00`000000oooo0?ooo`060?ooo`030=So
003oool0oooo0140oooo00<0a_l00?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`80aol0
2@3oool00`00oeD0oooo0?ooo`070?ooo`<0POl0103oool3003oVa00oooo2000on`;0?ooo`800;_o
3P3oool2003o`180oooo1P00gol@0?ooo`04001Bo`00OOl007go001mo`@0oooo0`00D_l20?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool000d0oooo00<000000?ooo`3oool0
6P3oool00`36o`00oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<0m_l00?ooo`3oool0
2@3oool00`00oad0oooo0?ooo`050?ooo`<0aol01`3oool3003oE@/0oooo0P21o`020?ooo`L00?nK
3@3oool00`00on`0oooo0?ooo`0M0?ooo`D00?o04P3oool3003Oo`03002do`3oool00=oo00D00=oo
2@3oool3001Bo`03001mo`00D_l005;o00<005;o1@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00P0oooo000=0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01@3o
ool00`3oo@00oooo0?ooo`0;0?ooo`0300Ko003oool0oooo00<0oooo0P3fo`090?ooo`<00?lM2@3o
ool20<Oo00D0oooo0P00oeD0103oool00?mE003oE@00oeD=0?ooo`800?nK703oool3003oHa<0oooo
0`00ol000`3oool00?o0003o`004003o`0<00?o]2@3oool00`00]?l00=oo002do`03002do`h0oooo
1000D_l:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool000d0oooo00<0
00000?ooo`3oool04`3oool20>Go00/0oooo00D000000?ooo`3oool0oooo01?o00020?ooo`80ood0
303oool300Ko00D0oooo00<0m_l00?ooo`3oool0203oool3003o7B/0oooo0P00o`/C0?ooo`H00?mS
00<0oooo003oT`3oool03P3oool00`00ol00oooo003ok@04003ok@l0oooo0`00]?lB0?ooo`8005;o
00<0oooo01L0o`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo
000=0?ooo`030000003oool0oooo01@0oooo00<0iOl00?ooo`3oool02P3oool00`000000oooo01?o
000201?o00<0oooo00<0ood00?ooo`3oool02P3oool200Ko00H0oooo00<0m_l00?ooo`3oool02P3o
ool00`00oad0oooo0?ooo`0B0?ooo`<0A_l04`3oool5003o2`80oooo0`00ocl<0?ooo`05003oH`3o
ool0oooo0?ooo`00oi<00`00of<5003oT``0oooo0P00ondB0?ooo`03001;o`3oool0oooo0180oooo
0`0G0?l80?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool000d0oooo00<0
00000?ooo`3oool0503oool00`3Uo`00oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0Co`00
0`3oool00`3oo@00oooo0?ooo`0<0?ooo`0300Ko003oool0oooo0100oooo00<0S?l00?ooo`3oool0
4P3oool304Ko00L0oooo0`0:o`0:0?ooo`04003o2`3oool0oooo0?ooo`800?l;00<0oooo003o?`00
ocl01000ocl=0?ooo`800?nC903oool3001;oa80oooo1`0G0?l00`3oool0`P3o002oo`02002oo`03
0?ooo`000000oooo00D0oooo00<000000?ooo`3oool0203oool000d0oooo00<000000?ooo`3oool0
503oool00`3Uo`00oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0Co`00403oool00`2oo`00
oooo0?ooo`0B0?ooo`<0S?l02@3oool204Ko00P0oooo00@0A_l00?ooo`16o`00A_l01@3oool400[o
0140oooo00<00?lo0?ooo`3oool07P3oool3002/oa80oooo1`00Bol?0?ooo`030<80o`3oool05`3o
00<05`3o0P00_ol801L0o`D0oooo00<000000?ooo`3oool0203oool000d0oooo00<000000?ooo`3o
ool0503oool00`3Uo`00oooo0?ooo`0;0?ooo`030=Co003oool0oooo00`0oooo00<0NOl00?ooo`3o
ool00P3oool20;oo00`0oooo0P1]o`060?ooo`<0S?l0203oool304Ko00/0oooo0P16o`070?ooo`80
2_l06`3oool00`00ooD0oooo0?ooo`0A0?ooo`@00:co0P3oool00`00oh4000Go0?ooo`0>0?ooo`@0
04_o0P00oml7001;o`L0oooo0P320?l2002oo`805`3o2@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00P0oooo000=0?ooo`030000003oool0oooo01l0oooo00@0Iol00?ooo`3Do`00
e?l03P3oool207Wo00@0oooo00<0_ol00?ooo`3oool02`3oool206go00P0oooo00<0S?l00?ooo`3o
ool0203oool204Ko02d0oooo0`00ooD50?ooo`04003o9P3oool0oooo001So`X0oooo2@00[?l5003o
P@8000Go203oool2001;o`800?oO101L0?l;0?ooo`80`P3o00<0oooo002oo`00_ol02P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo000=0?ooo`030000003oool0oooo00`0
oooo0P36o`0@0?ooo`<0Iol00P3Do`000`000000oooo0?ooo`0<0?ooo`0307Wo003oool0oooo00<0
oooo00<0_ol00?ooo`3oool0303oool00`1]o`00oooo0?ooo`0X0?ooo`@00?nK1P3oool00`0]o`00
oooo0?ooo`030?ooo`03002ko`3oool0oooo00@0oooo1`00ooD3003o9P03001So`3oool006?o0080
oooo1000Hol40?ooo`800:co0P3oool2003oP@8000Go0`00[?l<0?ooo`<0G03o00<00?oO0?ooo`3o
ool03P3oool30<80o`/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`00
303oool00`000000oooo0?ooo`0>0?ooo`030<Ko003oool0oooo00l0oooo00D0Iol00?ooo`3oool0
e?l00000000>0?ooo`0307Wo003oool0oooo00@0oooo00<0_ol00?ooo`3oool0803oool3003oB0T0
oooo00<0MOl00?ooo`3oool0103oool00`00ooD0oooo0?ooo`04003oV`D0oooo0`0]o`030?ooo`@0
0;_o1@3oool00`00ooD0oooo0?ooo`030?ooo`<00?oe1@00obH>0?ooo`<000Go403oool205`0oa40
oooo0P320?l;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool000`0oooo
00<000000?ooo`3oool03@3oool00`36o`00oooo0?ooo`0@0?ooo`0606Oo003oool0oooo0=Co003o
ool000003P3oool00`1io`00oooo0?ooo`0B0?ooo`0500;o003oool0oooo0?ooo`00og`01`3oool0
0`2/o`00oooo0?ooo`050?ooo`<00?m800<00?na0?ooo`3oool01@3oool307Go00D0oooo0`00ooD0
0`3oool00?nK003oV`04003oV`<0oooo00<0;Ol00?ooo`0]o`000`0]o`000`00^ol0oooo0?ooo`04
002ko`/0oooo0P00HolA0?ooo`8000Go903oool00`005_l0oooo002oo`040?ooo`<001Ko0P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000003oool0oooo
00d0oooo00<0a_l00?ooo`3oool0403oool00`1Wo`00oooo0?ooo`020?ooo`030000003oool0oooo
0180oooo0P00oeX50?ooo`80aol0103oool300;o0080oooo0`00og`60?ooo`80[?l01`3oool3003o
B003003o/@3oool0oooo00D0oooo0`1eo`040?ooo`800?oe00@0oooo003om@00ooD00?oe103oool2
003oV`L0oooo00<00;_o0?ooo`3oool0=03oool2003og`D0oooo0`00Mol90?ooo`03000Fo`00_ol0
0;oo00/00;oo1`3oool00`000000oooo0?ooo`070?ooo`00303oool00`000000oooo0?ooo`0=0?oo
o`030<Ko003oool0oooo01D0oooo00D000000?ooo`3oool0oooo003oC`030?ooo`80_ol00P3oool3
03ko00H0oooo0`00oeX40?ooo`80aol0103oool300;o0080oooo0`00og`80?ooo`030:co003oool0
oooo00D0oooo00D00?na0?ooo`00odP00?m8003o/@080?ooo`80MOl0=`3oool2003oP@03003Eo`3o
ool0oooo00h0oooo3000oml80?ooo`<001Ko0P00_ol90?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool06P3oool0102Fo`00Iol006Oo001W
o`080?ooo`030000003oool00?m?00800?m?0P3oool20;oo0080oooo0P0no`080?ooo`03003oFP3o
ool0oooo00@0oooo00<0aol00?ooo`3oool0103oool200;o00@0oooo0P00og`70?ooo`030:co003o
ool0oooo00P0oooo00<00?m80?ooo`3oool0:P3oool01000obH0oooo0?ooo`3oool2003od`d0oooo
1@00oh48003Eo`T0oooo0`00oml00`00Mol0oooo0?ooo`0>0?ooo`<001Ko00<00;oo0?ooo`3oool0
1`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000003o
ool0oooo00H0oooo00<0MOl00?ooo`3oool0403oool209Ko0080Iol02@3oool010000000oooo0?oo
o`00odl40?ooo`050;oo003oool0oooo0?ooo`0no`002@3oool00`00oeX0oooo0?ooo`040?ooo`03
0<Oo003oool0oooo00D0oooo00<00_l00?ooo`3oool08@3oool00`00ocl0oooo0?ooo`090?ooo`03
02go003oool0oooo00<0oooo0P00oh<<0?ooo`@00?lV2@00om<80?ooo`800?n100<0oooo003Eo`00
oh401@00oh4=0?ooo`8007Oo7@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo000<0?ooo`030000003oool0oooo00D0oooo0`1eo`0B0?ooo`0309Ko003oool0Iol000X0oooo
00@000000?ooo`3oool00?m?0`3oool00`2oo`00oooo0?ooo`020?ooo`0303ko003oool0oooo00L0
oooo00<00?mJ0?ooo`3oool0703oool00`00o`/0oooo0?ooo`060?ooo`<0MOl01P3oool2003o?`X0
oooo0P0]o`040?ooo`P00?n3203oool00`00obH0oooo0?ooo`04003o9Q40oooo00<00=Go0?ooo`3o
ool09P3oool01000D_l0oooo0?ooo`3oool20?l0f@<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`00303oool00`000000oooo0?ooo`060?ooo`0307Go003oool0oooo0140
oooo00@0U_l00?ooo`3oool0Iol02@3oool010000000oooo0?ooo`00odl40?ooo`030;oo003oool0
oooo0080oooo00<0?_l00?ooo`3oool04P3oool00`0Co`00oooo0?ooo`050?ooo`030:co003oool0
oooo00L0oooo0`00o`/70?ooo`<0MOl01P3oool4003o?`T0oooo100]o`020?ooo`800?n3=`3oool2
0;d0o`H0oooo0P2m0?l80?ooo`<0o`3I0`00D_l30?l0f@060?ooo`00/Ol00;7o002ao`3oool00000
1`3oool00`000000oooo0?ooo`070?ooo`00303oool00`000000oooo0?ooo`060?ooo`0307Go003o
ool0oooo0140oooo00@0U_l00?ooo`3oool0Iol01P3oool01006o`00oooo0?ooo`00000>0?ooo`<0
6_l00`3oool00`37o`00oooo0?ooo`090?ooo`<04ol01P3oool20:co00T0oooo0P00o`/80?ooo`04
07Go003oool0MOl007Go00P0oooo0P00ocl;0?ooo`80;Ol09`3oool00`1I0?l0oooo0?ooo`030?oo
o`<0F@3o2@3oool2002do`03003ok@2m0?l0oooo00<0_@3o2@3oool30?l0f@L005;o00<00;7o0?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo000;0?ooo`03
0000003oool0oooo00L0oooo00<0MOl00?ooo`3oool06P3oool300Ko0080oooo00<0_ol00?ooo`3o
ool02`3oool201[o00@0oooo0P37o`0;0?ooo`0301?o003oool04ol000H0oooo00<0[?l00?ooo`3o
ool02@3oool2003o2`X0oooo00<0MOl00?ooo`3oool0603oool00`00GOl0oooo0?ooo`0>0?ooo`<0
00Go2`3oool2003ok@030?ooo`00oi400?nA00D0F@3o2P3oool6002do`H00?o]1`3oool20?l0f@80
0;7o0`00D_l30?ooo`L005;o1P3oool00`000000oooo0?ooo`070?ooo`002`3oool00`000000oooo
0?ooo`070?ooo`0307Go003oool0oooo00/0oooo00<0U_l00?ooo`3oool03@3oool00`06o`00oooo
0?ooo`030;oo00d0oooo00<06_l00?ooo`3oool00`3oool00`37o`00oooo0?ooo`0<0?ooo`0301?o
003oool0oooo00@0oooo00<0[?l00?ooo`3oool02`3oool00`00kol0oooo0?ooo`0?0?ooo`03002/
o`3oool0oooo00h0oooo00<005go0?ooo`00GOl0203oool00`00oi<0oooo0?ooo`020?ooo`03003o
>`001Ol000Go00L000Go103oool4003ok@T00?nA2P3oool3002do`03003ok@3oool00;Co00H00;Co
1`3oool20?l0f@030?ooo`00/Ol005;o00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`002`3oool00`000000oooo0?ooo`0D0?ooo`80U_l0403oool01@06o`00oooo0?oo
o`2oo`00000000d0oooo00<06_l00?ooo`3oool00`3oool00`37o`00oooo0?ooo`0@0?ooo`05003o
g@3oool0oooo0?ooo`2/o`002`3oool4003_o`h0oooo0`00[?l40?ooo`03003o?`3oool0oooo00<0
oooo0P0@o`030?ooo`L005go0P3oool3003oT`80oooo2000oc/90?ooo`L00?o]00<0F@3o0?ooo`3o
ool03@3oool00`00]?l0_@3o0;d0o`0A0?ooo`80o`3I2P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo000;0?ooo`030000003oool0oooo01D0oooo00<0U_l00?ooo`3oool0
3P3oool01@06o`00oooo0?ooo`3oool0_ol000<0oooo00<00?na0?ooo`3oool0203oool00`0Jo`00
oooo0?ooo`030?ooo`030<Oo003oool0oooo00h0oooo0`00omd60?ooo`80MOl01P3oool4003_o`L0
oooo0`1=o`040?ooo`800:co00<0oooo002/o`00[?l00`00ocl50?ooo`D04?l000<0oooo001Mo`3o
ool01P3oool6003oT`800?lk0P3oool20005o`/0oooo00<00?o]0?ooo`3oool00`3oool3003okB40
oooo00<0=03o0?ooo`3oool01@3oool203@0o`80oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`002`3oool00`000000oooo0?ooo`0D0?ooo`0309Ko003oool0oooo00l0oooo
00L01_l00?ooo`3oool0oooo0;oo00000000oooo00<00?na3P3oool4003o_0@0oooo0P21o`080?oo
o`800?oM1`3oool207Go00L0oooo0`0:o`02003_o`H0oooo0`1=o`040?ooo`04002/o`3oool0oooo
0?ooo`<00?lo2P3oool2013o00L0oooo0P00oi<40?ooo`<00?nC9@3oool00`00;Ol0oooo0?ooo`03
0?ooo`<002go2P3oool303@0o`03003[o`1W0?l0=03o0080=03o103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo000;0?ooo`030000003oool0oooo01@0oooo00<0U_l00?oo
o`3oool02@3oool00`0no`00oooo0?ooo`080?ooo`040000003oool0oooo003o/@@0oooo0P1]o`0:
0?ooo`800?nl1@3oool2087o00D0oooo0P16o`020?ooo`<00?oM1P3oool307Go00H0oooo0P0:o`0;
0?ooo`80COl02@3oool2003o?aX0oooo00<00>3o0?ooo`3oool0403oool2002:o`030?ooo`00R_l0
08[o00<008[o2@3oool00`00;Ol00`3o003o/`04000]o``0oooo0P0d0?l01000jol0I`3o06L0o`1W
0?l20?ooo`H00>_o203oool00`000000oooo0?ooo`060?ooo`002`3oool00`000000oooo0?ooo`0D
0?ooo`0309Ko003oool0oooo00P0oooo0`0no`000`1io`00oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`00ok400P3oool206go00@0oooo0P1]o`070?ooo`03003o_03oool0oooo00<0oooo00<0
POl00?ooo`3oool00`3oool204Ko00D0oooo00<00?oM0?ooo`3oool01P3oool00`1eo`00oooo0?oo
o`050?ooo`802_l05P3oool2003o?`H0oooo00<00?oC0?ooo`3oool03P3oool00`00h?l0oooo003P
o`0<0?ooo`04001Mo`3oool0oooo003oEP@008[o3@3oool300<0o`T00?nc203oool00`0d0?l0I`3o
06L0o`0606L0o`@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`002`3o
ool00`000000oooo0?ooo`0=0?ooo`0306Oo003oool0oooo0100oooo00@0?_l00?ooo`1io`00NOl0
203oool010000000oooo0?ooo`00ok430?ooo`0406go003oool0oooo0?ooo`80KOl02@3oool00`00
ok`0oooo0?ooo`020?ooo`03087o003oool0oooo00@0oooo00<0A_l00?ooo`3oool03`3oool00`00
of<0oooo0?ooo`040?ooo`0300[o003oool0oooo00P0oooo0P00oi<@0?ooo`<00?oC303oool2003o
00030?ooo`00h?l00>3o00H00>3o1@3oool3001Mo`D00?mF00<008[o0?ooo`3oool02P3oool500<0
o`03003o/`00;Ol0oooo0100oooo1@1W0?l00`3oool0o`1_06L0o`0706L0o`D0oooo00<000000?oo
o`3oool01P3oool000/0oooo00<000000?ooo`3oool0303oool206Oo0180oooo00@0?_l00?ooo`1i
o`00NOl0203oool010000000oooo0?ooo`00ok440?ooo`0306go003oool0oooo0080oooo00<0KOl0
0?ooo`3oool0303oool00`21o`00oooo0?ooo`020?ooo`800?m900<0A_l00?ooo`3oool03@3oool3
003oH`l0oooo0`00oi<:0?ooo`80C?l0103oool2003od`030?ooo`00om<00?oC00800?oC0P3oool2
002ko`<0oooo1000o`000`3oool00>3o003Po`090?ooo`@005go00D0oooo003oEP00oeH0oooo002:
o`05003oEPT0oooo2@030?l00`3oool0o`3K0?l0f`090?ooo`030?l0K`3oool0oooo0080I`3o00<0
oooo0?l0K`3o06l01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo000;
0?ooo`030000003oool0oooo00d0oooo0P1Wo`0A0?ooo`0303ko003oool0NOl000L0oooo00@00?mJ
0?ooo`3oool000001P3oool00`1]o`00oooo0?ooo`020?ooo`0306go003oool00?m600800?m63`3o
ool3003oB@0304Ko003oool0oooo00`0oooo0`00of<80?ooo`80R?l01P3oool4003oT`800?o/1`3o
ool304co00<0oooo00<00?oC0?ooo`3oool00`3oool4002ko`@0oooo00<00?l00?ooo`3oool01000
o`080?ooo`P005go0P2m0?l40?ooo`<0_@3o1`3oool200<0o`<0o`3K00<0oooo0?l0f`3o0=/01003
0?l80?ooo`<0o`1_00<008go0?l0K`3o06l00`3oool3002=o`030?ooo`000000oooo00L0oooo00<0
00000?ooo`3oool01P3oool000X0oooo00<000000?ooo`3oool03P3oool00`1Wo`00oooo0?ooo`0@
0?ooo`0403ko003oool0oooo07Wo00D0oooo0`00oeX00`3oool000000?ooo`0;0?ooo`0306go0000
odH00?m600D0oooo00<0[?l00?ooo`3oool02@3oool00`00odT0oooo0?ooo`050?ooo`80Z_l0203o
ool01000oi/0oooo003oH`00of<60?ooo`80R?l0203oool4003ok0X0oooo0P1<o`030?ooo`0400<0
o`3oool0oooo0?ooo`D00;_o203oool405`0o`L0oooo0P00GOl40?ooo`040;d0o`00GOl005go001M
o`<0_@3o2`3oool20?l0f`03003/o`3o0=/0o`3K00d0oooo0`3o06l3002=o`04002ao`00SOl008go
002=o`@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`002P3oool00`00
0000oooo0?ooo`0>0?ooo`0306Oo003oool0oooo00X0oooo00<0D_l00?ooo`3oool01P3oool00`1i
o`00oooo0?ooo`040?ooo`05003oFP3oool0oooo0?ooo`2<o`003@3oool00`00odH0oooo0?ooo`02
0?ooo`<0[?l02`3oool00`00odT0oooo0?ooo`020?ooo`040030o`3oool0Z_l00:[o00H0oooo0`00
oi/40?ooo`03002>o`3oool0oooo00@0oooo0P28o`060?ooo`@00?o/3P3oool400<0o`80oooo0P00
^ol20?ooo`<00;_o1@3oool905`0o`P0oooo00D0_@3o003o^@00okT0oooo0;d0o`0=0?ooo`040?l0
f`00k?l00?o]003/o`80oooo1@00k?l70?ooo`80o`1_0P00SOl3002ao`L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`002P3oool00`000000oooo0?ooo`0>0?ooo`0306Oo
003oool0oooo00T0oooo0P1Bo`080?ooo`0307Wo003oool0oooo00@0oooo00<00?mJ0?ooo`3oool0
0`2<o`020?ooo`03003[o`3oool0oooo00L0oooo00<00?m60?ooo`3oool00`3oool00`2/o`000>3o
0?ooo`030?ooo`800?mE1P3oool00`00odT0oooo0?ooo`020030o`<0oooo00<0Z_l00?ooo`3oool0
0`3oool3003oV`<0oooo0`00S_l70?ooo`0308So003oool0oooo00@0oooo1000on`:0?ooo`03003o
8`3oool0oooo00P00`3o1@3oool2002ko`030?ooo`00ofP00?mX00<0G03o303oool2003oT@P00?ni
2`3oool2003ok@<00>co3P3oool00`3o06l00;7o002ao`0;002ao`P0oooo00<000000?ooo`3oool0
1@3oool000X0oooo00<000000?ooo`3oool03P3oool00`1Wo`00oooo0?ooo`090?ooo`<0D_l03P3o
ool01@00oeX0oooo0?ooo`3oool0S?l00080oooo0`00oad90?ooo`03003oAP3oool0oooo0080oooo
00<00>3o0:co0000h?l00P3oool00`00oeD0oooo003oE@090?ooo`<00<3o0`3oool00`2Zo`00oooo
0?ooo`020?ooo`@00?nK0P3oool4002>o`L0oooo0P0@o`050?ooo`<004_o0P00on`00`00Bol0oooo
0?ooo`040?ooo`<00?lS0P3oool200<0o``0oooo2000ofP80?ooo`@00?nA0P00okT20;d0o`h0oooo
2`00ond;0?ooo`<00;7o0`3oool208`0o`80oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`050?ooo`002P3oool00`000000oooo0?ooo`0K0?ooo`0305;o0006o`001_l000d0oooo00L0
0?mJ0?ooo`3oool0oooo08co00000000oooo00<00?lM3`3oool0102/o`00oooo0?ooo`3oool3003o
E@0302ko003oool0oooo00L0oooo0`00`?l60?ooo`80;Ol00`3oool01000oi/0oooo0?ooo`00S_l2
0?ooo`8008ko1@3oool3013o00D0oooo00@004_o0?ooo`3oool0oooo0P00on`60?ooo`03003o8`3o
ool00?lS00<00?lS1`3oool3003o>`<0oooo0P00ofP>0?ooo`H00?nA403oool2003ok@D0oooo0`0X
0?l90?ooo`80S03o0P3oool010000000S03o08`0o`2<0?l5000000T0oooo00<000000?ooo`3oool0
1@3oool000X0oooo00<000000?ooo`3oool01P3oool00`0Co`00oooo0?ooo`0B0?ooo`0305;o0006
o`001_l000P0oooo00<00?lM0?ooo`3oool01P3oool01@2<o`0000000?ooo`3oool00?lM00@0oooo
0P0Co`0:0?ooo`030:co0000h?l0oooo00<0oooo00<0;_l0003oE@0^o`002`3oool00`00`?l0oooo
0?ooo`020?ooo`<0;Ol0103oool01000oi/0oooo0?ooo`1=o`090?ooo`04013o003oool04?l0013o
00L0oooo0`0@o`0C0?ooo`D00?lk0`3oool00`00R_l0oooo0?ooo`0;0?ooo`05003oT@3oool0oooo
0?ooo`00=?l00`00oi4=0?ooo`L0:03o2`00000608`0o`L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`050?ooo`002P3oool00`000000oooo0?ooo`050?ooo`<04ol04`3oool00`1B
o`001_l00?ooo`070?ooo`<00?lM1`3oool01P2<o`00oooo0000003oool00>_o003o7@<0oooo0P0C
o`0<0?ooo`03003Po`3oool0oooo0080oooo00<00?mE02ko003oool0103oool00`1eo`00oooo0?oo
o`0;0?ooo`0302go003oool0oooo00@0oooo0`1=o`0;0?ooo`03013o003oool0oooo00D0oooo0P0@
o`090?ooo`03003Eo`3oool0oooo00`0oooo0`00oc/2002:o`l0oooo00D003Co0?ooo`00=?l003Co
0?ooo`04000do`T00000100X0?l2000000`0oooo102<0?l2003oo`80oooo1P00ool90?ooo`030000
003oool0oooo00D0oooo000:0?ooo`030000003oool0oooo00H0oooo00<04ol00?ooo`3oool04P3o
ool00`1Bo`001_l00?ooo`080?ooo`03003o7@3oool0oooo00P0oooo00@000000?ooo`3oool00?lM
0`3oool00`0Co`00oooo0?ooo`030?ooo`03087o003oool0oooo00/0oooo00<00?mE0?ooo`3oool0
0`3oool307Go00`0oooo00@0;Ol00?ooo`3oool00?o00P3oool404go00X0oooo0`00ond70?ooo`80
4?l01P3oool3003Eo`l0oooo2000R_l00`3oool000000000000700000003003oAP00=?l003Co0080
03Co0`00000;0?ooo`0402P0o`00oj00:03o0?ooo`D00?nP2@3oool00`2<0?l00?oo003oo`02003o
o`04000Fo`00ool0o`000?l000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`05
0?ooo`002P3oool00`000000oooo0?ooo`060?ooo`0301?o003oool0oooo00/0oooo00<0?_l00?oo
o`3oool01P3oool00`06o`00oooo0?ooo`060?ooo`04003o7@3oool0oooo06go00D0oooo00<00?nl
0?ooo`0000000`3oool01@00oad0oooo0?ooo`3oool04ol000<0oooo0`21o`000`00ojL0oooo0?oo
o`0:0?ooo`0302ko003oool0oooo0080oooo00<00?nX07Go003oool03P3oool3003o`0D0oooo00<0
COl00?ooo`3oool01`3oool4003ok@P0oooo0P0@o`040?ooo`800=Go00<0oooo003Eo`00eOl00P00
eOl30?ooo`H0000000<02_l000000000R_l00P00R_l6000000L0oooo1000odH00`00=?l0oooo0?oo
o`0=0?ooo`8007Oo0`00oj030?ooo`80o`1_203oool20?l000030?ooo`00ool001Ko008001Ko00<0
o`000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo000:
0?ooo`030000003oool0oooo00H0oooo00<04ol00?ooo`3oool02P3oool203ko00P0oooo00<01_l0
0?ooo`3oool01P3oool00`00oad0oooo06go000206go00<0oooo0`00ok`00`3oool000000?ooo`05
0?ooo`0301?o003oool0oooo0080oooo00<0POl0003oY`00ojL00P00ojL>0?ooo`<00?nX00<0MOl0
0?ooo`3oool03@3oool2003o`0H0oooo00<0COl00?ooo`3oool01`3oool00`00ond0oooo0?ooo`02
003ok@D0oooo00@0000004go001=o`00COl0100000000`00eOl0000006L0o`06000000@0oooo100:
o`020?ooo`80`P3o2P3oool2003Eo`040?ooo`00odH00?m60?l0f@D00?m60`3o0=T60?ooo`@007Oo
00<00?nP0?l0K`3oool00`3o06l:0?ooo`030?l0003oool0o`0000L001Ko0`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00D0oooo00090?ooo`030000003oool0oooo00L0oooo00<0
4ol00?ooo`3oool02`3oool203ko00L0oooo00<01_l00?ooo`3oool01P3oool01000oad0oooo0?oo
o`1]o`050?ooo`04003o_03oool0oooo000000`0oooo00<0POl0003oY`00ojL0403oool2003oZ007
07Go003oool0oooo0?ooo`00G_l0oooo08So000;0?ooo`800?o000<002_o0?ooo`3oool00`3oool2
07Wo00T0000000<05`3o000000000000100000020?ooo`@0COl00`3oool406L0o`@0oooo00<00?oC
0?ooo`3oool00P3oool200[o00030?ooo`0:o`002_l000802_l01P320?l20?ooo`@00=Go0P3oool2
0?l0f@030?ooo`3o0=T0o`3I0080o`3I2P3oool8001go`X0oooo00D0o`000?ooo`3o0000o`00001E
o`03000Fo`80oooo00<005Go000Fo`005_l01@005_l60?ooo`030000003oool0oooo00D0oooo0009
0?ooo`030000003oool0oooo00L0oooo00<04ol00?ooo`3oool02`3oool00`0no`00oooo0?ooo`0?
0?ooo`04003o7@3oool0oooo06go00D0oooo00L00?nl0?ooo`3oool0oooo00000016o`00oooo0080
08Wo1`3oool00`21o`00oooo003oY`040?ooo`03001no`1eo`00oooo00/0oooo00<00?nX07Go003o
ool00P00G_l00`3oool0R?l008So00030?ooo`P000001000:ol300000080NOl0203oool401L0o`X0
oooo0P1=o`000`3oool0I`3o06L0o`0406L0o`<00?oC203oool50<80o`H0oooo1@00eOl01P3oool0
o`3I003om03o0=T0oooo0?l0f@`0oooo0`00Mol2002co`80oooo00<00;?o001go`00Mol00P00Mol6
0?ooo`80o`0000D0oooo001Eo`00EOl005Go000Fo`03001Eo`D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`0E0?ooo`0303ko003oool0
oooo00T0oooo00<00_l00?ooo`3oool01P3oool00`1]o`00oooo0?ooo`040?ooo`03003o_03oool0
oooo00<0A_l00`00ROl60?ooo`04087o003oool0oooo003oY`<0oooo0`1eo`000`00O_l0oooo0?oo
o`020?ooo`P000001000G_l00`000000R?l000000002000000P0oooo1@00:ol40?ooo`80NOl01P3o
ool0100G0?l00?n3003oP`00oh<301L0o`X0oooo0`1W0?l30?ooo`@00?oC1P3oool00`00ojL0oooo
0<80o`020<80o`P0oooo0`00eOl00`3oool00=Go003Eo`02003Eo`030?l0f@00oo@00?od00800?od
2P3oool00`00Mol00;?o002co`03002co`d0oooo00D0o`00001Eo`00EOl005Go003oo`080?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool000T0oooo00<000000?ooo`3oool0
5@3oool00`0no`00oooo0?ooo`080?ooo`<00_l01`3oool00`1]o`00oooo0?ooo`040?ooo`05003o
_03oool0oooo0?ooo`16o`000`00ROl50?ooo`D0000000<00?nW0000000000000P0000000`1eo`00
07ko0000000300000003003o2`3oool0oooo00L0oooo1000G_l00`3oool0R?l00?ooo`050?ooo`<0
0?lo0P3oool2000[o`80oooo0P00:ol40?ooo`0307Wo003oool00?lk00@0oooo0`00oh<:0?ooo`<0
0?mX00<0oooo06L0o`1W0?l0103oool00`00om<0oooo0?ooo`03003od`80oooo2000ojL;0?ooo`<0
0?od0P00eOl?0?ooo`03003oX000/ol0oooo0100oooo00<005Go003oo`00ool00`3oool20>d0o`<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo
0?ooo`0E0?ooo`0303ko003oool0oooo00T0oooo00<00_l00?ooo`3oool03@3oool01P00ok`0oooo
0?ooo`3oool0A_l00000008008Wo00D04ol00000000000000000003oB@0;0?ooo`0307Go0000O_l0
oooo0080oooo0`00o`/;0?ooo`03001No`3oool0R?l000<0oooo0P00obH3003o?`d0oooo0`00oc/4
0?ooo`03003oP`3oool00?n300T0oooo1000ofP<0?ooo`800?oC00<0oooo003oY`00ojL03`3oool0
1000odH0oooo003om000oo@?0?ooo`D00?nP0`3oool208L0o`X0oooo00<0k@3o003oo`00ool00P00
ool00`320?l00?oo003oo`05003oo`T0oooo00<000000?ooo`3oool0103oool000T0oooo00<00000
0?ooo`3oool05@3oool00`0no`00oooo0?ooo`090?ooo`0300;o003oool06_l000L0oooo00<00?ml
0?ooo`3oool01`3oool00`16o`00oooo0?ooo`0301?o00030?ooo`00odT00?m900800?m92@3oool0
0`1eo`00oooo001no`020?ooo`<00?l;00<00?l[0?ooo`3oool03@3oool3003o9P80oooo0P00ocl=
0?ooo`800?lk1`3oool2003oP`P0oooo00<00?mX0?ooo`3oool00P00ofP90?ooo`802_l0103oool0
0`00;Ol0oooo0?ooo`0:0?ooo`D00?m600<0:03o0?ooo`3oool00`3oool202P0o`T0oooo00@0G03o
003oX0270?l0Q`3o1P00oj090?ooo`80k@3o00@00?oo0<80o`320?l0`P3o1P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00090?ooo`030000003oool0oooo00h0oooo00<0
1_l00?ooo`3oool0403oool01002o`00oooo01[o000Jo`050?ooo`<00?ml203oool00`16o`00oooo
0?ooo`0301?o0080oooo0P00odTA0?ooo`03003o2`3oool0oooo0140oooo00D00?lV0?ooo`3oool0
oooo003o?`0>0?ooo`800?lk00<00;Co0?ooo`3oool0103oool00`00oh<0COl004go00070?ooo`80
07Oo2@3oool200[o00@0oooo00<002go0?ooo`00;Ol01@00;Ol70?ooo`800?m600<0oooo02P0o`00
odH01000odH00`0X0?l0oooo0?ooo`070?ooo`<0G03o00@00?nP08L0o`270?l0Q`3o3@3oool20>d0
o`<0`P3o00<0oooo0<80o`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00090?ooo`030000003oool0oooo00d0oooo0`06o`0A0?ooo`0400;o003oool06_l001[o
00H0oooo00<00?ml0?ooo`3oool01P3oool00`00h?l0A_l00?ooo`020?ooo`030029o`0Co`00oooo
0080oooo00<00?m90?ooo`3oool0103oool00`00m_l0oooo0?ooo`090?ooo`03003o2`3oool0oooo
0080oooo00<00?Ko0?ooo`28o`00303oool01@00obH0oooo003Oo`00gol00?lo0080oooo0P1io`0:
0?ooo`@00;Co1@3oool204go00L0oooo1`00Mol50?ooo`D02_l01000;Ol80?ooo`8000Go103oool3
02P0o`/0oooo0`1L0?l0103oool0G03o08L0o`270?l?0?ooo`80k@3o00<0oooo0<80o`320?l01@32
0?l3003io`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool000T0oooo00<00000
0?ooo`3oool03@3oool200Ko0180oooo00<00_l00?ooo`0Jo`001`3oool01@00og`0oooo0?ooo`3o
ool0A_l00080oooo1000h?l40?ooo`0501?o003oool0oooo0?ooo`00odT0103oool0101eo`000?Ko
003fo`00m_l:0?ooo`04003o2`00ob/0oooo0?ooo`<00?Ko0P28o`0<0?ooo`<00=oo0`3oool207Wo
00X0oooo1000]?l70?ooo`80COl01P3oool01000Mol0oooo0?ooo`3oool2001So`X0oooo0P0:o`00
0`00;Ol0oooo0?ooo`040?ooo`<000Go00<0oooo0005o`3oool00`3oool00`00oe40:03o02P0o`0<
0?ooo`H0G03o00<00?nX0?ooo`00ojP01000ojP:0?ooo`03003io`320?l0`P3o0080`P3o00<00?Wo
0?ooo`3oool01@320?l80?ooo`030000003oool0oooo00@0oooo00090?ooo`030000003oool0oooo
00h0oooo00<01_l00?ooo`3oool02P3oool00`02o`00oooo0?ooo`060?ooo`0301[o003oool0oooo
00@0oooo00<00?ml0?ooo`3oool00`16o`020?ooo`800>3o00<000000?ooo`3oool00`3oool0100C
o`00oooo0?ooo`00odT40?ooo`80MOl00P00m_l;0?ooo`04003o2`3oool0oooo0?ooo`800?Ko00<0
oooo08So003oool0303oool4003Oo`<0oooo0P1io`080?ooo`800;_o00@00;Co0?ooo`00]?l00;Co
1`3oool204go00H0oooo1000Hol70?ooo`<00?l82@3oool50005o`<0oooo2000oe480?ooo`80G03o
00@0oooo05`0o`1L0?l00?nX101L0?l>0?ooo`04003io`320?l0`P3o002=o`H0oooo00<000000?oo
o`320?l00P320?l50?ooo`030000003oool0oooo00@0oooo00080?ooo`030000003oool0oooo00h0
oooo00<01_l00?ooo`3oool02P3oool300;o00L0oooo00<06_l00?ooo`3oool0103oool01@00og`0
oooo0?ooo`3oool0A_l000@0oooo00<00>3o0000003oool0103oool00`0Co`00oooo0?ooo`060?oo
o`0307Go003oool00?Ko0140oooo00<00?Ko08So003oool0103oool0101<o`000?oe003om@00ooD8
0?ooo`03003Oo`3oool0oooo0080oooo00@0NOl00?ooo`1=o`00COl00P3oool4002ko`/0oooo0`0_
o`050?ooo`@006?o203oool5003o20L0oooo00<000Go0?ooo`001Ol00`001Ol20?ooo`800?mA3P3o
ool205`0o`030?ooo`00ojP00>co00@0oooo0`1L0?l:0?ooo`03000<o`3oool008go008008go0P3o
ool2000<o`80oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`00203oool0
0`000000oooo0?ooo`0>0?ooo`0300Ko003oool0oooo00/0oooo00<00_l00?ooo`3oool01P3oool0
0`0Jo`00oooo003oE@040?ooo`05003oO03oool0oooo0?ooo`16o`001@3oool01@00h?l0oooo0?oo
o`3oool00?l;00X0oooo00D0MOl00?ooo`3oool00?Ko0?ooo`03003o/@0302go003oool0oooo00X0
oooo00<00?Ko08So003oool00`3oool4003om@l0oooo0P1=o`020?ooo`@00;_o303oool302oo00D0
oooo0P00Hol00`3oool006?o001So`070?ooo`04003o203oool0oooo0?ooo`800?l81@3oool20005
o`<0oooo00D00?ni0005o`001Ol000Go0030o`0@0?ooo`<00>co1@3oool2001[o`X0oooo00<000co
002=o`00SOl01000SOl40?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool0
00P0oooo00<000000?ooo`3oool03P3oool00`06o`00oooo0?ooo`0;0?ooo`0300;o003oool0oooo
00H0oooo00<06_l0003oE@00oeD0203oool01016o`00oooo0?ooo`00og`20?ooo`03003Po`3oool0
oooo00<00?l;2P3oool0101eo`00oooo003fo`3oool3003o/@80;Ol0303oool00`28o`00oooo0?oo
o`020?ooo`800?oe00<0oooo003om@3oool0403oool204go00040?ooo`00^ol00;_o002ko`l0oooo
0P0_o`080?ooo`8006?o00<00?mX0?ooo`3oool0103oool00`00oo@0oooo0?ooo`090?ooo`@00?ni
00@0oooo0030o`001Ol000Go1@00`?l90?ooo`D00>co1000Jol;0?ooo`<000co0`00SOl00`3oool0
o`2Z002=o`06002=o`L0oooo00<000000?ooo`3oool0103oool000P0oooo00<000000?ooo`3oool0
3P3oool00`06o`00oooo0?ooo`0:0?ooo`0300;o003oool00?mJ00P0oooo0`00oeD70?ooo`0304Ko
003oool0oooo00<00?ml00D00>3o0?ooo`3oool0oooo003o2`0;0?ooo`0407Go003oool0oooo0?oo
o`<00?na00<0;Ol00?ooo`3oool0103oool00`00ohP0oooo0?ooo`0:0?ooo`<00?oe0P3oool00`00
oh40oooo0?ooo`0>0?ooo`0404go0000oi400?nA003oT@800;_o0P3oool2003o8`T0oooo0`00okT7
0?ooo`800?mX0P00Hol40?ooo`L00?od1`3oool4003o^@@00<3o3P3oool3003/o`03001[o`00k?l0
0>co00@00>co2@3oool2000<o`030?ooo`003?l008go0080o`2Z1@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00@0oooo00080?ooo`030000003oool0oooo00H0oooo00<00?m?0?oo
o`3oool04P3oool01002o`000?mJ003oFP00oeX80?ooo`03003oE@3oool0oooo00H0oooo00<0A_l0
003og@3oool00`00og`40?ooo`03003o2`3oool0oooo00D0oooo0P00ojP60?ooo`<00?na00<0oooo
02go003oool00`3oool4003oR0/0oooo00<0C?l00?ooo`00ooD01000oh43013o00`0oooo0P00oi43
0?ooo`800;_o0P00ob<90?ooo`800?ni00@0oooo003o^@00okT00?ni103oool4003oJ0@0oooo0`00
oo@00`0d0?l0oooo0?ooo`090?ooo`03003o^@3oool0oooo00<00?ni1@3oool208`0o`T0oooo00<0
k@3o001[o`00Jol00P3oool20>d0o`/0oooo0P3o0:X2000<o`03003oa`3oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`00203oool00`000000oooo0?ooo`05
0?ooo`<00?m?4`3oool01002o`000?mJ003oFP00oeX70?ooo`03003oE@3oool0oooo00H0oooo1000
omd2003oO0030000003oool0oooo0080oooo00<00?l;0?ooo`3oool00P3oool00`0^o`00oooo003o
Z003003oZ0L0oooo00<00?na0?ooo`0]o`001@3oool302go00<0oooo00<009?o0?ooo`3oool0203o
ool01000ooD00?n1003oP@3oool2013o0003001mo`3oool0oooo00/0oooo0`00oi401000D_l0oooo
0?ooo`00^ol3003o8`P0oooo00@00?ni0?ooo`3oool001Ko1P3oool00`00ofP0oooo0?ooo`02003o
J0@0oooo100d0?l<0?ooo`03003o4@2<0?l0S03o00800?ni0`2<0?l;0?ooo`030>d0o`00ofP0k@3o
0080k@3o303oool00`3o0:X0oooo0?l0ZP0;003oa`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool000P0oooo00<000000?ooo`3oool01@3oool3003oC`d0oooo00<00?lM0?ooo`3o
ool00`3oool00`02o`00oooo003oFP080?ooo`05003oE@3oool0oooo0?ooo`0Co`001@3oool2003o
g@80oooo00@00?ml0000003oool0oooo0P00O_l00`00o`/0oooo0?ooo`020?ooo`80;_l000<0oooo
003oZ000ojP01@3oool01P00U?l0oooo0?ooo`3oool00?na02go00D0oooo0P0]o`030?ooo`<009?o
2P3oool00`00ooD0oooo003oP@03013o008007go3@3oool01000D_l00?nA001Bo`00D_l40?ooo`03
003o8`3oool0oooo00L0oooo0`005_l80?ooo`80>?l00P00ofP20?ooo`L0=03o1`3oool4003o4@<0
S03o3P3oool9003oJ0P0oooo0`3o0:X00`3oool00?o7003oa`080?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool000P0oooo00<000000?ooo`3oool01P3oool00`00odl0oooo
0?ooo`0;0?ooo`800?lM1`3oool00`00oeX0oooo0?ooo`060?ooo`03003oE@3oool0oooo00<04ol0
103oool01`00omd0oooo0?ooo`3oool00?ml0000003oool00`00O_l00`00o`/0oooo0?ooo`020?oo
o`80;_l00P3oool00`00ojP0oooo0?ooo`020?ooo`@009Co00<0oooo003o/@3oool01P3oool0100]
o`000?n80?ooo`3oool4002Co``0oooo00@00?n1001mo`0@o`0007go0`3oool00`24o`00oooo0?oo
o`080?ooo`@005;o1@3oool00`00ob<0KOl006go00050?ooo`<001Ko00@0oooo000Fo`005_l001Ko
1@3oool303So00<0oooo0`0d0?l<0?ooo`800?lA00<0S03o003o4@00oa400`00oa4=0?ooo`03003o
J03]0?l0oooo00h0oooo0`3o0:X01000fOl0oooo03@0o`0d0?l20?ooo`<00=Wo00<0oooo0000003o
ool0203oool00`000000oooo0?ooo`030?ooo`00203oool00`000000oooo0?ooo`060?ooo`03003o
C`3oool0oooo00/0oooo0`00oad60?ooo`03003oFP3oool0oooo00H0oooo00D00?mE0?ooo`3oool0
oooo01?o00050?ooo`03003og@3oool0oooo0080oooo00<00?ml0?ooo`3oool00P00O_l50?ooo`05
02ko003oool0oooo0?ooo`00ojP01@3oool00`1=o`0009Co0?ooo`020?ooo`03003o/@3oool0oooo
00D0oooo00@0;Ol00?ooo`3oool0oooo0P00Tol00`3oool0NOl007Wo000<0?ooo`03001mo`0@o`00
07go00<0oooo00<0Q?l00?ooo`3oool0203oool2001Bo`030?ooo`00D_l005;o00@0oooo0P1]o`06
0?ooo`8001Ko2P3oool0100ho`00oooo03So000ho`020?ooo`80=03o3`3oool00`00ogP0S03o0?oo
o`0>0?ooo`8002go0P00olX00`3oool00?o:003obP02003obP/0oooo00<00=Wo03@0o`0d0?l00P0d
0?l2003Io`@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`001`3oool0
0`000000oooo0?ooo`070?ooo`03003oC`3oool0oooo00`0oooo00<00?lM0?ooo`3oool01@3oool0
0`00oeX0oooo0?ooo`020?ooo`03003oB03oool0oooo00D0oooo00<04ol00?ooo`3oool00`3oool0
1P00omd0oooo0?ooo`3oool02_l0003oO080oooo00<007ko0?ooo`3oool01@3oool0100^o`00oooo
0?ooo`00ojP40?ooo`<0COl02`3oool00`0]o`00oooo0?ooo`030?ooo`80NOl03`3oool00`0@o`00
07go0?ooo`020?ooo`0308Co003oool0oooo0180oooo0P1]o`000`3oool00?l80?ooo`0@0?ooo`03
003o=P0ho`00>?l000/0oooo0P00R_l30?ooo`<00?mh303oool5000]o`<00?o:3`3oool503@0o`80
oooo0P190?l20?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool000L0oooo
00<000000?ooo`3oool01`3oool00`00odl0oooo0?ooo`0;0?ooo`03003o7@3oool0oooo00H0oooo
00<00?mJ0?ooo`3oool01000odP60?ooo`0301?o003oool0oooo00<0oooo00@00?oM0?ooo`3oool0
oooo0`0:o`020?ooo`03001no`3oool0oooo0080oooo00<00?mS0?ooo`0^o`00203oool00`1=o`00
oooo002Do`050?ooo`03003o9P3oool0oooo00<0oooo00<0;Ol00?ooo`3oool00`3oool00`00Tol0
NOl00?ooo`030?ooo`800?l03P3oool00`24o`00oooo0?ooo`0200[o0140oooo00<0KOl0003o203o
ool0203oool00`00h?l0oooo0?ooo`050?ooo`<00?lf2@3oool4002:o`<0oooo0P00ogP00`3oool0
0?mh003oN002003oN0T0oooo1@00;Ol01000olX0oooo0?ooo`3oool2000Eo`/0oooo00<0B@3o03@0
o`0d0?l0200d0?l00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00070?ooo`03
0000003oool0oooo00L0oooo00<00?m?0?ooo`3oool02`3oool00`00oad0oooo0?ooo`060?ooo`05
003oFP3oool0oooo0?ooo`00odP0203oool00`0Co`00oooo003o/@080?ooo`0500[o003oool0oooo
0?ooo`00O_l00`3oool3003oH`0302ko003oool0oooo00H0oooo00<0COl00?ooo`00U?l0103oool3
003o9P/0oooo00<0NOl00?ooo`3oool00P3oool3003o00h0oooo00@0Q?l00?ooo`0:o`002_l00`3o
ool4003od`X0oooo0`00o`P00`3oool00>co0?ooo`030?ooo`<00>3o203oool00`00ocH0oooo003o
=P02003o=PH0oooo1000R_l40?ooo`03003oN000Jol0oooo0080oooo0P00Jol80?ooo`@002go00<0
01Go000]o`00;Ol00P00;Ol=0?ooo`80B@3o0P0d0?l00`190?l0oooo0?ooo`040?ooo`@0=03o1P3o
ool00`000000oooo0?ooo`030?ooo`001`3oool00`000000oooo0?ooo`070?ooo`03003oC`3oool0
oooo00/0oooo00<00?lM0?ooo`3oool02P3oool00`00odP0oooo0?ooo`060?ooo`0401?o0000ok40
0?na003o/@L0oooo00D02_l00?ooo`3oool0oooo001no`030?ooo`<00?mS00<0;_l00?ooo`3oool0
0`3oool01@00m_l0oooo0?ooo`3oool0COl000H0oooo00<00?lV0?ooo`3oool00`3oool2003oj@H0
oooo00<0NOl00?ooo`3oool00P3oool01P00o`000?nC003oT`00oi<0oooo003og`h0oooo00<02_l0
0?ooo`00ond00`00om<>0?ooo`800?l800@00>co0?ooo`3oool0oooo0`00h?l90?ooo`03002co`3o
ool00;?o00P0oooo00<008[o0?ooo`00R_l00`00R_l00`3oool006_o0?ooo`03001[o`/0oooo0P00
;Ol010005Ol00?nX000Eo`005Ol20?ooo`<002go2@3oool304T0o`800?Wo1`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00070?ooo`030000003oool0oooo01D0oooo00<0
0?lM0?ooo`3oool02P3oool00`00odP0oooo0?ooo`060?ooo`0301?o003oool00?na00L0oooo00<0
0<3o00[o003oool00P3oool00`00odT0oooo0?ooo`020?ooo`03003oH`3oool0oooo00@0oooo0`00
m_l20?ooo`0304go003oool0oooo0080oooo0`00of<01000obH0oooo0?ooo`3oool4003oj@/0oooo
0`00oi<4003og`d0oooo00<02_l0003ok@00ond00P00om<>0?ooo`@00>co0P3oool2003Po`030?oo
o`00h?l00>3o00L0oooo1`00/ol40?ooo`8008[o0P3oool2003oD@8008[o0P00Jol>0?ooo`<00?nX
00<001Go0?ooo`3oool03@3oool204T0o``00?Wo203oool00`000000oooo0?ooo`030?ooo`001`3o
ool00`000000oooo0?ooo`0E0?ooo`03003o7@3oool0oooo00X0oooo00<00?m80?ooo`00odH0203o
ool00`00ok40oooo0?ooo`040?ooo`800<3o00<02_l00030o`3oool00`00odT30?ooo`03003oH`3o
ool0oooo00@0oooo0P00m_l0103oool00?Ko0?ooo`1=o`040?ooo`800?mS00<0oooo003o9P3oool0
0`3oool2003oj@`0oooo0`00oi<00`3oool00?oO003og`0@0?ooo`04003ok@00om<00?o]003od`<0
oooo00<0;ol00?ooo`3oool0203oool00`00k?l0oooo0?ooo`02003/o`D0oooo0P00h?l00`00o`P0
oooo0?ooo`030?ooo`03002co`3oool0oooo00X0oooo0P00oe430?ooo`8008[o3P3oool7003oZ0h0
oooo00<0B@3o003io`00nOl01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo00070?ooo`030000003oool0oooo00h0oooo00<00?mJ0?ooo`3oool0403oool00`00odP0oooo
003oAP02003oAPH0oooo00<00?na0?ooo`3oool01P3oool01000`?l02_l00?ooo`3oool3003oB@<0
oooo00<00?mS0?ooo`3oool01@3oool2003fo`L0oooo0P00of<00`3oool00?lV0?ooo`040?ooo`03
003oj@1<o`00oooo00`0oooo00H00?nC0?ooo`3oool0oooo003og`3oool304go00h0oooo00@00?o]
003od`3oool0oooo0`0_o`0B0?ooo`800?l800<00>3o0?ooo`3oool04@3oool5003oDA00oooo00<0
0?nX0?ooo`00od`00`3oool3003oZ0d0oooo00<00?nZ0?l0f@3oool01@00ojX00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00070?ooo`030000003oool0oooo00d0oooo0`00oeX<
0?ooo`03003oE@3oool0oooo0080oooo00<00?m80?ooo`3oool00P00odH60?ooo`03003o/@3oool0
oooo0080oooo00<00?l;0?ooo`3oool00P3oool01000`?l0oooo0?ooo`3oool2003oB@<0oooo00<0
0?mS0?ooo`3oool00`3oool0100]o`00oooo0?ooo`00m_l80?ooo`03003oH`3oool0oooo00D0oooo
0`1<o`0=0?ooo`05003oT`3oool0oooo0?ooo`00oml00P1=o`0A0?ooo`03003od`3oool0;ol000<0
;ol0503oool2003o200304Go003oool0oooo0140oooo00@01Ol00?ooo`00oe400?mA3@3oool00`2m
0?l00?m<003oC007003oC0/0oooo00D00?nZ0?l0f@3o0=T0o`3I003oZP060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00`3oool000L0oooo00<000000?ooo`3oool03P3oool2003o
FP/0oooo0P00oeD70?ooo`03003oAP3oool0oooo00D0oooo00<00?na0?ooo`3oool00`00o`/40?oo
o`030030o`3oool0oooo0080oooo00D00?m90?ooo`3oool0oooo003oH`040?ooo`<0;Ol000<0oooo
003fo`3oool0203oool00`00of<0oooo0?ooo`040?ooo`<0C?l01@3oool00`1=o`00oooo0?ooo`06
0?ooo`03003oT`3oool0oooo00<0oooo00<0COl00?ooo`3oool00P3oool00`1]o`00oooo0?ooo`0:
0?ooo`03003od`3oool0oooo0080oooo00<0;ol006[o001Zo`004P3oool00`15o`000?l8003o200;
0?ooo`0305T0o`3oool0oooo0080oooo1005o`0=0?ooo`<0_@3o00<0oooo003oC000od`0403oool2
0?l0f@800?nZ00@0o`3I0?ooo`3oool0oooo0P00X_l20?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00`3oool000L0oooo00<000000?ooo`3oool03P3oool00`00oeX0oooo0?ooo`0:
0?ooo`<00?mE1P3oool01@00odH0oooo0?ooo`3oool00?nK00<0oooo00@00?na0?ooo`3oool0oooo
0`00o`/30?ooo`030030o`3oool0oooo0080oooo00<00?m90?ooo`3oool01`3oool0100]o`00oooo
0?ooo`00m_l50?ooo`05013o003oool0oooo0?ooo`00of<0203oool00`1<o`00oooo0?ooo`030?oo
o`80COl0203oool00`00oi<0oooo0?ooo`020?ooo`0304go003oool0oooo0080oooo0P1]o`0A0?oo
o`0302oo001Zo`00oooo00L0oooo0P001Ol80?ooo`@0AOl0203oool305T0o`D0oooo0P05o`000`00
okD01Ol000Go000200Go00P0oooo0P2m0?l0103oool0_@3o0?ooo`3oool2003lo`030?ooo`00o?l0
0?co00800?co2P3oool60?l0f@800:;o00D0ZP3o0?ooo`3oool0oooo000000090?ooo`030000003o
ool0oooo0080oooo00060?ooo`030000003oool0oooo00l0oooo00<00?mJ0?ooo`3oool02`3oool0
0`00oeD0oooo0?ooo`050?ooo`03003oAP3oool00?nK00800?nK203oool00`00o`/00>oo0?ooo`02
0?ooo`070030o`3oool0oooo0?ooo`00ocl00?m9003o?`060?ooo`03003o`03oool0;Ol000L0oooo
0`0@o`030?ooo`03003oH`3oool00?n100D0oooo00<0C?l00?ooo`3oool00`3oool204go00D0oooo
00<00?mF0?ooo`3oool01P3oool00`1=o`00oooo0?ooo`020?ooo`0506go003oool0oooo0?ooo`00
odH03`3oool206[o00<00?mA00<0oooo0005o`001Ol00P001Ol;0?ooo`03003oN015o`00AOl000D0
oooo0P1I0?l00`3oool0F@3o0?ooo`050?ooo`L00?ne1`3oool50;d0o`@00?co0P3oool204T0o`/0
oooo00<0o`3I002Ro`00X_l01P3o0=T20?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool000H0oooo00<000000?ooo`3oool03P3oool00`00oeX0oooo0?ooo`0<0?ooo`03003o
E@3oool0oooo00D0oooo00<00?m60?ooo`3oool00`00oi/60?ooo`03003o2`00kol00>oo00<0oooo
00<000000?ooo`3oool00P3oool00`00ocl00?m90?ooo`040?ooo`<00?o000<0oooo02go003oool0
1P3oool00`0@o`00oooo0?ooo`030?ooo`@00?n1103oool00`1<o`00oooo0?ooo`030?ooo`0304go
003oool0oooo0080oooo0`00oeH80?ooo`0304go003oool0oooo0080oooo00<0KOl0001Mo`00GOl0
0P00GOl20?ooo`03002ao`3oool0oooo00/0oooo00@0J_l0003oD@00oe40oooo10001Ol;0?ooo`80
0?mh00@005Go003oN000ogP00?mh0P3oool505T0o`D0oooo0`00okD30?ooo`8000co1`3oool00`2m
0?l0oooo0;d0o`050;d0o`80B@3o303oool00`2Z0?l0o`3I0?l0f@020?l0f@030:X0o`3oool0oooo
0080oooo103o0=T80?ooo`030000003oool0oooo0080oooo00060?ooo`030000003oool0oooo00h0
oooo00<00?mJ0?ooo`3oool02`3oool00`00oeD0oooo0?ooo`060?ooo`04003oAP3oool0oooo003o
V`P0oooo00H00?l;003_o`00kol00>oo0?ooo`0000040?ooo`03001No`00ocl00?m900D0oooo1000
ol000`0]o`00oooo0?ooo`020?ooo`04002Co`3oool0oooo013o00H0oooo0P00oh450?ooo`0304co
003oool0oooo0080oooo0`00[?l40?ooo`800?mF0`3oool00`00_ol0oooo0?ooo`080?ooo`@005go
00@00?m6002ao`00/Ol00;7o3@3oool01`00oe40oooo003oD@001Ol008go0?ooo`001Ol0303oool0
1000ogP005Go001Eo`00EOl40?ooo`0305T0o`3oool0F@3o0080F@3o00<0oooo003om03oool00P3o
ool00`003?l0oooo000<o`02000<o`T0oooo0P2m0?l3002co`030?ooo`190?l0B@3o00<0_@3o2`3o
ool00`2Z0?l005Go0?l0f@04001Eo`D0oooo00<000000?ooo`3o0=T00P3o0=T50?ooo`030000003o
ool0oooo0080oooo00060?ooo`030000003oool0oooo00h0oooo00<00?mJ0?ooo`3oool02`3oool0
0`00oeD0oooo0?ooo`060?ooo`04003oAP3oool0oooo003oV`P0oooo00H00?l;003_o`00kol00?oM
0?ooo`0000020?ooo`8005ko00<00?lo001No`3oool01P3oool2003o`0050?ooo`0]o`00oooo0?oo
o`00Tol00`00kol20?ooo`03013o003oool0oooo00<0oooo00<00?n10?ooo`3oool00P3oool4002d
o`<0oooo0`00[?l50?ooo`03003oEP3oool0oooo00@00;oo203oool4001Mo`030?ooo`00odH00;7o
00800;7o3P3oool01@00SOl000Go0005o`001Ol0oooo008000Go0`00ojL70?ooo`L005Go00<0oooo
05T0o`1I0?l00P3oool00`00oo@0F@3o05T0o`030?ooo`<000co3@3oool5002co`@0oooo0P2m0?l9
0?ooo`80ZP3o1000EOl00`3oool005Go001Eo`05001Eo`P0oooo00<000000?ooo`3oool00P3oool0
00H0oooo00<000000?ooo`3oool03P3oool00`00oeX0oooo0?ooo`0;0?ooo`03003oE@00ok`0oooo
00T0oooo00<00?nK0?ooo`3oool01P3oool00`00o`/00>oo003og@03003og@<0oooo00<005ko003o
?`3oool01`3oool00`00ol00oooo0?ooo`030?ooo`@00>oo0P3oool00`0@o`00oooo0?ooo`040?oo
o`03003oP@3oool0oooo0080oooo0P00]?l40?ooo`04002/o`3oool00:co002/o`D0oooo00<00?lk
0?ooo`3oool00P00_ol:0?ooo`<005go0P3oool2002ao`<00?mX3@3oool00`001Ol0oooo0?ooo`02
002=o`040?ooo`001Ol00?nW003oY`P0oooo0P00EOl90?ooo`<00?od0P1I0?l20?ooo`8000co3P3o
ool01000/ol0oooo003oC0190?l4002co``0oooo0P2Z0?l2001Eo`L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`001P3oool00`000000oooo0?ooo`060?ooo`03003o/@3o
ool0oooo00D0oooo00<00?mJ0?ooo`3oool02`3oool3003o_0P0oooo00<00?nK0?ooo`3oool01`3o
ool00`00o`/00>oo003og@03003og@@0oooo00<00?lo0?ooo`3oool00`3oool01000ob/0oooo0?oo
o`00ol050?ooo`@00>oo0P3oool00`0@o`00oooo0?ooo`030?ooo`03003o9P00oh40oooo00D0oooo
00@00;Co0?ooo`3oool0oooo0P00[?l00`3oool00:co0?ooo`040?ooo`<00?lk00<0oooo002oo`3o
ool0303oool2001Mo`80oooo0`00ofPC0?ooo`03003oY`001Ol000Go00800?nW00<0oooo04Go003o
ool03P3oool2003om0030?ooo`05o`000?od0080F@3o403oool5003oC0<0oooo0P00/ol;0?ooo`/0
0?nZ2@3oool00`000000oooo0?ooo`020?ooo`001P3oool00`000000oooo0?ooo`050?ooo`<00?na
3P3oool00`00og`0oooo0?ooo`030?ooo`<00?nl203oool01@00oi/0oooo0?ooo`3oool00?m900D0
oooo00<00>oo0?ooo`00omd00`00omd30?ooo`03001No`00ocl0oooo00<0oooo0P00ob/20?ooo`03
003o`03oool0oooo00@0oooo0P00kol80?ooo`<00?lV1P3oool00`00]?l0COl00?ooo`040?ooo`03
002/o`3oool0oooo00<0oooo0`00oc/20?ooo`04002oo`3oool0oooo06go00/0oooo00<005go0?oo
o`00ofP00P00ofP30?ooo`80J_l04@3oool010001Ol0AOl0003oY`00ojLB0?ooo`@01Ol00P00oo@?
0?ooo`800?m<0P3oool5003oC0`0oooo0P00ojX40?ooo`800?n[00<0oooo0000003oool0203oool0
0`000000oooo0?ooo`020?ooo`001P3oool00`000000oooo0?ooo`050?ooo`@00?na303oool2003o
O0D0oooo1000ok`30?ooo`05003oV`3oool0oooo0?ooo`00oi/00P3oool3003oB@@0oooo00L00>oo
0?ooo`3oool0oooo003og@0000000?lo0080oooo00<005ko0?ooo`3oool00`3oool3003o:`030?oo
o`00ol00oooo00D0oooo00<04?l0002Co`00kol0203oool2003o9PH0oooo0`1=o`050?ooo`03002/
o`3oool0oooo00@0oooo00<00?lk0?ooo`3oool00`3oool206go00/0oooo00D005go0?ooo`3oool0
oooo003oJ0020?ooo`80J_l04`3oool204Go0003003oY`3oool0;ol00100oooo00D01Ol00?ooo`00
o`D00?l50?ooo`0200Go00l0oooo00<00?m@0?ooo`00oe000`00oe0<0?ooo`L00?n[00@005So0?oo
o`3oool000002@3oool00`000000oooo0?ooo`020?ooo`001P3oool00`000000oooo0?ooo`060?oo
o`800?na303oool4003oO0D0oooo00<00?nl0?ooo`3oool00P3oool2003oV`L0oooo00@00?m90?oo
o`3oool00?oe0P3oool01@00kol0oooo0?ooo`3oool00?oM00<00?lo00<0oooo001No`3oool0103o
ool00`00oi<00?l[0?ooo`070?ooo`<04?l000<00>oo0?ooo`3oool00`3oool01@00oc/0oooo0?oo
o`3oool00?lV00H0oooo0P1=o`060?ooo`0300[o0000[?l0oooo00D0oooo00<00?lk0?ooo`3oool0
0`3oool00`1]o`00oooo0?ooo`020?ooo`80>?l01P3oool01@00GOl0oooo0?ooo`3oool00?mX00<0
oooo00<0J_l00?ooo`3oool00P15o`0@0?ooo`80AOl00P0_o`0@0?ooo`L00?l5303oool4003oD080
oooo0P00/Ol<0?ooo`<00?n[00<0oooo001Ho`00F?l0103oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo00060?ooo`030000003oool0oooo00H0oooo00<00?na0?ooo`3oool0
303oool00`00og`0oooo0?ooo`060?ooo`03003o_03oool0oooo00@00?nK1P3oool01000odT00?oe
003om@00ooD60?ooo`03003og@00ocl00?lo0080oooo00<005ko0?ooo`3oool00P3oool2003oT`03
003o:`3oool0oooo00@0oooo00@00=oo0?ooo`3oool04?l00P3oool01000kol0oooo0?ooo`3oool3
003o>`80oooo00@00?lV0?ooo`3oool00?oO103oool00`1=o`00oooo0?ooo`030?ooo`<02_l000L0
0:co0?ooo`3oool0oooo003o/`3oool00?lk00H0oooo00<0KOl00?ooo`3oool00P0ho`030?ooo`80
0?nP1`3oool01P00ofP0oooo0?ooo`3oool0J_l00?ooo`80AOl000<0oooo003oZ000ojP03`3oool2
04Go00<0;ol03P3oool00`00o`D00?co003lo`04003lo``0oooo0P00oe03002ao`d0oooo0`00F?l2
08`0o`H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`001@3oool00`00
0000oooo0?ooo`060?ooo`03003o/@3oool0oooo00d0oooo00<00?ml0?ooo`3oool01P3oool01@00
ok`0oooo0?ooo`3oool00?nK00P0oooo00<00?m90?ooo`00ooD00P00ooD50?ooo`03002>o`00omd0
0?lo00P0oooo00<00?nC003o:`3oool0103oool4003Oo`04013o003oool0oooo003_o`@0oooo00<0
0?lk0?ooo`3oool00P3oool01000obH00?oO003og`00oml40?ooo`0304go003oool0oooo00<0oooo
00<02_l00?ooo`3oool00P3oool3003o/`030?ooo`00oc/0oooo00@0oooo00<0KOl00?ooo`3oool0
0P3oool00`0ho`00oooo0?ooo`03003oX0/0oooo00@0J_l00?ooo`3oool0AOl00`00ojP?0?ooo`H0
0?o:1P3oool2000do`D0oooo0`00o?l=0?ooo`80:03o0`00/Ol?0?ooo`03001Ho`2<0?l0S03o0080
S03o1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0040oooo00050?ooo`030000
003oool0oooo00H0oooo00<00?na0?ooo`3oool03@3oool00`00og`0oooo0?ooo`060?ooo`05003o
_03oool0oooo0?ooo`00oi/0203oool00`00odT0oooo003om@080?ooo`03003og@00S_l008ko00L0
oooo00<00?nC003o:`3oool01@3oool2003Oo`030?ooo`0@o`00oooo0080oooo00D00>oo0?ooo`3o
ool0oooo003o>`040?ooo`03003o9P3oool00?oO00D0oooo00<0COl00?ooo`3oool0103oool00`0:
o`00oooo0?ooo`020?ooo`03003o/`3oool0oooo00L0oooo00D0KOl00?ooo`3oool0oooo03So0003
0?ooo`800?nP3`3oool00`15o`000?nX0?ooo`02003oZ080oooo0P00R_l:0?ooo`800?o:1`3oool4
000do`H0oooo00<00?co0?ooo`3oool02P3oool402P0o`030?ooo`00/Ol00;7o0100oooo1@2<0?l6
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00@3oool000D0oooo00<000000?oo
o`3oool01P3oool00`00ok40oooo0?ooo`0=0?ooo`03003oO03oool0oooo00H0oooo00D00?nl0?oo
o`3oool0oooo003oV`080?ooo`03003oB@3oool00?oe00P0oooo00<00?oM002>o`3oool01`3oool0
0`00oi<00?l[0?ooo`050?ooo`04003Oo`3oool0oooo013o00L0oooo00<00?lk0?ooo`3oool0103o
ool00`00oml0oooo0?ooo`030?ooo`0304go003oool0oooo00@0oooo00<02_l00?ooo`3oool00`3o
ool00`00ok<0oooo0?ooo`0;0?ooo`0303So003oool0oooo0080oooo00<00=Go0?ooo`3oool04@3o
ool2002:o`030?ooo`00R_l0oooo0180oooo1000=?lC0?ooo`D0:03o00<00?o:0?ooo`3oool0403o
ool00`2<0?l0oooo08`0o`0508`0o`80oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`010?ooo`001@3oool00`000000oooo0?ooo`060?ooo`03003o/@3oool0oooo00`0oooo00<00?ml
0?ooo`3oool01`3oool01@00ok`0oooo0?ooo`3oool00?nK00P0oooo00<00?m90?ooo`00ooD0203o
ool00`00ocl0oooo0?ooo`070?ooo`03003oT`00ob/0oooo00D0oooo00@00=oo0?ooo`3oool04?l0
1`3oool00`00oc/0oooo0?ooo`050?ooo`03003og`3oool0oooo00T0oooo0`00ond30?ooo`03003o
/`3oool0oooo00h0oooo0`00eOlC0?ooo`@008[o4`3oool2000do`050?ooo`00=?l003Co0?ooo`00
ogP04@3oool0100X0?l00?o:02P0o`00olX202P0oa40oooo0P2<0?l3003Io`<0oooo0`2<0?l90?oo
o`030000003oool0oooo0040oooo00050?ooo`030000003oool0oooo00H0oooo00<00?na0?ooo`3o
ool0303oool00`00og`0oooo0?ooo`0:0?ooo`03003oV`3oool0oooo00L0oooo00<00?m9003om@3o
ool0203oool01@00ocl0oooo0?ooo`3oool00?nX00D0oooo00<00?nC0?ooo`3oool01@3oool00`00
gol0oooo0?ooo`060?ooo`800?o000<00?lk0?ooo`3oool01@3oool00`00oml0oooo0?ooo`090?oo
o`<00?o]503oool3003Eo`@0oooo00<00?l80?ooo`3oool03@3oool3002:o`80oooo0`00ocH?0?oo
o`8003Co00@0oooo003oN000=?l003Co4@3oool202P0o`@00?o:0`0X0?l>0?ooo`<00=Wo0P3oool6
003Io`80S03o1`3oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`060?oo
o`03003o/@3oool0oooo00H0oooo00<00?nl0?ooo`3oool00`3oool00`00og`0oooo0?ooo`0:0?oo
o`04003oV`3oool0oooo003oY`L0oooo00<00?oe0?ooo`3oool00P3oool00`00of<0oooo0?ooo`02
0?ooo`04003o?`3oool0oooo0?ooo`<00?nX0`3oool00`00oi<0oooo0?ooo`030?ooo`03003o9P3o
ool00=oo00L0oooo0`00ol080?ooo`03003o003oool0oooo00T0oooo0`00ond50?ooo`<02_l0303o
ool3003Eo`<0oooo0`00o`P>0?ooo`8008[o00<0oooo002:o`3oool00P00ocHD0?ooo`800?mh0P00
=?lA0?ooo`800?o:0P00o`P3003obP80:03o303oool00`00ofD00=Wo003oI@07003oI@030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00@3oool000D0oooo00<000000?ooo`3oool03P3oool2
003o_0d0oooo00<00?na0?ooo`3oool00P3oool00`00oi/0oooo003oY`02003oY`80oooo00D00?o/
0?ooo`3oool0oooo003om@030?ooo`800?mS00D0oooo002/o`3oool0oooo002>o`020?ooo`<00?nX
00<00?n30?ooo`3oool01P3oool2003o9P030?ooo`00gol0oooo00D0oooo00@00?lS003o`000ol00
0?o01`3oool3003o00H0oooo00@0;ol00?ooo`3oool0oooo0`00ond50?ooo`802_l01@3oool206[o
00T0oooo00<00=Go0?ooo`3oool01000o`P20?ooo`80Q?l03@3oool00`00R_l00?lf0?ooo`02003o
=P80M_l04P3oool01014o`000?mh000do`00=?lA0?ooo`03003o2000og@0oooo00800?l80P00olX=
0?ooo`800?mU0`00ol/01@000?l0oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00@3o
ool000D0oooo00<000000?ooo`3oool03@3oool4003o_0X0oooo0`00ok460?ooo`<00?nW00<0oooo
003ok000on`01P3oool4003oH`04002/o`3oool0oooo002>o`80oooo0`00ojP00`00oh<0oooo0?oo
o`050?ooo`04003ok@00obH00?lV003o9P@0oooo00<007go0?ooo`00ob<00P00ob<00`3oool00?o0
0?ooo`030?ooo`03003oT@3oool0oooo00800?l000<0oooo002oo`3oool00`3oool302oo00@0oooo
00<00?o]003oAP3oool00`3oool00`00jol02_l00?ooo`040?ooo`80J_l0103oool00`00oa40oooo
0?ooo`020?ooo`03003oo`00eOl0oooo00<0oooo00<00?l80?ooo`3oool00P24o`020?ooo`<01Ol0
00<0oooo003io`3oool01P3oool2002:o`80oooo00<00?lf07Ko001fo`000`00o`D00`00fOl0oooo
0?ooo`0<0?ooo`0404Co0000oc000?mh003oN080A?l03P3oool4003oM0030?ooo`00F?l005So00/0
oooo00@0003o003ob`00ol/00?o;0P000?l50?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00@3oool000D0oooo00<000000?ooo`3oool03P3oool3003o_0/0oooo0`00ok460?ooo`03
003oY`3oool0oooo00<00?o/1`3oool01P00of<00:co002/o`00[?l0oooo00000080oooo00<002_o
003oZ000oh<00P00oh<50?ooo`<00?o]00@00?lV0?ooo`3oool0oooo1000OOl01@3oool00?lS0?oo
o`3oool00?o000<0oooo0`00oi420?ooo`03003o0000_ol00;oo00800;oo0`3oool00`0_o`00oooo
0?ooo`020?ooo`800?m600@00?o]003oAP3oool0oooo0P00jol00`0:o`00oooo0?ooo`040?ooo`04
06[o003oool0oooo0?ooo`<00?lA0P3oool3003oo`03003Eo`3oool0oooo0080oooo00@00?l80?oo
o`3oool0Q?l00P3oool200Go00030?ooo`00nOl00?Wo00800?Wo1`3oool01@00R_l0oooo0?ooo`00
ocH0oooo0080M_l000<00?l50?ooo`00fOl03P3oool2003o<0050?ooo`00oc000?l`003o<000X_l0
303oool2003oM0<005So3@3oool01@000?l0oooo003ob`00ol/0o`1_00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`0>0?ooo`03003o
_03oool0oooo00/0oooo00<00?na0?ooo`3oool01P3oool00`00ojL0oooo0?ooo`02003ok0P0oooo
00<00?mS002/o`00[?l00P3oool01`000000oooo0?ooo`3oool002_o003oZ000:ol01`3oool2003o
k@03003o9P3oool0oooo0080oooo0P00OOl00`3oool007go003o8`020?ooo`03003o`03oool0oooo
0080oooo00<00?nA0?ooo`3oool00P3oool00`00o`000;oo002oo`040?ooo`0302oo003oool0oooo
00<0oooo00<00?m6003ok@3oool00P3oool2003[o`030?ooo`0:o`00oooo00@0oooo00<0J_l00?oo
o`3oool00`3oool00`00oa40oooo003oo`02003oo`80oooo00<00=Go0?ooo`3oool00P3oool01000
o`P0oooo0?ooo`24o`030?ooo`0300Go0000nOl00?Wo00800?Wo3P3oool00`00fOl00?l5003o1@02
003Io`d0oooo0`00X_l;0?ooo`80o`3K0P3oool3001Ho`l0oooo0P000?l30?l0K`H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`0?0?oo
o`03003o_03oool0oooo00/0oooo00<00?na0?ooo`3oool01P3oool01000ojL0oooo0?ooo`00on`8
0?ooo`03003oH`3oool00:co0080oooo00<000000?ooo`3oool00`3oool00`00ojP0oooo0?ooo`07
0?ooo`03003ok@00obH0oooo00@0oooo0P00OOl01@3oool00?lS0?ooo`3oool00?o000@0oooo00<0
0?nA0?ooo`3oool00P3oool00`00o`000;oo0?ooo`050?ooo`0302oo003oool0oooo00<0oooo00<0
0?m6003ok@3oool00P3oool00`00jol0oooo00[o00060?ooo`0306[o003oool0oooo0080oooo00<0
0?lA0?ooo`3oool00P00ool;0?ooo`0608Co003oool0oooo0?ooo`05o`000?Wo0P3oool00`00nOl0
oooo0?ooo`0<0?ooo`03003Io`3oool0oooo00@0oooo0P2m0?l90?ooo`03002Ro`3oool0oooo00P0
oooo103o0=/30?ooo`8005So3`3oool20?l0K`030000o`3oool0o`1_00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`0?0?ooo`03003o
_03oool0oooo00/0oooo00<00?na0?ooo`3oool01P3oool01000ojL0oooo0?ooo`00on`80?ooo`03
003oH`00[?l0oooo0080oooo00<000000?ooo`3oool00P3oool00`00:ol00?nX0?ooo`070?ooo`03
003ok@3oool00?lV00D0oooo00@007go0?ooo`3oool00?lS0`3oool01@00ol00oooo0?ooo`3oool0
0?nA00@0oooo00<00?l00?ooo`00_ol01@3oool00`0_o`00oooo0?ooo`030?ooo`03003oAP3oool0
oooo00<0oooo00<00>_o0?ooo`0:o`001@3oool00`1Zo`00oooo0?ooo`030?ooo`05003o4@3oool0
oooo0?ooo`00ool0403oool205`0oa@0oooo0P2m0?l00`3oool0_@3o0?ooo`0C0?ooo`D0o`3K0P00
JolA0?ooo`030?l0K`3oool0o`1_00<0o`1_1@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0040oooo00040?ooo`030000003oool0oooo00l0oooo00<00?nl0?ooo`3oool02`3oool0
0`00ok40oooo0?ooo`060?ooo`04003oY`3oool0oooo003ok0P0oooo00<00?mS002/o`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`03003oP`00ojP0oooo00L0oooo00<00?o]0?ooo`00obH01@3o
ool01000OOl0oooo0?ooo`00ob<30?ooo`05003o`03oool0oooo0?ooo`00oi40103oool00`00o`00
oooo002oo`050?ooo`0302oo003oool0oooo00<0oooo00<00?m60?ooo`3oool00`3oool00`00jol0
oooo0?ooo`060?ooo`@00`3o503oool205`0o`030?ooo`1L0?l0oooo01<0oooo0`2m0?l01@3oool0
_@3o0?ooo`3oool00<3o0100oooo00<0o`3K0?ooo`3oool00`3o0=/00`00Jol0oooo0?ooo`0?0?oo
o`040?l0K`003?l000co0?ooo`@0o`1_0`3oool00`000000oooo0?ooo`080?ooo`4000000@3oool1
0?ooo`00103oool00`000000oooo0?ooo`0?0?ooo`03003o_03oool0oooo00X0oooo00<00?na0?oo
o`3oool01`3oool00`00ojL0oooo003ok0090?ooo`03003oH`00[?l0oooo0080oooo00<000000?oo
o`3oool00P3oool00`00oh<00?nX0?ooo`070?ooo`03003ok@3oool00?lV00D0oooo00@007go0?oo
o`3oool00?lS1`3oool00`00oi40oooo0?ooo`040?ooo`04002oo`3oool0oooo0?ooo`<004_o503o
ool200<0o`030?ooo`030?l0oooo00<0oooo00<00?ni0?ooo`3oool03@3oool305`0o`030?ooo`1L
0?l0oooo00@00?od3P3oool00`2m0?l0oooo0?ooo`020;d0o`<00<3o4@3oool30?l0f`8006_o0P3o
0=/A0?ooo`040?l0K`003?l0o`1_0?l0K`8000co00H0oooo0?l0K`3o06l0o`1_0?ooo`0000090?oo
o`4000000@3oool10?ooo`00103oool00`000000oooo0?ooo`0>0?ooo`03003o_03oool0oooo00/0
oooo00<00?na0?ooo`3oool01`3oool00`00ojL0oooo003ok0090?ooo`06003oH`3oool0oooo0030
o`3oool00000103oool00`00oh<0oooo0?ooo`030?ooo`05003oR03oool0oooo0?ooo`00ond01@3o
ool3002>o`T0oooo00<00?n10?ooo`3oool0203oool4001;o`L0oooo0P00oi450?ooo`0303So003o
ool0oooo00<0oooo00<00`3o0?ooo`030?l00P030?l30?ooo`<00?ni103oool00`15o`00oooo0?oo
o`070?ooo`@0G03o00<0oooo003om000oo@00P00oo@0103oool0;ol002oo000_o`0;0?ooo`D0_@3o
0P00`?l3003o1@h0oooo00D0o`3K0?ooo`3oool006_o003oD002001[o`80o`3K3`3oool20?l0K`80
00co0P00oj/4000<o`<0o`1_203oool100000040oooo0@3oool000@0oooo00<000000?ooo`3oool0
3P3oool00`00ok`0oooo0?ooo`060?ooo`03003og@3oool0oooo0080oooo00<00?na0?ooo`00h?l0
1@3oool01@00ooD0oooo0?ooo`3oool00?o/00<0oooo00<00?nX0?ooo`3oool00P00^ol00`3oool0
0:co0?ooo`030030o`0300000000oi<004_o0080oooo00<002_o0?ooo`3oool00P3oool2003oR0L0
oooo00<00;Co002>o`00S_l00P00S_l60?ooo`03003oJ03oool00?n100800?n10`3oool01P00ond0
oooo0?ooo`3oool02_l00?ooo`D004_o00<00?l80?ooo`3oool00P3oool3003oT@D0oooo0P0ho`05
0?ooo`0700<0o`3oool00`3o00<0o`3oool00?mX0?ooo`03003o^@@0oooo0P15o`030?ooo`80M_l0
0P3oool01@00od`0G03o05`0o`3oool0G03o0080oooo0`00oo@00`3oool0;ol002oo00020?ooo`80
Ool00P3oool00`00oe00oooo0?ooo`030?ooo`050;d0o`3oool0oooo0?ooo`00`?l00P2m0?l20030
o`04003o1@1Mo`00GOl0003oM0h0oooo0P00Jol4003oD080o`3K00<00?nb0?ooo`3oool02`3oool0
0`00ocl00?n[003o?`02003o?`@00?n[0`003?l20?l0K`H0oooo0@0000010?ooo`40oooo00040?oo
o`030000003oool0oooo00H0oooo00<00>_o0?ooo`3oool01@3oool00`00ok`0oooo0?ooo`050?oo
o`800?oM1@3oool3003Po`<0oooo0P00ooD60?ooo`<00?nX0`00^ol30?ooo`<00<3o0P00oi<00`00
Bol0oooo0?ooo`050?ooo`<00?n81@3oool2002do`D008ko103oool3003oJ0<00?n100<0oooo003o
k@00ond00P00ond01@3oool02_l000[o000:o`00oooo00<004_o00@0oooo003o2000o`P00?l80P3o
ool3003oT@03003oX03oool0oooo0080oooo0P0ho`040?ooo`0504Go00030?l00`3o0?ooo`030?l0
0`00ofP3003o^@@0oooo0P15o`030?ooo`80M_l000@0oooo003oC000od`00?m<0`3oool0101L0?l0
oooo0?ooo`3oool2003om0070?ooo`0_o`00;ol002oo003oool0Ool00?ooo`03003oD0/0oooo00D0
_@3o0?ooo`00`?l00<3o003o1@0205go00<00?md3@3oool201[o0003003o/P0Jo`000?m@0080o`3K
2`3oool2003jo`800?lo1`3oool00`000000oooo0?ooo`070?ooo`4000000@3oool10?ooo`00103o
ool00`000000oooo0?ooo`050?ooo`<00>_o3@3oool4003og@<0oooo1000h?l20?ooo`@00?oe1@3o
ool4003oZ0<00;_o0P3oool40030o`800?nC00<004_o0?ooo`3oool0103oool3003oR0H0oooo0P00
]?l2002>o`L0oooo00@00?mX0?ooo`3oool00?n10`3oool2003ok@<0oooo00<02_l00?ooo`3oool0
0P3oool01000Bol0oooo003o2000o`P40?ooo`03003oX000oi40oooo00D0oooo00<0>?l00?ooo`3o
ool00`3oool01P15o`00oooo0?ooo`3oool00`3o003oJ0@0oooo00<00?ni0?ooo`3oool00`3oool0
1P15o`00oooo0?ooo`3oool0M_l00?ooo`<00?m<103oool205`0o`<0oooo00H00?od0?ooo`3oool0
oooo02oo003oool207oo00@00?m@2P3oool20;d0o`040?ooo`00`?l00<3o003o1@80GOl03P3oool2
003o/Q00oooo0`00n_l80?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`40oooo00040?oo
o`030000003oool0oooo00@0oooo1@00jol=0?ooo`<00?oM103oool3003Po`<0oooo00<00?oe0?oo
o`3oool01P3oool01000ojP0oooo0?ooo`00^ol60?ooo`030030o`0000000?nC00T0oooo00<00?n8
0?ooo`3oool01@3oool01@00]?l0oooo0?ooo`00oc/008ko00H0oooo00@00?mX0?ooo`3oool00?n1
103oool01@00ond0oooo0?ooo`3oool02_l000D0oooo00<004_o003o203oool01@3oool00`00oj00
0?nA0?ooo`040?ooo`0303So003oool0oooo00@0oooo00H0AOl00?ooo`3oool0oooo00<0o`00ofP4
0?ooo`03003o^@3oool0oooo0080oooo00<0AOl00?ooo`3oool00P3oool01@1fo`00oooo0?ooo`3o
ool00?m<00D0oooo00D0G03o0?ooo`3oool0oooo003om0030?ooo`0402oo003oool0oooo07oo00l0
oooo00<0_@3o0?ooo`3oool04P3oool00`00ok80oooo0?ooo`0?0?ooo`800?[o203oool00`000000
oooo0?ooo`070?ooo`4000000@3oool10?ooo`000`3oool00`000000oooo0?ooo`070?ooo`800>_o
3P3oool00`00omd0oooo0?ooo`050?ooo`03003Po`3oool0oooo0080oooo00<00?oe0?ooo`3oool0
1P3oool01000ojP0oooo0?ooo`00^ol60?ooo`030030o`0000000?nC00P0oooo00<00?oC003oR03o
ool01P3oool01@00]?l0oooo003o>`3oool008ko00H0oooo00D00?mX0?ooo`3oool0oooo003oP@02
0?ooo`03003ok@3oool0oooo00<0oooo00<02_l00?ooo`3oool00P3oool00`00Bol0oooo003o2005
0?ooo`03003oX000oi40oooo00D0oooo00<0>?l00?ooo`3oool00`3oool00`15o`00oooo0?ooo`02
0?ooo`0300<0o`3oool0oooo0080oooo00<00?ni0?ooo`3oool00`3oool00`15o`00oooo0?ooo`02
0?ooo`0307Ko003oool0oooo00L0oooo00D0G03o0?ooo`3oool0oooo003om0160?ooo`030000003o
ool0oooo00L0oooo0@0000010?ooo`40oooo00030?ooo`030000003oool0oooo00L0oooo00<00>_o
0?ooo`3oool03@3oool00`00omd0oooo0?ooo`050?ooo`05003Po`3oool0oooo0?ooo`00ooD0203o
ool01000ojP0oooo0?ooo`00^ol70?ooo`030030o`00oi<004_o00P0oooo00<00?oC003oR03oool0
1P3oool00`00]?l0oooo003o>`020?ooo`03002>o`3oool0oooo00<0oooo00D00?mX0?ooo`3oool0
oooo003oP@020?ooo`03003ok@3oool0oooo00<0oooo00<02_l00?ooo`3oool00`3oool00`00Bol0
0?l80?ooo`040?ooo`03003oX03oool00?nA00D0oooo00<0>?l00?ooo`3oool00`3oool00`15o`00
oooo0?ooo`030?ooo`0300<0o`3oool0oooo0080oooo00<00?ni0?ooo`3oool0E@3oool00`3]0?l0
oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`40oooo00030?ooo`030000
003oool0oooo00L0oooo00<00>_o0?ooo`3oool0303oool00`00omd0oooo0?ooo`060?ooo`05003P
o`3oool0oooo0?ooo`00ooD0203oool01000ojP0oooo0?ooo`00^ol70?ooo`030030o`00oi<004_o
00P0oooo00<00?oC003oR03oool01@3oool01000]?l0oooo0?ooo`00oc/20?ooo`03002>o`3oool0
oooo00<0oooo00D00?mX0?ooo`3oool0oooo003oP@020?ooo`03003ok@3oool0oooo00<0oooo00<0
2_l00?ooo`3oool00`3oool00`00Bol00?l80?ooo`060?ooo`03003oT@3oool0oooo03`0oooo0P0X
0?lE0?ooo`80Q`3o5@3oool30>d0o`H0oooo00<000000?ooo`3oool01`3oool100000040oooo0@3o
ool000<0oooo00<000000?ooo`3oool01P3oool00`00jol0oooo0?ooo`0=0?ooo`03003og@3oool0
oooo00H0oooo00D00>3o0?ooo`3oool0oooo003om@080?ooo`04003oZ03oool0oooo002ko`P0oooo
00<00<3o0?ooo`3oool00`3oool01P0G0?l0oooo0?ooo`3oool00?oC003oR0H0oooo00@00;Co0?oo
o`3oool00?lk0`3oool00`00S_l0oooo0?ooo`020?ooo`05003oJ03oool0oooo0?ooo`00oh400P3o
ool00`00ond0oooo0?ooo`030?ooo`0300[o003oool0oooo00@0oooo00<004_o0?ooo`3oool0;@3o
ool00`00;Ol0oooo0?ooo`0B0?ooo`@0:03o4`3oool208L0o`040?ooo`270?l0oooo003loa40oooo
0`3]0?l00`3oool00:;o0>d0o`050?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`40oooo
00030?ooo`030000003oool0oooo00H0oooo00<00>_o0?ooo`3oool03@3oool00`00omd0oooo0?oo
o`060?ooo`05003Po`3oool0oooo0?ooo`00ooD0203oool00`00ojP0oooo002ko`070?ooo`03001M
o`3oool00<3o00@0oooo0`0G0?l20?ooo`03003od`00ohP0oooo00<0oooo00<00=Go0?ooo`00]?l0
0P3oool01@00oc/0oooo001Bo`00D_l008ko00P0oooo00<00?ni0?ooo`3oool0103oool00`00/Ol0
oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00/0oooo0`00MolD0?ooo`<002go0`3oool3003oN0h0
oooo100X0?l3003o]A00oooo1@270?l00`00o?l06_l00?ooo`0@0?ooo`D0k@3o00<0oooo003o?`00
ocl00P3oool00`000000oooo0?ooo`070?ooo`4000000@3oool10?ooo`000`3oool00`000000oooo
0?ooo`060?ooo`03003[o`3oool0oooo00d0oooo00<00?oM0?ooo`3oool01P3oool01000h?l0oooo
0?ooo`00ooD80?ooo`04002ko`00ojP0oooo002ko`@0oooo00H00?o0001Mo`00GOl005go0?ooo`00
`?l30?ooo`<05`3o00D00?oC01L0o`3oool0oooo003oR0030?ooo`03003Eo`00oh40oooo00@0oooo
1000D_l00`00ofP00=oo0?ooo`040?ooo`800?ni0`3oool01000oeH0oooo002ao`00/Ol40?ooo`04
003o203oool0oooo0?ooo`<00;Co00<00?mA0?ooo`3oool00P3oool00`00ool00?m60?ooo`050?oo
o`0304Go003oool0oooo00<0oooo1000Mol2003oa`80oooo0`00oe430?ooo`0307Ko003oool0oooo
0080oooo00D0A?l00?ooo`3oool00?nZ0?ooo`04000]o`80oooo0P00ogP20?ooo`80Ool000D0oooo
05go001Mo`00oooo003oZ`060?ooo`0402P0o`3oool0:03o02P0o`<00?ne0`1Mo`0204co00`0oooo
00<0Q`3o0?ooo`270?l00P270?l00`00o?l06_l00?ooo`0301?o00`0oooo103]0?l01`00X_l0k@3o
0>d0o`3]0?l00:;o003o?`0000002P3oool100000040oooo00030?ooo`030000003oool0oooo00H0
oooo00<00>_o0?ooo`3oool0303oool00`00omd0oooo0?ooo`060?ooo`05003_o`00h?l0oooo0?oo
o`00ooD00`3oool00`00m_l0oooo0?ooo`03002ko`03003oZ03oool0oooo00<0oooo0P00ol04001M
o`050000003oool0oooo0?ooo`00m_l00`00om<60?ooo`04003Eo`00oh400?n1003oP@@0oooo0`00
D_l00`00ofP00=oo003Oo`02003Oo`<0oooo0`00okT0103oool00?mF003oEP3oool3002ao`80oooo
0`00o`P00`3oool00;Co002do`02002do`800?mA0P3oool01000ool00?m6003oAP00odH40?ooo`<0
AOl00`3oool00`05o`0007Oo001go`02001go`<00?o700<0oooo003oD@00oe40103oool207Ko0080
oooo0`14o`03003oZP04000]o`3oool002go000]o`80oooo0`00ogP0103oool0Ool007oo003oool3
05go00<00?n[1@3oool202P0o`030?ooo`0X0?l00?ne00<00?ne0`1Mo`04003ob`P0oooo0P270?l0
0`3oool00?co0?ooo`0308L0o`03003lo`0Jo`006_l000`0oooo00@00:[o0>d0o`00X_l00:;o103o
ool40>d0o`T0oooo0@0000010?ooo`000`3oool00`000000oooo0?ooo`060?ooo`03003[o`3oool0
oooo00H0oooo00<00>3o0?ooo`3oool00`3oool00`00omd0oooo0?ooo`040?ooo`<00>oo00<00>3o
0?ooo`3oool00`3oool2003fo`<0oooo0`00^ol50?ooo`<00?o00P00GOl0103oool000000?ooo`3o
ool4003fo`800?oC1P3oool4003oP@@0oooo00<005;o0?ooo`3oool01000gol40?ooo`03003o^@3o
ool0oooo00<00?mF00<0oooo002ao`3oool00`3oool00`00o`P0oooo0?ooo`04002do`03003oD@3o
ool0oooo0080oooo0`00odH50?ooo`0304Go003oool0oooo00<0oooo00@01Ol0001go`3oool007Oo
0P00olL20?ooo`800?mA1@3oool00`1fo`00oooo0?ooo`020?ooo`0404Co003oool00?nZ003oZP80
02go00<0oooo000]o`3oool00`3oool01@00ogP0oooo0?ooo`3oool0Ool00080oooo0P1Mo`03003o
Z`@0oooo00D0:03o0?ooo`3oool0oooo02P0o`030?ooo`800?ne00@0oooo05go001Mo`00C?l03P3o
ool00`00n_l04ol00?ooo`0208L0o`03003lo`3oool0oooo00X0oooo0P00Z_l2003o?`L0oooo00<0
00000>d0o`3]0?l01`3oool100000040oooo00030?ooo`030000003oool0oooo00H0oooo00<00>_o
0?ooo`3oool0103oool3003Po`d0oooo0`00kol40?ooo`@00?Ko0P3oool00`00^ol0oooo0?ooo`06
0?ooo`800?o00`3oool00`000000oooo0?ooo`04003fo`P0oooo00<00=Go003oP@3oool01@3oool0
0`00D_l0oooo0?ooo`04003Oo`<0oooo00<00?ni0?ooo`3oool00P3oool00`00oeH0oooo002ao`05
0?ooo`04003o203oool0oooo0?ooo`800;Co00<0oooo003oD@3oool0103oool00`00ool00?m60?oo
o`040?ooo`0304Go003oool0oooo00@0oooo0P00Mol00`3oool007Oo003oa`040?ooo`03003oD@3o
ool0oooo00<0oooo00D0M_l00?ooo`3oool0oooo04Co00030?ooo`05003oZP3oool0oooo0?ooo`00
;Ol0103oool01@00ogP0oooo0?ooo`3oool0Ool000<0oooo00<0GOl00?ooo`3oool02@3oool202P0
o`<0oooo00<00?ne0?ooo`3oool0503oool208L0o``0oooo0P00Z_l80?ooo`030000003oool0oooo
00L0oooo0@0000010?ooo`000`3oool00`000000oooo0?ooo`0>0?ooo`<00>3o303oool00`00kol0
oooo0?ooo`050?ooo`<00?Ko0P3oool00`00^ol0oooo0?ooo`060?ooo`05003o`000GOl0oooo0?oo
o`0000000`3oool2003fo`0301L0o`00om<0oooo00L0oooo00<00=Go003oP@3oool01@3oool00`00
D_l0oooo003oJ0020?ooo`03003Oo`3oool0oooo0080oooo00<00?ni0?ooo`3oool00P3oool00`00
oeH0oooo002ao`050?ooo`03003o203oool0oooo00<0oooo00<00;Co003oD@3oool0103oool00`00
ool00?m60?ooo`050?ooo`0304Go003oool0oooo00<0oooo00D01Ol00?ooo`3oool0oooo001go`05
0?ooo`03003oD@3oool0oooo0080oooo00<0M_l00?ooo`3oool00P3oool00`14o`00oooo0?ooo`05
0?ooo`03000]o`3oool0oooo0080oooo00D00?mh0?ooo`3oool0oooo07oo000@0?ooo`0302P0o`3o
ool0oooo02l0oooo00<000000?ooo`3oool01`3oool100000040oooo00020?ooo`030000003oool0
oooo00l0oooo00<00>3o0?ooo`3oool0303oool00`00kol0oooo0?ooo`060?ooo`04003fo`3oool0
oooo002ko`T0oooo00D00?o0001Mo`3oool0oooo000000040?ooo`03003fo`00om<0oooo00P0oooo
00<00=Go003oP@3oool0103oool01000D_l0oooo0?ooo`00ofP20?ooo`03003Oo`3oool0oooo0080
oooo00<00?ni0?ooo`3oool00P3oool00`00oeH0oooo002ao`050?ooo`03003o203oool0oooo00<0
oooo00<00;Co003oD@3oool0103oool00`00ool00?m60?ooo`050?ooo`0304Go003oool0oooo00<0
oooo00D01Ol00?ooo`3oool0oooo001go`050?ooo`03003oD@3oool0oooo00<0oooo00<0M_l00?oo
o`3oool02P3oool00`00;Ol0oooo0?ooo`020?ooo`03003oN03oool0oooo0180oooo00<0:03o0?oo
o`3oool0;P3oool00`000000oooo0?ooo`070?ooo`4000000@3oool00080oooo00<000000?ooo`3o
ool03`3oool00`00h?l0oooo0?ooo`0<0?ooo`03003_o`3oool0oooo00H0oooo00@00?Ko0?ooo`3o
ool00;_o203oool00`00ol0005go0?ooo`020?ooo`030000003oool0oooo0080oooo00<00?Ko003o
d`3oool01`3oool00`00eOl0oooo003oP@050?ooo`04001Bo`3oool0oooo003oJ080oooo00<00=oo
0?ooo`3oool00P3oool00`00okT0oooo0?ooo`020?ooo`03003oEP3oool00;7o00D0oooo00<00?l8
0?ooo`3oool0103oool00`00]?l0oooo0?ooo`050?ooo`03003oAP3oool0oooo00<0oooo00<0AOl0
0?ooo`3oool0203oool00`00Mol0oooo0?ooo`030?ooo`03003oD@3oool0oooo0100oooo00<002go
0?ooo`3oool0?`3oool00`3o0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0@000001
0?ooo`000P3oool00`000000oooo0?ooo`0?0?ooo`03003Po`3oool0oooo00/0oooo00<00>oo0?oo
o`3oool01P3oool01@00m_l0oooo0?ooo`3oool00;_o00P0oooo00<00?o0001Mo`3oool00P3oool0
1`000000oooo0?ooo`030?l0oooo01L0o`00m_l0203oool00`00eOl0oooo003oP@030?ooo`03001g
o`3oool005;o0080oooo00@00?mX0?ooo`3oool00=oo103oool00`00okT0oooo0?ooo`020?ooo`03
003oEP3oool0oooo00D0oooo00<00?l80?ooo`3oool0103oool00`00]?l0oooo0?ooo`050?ooo`03
003oAP3oool0oooo00l0oooo00<007Oo0?ooo`3oool0?`3oool00`3o06l0oooo0?ooo`0C0?ooo`<0
o`0000<0B@3o0?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`4000000@3oool00080oooo
00<000000?ooo`3oool03`3oool00`00h?l0oooo0?ooo`0;0?ooo`03003_o`3oool0oooo00H0oooo
00D00?Ko0?ooo`3oool0oooo002ko`060?ooo`03001So`3oool00?o000@0oooo00L000000?ooo`03
0?l00`3o0?ooo`00om<00?Ko00D0oooo00H00>3o0?ooo`3oool00=Go0?ooo`00oh420?ooo`8007Oo
103oool01`00ofP0oooo0?ooo`3oool00=oo0?ooo`00ojL01P3oool00`00oeH0oooo0?ooo`0=0?oo
o`03002do`3oool00?nX0180oooo00<00?m<0?ooo`3oool03`3oool00`00o`P0oooo0?ooo`0G0?oo
o`80o`3I5P3oool30?l0K`8001Go4@3oool20?l000050?ooo`190?l0B@3o0?l0003oool00P00ofD3
0?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`0?0?oo
o`03003Po`3oool0oooo00/0oooo00<00>oo0?ooo`3oool01P3oool01000m_l0oooo0?ooo`00^ol6
0?ooo`8006?o00<0oooo003o`03oool00`3oool00`0000000`3o003ok@0200<0o`03003od`00m_l0
oooo00<0oooo0P00h?l40?ooo`03003oP@3oool007Oo00<007Oo00<00?nA0?ooo`3oool0103oool0
0`00gol00?nW003oY`050?ooo`<00>co0P3oool00`00odH0oooo0?ooo`050?ooo`05003o=P3oool0
oooo0?ooo`00]?l01000ojP40?ooo`03003o4@3oool0oooo00<0oooo00<0;ol00?ooo`3oool00P3o
ool3003oC0L0oooo00<01Ol00?ooo`3oool00P3oool0101oo`00oooo0?ooo`3oool2003o2080`P3o
0P3oool4002co`80oooo00D00?l50?ooo`3oool0oooo0:[o00020?ooo`806_l00`3oool40?l0f@05
0?ooo`00Jol006_o001[o`3oool00P00oc020:;o00<04ol0203oool20?l0K`030?ooo`005Ol0o`1_
008001Go0P00og@0101[o`000?lI003o6@00oaT;0?ooo`H0o`0000<0B@3o01?o000Co`000P0Co`00
0`3oool000000?ooo`080?ooo`4000000@3oool00080oooo00<000000?ooo`3oool03`3oool00`00
h?l0oooo0?ooo`0;0?ooo`03003_o`3oool0oooo00@0oooo0P00[?l01000m_l0oooo0?ooo`00^ol5
0?ooo`@006?o00<00?o00?ooo`3oool00P3oool0100000000?o]003ok@030?l20?ooo`06003fo`3o
ool0oooo0?ooo`00h?l00?oY0P00h?l60?ooo`8007Oo0P00oi460?ooo`04003Oo`00ojL00?nW003o
g`D0oooo00<00>co0?ooo`3oool00P00odH60?ooo`<00?lf0`3oool00`00ond00?nX003oZ0040?oo
o`<00?lA0`3oool406L0o`<0oooo00<00?m<0?ooo`00k?l00P00k?l30?ooo`<01Ol00`3oool207oo
00030?ooo`320?l0`P3o00<0`P3o0P3oool4002co`80oooo0P00o`D20?ooo`80Z_l00`0Jo`020?oo
o`D0o`3I00D0oooo001[o`00Jol006_o0?ooo`02003o<0040?ooo`2Ro`00X_l00:;o00<04ol01P3o
ool40?l0K`04000Eo`3o06l00?md000Eo`800?md101[o`0;0?ooo`030?l000190?l0B@3o00<0o`00
0`00ol/20?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`000P3oool00`000000oooo0?oo
o`0>0?ooo`03003Po`3oool0oooo00H0oooo00<00<3o0?ooo`3oool00P3oool00`00kol0oooo0?oo
o`040?ooo`<00:co00<00?Ko0?ooo`3oool0103oool00`00m_l0oooo0?ooo`03001So`03003o`03o
ool0oooo0080oooo1000ond20?ooo`04003fo`3oool0oooo0?ooo`<00?oY1`3oool00`00Mol00?nA
000[o`02003oT@H0oooo0P00ojL3003og`<0oooo00<00>co0?ooo`3oool00`00odH401L0o`80oooo
00@00?lf0?ooo`3oool0oooo0`00ond50?ooo`<00?lA0`3oool206L0o`030?ooo`1W0?l0oooo0080
oooo00<00?m<0?ooo`00k?l00P00k?l30?ooo`<01Ol0103oool00`1oo`00oooo0<80o`020<80o`06
0?ooo`320?l0oooo0?ooo`00/ol0oooo0P00/ol20?ooo`<00?l50P3oool01P2Zo`00oooo0?ooo`3o
ool06_l00?ooo`80o`3I00H0oooo0?l0f@3o0=T0o`3I001[o`3oool2001[o`04003o<03oool00?l`
003o<080oooo0P2Ro`070?ooo`030?l0K`3oool0oooo00<0o`1_0P005Ol0103oool00?lI003oM000
og@=0?ooo`80o`000P190?l30?l00080B@3o0`00ol/90?ooo`4000000@3oool00080oooo00<00000
0?ooo`3oool03P3oool00`00h?l0oooo0?ooo`050?ooo`<00<3o0`3oool00`00kol0oooo001no`05
0?ooo`800:co00<00?Ko0?ooo`3oool00`3oool3003fo`030?ooo`00Hol0oooo00@0oooo00<005ko
0?ooo`0000000`00ond60?ooo`<00?oY1`3oool01000Mol002_o000[o`00:ol70?ooo`03003oY`00
oml00?oO00800?oO0P3oool00`00k?l0oooo0?ooo`020?ooo`03003oAP0G0?l05`3o00<05`3o0P3o
ool01`00ocH0oooo0?ooo`3oool00?o]0?ooo`00ond01P3oool00`00oa40oooo0?ooo`020?ooo`03
06L0o`0_o`00I`3o0080I`3o0P3oool00`00od`0oooo003/o`02003/o`D0oooo00<01Ol00?ooo`3o
ool00P3oool0101oo`00oooo0<80o`3oool30<80o`80oooo0P00/ol00`3oool00;?o0?ooo`030?oo
o`05003o1@3oool0oooo0?ooo`2Zo`00103oool20?l0f@<0oooo00<0o`3I001[o`00Jol00P3oool0
1@00Jol0oooo0?ooo`3oool00?l`00/0oooo00<0o`1_0?ooo`3o06l00`3o06l00`3oool001Go000E
o`020?ooo`800?md303oool30?l000<0oooo0`3o000204T0o`X0oooo0@0000000080oooo00<00000
0?ooo`3oool01P3oool00`00ROl0oooo0?ooo`050?ooo`03003Po`3oool0oooo00@0oooo1000`?l4
0?ooo`<007ko1@3oool00`00[?l0oooo0?ooo`030?ooo`D00?Ko00<006?o0?ooo`3oool00P3oool3
001No`0300000000ond0oooo00L0oooo1000onT60?ooo`@002_o1`3oool00`00ojL00?oO003og`02
003og`80oooo00<00>co0?ooo`3oool00P3oool01@00odH05`3o01L0o`0G0?l0oooo00805`3o00<0
0?lf0?ooo`3oool00P3oool3003ok@H0oooo00<00?lA0?ooo`3oool00`3oool406L0o`80oooo00@0
0?m<0?ooo`3oool00>co1P3oool00`05o`00oooo0?ooo`030?ooo`0307oo003oool0`P3o0080`P3o
1P3oool00`00/ol0oooo0?ooo`030?ooo`05003o1@3oool0oooo0?ooo`2Zo`00103oool01@3o0=T0
oooo0?l0f@3o0=T0oooo0080o`3I0`3oool01@00Jol0oooo0?ooo`3oool00?l`00X0oooo0P3o06l4
0?ooo`80o`1_00<0oooo000Eo`005Ol03P3oool00`3o0000oooo0?ooo`060?ooo`80o`000P190?l8
0?ooo`40000000020?ooo`030000003oool0oooo00D0oooo0`00ROl60?ooo`03003Po`3oool0oooo
00D0oooo1000`?l20?ooo`@007ko103oool00`00[?l0oooo0?ooo`060?ooo`03003fo`3oool006?o
00@0oooo1000G_l00`0000000?o]0?ooo`050?ooo`0406L0o`3oool0oooo003oj@L0oooo00@007Oo
000[o`00:ol00?nA0P00:ol60?ooo`04003oY`3oool0oooo003og`<0oooo00<00>co0?ooo`3oool0
0P3oool01000odH0oooo01L0o`3oool201L0o`030?ooo`00ocH0oooo00D0oooo00<00?o]0?ooo`3o
ool01@3oool00`00oa40oooo0?ooo`020?ooo`<0I`3o1`3oool00`00k?l0oooo0?ooo`040?ooo`03
00Go003oool0oooo0080oooo00<0Ool00?ooo`320?l00P3oool00`320?l0oooo0?ooo`040?ooo`03
002co`3oool0oooo00<0oooo00<00?l50?ooo`3oool01@3oool20?l0f@D0oooo00@0o`3I0?ooo`3o
ool0oooo0P00JolD0?ooo`80o`1_00<0oooo000Eo`005Ol05`3oool20?l000P0oooo0@0000000003
0?ooo`000000oooo00L0oooo1000ROl=0?ooo`030030o`3oool0oooo00<0oooo1@00O_l30?ooo`03
002/o`3oool0oooo00H0oooo00<00?Ko0?ooo`00Hol01@3oool4001No`03003ok@3oool0oooo0080
oooo0`1W0?l20?ooo`03003oj@3oool0oooo00D0oooo00<007Oo0?ooo`00:ol00P00:ol00`3oool0
01Ko0?ooo`030?ooo`05003oY`3oool0oooo0?ooo`00oml00`3oool00`00k?l0oooo0?ooo`020?oo
o`03003oAP3oool05`3o00805`3o0P3oool00`00ocH0oooo0?ooo`050?ooo`03003ok@3oool0oooo
00@0oooo00<00?lA0?ooo`3oool00`3oool00`0_o`00oooo06L0o`060?ooo`03003/o`3oool0oooo
00@0oooo00<01Ol00?ooo`3oool0203oool20<80o`D0oooo00<00;?o0?ooo`3oool04P3oool00`3o
0=T0oooo0?ooo`020?ooo`03001[o`3oool0oooo01<0oooo0P3o06lH0?ooo`040000003oool0o`00
0?l000H0oooo0@00000000030?ooo`000000oooo00H0oooo1000ROl>0?ooo`030030o`3oool0oooo
00@0oooo0P00O_l50?ooo`03002/o`3oool0oooo00H0oooo00<00?Ko0?ooo`00Hol01P3oool01000
G_l0oooo00<0o`00ond30?ooo`D0I`3o00<00>3o003oj@3oool0103oool00`00R_l0oooo001go`02
0?ooo`04003oT@00:ol001Ko000Fo`@0oooo00D00?nW0?ooo`3oool0oooo003og`070?ooo`03002=
o`00odH0oooo00<0oooo00<05`3o0?ooo`00ocH01`3oool01000ond0oooo0?ooo`00nOl30?ooo`03
003o4@3oool0oooo00H0oooo00<0I`3o0?ooo`3oool00P3oool00`00ojX0oooo003/o`0?0?ooo`04
003oI@3oool0oooo0<80o`D0oooo00<00;?o0?ooo`3oool04P3oool20?l0fAX0oooo0P3o06lA0?oo
o`03003oZP3oool0oooo0080oooo00<000000?ooo`3oool01`3oool10000000000<0oooo0000003o
ool0203oool00`00ROl0oooo0?ooo`0=0?ooo`030030o`3oool0oooo00D0oooo00<007ko0?ooo`3o
ool00P3oool00`00[?l0oooo0?ooo`060?ooo`04003fo`3oool0oooo001So`D0oooo00D000Go001N
o`3oool00`3o003ok@040?ooo`80I`3o00@0oooo06L0o`00h?l00?oY103oool2002:o`<0oooo00<0
0?nA0?ooo`00:ol00`005_l30?ooo`07003oY`3oool0oooo0?ooo`00oml0oooo003om0040?ooo`80
08go00<00?m6002=o`3oool00`3oool00`0G0?l0oooo0?ooo`030?ooo`04003oN03oool0oooo003o
k@@00?Wo0P3oool00`00oa40oooo0?ooo`060?ooo`03003o1@1W0?l0oooo00@00?nZ00<00>co0?oo
o`3oool0303oool3003oI@80oooo00<0`P3o0?ooo`3oool02`3oool00`00ocl0oooo0?ooo`0;0?oo
o`050?l0f@3oool0oooo0?ooo`00ocl04P3oool01000ofD0oooo003oI@00ofD>0?ooo`04003oZP3o
ool0o`2Z003oZPD0oooo2`00000000030?ooo`000000oooo00P0oooo00<008Wo0?ooo`3oool03@3o
ool00`00`?l0oooo0?ooo`050?ooo`03001no`3oool0oooo0080oooo00<00:co0?ooo`3oool01@3o
ool01000GOl00?Ko0?ooo`00Hol50?ooo`8000Go00<005ko0005o`00ond01P3oool01@00eOl0I`3o
0?ooo`00h?l00?oY00<0oooo1000R_l20?ooo`07003oT@3oool0oooo000[o`005_l0oooo003o^@06
0?ooo`04003om000oml00?od003om0@0oooo00<008go003oAP3oool00`3oool00`00oe405`3o0?oo
o`020?ooo`@00?mh0P3oool00`00ond00?Wo003io`060?ooo`0300Go003oool0oooo0080oooo0P00
o`D00`1W0?l0oooo0?ooo`02003oZP80oooo00<00>co0?ooo`3oool00`3oool00`14o`00oooo0?oo
o`020?ooo`80GOl000<0oooo003oI@00ofD0103oool00`320?l0oooo0?ooo`070?ooo`80X_l00`00
ocl>0?ooo`80]_l01000ocl;0?ooo`060>d0o`00/Ol00;7o01?o002@o`000?mU103ooolF000000T0
oooo0@00000000030?ooo`000000oooo00P0oooo00<008Wo0?ooo`3oool03@3oool00`00`?l0oooo
0?ooo`050?ooo`03001no`3oool0oooo0080oooo00<00:co0?ooo`3oool0103oool2001Mo`03003f
o`3oool006?o00H0oooo0P001Ol00`00G_l00?o]0?ooo`040?ooo`800=Go0`3oool00`00onT0oooo
0?ooo`020?ooo`8008[o0`3oool01@00oi40oooo0?ooo`00:ol0oooo00800?ni1`3oool00`00oml0
0?od0?ooo`040?ooo`03002=o`3oool0oooo0080oooo0P00oe400`3oool05`3o0?ooo`020?ooo`80
0?mh0`3oool00`00ond00?Wo0?ooo`050?ooo`801Ol01@3oool01@00o`D0oooo06L0o`3oool00?nZ
00<0oooo00<00?nX0?ooo`3oool00`3oool204Co0080oooo0P1Mo`030?ooo`03003oI@3oool0oooo
00<0oooo00<0`P3o003obP3oool00P3oool305go00040?ooo`2Ro`00X_l00?ooo`800?lo1P3oool2
08`0o`@00?co0P1<o`00103oool0]_l00;Ko0000ocl20?oooaD000002P3oool30?l0ZP03001Ho`3o
0:X00?lo00D0oooo00<000000?ooo`3oool01`3oool10000000000<0oooo0000003oool01`3oool0
0`00ROl0oooo0?ooo`0=0?ooo`030030o`3oool0oooo00H0oooo00D007ko0?ooo`3oool0oooo002/
o`060?ooo`<005go00<00?Ko0?ooo`3oool01@3oool01@00gol000Go0?ooo`00G_l00?o]00@0oooo
1000eOl20?ooo`03003oj@3oool0oooo0080oooo00<008[o003og`3oool0103oool00`005_l002_o
0?ooo`03003o^@H0oooo00D00?oO0?ooo`3oool0oooo003o/`020?ooo`04002=o`3oool0oooo0?oo
o`@00?mA00<05`3o0?ooo`3oool00P3oool00`00ogP0oooo0?ooo`020?ooo`03003oX03oool0oooo
00@0oooo0`05o`040?ooo`05003o1@3oool0oooo06L0o`00ojX00`3oool3003oZ0<0oooo0P14o`03
0?ooo`0405go003oool0oooo0?ooo`@0=03o0`3oool3003obP030?ooo`1Mo`00GOl000<0oooo00@0
X_l00?ooo`3oool0oooo500000070?ooo`80k@3o00<0oooo002ao`3]0?l00P00/Ol301?o00h0oooo
00L0o`2Z0?ooo`3o0:X0o`2Z001Ho`3o0:X005So00@00?lo00<000000?ooo`3oool01`3oool10000
000000<0oooo0000003oool01`3oool00`00ROl0oooo0?ooo`0=0?ooo`030030o`3oool0oooo00D0
oooo00<008ko001no`3oool00P3oool00`00[?l0oooo0?ooo`050?ooo`8005go00<00?Ko0?ooo`3o
ool0103oool2003Oo`80oooo00<005ko0000003oool00`3oool00`1W0?l00=Go0?ooo`030?ooo`05
003oj@3oool0oooo0?ooo`00R_l00P00oml50?ooo`06000Fo`00:ol0oooo003o^@3oool007go1P3o
ool00`00oo@0oooo003o/`02003o/`030?ooo`00SOl0oooo00D0oooo00@00?mA0?ooo`3oool05`3o
0P3oool00`00ogP0oooo0?ooo`020?ooo`@00?nP1@3oool00`05o`00oooo0?ooo`030?ooo`<001Ko
00@0oooo003oZP3oool0oooo0`00ojP50?ooo`0304Co003oool0oooo0080oooo00<0GOl00?ooo`00
0000500000040?ooo`<0S03o00<0oooo08`0o`00o?l00P00o?l20?ooo`80C?l02`3oool40>d0o`04
002ao`3]0?l00;7o002ao`80oooo0P0Co`0<0?ooo`040?l0ZP3oool005So001Ho`80o`2Z00<0oooo
001Ho`00F?l00P00F?l00`000000oooo0?ooo`070?ooo`40000000000`3oool000000?ooo`070?oo
o`030029o`3oool0oooo00H0oooo00<007ko0?ooo`3oool0103oool00`00`?l0oooo0?ooo`040?oo
o`8008ko00<007ko002>o`3oool0103oool00`00U?l0oooo0?ooo`020?ooo`03001Mo`3oool00?Ko
00D0oooo1000gol00`3oool005ko0?ooo`030?ooo`03002Co`1W0?l00=Go00P0oooo1000oml40?oo
o`04000Fo`3oool002_o003o^@<007go1@3oool00`00oo@0oooo0?ooo`03003o/`03002=o`3oool0
oooo00<0oooo00<00?mA0?ooo`3oool01000D_l00`00ogP0oooo0?ooo`020?ooo`<00?nP1P3oool0
0`05o`00oooo0?ooo`020?ooo`8001Ko5@0000000`3oool0=03o0?ooo`0303@0o`80oooo0`00olX3
0?ooo`0305go003oool0oooo00P0oooo00<0S03o0?ooo`2<0?l00P2<0?l4003lo`<0oooo00<0C?l0
0?ooo`3oool0203oool00`3]0?l0oooo0?ooo`030>d0o`80oooo0P00/Ol?0?ooo`050?l0ZP3oool0
o`2Z0?l0ZP3oool00`3o0:X20?ooo`8005So203oool10000000000<0oooo0000003oool01`3oool0
0`00ROl0oooo0?ooo`050?ooo`8007ko1P3oool00`00`?l0oooo0?ooo`050?ooo`03002>o`00O_l0
08ko00@0oooo0`00U?l20?ooo`03001Mo`3oool0oooo00L0oooo0`00gol00`3oool005ko0?ooo`02
0?ooo`@009?o203oool00`00R_l0oooo003og`040?ooo`04000Fo`3oool0oooo000[o`@007go103o
ool00`00oo@0oooo0?ooo`020?ooo`03003o/`3oool008go00D0oooo00<00?mA0?ooo`3oool01000
D_lE000000<001Ko1@3oool00`00ojP0oooo0?ooo`040?ooo`0304Co003oool0oooo00D0oooo00@0
=03o0?ooo`0d0?l0=03o103oool00`00olX0oooo0?ooo`020?ooo`0305go003oool0oooo00L0oooo
00@0S03o0?ooo`2<0?l0S03o1@3oool00`00o?l0oooo0?ooo`0<0?ooo`030>d0o`3oool0k@3o0080
k@3o103oool2002ao`d0oooo0P3o0:X60?ooo`80o`2Z00<000000?ooo`3oool01`3oool100000000
00<0oooo0000003oool01`3oool00`00ROl0oooo0?ooo`050?ooo`<007ko3@3oool00`00S_l007ko
0?ooo`040?ooo`<009Co0P3oool00`00GOl0oooo0?ooo`070?ooo`05003Oo`3oool0oooo0?ooo`00
G_l00P3oool00`1L0?l009?o002Co`02002Co`P0oooo00<008[o0?ooo`00oml0103oool01000;Ol0
oooo0?ooo`3oool5001mo`80oooo5@0000000`00ogP0oooo0?ooo`040?ooo`03003oX03oool0oooo
00@0oooo00<01Ol00?ooo`3oool00`3oool3000Fo`L0oooo00<00?nX0?ooo`3oool00`3oool00`14
o`00oooo0?ooo`050?ooo`80=03o00<0oooo03@0o`3oool0103oool00`00olX0oooo0?ooo`0;0?oo
o`80S03o0P3oool208`0o`@0oooo00<00?co0?ooo`3oool02`3oool20>d0o`<0oooo0P3]0?l40?oo
o`03002ao`3oool0oooo01@0oooo0P3o0:X80?ooo`40000000000`000000oooo0?ooo`070?ooo`03
0029o`3oool0oooo00@0oooo1000O_l=0?ooo`03002>o`00O_l0oooo00<0oooo1@00U?l00`3oool0
05go0?ooo`080?ooo`06003Oo`3oool0oooo0?ooo`000000oooo0P1L0?l4002Co`D0oooo5@000000
0`3oool00?od0?ooo`030?ooo`03003o/`00/ol0oooo00D0oooo00<00?mA0?ooo`3oool00P00D_l0
0`3oool005;o0?ooo`030?ooo`04003obP3oool0oooo003oX0H0oooo00<01Ol00?ooo`3oool01P3o
ool00`005_l0oooo0?ooo`040?ooo`03003oZ03oool0oooo00h0oooo00<0=03o0?ooo`3oool00`3o
ool00`00olX0oooo0?ooo`0A0?ooo`0308`0o`3oool0oooo0080oooo00<00?co0?ooo`3oool04@3o
ool20>d0oaT0oooo00@000000?ooo`3o0:X0o`2Z1P3oool10000000000<000000?ooo`3oool01`3o
ool00`00ROl0oooo0?ooo`050?ooo`04001no`3oool007ko001no``0oooo00<008ko0?ooo`3oool0
1@3oool01000U?l0oooo0?ooo`00GOl70?oooa@0000000D0oooo002:o`00R_l0oooo003og`020?oo
o`D002go00<0oooo003o^@3oool00P3oool01000OOl0oooo0?ooo`00oo@50?ooo`04002co`00ok<0
0;?o002co`D0oooo00<00?mA0?ooo`3oool00`3oool01000D_l0oooo0?ooo`3oool3003obP030?oo
o`00oj00oooo00d0oooo00<00?m@000Fo`3oool01P3oool00`00ojP0oooo0?ooo`080?ooo`0301[o
003oool0oooo00<0oooo00<0=03o0?ooo`3oool00`3oool00`00olX0oooo0?ooo`030?ooo`80Jol0
303oool00`2<0?l0oooo0?ooo`030?ooo`03093o003oool0oooo0140oooo0P3]0?lC0?ooo`80=ol0
0P3oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`0?0?ooo`03001no`3o
ool0oooo00/0oooo5@0000020005o`03003Oo`3oool0oooo0080oooo00<000000?ooo`3oool00P1L
0?l00`00Tol00=Go0?ooo`040?ooo`<008[o0P3oool01000oml0oooo0?ooo`3oool3000]o`80oooo
00H00?ni0?ooo`3oool0oooo001mo`3oool2003om0H0oooo00<00?nc002co`3oool02P3oool00`00
ogP005;o0?ooo`030?ooo`05003obP3oool0oooo0?ooo`00oj00203oool00`00o`D0oooo0?ooo`03
0?ooo`03003oD0005_l0oooo00D0oooo00<00?nX0?ooo`3oool00`3oool0101Mo`00oooo0?ooo`3o
ool301[o00D0oooo00<0=03o0?ooo`3oool01@3oool00`2Ro`00oooo0?ooo`0206_o00d0oooo00@0
S03o0?ooo`3oool0oooo0P2@o`0A0?ooo`@0O?l000<0k@3o0?ooo`3oool03@3oool303Oo00D0oooo
00<000000?ooo`3oool01@3oool100000040oooo00000`000000oooo0?ooo`080?oooaD0000000<0
oooo002>o`3oool01`3oool01000U?l0oooo0?ooo`00GOl50?ooo`@000Go00<00=oo0?ooo`3oool0
0P3oool01P000000oooo05`0o`00]?l0oooo002Co`D0oooo00@008[o0?ooo`00R_l008[o0P3oool0
1`00oml0oooo0?ooo`3oool002go0?ooo`00ond00P3oool01@00okT0oooo0?ooo`3oool007go00@0
0?od1@3oool00`00ok<0oooo0?ooo`080?ooo`@00?mh00D005;o0?ooo`3oool0oooo003obP030?oo
o`03003oX03oool0oooo00D0oooo0`00o`D30?ooo`04003oD03oool0oooo000Fo`/0oooo0P1Mo`03
0?ooo`0301[o003oool0oooo00D0oooo00<0=03o0?ooo`3oool0103oool20:;o0080oooo00<0Jol0
0?ooo`3oool0303oool0102<0?l0]_l00;Ko003oool2093o00l0oooo00<00?nb093o001lo`004@3o
ool203ko00030:X0o`3oool0oooo00@0oooo00<000000?ooo`3oool01@3oool100000040oooo000;
000000L0oooo00<007ko0?ooo`3oool0303oool00`00S_l0oooo0?ooo`040?ooo`05001;o`00U?l0
04_o0?ooo`00GOl0203oool20005o`03003Oo`3oool0oooo0080oooo00L00000002do`00]?l00;Co
0?ooo`00eOl009?o00D0oooo0`00R_l20?ooo`05003og`3oool0oooo0?ooo`00;Ol00P00ond60?oo
o`04001mo`3oool00?od003om0D0oooo00<00;?o003o/`3oool00P3oool00`00oj00oooo0?ooo`05
0?ooo`800?mh00D0oooo001Bo`3oool0oooo003obP060?ooo`03003oJ03oool0oooo00@0oooo00<0
0?l50?ooo`3oool00P3oool01000oe00oooo0?ooo`005_l60?ooo`03003oC03oool0oooo0080oooo
00<0GOl00?ooo`3oool00P3oool00`0Jo`00oooo0?ooo`060?ooo`0403@0o`3oool00?m@003oD080
oooo0P2Ro`030?ooo`0306_o003oool0oooo00T0oooo0`00og@20;Ko0100oooo0P190?l01000ok80
T?l0093o002@o`0@0?ooo`<0ZP3o100no`020?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`0000<0oooo0000003oool03`3oool00`00O_l0oooo0?ooo`0<0?ooo`03002>o`3oool0oooo00<0
oooo0P00Bol01000U?l004_o001;o`00GOl70?ooo`030005o`3oool00=oo00D0oooo1@00]?l00`3o
ool009?o0?ooo`050?ooo`05002:o`3oool0oooo0?ooo`00oml00`3oool01000;Ol00?o]003ok@00
ond50?ooo`03001mo`3oool00?od00H0oooo00@00;?o0?ooo`3oool0oooo0`00oj060?ooo`07003o
N03oool0oooo0?ooo`00D_l0oooo003obP050?ooo`<00?mX1@3oool00`00o`D0oooo0?ooo`020?oo
o`05003oD03oool0oooo0?ooo`005_l0103oool3003oC0<0oooo00<0GOl00?ooo`3oool00P3oool0
0`0Jo`00oooo0?ooo`020?ooo`<005Go0`3oool2003oD0<0oooo00<0X_l00?ooo`3oool02@3oool3
000<o`040?ooo`00og@00?md003oM080oooo00<0]_l00?ooo`3oool02`3oool404T0o`800?nb0P3o
ool2093o00d0oooo0P2Z0?l00`00n_l0ZP3o003jo`050?ooo`030000003oool0oooo00D0oooo0@00
00010?ooo`000P3oool00`000000oooo0?ooo`0=0?ooo`03001no`3oool0oooo00H0oooo00<005ko
0?ooo`3oool00P3oool00`00S_l0oooo0?ooo`060?ooo`03002Do`00Bol004_o00D0oooo00H009?o
0?ooo`3oool000Go0?ooo`00gol50?ooo`0300000000]?l00;Co00800;Co00D0oooo002Co`3oool0
oooo0<80o`020?ooo`03002do`3oool0oooo00D0oooo00<002go0?ooo`00ond00P00ond20?ooo`05
03@0o`3oool0oooo0?ooo`00OOl00P3oool00`00_ol0oooo0?ooo`020?ooo`03002co`3oool0oooo
0080oooo0`00oj050?ooo`07003oN03oool0oooo0?ooo`00D_l00;7o003obP060?ooo`<00?mX103o
ool00`00o`D0oooo0?ooo`020?ooo`03003oD03oool008go008008go103oool3003oC0@0oooo00<0
GOl00?ooo`3oool01P3oool3001Eo`<0oooo0P00oe040?ooo`030:;o003oool0oooo00P0oooo0`00
3?l0103oool00?md003oM000og@30?ooo`030;Ko003oool0oooo00X0oooo10190?l3003o/Q00oooo
1@2Z0?l3003jo`80oooo00<000000?ooo`3oool01@3oool100000040oooo00020?ooo`030000003o
ool0oooo00d0oooo00<007ko0?ooo`3oool01@3oool2001No`@0oooo00<008ko0?ooo`3oool01@3o
ool00`00Bol009Co0?ooo`050?ooo`<009?o00@000Go0?ooo`3oool00=oo1@3oool00`000000G03o
002do`030?ooo`05002Co`320?l0`P3o0<80o`3oool00P00]?l70?ooo`03000]o`3oool00?o]0080
oooo0`0d0?l30?ooo`03001mo`3oool00;oo00800;oo0P3oool00`00/ol0oooo0?ooo`030?ooo`03
003oX000EOl0oooo00D0oooo00@00?mh0?ooo`3oool0oooo0`00/Ol40?ooo`03003Io`3oool00?mX
00H0oooo00<00?l50?ooo`3oool0103oool3002=o`H0oooo00<00?m<0?ooo`3oool00P3oool00`1M
o`00oooo0?ooo`060?ooo`@005Go0`3oool00`00oe00oooo0?ooo`020?ooo`030:;o003oool0oooo
00P0oooo00@000co0?ooo`003?l000co0`3oool00`00og@0oooo0?ooo`0=0?ooo`0304T0o`3oool0
oooo0080B@3o0P3oool2003o/Ph0oooo00<0ZP3o0?ooo`3oool00`2Z0?l20?ooo`800?[o00<00000
0?ooo`3oool01@3oool100000040oooo00030?ooo`030000003oool0oooo00/0oooo00<007ko0?oo
o`3oool01P3oool2001No`@0oooo00<008ko0?ooo`3oool01@3oool00`00Bol009Co0?ooo`040?oo
o`@009?o00<000Go0?ooo`3oool01@3oool00`1I0?l00000002do`040?ooo`03002Co`320?l0`P3o
0080`P3o0`00]?l50?ooo`05000]o`3oool0oooo003ok@3oool01@0d0?l20?ooo`03001mo`3oool0
0;oo00800;oo0P3oool00`00/ol0oooo0?ooo`020?ooo`03001Eo`00oj0005Go00D0oooo00<00?mh
0?ooo`3oool00P3oool4002ao`80oooo0P00fOl00`3oool00?mX0?ooo`050?ooo`03003o1@3oool0
oooo00@0oooo1000SOl50?ooo`03003oC03oool0oooo0080oooo00<0GOl00?ooo`3oool01P3oool0
1000EOl0oooo001Eo`00EOl40?ooo`03003oD03oool0oooo00`0oooo10003?l40?ooo`03003oM03o
ool0oooo00d0oooo0P190?l20?ooo`0504T0o`3oool0oooo0?ooo`00ok803P3oool30:X0o`80oooo
0`2Z0?l00`3oool000000?ooo`060?ooo`4000000@3oool000@0oooo00<000000?ooo`3oool02P3o
ool00`00O_l0oooo0?ooo`050?ooo`@005ko2`3oool00`00Bol009Co0?ooo`050?ooo`@009?o1@3o
ool305T0o`0305`0o`00]?l0oooo00<0oooo00@009?o0<80o`320?l0`P3o0`00]?l50?ooo`05000d
o`00;Ol0oooo0?ooo`00ond00P3oool203@0o`060?ooo`0d0?l0oooo0?ooo`00oo@0oooo1000_ol0
0`00`?l0oooo0?ooo`030?ooo`04001Eo`00oj00oooo001Eo`@0oooo00<00?mh0?ooo`3oool00P3o
ool3002ao`80oooo1000fOl00`3oool00?mX0?ooo`040?ooo`03003o1@3oool0oooo00@0oooo0`00
SOl00`00oj/0oooo0?ooo`030?ooo`03003oC03oool0oooo00L0oooo0P00ocl20?ooo`8005Go00<0
oooo001Eo`3oool00`3oool00`00oe00oooo0?ooo`050?ooo`0301?o003oool0oooo00@0oooo00D0
00co0?ooo`3oool0oooo000<o`040?ooo`03003oM03oool0?_l000`0oooo00<0B@3o0?ooo`3oool0
0P3oool204T0oa00oooo00<0ZP3o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`020:X0o`L0oooo
0@0000010?ooo`001@3oool00`000000oooo0?ooo`090?ooo`03001no`3oool0oooo00H0oooo0`00
G_l:0?ooo`03001;o`3oool009Co00H0oooo00<009?o0?ooo`001Ol01@3oool505T0o`03002do`3o
ool0oooo00<0oooo00H0`P3o0?ooo`3oool0oooo002:o`00]?l40?ooo`8003Co0`3oool00`00ond0
oooo0?ooo`0303@0o`80oooo00H00?od0?ooo`3oool0oooo002oo`3oool20030o`D0oooo00<005Go
003oX000EOl01@3oool00`00ogP0oooo0?ooo`030?ooo`03003o]@00/Ol0oooo0080oooo0P00fOl2
0?ooo`03003oJ03oool0oooo00L0oooo00H00?l`0?ooo`3oool0oooo003oZ`00SOl70?ooo`03003o
C03oool0oooo00<0oooo00@0C?l00?ooo`3oool0oooo0P00ocl40?ooo`03001Eo`3oool0oooo00<0
oooo00<00?m@0?ooo`3oool00`3oool301?o00X0oooo00<000co0?ooo`3oool00P3oool303ko0140
oooo00<0=ol004T0o`190?l03`3oool4003o00@0oooo00<000000:X0o`2Z0?l01@3oool100000040
oooo00050?ooo`030000003oool0oooo00T0oooo00<007ko0?ooo`3oool01P3oool00`00G_l0oooo
0?ooo`0:0?ooo`03001;o`3oool0oooo00H0oooo00<009?o0?ooo`001Ol01P3oool305T0o`03002d
o`3oool0oooo00@0oooo00H0`P3o0?ooo`3oool008[o0?ooo`00]?l30?ooo`@003Co0P3oool01000
ond0oooo0?ooo`0d0?l40?ooo`05003om03oool0oooo0?ooo`00_ol01000`?l40?ooo`03001Eo`00
oj00oooo00T0oooo0`00okD01000/Ol0oooo0?ooo`00fOl40?ooo`03003oJ03oool0oooo00H0oooo
0P00oc030?ooo`03003oZ`3oool008go00H0oooo00<00?m<0?ooo`3oool00P3oool204co00<0oooo
00<00?lo0?ooo`3oool0103oool00`00EOl0oooo0?ooo`060?ooo`040;Ko003oool0oooo01?o00`0
oooo00D000co0?ooo`3oool0m_l00?ooo`0203ko0100oooo0P0go`020?ooo`0304T0o`3oool0oooo
00`0oooo0P00o`060?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`001P3oool00`000000
oooo0?ooo`0A0?ooo`03001No`3oool0oooo00X0oooo00<004_o0?ooo`3oool01@3oool00`030?l0
09?o0005o`070?ooo`0405T0o`3oool0F@3o002do`D0oooo00H0`P3o0?ooo`00Mol0oooo002:o`00
]?l50?ooo`8003Co0P3oool01@00ond0oooo0?ooo`3oool0=03o00<0oooo00<00>co0?ooo`3oool0
0`3oool00`00_ol00<3o0030o`040?ooo`03001Eo`3oool00?nP00@0oooo00<00?nX0?ooo`3oool0
103oool00`00okD0oooo002ao`020?ooo`03003Io`3oool0oooo0080oooo00@00?mX0?ooo`3oool0
0?m<1P3oool2003o<080oooo00<00?n[0?ooo`00SOl02`3oool304co0080oooo00<00?lo0?ooo`3o
ool01@3oool00`00EOl0oooo0?ooo`040?ooo`80]_l00P3oool00`0Co`00oooo0?ooo`0;0?ooo`04
000<o`3oool0m_l00?Ko0180oooo0P3]o`0A0?ooo`H0XOl00P3oool00`000000oooo0?ooo`050?oo
o`4000000@3oool000L0oooo00<000000?ooo`3oool0403oool00`00G_l0oooo0?ooo`090?ooo`03
001;o`3oool0oooo00D0oooo0P030?l00`00Tol00`3o0?ooo`060?ooo`0405T0o`3oool0oooo002d
o`D0oooo00<0`P3o001go`00Mol00P3oool00`00]?l0oooo0?ooo`030?ooo`05000do`3oool0oooo
0?ooo`00ond00P3oool0100d0?l0oooo0?ooo`3oool2003/o`D0oooo00<00;oo0030o`3oool0103o
ool00`00EOl0oooo003oX0030?ooo`800?nX1P3oool01@00okD0oooo002ao`3oool00=Wo00L0oooo
0`00od`50?ooo`04003o<03oool0oooo003oZ`<0oooo00<008go0?ooo`3oool0103oool00`00o`P0
oooo0?ooo`020?ooo`0504co003oool0oooo0?ooo`00ocl01`3oool01@00EOl0oooo0?ooo`3oool0
6_l000<0oooo00<0]_l00?ooo`3oool03@3oool201?o0003000<o`3oool0m_l00100oooo0`00oaT0
0`3oool0kOl00>go000@0?ooo`030:7o0000ofD0oooo00@0oooo00<000000?ooo`3oool01@3oool1
00000040oooo00080?ooo`030000003oool0oooo00h0oooo00<005ko0?ooo`3oool02P3oool00`00
Bol0oooo0?ooo`040?ooo`<00`3o00<009?o00<0o`3oool01P3oool0101I0?l0oooo002do`000004
0?ooo`030<80o`00Mol007Oo008007Oo00<0oooo002do`3oool00`3oool00`00=?l0oooo0?ooo`02
0?ooo`04003ok@3oool0oooo03@0o`80oooo0`00k?l50?ooo`03002oo`3oool0oooo00<0oooo00<0
05Go0?ooo`3oool00`3oool4003oZ0@0oooo00H00?ne0?ooo`3oool0oooo002ao`00fOl70?ooo`@0
0?m<0`3oool01@00oc00oooo0?ooo`3oool00?n[00<0oooo00<008go0?ooo`3oool00`3oool3003o
20<0oooo00<0C?l00?ooo`3oool02P3oool00`00EOl0oooo01[o000201[o00<0oooo00<0]_l00?oo
o`3oool0303oool301?o0080oooo00<0m_l00?ooo`3oool03@3oool00`00F?l00?lI003o6@0B0?oo
o`03003oI@000?l0003o00H0oooo00<000000?ooo`3oool0103oool100000040oooo00080?ooo`03
0000003oool0oooo00h0oooo00<005ko0?ooo`3oool01P3oool01000:ol0oooo0?ooo`00Bol90?oo
o`0300<0o`00Tol0oooo00H0oooo00@007go0?ooo`3oool00;Co1@3oool010320?l0oooo001go`00
Mol20?ooo`03002do`3oool0oooo0080oooo00<003Co0?ooo`00_ol0103oool00`0d0?l0oooo0?oo
o`020?ooo`03003/o`3oool0oooo00@0oooo00<00;oo0?ooo`3oool00P3oool00`00jol005Go0?oo
o`050?ooo`03003oZ03oool0oooo00@0oooo00L00?ne0?ooo`3oool0oooo002ao`3oool00?oo00L0
oooo00<00?m<0?ooo`3oool00`3oool00`00oc00oooo0?ooo`050?ooo`03003io`00SOl0oooo00@0
oooo00<00?l80?ooo`3oool00P3oool00`1<o`00oooo0?ooo`080?ooo`800=Wo103oool01@0Jo`00
oooo0?ooo`3oool0]_l000/0oooo0`00X_l301?o0100oooo0`00F?l00`00oaT0oooo003o6@0@0?oo
o`@0003o0`00ofD30?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`002@3oool00`000000
oooo0?ooo`0=0?ooo`03001No`3oool0oooo00D0oooo0P00:ol20?ooo`03001;o`3oool0oooo00H0
oooo00<00`3o002Co`3oool01P3oool2001mo`80oooo00<000000?ooo`3oool00P3oool010320?l0
_@3o0?ooo`00Mol30?ooo`06002do`3oool0oooo0?ooo`00=?l0oooo0P00_ol40?ooo`0302P0o`3o
ool0oooo0080oooo00<00>co0?ooo`3oool0103oool01000_ol0oooo0?ooo`3oool2003[o`L0oooo
00<00?nX0?ooo`3oool0103oool01@00okD0oooo0?ooo`3oool00;7o00@00?oo1@3oool00`00od`0
oooo0?ooo`030?ooo`03003o<03oool0oooo00D0oooo0`00nOl40?ooo`03003o203oool0oooo0080
oooo00<0C?l00?ooo`3oool01`3oool3003Io`@0oooo00<06_l00?ooo`3oool03@3oool3002Ro`80
oooo00<04ol00?ooo`3oool03P3oool4001Ho`80oooo0P00oaT>0?ooo`D0003o0P3oool2003oI@03
0?ooo`000000oooo00D0oooo0@0000010?ooo`002P3oool00`000000oooo0?ooo`0<0?ooo`03001N
o`3oool0oooo00@0oooo1000:ol:0?ooo`0300<0o`00Tol0oooo00D0oooo1000OOl00`3oool00000
0?ooo`020?ooo`<0_@3o00<007Oo0?ooo`3oool00P3oool01@00]?l0oooo0?ooo`3oool003Co00@0
0;oo00@0oooo02P0o`0X0?l0:03o103oool00`00k?l0oooo0?ooo`040?ooo`05002oo`3oool0oooo
003[o`3oool00P00jol00`00Jol0oooo0?ooo`030?ooo`03003oZ03oool0oooo00<0oooo00<00?ne
0?ooo`3oool00`3oool2003oo`030?ooo`00ool0oooo00@0oooo00<00?m<0?ooo`3oool00`3oool0
0`00oc00oooo0?ooo`050?ooo`<00?Wo1@3oool00`00o`P0oooo0?ooo`0;0?ooo`04003Io`3oool0
0=Wo003Io`<0oooo00<06_l00?ooo`3oool03@3oool00`00X_l0oooo002Ro`030?ooo`0301?o003o
ool0oooo00d0oooo1000F?l40?ooo`03003o6@3oool0oooo00`0oooo10000?l50?ooo`030000003o
ool0oooo00@0oooo0@0000010?ooo`002`3oool00`000000oooo0?ooo`0;0?ooo`03001No`3oool0
oooo00D0oooo0`00:ol90?ooo`0300<0o`3oool009?o00L0oooo0`00OOl00`3oool000000?ooo`02
0;d0o`040?ooo`2m0?l0_@3o001go`@0oooo00D00;Co0?ooo`3oool0oooo000do`04002oo`D0:03o
0P3oool00`00k?l0oooo0?ooo`040?ooo`030030o`3oool0oooo0080oooo0P00jol2001[o`D0oooo
00<00?nX0?ooo`3oool00`3oool00`00okD0oooo0?ooo`020?ooo`800?co0P00ool60?ooo`03003o
C03oool0oooo00L0oooo00@00?md0?ooo`3oool0oooo0P00nOl60?ooo`03003o203oool0oooo00@0
oooo00<04ol00?ooo`3oool0103oool3003Io`D0oooo00<06_l00?ooo`3oool0303oool2002Ro`03
0?ooo`00X_l0oooo0080oooo00<04ol00?ooo`3oool03@3oool2001Ho`030?ooo`00F?l0oooo0140
oooo00@0003o0?ooo`3oool0oooo0P000?l30?ooo`030000003oool0oooo00@0oooo0@0000010?oo
o`002`3oool00`000000oooo0?ooo`0:0?ooo`03001No`3oool0oooo00H0oooo00<002_o0?ooo`3o
ool02@3oool00`030?l0oooo002Co`060?ooo`0305`0o`00OOl0oooo0080oooo00@000000?ooo`3o
ool0oooo0P2m0?l00`3oool007Oo0?ooo`060?ooo`04000]o`3oool0oooo002oo`<0oooo100X0?l2
0?ooo`03003/o`3oool0oooo00@0oooo00<00<3o0?ooo`3oool00`3oool00`00jol006_o001[o`05
0?ooo`03003oZ03oool0oooo00L0oooo1000o?l00`00ool0oooo0?ooo`040?ooo`03003oC03oool0
oooo00H0oooo0`00og@30?ooo`03003io`3oool0oooo00@0oooo00<00?l80?ooo`3oool00`3oool2
01?o00T0oooo00<00=Wo0?ooo`3oool00P3oool01@0Jo`00oooo0?ooo`3oool0T?l000d0oooo00<0
0:;o0?ooo`3oool05@3oool00`00F?l0oooo0?ooo`0E0?ooo`80003o00<0oooo0000003oool01@3o
ool100000040oooo000<0?ooo`030000003oool0oooo00T0oooo00<005ko0?ooo`3oool01P3oool0
0`00:ol0oooo0?ooo`090?ooo`0300<0o`3oool0oooo00@0oooo0`1L0?l01@00OOl0oooo0?ooo`3o
ool0000000<0oooo00<0_@3o0?ooo`00Mol01P3oool3000]o`80oooo00D00;oo0?ooo`3oool0oooo
02P0o`050?ooo`03003/o`3oool0oooo00<0oooo00<00;?o0?ooo`3oool0103oool00`00jol006_o
0?ooo`040?ooo`03003oZ03oool0oooo00<0oooo00<00?o:0?ooo`3oool00`3oool2003lo`030?oo
o`00ool0oooo00D0oooo00<00?m<0?ooo`3oool01P3oool2003oM0D0oooo00<00?Wo0?ooo`3oool0
0`3oool00`00o`P0oooo0?ooo`040?ooo`804ol0203oool00`00fOl0oooo0?ooo`050?ooo`<0T?l0
3@3oool01000X_l0oooo0?ooo`3oool20>go0140oooo00<0ooP0001Ho`00F?l04@3oool0103<o`00
oooo0<co003<o`020?ooo`80003o1P3oool100000040oooo000=0?ooo`030000003oool0oooo00P0
oooo00<005ko0?ooo`3oool01@3oool00`00:ol0oooo0?ooo`090?ooo`0300<0o`3oool0oooo00@0
oooo0`1L0?l00`1I0?l007go0?ooo`020?ooo`040000003oool0oooo0;d0o`80oooo00<007Oo0?oo
o`3oool00`3oool4000]o`80oooo00D00;oo0?ooo`3oool0oooo02P0o`050?ooo`03003/o`3oool0
oooo0080oooo0P00/ol50?ooo`03003[o`00Jol0oooo00D0oooo00<00?nX0?ooo`3oool00P3oool2
003obP@0oooo00D00?co0?ooo`3oool0oooo003oo`060?ooo`05003oC03oool0oooo0?ooo`00oe00
103oool00`00og@0oooo0?ooo`040?ooo`03003io`3oool0oooo00D0oooo00D06_l00?ooo`3oool0
oooo01?o000;0?ooo`03003Io`3oool0oooo0080oooo00@0Jol00?ooo`3oool0T?l03`3oool01000
X_l0oooo0?ooo`3]o`0C0?ooo`80ooP000<005So0?ooo`3oool03P3oool20<co00D0oooo00<00000
0?ooo`3oool0103oool100000040oooo000>0?ooo`030000003oool0oooo00l0oooo00<002_o0?oo
o`3oool02@3oool00`030?l0oooo0?ooo`050?ooo`80G03o00<007go05`0o`3oool00P3oool01000
0000oooo0?ooo`2m0?l20?ooo`05001go`3oool0oooo0?ooo`3o0=T00P3oool3000]o`80oooo00@0
0;oo0?ooo`3oool0:03o1@3oool00`00k?l0oooo0?ooo`020?ooo`@00;?o103oool00`00jol006_o
0?ooo`050?ooo`04003oZ03oool0oooo0?ooo`@00?o:0`3oool01@00o?l0oooo0?ooo`3oool00?oo
00T0oooo0`00oe030?ooo`03003oM03oool0oooo00@0oooo00<00?Wo0?ooo`3oool0103oool301[o
0080oooo00<04ol00?ooo`3oool02@3oool01000fOl0oooo0?ooo`3oool206_o0080oooo00<0T?l0
0?ooo`3oool03P3oool01000X_l0T?l00?ooo`3]o`0@0?ooo`80O?l0503oool00`0go`00oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`40oooo000>0?ooo`030000003oool0
oooo00l0oooo00<002_o0?ooo`3oool01P3oool0100G0?l0oooo0?ooo`030?l70?ooo`80G03o00<0
07go0?ooo`3oool00P3oool01P000000oooo0;d0o`00D_l0oooo001go`<0oooo0P3o0=T20?ooo`80
02go0`3oool01000_ol0oooo0?ooo`0X0?l20?ooo`06002ao`3oool0oooo003/o`3oool0S03o0`3o
ool00`00/ol0oooo0?ooo`040?ooo`03003[o`3oool0oooo00<0oooo00<00?oo0?ooo`3oool0103o
ool00`00olX0oooo0?ooo`030?ooo`03003lo`3oool0oooo0080oooo00<00?oo0?ooo`3oool01`3o
ool01@00oe00oooo0?ooo`3oool00?md00P0oooo00<00?Wo0?ooo`3oool0103oool01@0Jo`00oooo
0?ooo`3oool04ol000`0oooo00<00=Wo0?ooo`3oool00P1[o`020?ooo`03093o003oool0oooo00h0
oooo00<0T?l00?ooo`3oool04@3oool207co01<0oooo0`0go`040?ooo`030000003oool0oooo00<0
oooo0@0000010?ooo`40oooo000?0?ooo`030000003oool0oooo00d0oooo00<002_o0?ooo`3oool0
1@3oool301L0o`030?ooo`030?l0oooo00L0oooo00<0G03o0?ooo`00OOl0103oool01P000000oooo
001Bo`00D_l0oooo001go`80oooo103o0=T00`3oool002go0?ooo`020?ooo`04002oo`3oool0oooo
02P0o`80oooo0P00/Ol20?ooo`<0S03o0`3oool00`00/ol0oooo0?ooo`040?ooo`03003[o`3oool0
oooo0080oooo0P00ool00`003?l0oooo0?ooo`030?ooo`03003obP3oool0oooo0080oooo00<00?co
0?ooo`3oool00`3oool01000ool0oooo0?ooo`00olL60?ooo`05003oD03oool0oooo0?ooo`00og@0
203oool00`00nOl00?nZ0?ooo`040?ooo`0501[o003oool0oooo0?ooo`0Co`002`3oool00`00oj/0
oooo0?ooo`020?ooo`0306_o003oool0oooo00d0oooo0`00ol/20?ooo`03093o003oool0oooo00h0
oooo0`00n_l00`3oool0O?l007co000A0?ooo`0303Oo0000Z_l0oooo00<0=ol000<0oooo0000003o
ool0103oool100000040oooo0@3oool00100oooo00<000000?ooo`3oool0303oool00`00:ol0oooo
0?ooo`040?ooo`D05`3o00<00`3o0?ooo`3oool01@3oool0101L0?l0oooo0?ooo`00OOl40?ooo`03
00000000D_l005;o008005;o0P3oool50?l0f@030?ooo`00;Ol0oooo0080oooo00D00;oo0?ooo`3o
ool0:03o0?ooo`04002ao`0408`0o`3oool0S03o08`0o`<0oooo00<00;?o0?ooo`3oool00`3oool0
0`00Jol00>_o0?ooo`020?ooo`@00?oo1@3oool00`00olX0oooo0?ooo`020?ooo`03003lo`3oool0
oooo00<0oooo00<00?oo002Ro`00olL00P00olL40?ooo`03003oD03oool0oooo00L0oooo00<00?o;
0?ooo`3oool00P3oool3003oZP<0oooo00<06_l00?ooo`3oool0303oool3003oZ`@0oooo00<0Jol0
0?ooo`3oool0303oool3003ob`80oooo00<0T?l00?ooo`3oool03P3oool3003jo`<0oooo00<0O?l0
0?ooo`3oool03@3oool3002Zo`D0oooo00<000000?ooo`3oool00`3oool100000040oooo0@3oool0
0140oooo00<000000?ooo`3oool02`3oool00`00:ol0oooo0?ooo`060?ooo`<05`3o203oool00`1L
0?l0oooo001mo`050?ooo`80_@3o0`00D_l30?ooo`<0o`3I00<0oooo000]o`3oool00`3oool00`00
_ol0oooo02P0o`030?ooo`<00;7o102<0?l20?ooo`03002co`3oool0oooo00@0oooo00<006_o003[
o`3oool00P3oool4003oo`D0oooo00<00?o:0?ooo`3oool01`3oool2002Ro`<00?o71@3oool00`00
oe00oooo0?ooo`060?ooo`800?o;103oool3003oZP<0oooo00<06_l00?ooo`3oool0103oool2003o
?`L0oooo0`00oj/30?ooo`0306_o003oool0oooo00`0oooo0P00ol/01@3oool00?o;0?ooo`3oool0
T?l000l0oooo1000n_lB0?ooo`04002Zo`3oool00:[o002Zo`@0oooo00<000000?ooo`3oool00`3o
ool100000040oooo0@3oool00140oooo00<000000?ooo`3oool02`3oool00`00:ol0oooo0?ooo`06
0?ooo`0301L0o`3oool0oooo00L0oooo00@0G03o0?ooo`3oool007go0`3oool30;d0o`030?ooo`00
D_l0oooo00@0oooo00D0o`3I0?ooo`3oool0oooo000]o`040?ooo`04002oo`3oool0:03o02P0o`80
oooo00@00;7o0?ooo`3oool0oooo0P2<0?l30?ooo`03002co`3oool0oooo00@0oooo00<006_o0?oo
o`3oool00`3oool00`00ool000co0?ooo`050?ooo`03003obP3oool0oooo00P0oooo0P00X_l00`3o
ool00?o70?ooo`040?ooo`03003oD03oool0oooo00H0oooo0`00ol/40?ooo`03003oZP3oool0oooo
0080oooo00<06_l00?ooo`3oool00`3oool3003o?`P0oooo00<00?n[0?ooo`3oool00P3oool00`1[
o`00oooo0?ooo`0303ko00X0oooo0P00ol/50?ooo`030:7o003oool0oooo00`0oooo1000n_lB0?oo
o`800:[o00@0oooo002Zo`00Z_l00:[o0P3oool00`000000oooo0?ooo`020?ooo`4000000@3oool1
0?ooo`004P3oool00`000000oooo0?ooo`090?ooo`03000[o`3oool0oooo00H0oooo00<05`3o0?oo
o`3oool0203oool0101L0?l0oooo0?ooo`00OOl20?ooo`D0_@3o00<005;o0?ooo`3oool00P3oool0
0`3o0=T0oooo0?ooo`020?ooo`03000]o`3oool0oooo00<0oooo0`0X0?l20?ooo`04002ao`3oool0
oooo08`0o`D0oooo00<00;?o0?ooo`3oool00`3oool2001[o`D0oooo00<00?oo0?ooo`3oool0103o
ool00`00olX0oooo0?ooo`030?ooo`03003lo`3oool0oooo0080oooo00D00:;o0?ooo`3oool0oooo
003oa`050?ooo`03003oD03oool0oooo0080oooo00D00?md0?ooo`3oool0oooo003ob`060?ooo`03
003oZP3oool0oooo0080oooo00<06_l00?ooo`3oool0103oool2003o?`P0oooo00<00?n[0?ooo`3o
ool01P3oool00`0no`00oooo0?ooo`0;0?ooo`04003ob`3oool0oooo0?ooo`<0XOl0403oool00`3<
o`000?[o0<co000A0?ooo`80Z_l00`3oool2002Zo`030000003oool0oooo0080oooo0@0000010?oo
o`40oooo000C0?ooo`030000003oool0oooo00P0oooo00<002_o0?ooo`3oool01P3oool00`0G0?l0
oooo0?ooo`070?ooo`0305`0o`3oool0oooo00D0oooo0`2m0?l00`00D_l0oooo0?ooo`030?ooo`05
0?l0f@3oool0oooo0?ooo`00;Ol01@3oool0100X0?l0oooo02P0o`0X0?l20?ooo`04002ao`3oool0
oooo08`0o`D0oooo00<00;?o0?ooo`3oool00P3oool4001[o`<0oooo00<000co003oo`3oool01@3o
ool01000olX0oooo0?ooo`3oool3003lo`@0oooo00D00:;o0?ooo`3oool0oooo003oa`050?ooo`04
003oD03oool0oooo0?ooo`800?md0P3oool00`00ol/0oooo0?ooo`050?ooo`03003oZP3oool0oooo
00H0oooo00@04ol00?ooo`3oool00?lo2P3oool00`00oj/0oooo0?ooo`020?ooo`04093o003oool0
oooo03ko00h0oooo00D00?o;0?ooo`3oool0oooo0:7o000B0?ooo`030<co0000n_l0oooo0100oooo
00<0Z_l00?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`4000000@3oool10?ooo`00503o
ool00`000000oooo0?ooo`0@0?ooo`0301L0o`3oool0oooo00D0oooo00<0I`3o0?ooo`1L0?l01`3o
ool0102m0?l0oooo0;d0o`00D_l40?ooo`030?l0f@3oool0oooo0080oooo00<002go0?ooo`3oool0
103oool302P0o`80oooo00<00;7o0?ooo`2<0?l01@3oool00`00/ol0oooo0?ooo`040?ooo`<006_o
0`3oool00`003?l00?oo0?ooo`050?ooo`03003obP3oool0oooo0080oooo0`00o?l20?ooo`03002R
o`3oool0oooo0080oooo00<00?o70?ooo`3oool01P3oool4003oM0030?ooo`00ol/0oooo00H0oooo
00<00?nZ0?ooo`3oool0103oool301?o00030?ooo`00ocl0oooo00X0oooo00@00?n[0?ooo`3oool0
oooo0`2@o`000`3oool0?_l00?ooo`0=0?ooo`03003ob`3oool0kOl002h0oooo00<000000?ooo`3o
ool00P3oool100000040oooo0@3oool001@0oooo00<000000?ooo`3oool03`3oool00`0G0?l0oooo
0?ooo`050?ooo`80I`3o00<0G03o0?ooo`3oool01P3oool0102m0?l0oooo00000000D_l40?ooo`05
0?l0f@3oool0oooo000Fo`00;Ol01`3oool00`0X0?l0oooo0?ooo`020?ooo`03002ao`3oool0S03o
00@0oooo00<008go002co`3oool0103oool00`00Jol0oooo0?ooo`030?ooo`03000<o`3oool00?oo
00@0oooo00<00?Wo0?ooo`3oool0103oool00`00o?l0oooo0?ooo`020?ooo`03002Ro`3oool0oooo
0080oooo00<00?o70?ooo`3oool01`3oool01000og@0oooo0?ooo`00ol/90?ooo`03003oZP3oool0
oooo00@0oooo00@04ol00?ooo`3oool00?lo303oool01@00oj/0oooo0?ooo`3oool0T?l00180oooo
00<00?o;0>go003]o`004P3oool20?oh0180oooo0P3<o`050?ooo`030000003oool0oooo0080oooo
0@0000010?ooo`40oooo000E0?ooo`030000003oool0oooo00h0oooo00<05`3o0?ooo`3oool0103o
ool306L0o`0305`0o`3oool0oooo00D0oooo00@0_@3o0?ooo`3oool005;o103oool00`3o0=T0oooo
000Fo`02000Fo`03000]o`3oool0oooo00@0oooo00<0:03o0?ooo`3oool00`3oool00`00/Ol0S03o
0?ooo`020?ooo`<008go1P3oool00`00Jol0oooo0?ooo`030?ooo`03000<o`00ool0oooo00<0oooo
0P00nOl60?ooo`05003lo`3oool0oooo0?ooo`00X_l01@3oool01@00olL0oooo0?ooo`3oool00?nZ
00D0oooo00@00?md0?ooo`3oool00?o;2@3oool00`00ojX0oooo003oI@040?ooo`0301?o003oool0
oooo00d0oooo00D00?n[0?ooo`3oool0oooo093o000C0?ooo`030>go003oool0oooo0180oooo00<0
ooP00?ooo`3oool0403oool00`3<o`00oooo0<co00020<co0080oooo00<000000?ooo`3oool00P3o
ool100000040oooo0@3oool001H0oooo00<000000?ooo`3oool03@3oool00`0G0?l0oooo0?ooo`03
0?ooo`D0I`3o1`3oool0102m0?l0oooo00000000D_l40?ooo`030?l0f@005_l001Ko00<001Ko1P3o
ool00`0X0?l0oooo0?ooo`020?ooo`03002ao`3oool0S03o0080oooo1000SOl50?ooo`03001[o`3o
ool0oooo00<0oooo00<000co0?ooo`00ool0103oool3003io`@0oooo00<00?co0?ooo`3oool00P3o
ool00`00X_l0oooo0?ooo`030?ooo`03003oa`3oool0oooo00800?nZ1@3oool00`00og@0oooo0?oo
o`0:0?ooo`03003oZP00ofD00?mU00@0oooo00<04ol00?ooo`3oool03@3oool2003o?`80oooo00<0
T?l00?ooo`3oool03P3oool2003o?`80oooo00<0kOl00?ooo`3oool03P3oool3003oI@030?ooo`3o
n000oooo0140oooo00<00?nZ0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`4000000@3o
ool10?ooo`005`3oool00`000000oooo0?ooo`0;0?ooo`0301L0o`3oool0oooo00D0oooo101W0?l7
0?ooo`040;d0o`3oool00000001Bo`<0oooo0`3o0=/0103oool001Ko000Fo`005_l50?ooo`0302P0
o`3oool0oooo00<0oooo00@00;7o08`0o`3oool0Q`3o0`3oool2002=o`D0oooo00<006_o0?ooo`3o
ool0103oool00`005Ol00?oo0?ooo`030?ooo`<00?Wo103oool00`00o?l0oooo0?ooo`080?ooo`03
003oa`3oool0oooo00<00?nZ0`3oool00`00og@0oooo0?ooo`0<0?ooo`<00?mU0P3oool00`0Co`00
oooo0?ooo`0=0?ooo`<00?lo0P3oool00`2@o`00oooo0?ooo`0>0?ooo`<00?lo00<0oooo0>go003o
ool03`3oool3003oIA80oooo0`00ojX50?ooo`030000003oool0oooo0080oooo0@0000010?ooo`40
oooo000G0?ooo`030000003oool0oooo00/0oooo00<05`3o0?ooo`3oool01@3oool00`1W0?l0oooo
0?ooo`070?ooo`060;d0o`3oool0oooo00000000D_l0oooo0P3o0=/0103o0=T0o`3K0?l0f`005_l8
0?ooo`0302P0o`3oool0oooo00<0oooo00@00;7o08L0o`270?l0Q`3o0`3oool00`00SOl0oooo0?oo
o`030?ooo`03001[o`3oool0oooo00@0oooo0P005Ol00`00ool0oooo0?ooo`020?ooo`03003io`3o
ool0oooo00@0oooo00<00?co0?ooo`3oool00`3oool00`00/Ol0oooo0?ooo`060?ooo`03003oZP3o
ool0oooo0080oooo00<00?md0?ooo`3oool03@3oool01@00ofD0oooo0?ooo`3oool04ol00100oooo
0P00oclC0?ooo`800?lo503oool2003oIA80oooo1000ojX40?ooo`030000003oool0oooo0080oooo
0@0000010?ooo`40oooo000H0?ooo`030000003oool0oooo00X0oooo00<05`3o0?ooo`3oool01@3o
ool00`1W0?l0oooo0?ooo`070?ooo`040;d0o`3oool0oooo001Bo`<0oooo103o0=/00`005_l0oooo
0?ooo`050?ooo`0302P0o`3oool0oooo00<0oooo00<0Q`3o002ao`3oool00P270?l20?ooo`03002=
o`3oool0oooo00@0oooo00<006_o0?ooo`3oool00`3oool4000Eo`@0oooo00<00?Wo0?ooo`3oool0
0`3oool00`00o?l0oooo0?ooo`030?ooo`800;7o203oool00`00ojX0oooo0?ooo`020?ooo`03003o
M03oool0oooo0080oooo00<00?nb0?ooo`3oool0203oool00`00ofD0oooo0?ooo`060?ooo`03003o
6@3oool0oooo00X0oooo00<00?lo0?ooo`3oool04P3oool00`00ocl0oooo0?ooo`0D0?ooo`03003o
I@3oool0oooo0100oooo0P00ojX00`3oool00?nZ003oZP020?ooo`030000003oool0oooo0080oooo
0@0000010?ooo`40oooo000I0?ooo`030000003oool0oooo00P0oooo00<05`3o0?ooo`3oool01@3o
ool00`1W0?l0oooo0?ooo`070?ooo`050;d0o`3oool0oooo0?ooo`00D_l0103oool20?l0f`030?oo
o`005_l0oooo00H0oooo00<0:03o0?ooo`3oool01@3oool308L0o`80oooo00<008go0?ooo`3oool0
0`3oool00`00Jol0oooo0?ooo`050?ooo`<001Go103oool00`00nOl0oooo0?ooo`030?ooo`03003l
o`3oool0oooo0080oooo1000/Ol60?ooo`03003oZP3oool0oooo00L0oooo0P00ok8:0?ooo`03003o
I@3oool0oooo00D0oooo0P00oaT<0?ooo`03003o?`3oool0oooo00<0oooo00<0O?l00?ooo`3oool0
3@3oool00`00ocl0oooo0?ooo`0D0?ooo`03003oI@3oool0oooo01@0oooo0P00ojX00`000000oooo
0?ooo`020?ooo`4000000@3oool10?ooo`006P3oool00`000000oooo0?ooo`070?ooo`0301L0o`3o
ool0oooo00D0oooo00<0I`3o0?ooo`3oool01`3oool01@320?l0oooo0?ooo`3oool0000000<0oooo
00@0o`3K0?ooo`3oool001Ko1`3oool00`0X0?l0=03o0?ooo`060?ooo`0308L0o`3oool0oooo0080
oooo00<008go0?ooo`3oool00`3oool00`00Jol0oooo0?ooo`040?ooo`03000Eo`3oool001Go00D0
oooo00<00?Wo0?ooo`3oool02@3oool2002ao`L0oooo00<00?nZ0?ooo`3oool01`3oool3003o/PT0
oooo00<00?mU0?ooo`3oool0103oool3003o6@`0oooo00<00?lo0?ooo`3oool00P3oool207co00l0
oooo00<00?lo0?ooo`3oool00P3on00C0?ooo`03003oI@3oool0oooo01D0oooo00<000000?ooo`3o
ool00P3oool100000040oooo0@3oool001X0oooo00<000000?ooo`3oool03P3oool00`1W0?l0oooo
0?ooo`060?ooo`<0`P3o0`3oool01@000000oooo0?ooo`3oool0o`3K0080oooo00<001Ko0?ooo`3o
ool0103oool303@0o`H0oooo00<0Q`3o0?ooo`3oool00P3oool00`00SOl0oooo0?ooo`050?ooo`03
001Eo`3oool0oooo00<0oooo00<001Go0?ooo`3oool01@3oool00`00nOl0oooo0?ooo`030?ooo`03
003Io`3oool0oooo0080oooo00<00;7o0?ooo`3oool01`3oool00`00ojX0oooo0?ooo`070?ooo`03
003o/P3oool0oooo00T0oooo00<00?mU0?ooo`3oool01@3oool00`00oaT0oooo0?ooo`0<0?ooo`03
003o?`3oool0oooo0080oooo00<0O?l00?ooo`3oool03P3oool00`00ocl0oooo0?oh000C0?ooo`03
0?nG003oool0oooo0100oooo103o^P020?ooo`030000003oool0oooo0080oooo0@0000010?ooo`40
oooo000K0?ooo`030000003oool0oooo00d0oooo00<0I`3o0?ooo`3oool0103oool50<80o`<0oooo
00@000000?ooo`3oool0o`3K0`3oool00`005_l0oooo0?ooo`020?ooo`030?l0K`0d0?l0=03o0080
=03o1@3oool00`270?l0oooo0?ooo`030?ooo`03002=o`3oool0k@3o00<0oooo0`00EOl40?ooo`03
000Eo`3oool0oooo00D0oooo00<00?Wo0?ooo`3oool00`3oool2003Io`@0oooo00<00;7o0?ooo`3o
ool01`3oool00`00ojX0oooo0?ooo`020?ooo`05003oZ`3oool0oooo0?ooo`00ok80303oool01@00
ofD0oooo0?ooo`3oool00?lo0080oooo00<00?lI0?ooo`3oool03@3oool01@00ocl0oooo0?ooo`3o
ool0O?l001<0oooo00<0ooP00?ooo`3oool04P3oool00`3oU`00oooo0?ooo`0@0?ooo`030?nj003o
ool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`00703oool00`000000oooo0?oo
o`0<0?ooo`0306L0o`3oool0oooo00D0oooo10320?l30?ooo`030000003oool0o`3K00<0oooo00@0
01Ko0?ooo`3oool0oooo0`3o06l0103oool0=03o03@0o`0d0?l50?ooo`0308L0o`3oool0oooo00<0
oooo00<008go0>d0o`3]0?l00P3oool4001Eo`@0oooo00<001Go0?ooo`3oool01@3oool00`00nOl0
oooo0?ooo`020?ooo`@00=Wo0P3oool00`00/Ol0oooo0?ooo`080?ooo`04003oZP3oool0oooo0?oo
o`800?n[0`3oool00`00ok80oooo0?ooo`0:0?ooo`03003oI@3oool00?lo00800?lo0P3oool00`00
oaT0oooo0?ooo`0>0?ooo`0401?o003oool0oooo07co0140oooo00<0?_l00?ooo`3on000;@3oool0
1@000000oooo0?ooo`3oool000000080oooo000M0?ooo`030000003oool0oooo00X0oooo00<0I`3o
0?ooo`3oool01`3oool20<80o`@0oooo00<000000?ooo`3o0=/00`3oool01@005_l0oooo0?l0K`3o
06l0oooo0080o`1_00<0oooo03@0o`0d0?l01@3oool00`270?l0oooo0?ooo`030?ooo`03002=o`3o
ool0k@3o0080k@3o0`3oool2001Eo`<0oooo00<001Go0?ooo`3oool0103oool204T0o`03003io`3o
ool0oooo00<0oooo0`00fOl20?ooo`03002ao`3oool0oooo00@0oooo00D005So0?ooo`3oool0oooo
003oZP040?ooo`800?n[00<0oooo003o/P3oool03`3oool2003o?`030?ooo`00oaT0oooo00l0oooo
0`0Co`000`3oool0O?l00?ooo`0?0?ooo`<0?_l04P3oool203Oo01<0oooo0P00o`050?ooo`040000
003oool0oooo000000<0oooo000N0?ooo`030000003oool0oooo00T0oooo00<0I`3o0?ooo`3oool0
1`3oool00`320?l0oooo0?ooo`030?ooo`030000003o0=/0oooo0080oooo00@001Ko0?ooo`3oool0
oooo103o06l00`3oool0=03o0?ooo`050?ooo`0308L0o`3oool0oooo00<0oooo00D008go0>d0o`3]
0?l0oooo0>d0o`020?ooo`03001Eo`3oool0oooo00<0oooo00<001Go0?ooo`3oool00`3oool01019
0?l0oooo04T0o`190?l50?ooo`05003Io`3oool0oooo0?ooo`00/Ol01P3oool2001Ho`L0oooo00D0
0?n[0?ooo`3oool0oooo003o/P050?ooo`800?[o2@3oool01000ocl0oooo0?ooo`00oaTA0?ooo`03
01?o003oool0oooo0140oooo0P0no`0C0?ooo`80=ol04`3oool3003o00@0oooo00@000000?ooo`3o
ool000000`3oool001h0oooo00<000000?ooo`3oool0203oool00`1W0?l0oooo0?ooo`070?ooo`03
0<80o`3oool0oooo00@0oooo00<000000?l0f`3oool00P3oool00`005_l0oooo0?ooo`020?ooo`80
o`1_00<0oooo03@0o`3oool01@3oool00`270?l0oooo0?ooo`050?ooo`<0k@3o0`3oool00`00EOl0
oooo0?ooo`020?ooo`03000Eo`3oool0oooo00D0oooo0`190?l40?ooo`03003Io`3oool0oooo0080
oooo00<00;7o0?ooo`3oool00`3oool4001Ho`H0oooo00<00?n[0?ooo`3oool01P3oool3003jo`T0
oooo00<00?lo0?ooo`3oool01@3oool00`00ofD0oooo0?ooo`0:0?ooo`0301?o003oool0oooo01<0
oooo00<0?_l00?ooo`3oool04P3oool00`0go`00oooo0?ooo`0@0?ooo`@00?l00`3oool010000000
oooo0?ooo`0000030?ooo`007`3oool00`000000oooo0?ooo`070?ooo`0306L0o`3oool0oooo00L0
oooo00<0`P3o0?ooo`3oool0103oool00`3o0=/0o`3I0?ooo`060?ooo`050?l0K`3oool0oooo0?oo
o`0d0?l01P3oool00`270?l0S03o0?ooo`040?ooo`030>d0o`3oool0oooo00<0oooo00<005Go0?oo
o`3oool00`3oool00`005Ol0oooo0?ooo`040?ooo`0304T0o`3oool0B@3o00D0oooo00<00=Wo0?oo
o`3oool0203oool3001Ho`L0oooo00<00?n[0?ooo`3oool01`3oool2003jo`T0oooo00<00?lo0?oo
o`3oool0103oool3003oI@/0oooo00<04ol00?ooo`3oool00P3oool303Oo00h0oooo00@0?_l00?oo
o`3oool0c?l04P3oool00`0go`00oooo0?ooo`0C0?ooo`04003o003oool0oooo00000080oooo00<0
00000?ooo`3oool00@3oool00200oooo00<000000?ooo`3oool03`3oool00`320?l0oooo0?ooo`04
0?ooo`<0o`3I1P3oool00`3o06l0oooo0?ooo`020?ooo`0303@0o`3oool0oooo00<0oooo0`2<0?l5
0?ooo`030>d0o`3oool0oooo00<0oooo00<005Go0?ooo`3oool01@3oool00`003?l0oooo0?ooo`02
0?ooo`0304T0o`3oool0oooo00@0oooo00<00=Wo0?ooo`3oool0103oool00`00X_l0oooo0?ooo`02
0?ooo`03001Ho`3oool0oooo00L0oooo00<00?n[0?ooo`3oool01P3oool00`00n_l0oooo0?ooo`08
0?ooo`03003o?`3oool0oooo00D0oooo0P00ofD<0?ooo`0301?o003oool0oooo0080oooo0P0go`0?
0?ooo`0403ko003oool0c?l00<co0180oooo00<0okX00?ooo`3oool04@3oool00`3oZP00oooo0?oo
o`020?ooo`040000003oool0oooo000000<0oooo000Q0?ooo`030000003oool0oooo00h0oooo00<0
`P3o0?ooo`3oool00`3oool00`3o0=T0o`3K0?l0f@020?l0f@D0oooo00D0o`1_0?ooo`3oool0oooo
03@0o`050?ooo`@0S03o103oool00`3]0?l0oooo0?ooo`040?ooo`03001Eo`3oool0oooo00<0oooo
0`003?l30?ooo`0304T0o`3oool0oooo00D0oooo00<00=Wo0?ooo`3oool00`3oool2002Ro`<0oooo
00<005So0?ooo`3oool01`3oool00`00oj/0oooo0?ooo`030?ooo`04003ob`3oool0oooo003jo`/0
oooo00<00?lo0?ooo`3oool0103oool00`00ofD0oooo0?ooo`0<0?ooo`0301?o003oool0oooo0080
oooo00<0=ol00?ooo`3oool0403oool00`3<o`00oooo0?ooo`0A0?ooo`030?nj003oool0oooo0100
oooo0P3oZP040?ooo`040000003oool0oooo000000<0oooo000Q0?ooo`030000003oool0oooo00d0
oooo00<0`P3o0?ooo`3oool01@3oool40?l0f@@0oooo00<0o`1_0?ooo`3oool00P3oool00`0d0?l0
oooo0?ooo`040?ooo`<0S03o103oool00`3]0?l0oooo0?ooo`030?ooo`03001Eo`3oool0oooo00<0
oooo00@000co0?ooo`003?l000co0`3oool00`190?l0oooo0?ooo`050?ooo`03003Io`3oool0oooo
0080oooo1000X_l20?ooo`03001Ho`3oool0oooo00L0oooo00<00?n[0?ooo`3oool00P3oool2003o
b`030?ooo`00n_l0oooo00/0oooo00<00?lo0?ooo`3oool00P3oool00`00ocl0oooo003oI@0A0?oo
o`0303ko000go`00oooo0180oooo00<0c?l00?ooo`3oool0:P3oool010000000oooo0?ooo`000003
0?ooo`008P3oool00`000000oooo0?ooo`0<0?ooo`030<80o`3oool0oooo00D0oooo00<0o`3I0000
003o0=T0103oool00`3o06l0oooo0?ooo`020?ooo`0303@0o`3oool0oooo00D0oooo0P2<0?l40?oo
o`030>d0o`3oool0oooo00@0oooo00<005Go0?ooo`3oool0103oool3000<o`80oooo00<0B@3o0?oo
o`3oool01@3oool00`00fOl0oooo0?ooo`040?ooo`<00:;o00<0oooo001Ho`3oool02@3oool01000
oj/0oooo0?ooo`3oool3003ob`030?ooo`00n_l0oooo00l0oooo0P00ocl00`00ofD0oooo0?ooo`0?
0?ooo`80?_l000<0=ol00?ooo`3oool0403oool00`2Qo`00oooo0?ooo`0[0?ooo`040000003oool0
oooo000000<0oooo000S0?ooo`030000003oool0oooo00X0oooo00<0`P3o0?ooo`3oool01P3oool0
0`3o0=T000000?ooo`040?ooo`030?l0K`3oool0oooo0080oooo00<0=03o0?ooo`3oool0103oool0
0`2<0?l0oooo0?ooo`040?ooo`030>d0o`3oool0oooo00<0oooo00<005Go0?ooo`3oool01@3oool0
1@003?l0oooo0?ooo`3oool0B@3o00P0oooo00<00=Wo0?ooo`3oool0103oool01@00X_l0oooo0?oo
o`3oool005So00l0oooo00<00?o;0?ooo`00n_l04@3oool2003o?a80oooo0P0no`0B0?ooo`<0XOl0
4P3oool20<co0180oooo0P2Zo`040?ooo`040000003oool0oooo000000<0oooo000T0?ooo`030000
003oool0oooo00T0oooo00<0`P3o0?ooo`3oool01@3oool00`3o0=T000000?ooo`040?ooo`030?l0
K`3oool0o`1_0080oooo00<0=03o0?ooo`3oool01@3oool00`2<0?l0oooo0?ooo`030?ooo`030>d0
o`3oool0oooo00@0oooo00<005Go0?ooo`3oool0103oool00`003?l0oooo0?ooo`020?ooo`0304T0
o`3oool0oooo00`0oooo00D00:;o0?ooo`3oool0oooo001Ho`0@0?ooo`03003ob`3oool0oooo0140
oooo00<00?lo0?ooo`3oool04P3oool00`0no`00oooo0?ooo`0A0?ooo`030:7o003oool0oooo0140
oooo0P3<o`0B0?ooo`<0Z_l00`3oool010000000oooo0?ooo`0000030?ooo`00903oool00`000000
oooo0?ooo`080?ooo`030<80o`3oool0oooo00H0oooo00<0o`3I0000003oool0103oool30?l0K`80
oooo00<0=03o0?ooo`3oool0103oool00`2<0?l0oooo0?ooo`040?ooo`030>d0o`3oool0k@3o00/0
oooo00D000co0?ooo`3oool0oooo04T0o`0?0?ooo`03002Ro`3oool0oooo0140oooo00<00?o;0?oo
o`3oool04P3oool00`00ocl0oooo0?ooo`0A0?ooo`0303ko003oool0oooo0180oooo00<0XOl00?oo
o`3oool04P3oool00`3<o`00oooo0?ooo`0C0?ooo`070:[o003oool0oooo0?ooo`000000oooo0000
00030?ooo`009@3oool00`000000oooo0?ooo`070?ooo`030<80o`3oool0oooo00D0oooo00<0o`3I
0?ooo`000000103oool40?l0K`T0oooo00<0S03o0?ooo`3oool00`3oool40>d0o`X0oooo00<000co
0?ooo`3oool01@3oool00`190?l0oooo0?ooo`090?ooo`03002Ro`3oool0oooo00@0oooo00<005So
0?ooo`3oool02`3oool00`00ol/0oooo0?ooo`0B0?ooo`03003o?`3oool0oooo0140oooo00<0?_l0
0?ooo`3oool04P3oool00`2Qo`00oooo0?ooo`0C0?ooo`030<co003oool0oooo01H0oooo00<00000
0?ooo`0000000`3oool002H0oooo00<000000?ooo`3oool03P3oool00`3o0=T0oooo000000030?oo
o`030?l0K`3oool0o`1_0080o`1_203oool00`2<0?l0oooo0?ooo`030?ooo`80k@3o00<0oooo0>d0
o`3]0?l02P3oool00`003?l0oooo0?ooo`030?ooo`<0B@3o2`3oool00`00X_l0oooo0?ooo`030?oo
o`8005So3@3oool00`00ol/0oooo0?ooo`030?ooo`03003jo`3oool0oooo00/0oooo00<00?lo0?oo
o`3oool04P3oool00`0no`00oooo0?ooo`0B0?ooo`030:7o003oool0oooo02`0oooo00<000000?oo
o`0000000`3oool002L0oooo00<000000?ooo`3oool0303oool0103o0=T0oooo0?ooo`0000040?oo
o`@0o`1_203oool00`2<0?l0oooo0?ooo`040?ooo`@0k@3o2@3oool00`003?l0oooo0?ooo`030?oo
o`D0B@3o2P3oool00`00X_l0oooo0?ooo`020?ooo`@005So2`3oool00`00ol/0oooo0?ooo`020?oo
o`<00?[o3@3oool00`00ocl0oooo0?ooo`020?ooo`03003oI@3oool0oooo00d0oooo00<0?_l00?oo
o`3oool0@@3oool00`000000oooo000000030?ooo`009`3oool00`000000oooo0?ooo`0<0?ooo`04
0?l0f@3oool0oooo000000@0oooo00<0o`1_0?ooo`3o06l0203oool00`2<0?l0oooo0?ooo`060?oo
o`80k@3o2P3oool00`003?l0oooo0?ooo`040?ooo`<0B@3o2P3oool00`00X_l0oooo0?ooo`040?oo
o`<005So2`3oool00`00ol/0oooo0?ooo`020?ooo`<00?[o403oool3003oIA<0oooo00<0=ol00?oo
o`3oool0?@3oool00`000000oooo000000030?ooo`00:03oool00`000000oooo0?ooo`0:0?ooo`05
0?l0f@3oool0oooo0?ooo`0000000`3oool00`3o06l0oooo0?ooo`060?ooo`040?l0003oool0oooo
08`0o`L0oooo00<0k@3o0?ooo`3oool02@3oool00`003?l0oooo0?ooo`050?ooo`0304T0o`3oool0
oooo00X0oooo00<00:;o0?ooo`3oool00`3oool00`00F?l0oooo0?ooo`0A0?ooo`800?[o4P3oool2
003oIA40oooo0`0go`0A0?ooo`80c?l04`3oool00`3o^P00oooo0?ooo`0F0?ooo`030000003oool0
000000<0oooo000Y0?ooo`030000003oool0oooo00T0oooo00D0o`3I0?ooo`3oool0oooo00000003
0?ooo`030?l0K`3oool0oooo00@0oooo0`3o00000`3oool0S03o0?ooo`060?ooo`030>d0o`3oool0
oooo00D0oooo0P3o0:X30?ooo`03000<o`3oool0oooo00@0oooo00<0B@3o0?ooo`3oool04@3oool0
0`00F?l0oooo0?ooo`0A0?ooo`03003jo`3oool0oooo0140oooo00<00?mU0?ooo`3oool04@3oool0
0`0go`00oooo0?ooo`0A0?ooo`030<co003oool0oooo0100oooo0P3o^P0C0?ooo`030?nZ003oool0
oooo0080oooo00<000000?ooo`0000000`3oool002X0oooo00<000000?ooo`3oool01`3oool00`3o
0=T0oooo0?ooo`020?ooo`040000003oool0oooo0?l0K`H0oooo103o00000`3oool0S03o0?ooo`06
0?ooo`030>d0o`3oool0oooo00<0oooo103o0:X90?ooo`0304T0o`3oool0oooo00D0oooo0P2Z0?l:
0?ooo`03001Ho`3oool0oooo0140oooo00<00?[o0?ooo`3oool04@3oool00`00ofD0oooo0?ooo`0A
0?ooo`0303Oo003oool0oooo0140oooo00<0c?l00?ooo`3oool04P3oool00`3o^P00oooo0?ooo`0A
0?ooo`80ojX00`3oool00`000000oooo000000030?ooo`00:P3oool00`000000oooo0?ooo`070?oo
o`030?l0f@3oool0oooo0080oooo00@000000?ooo`3oool0o`1_1@3oool01P3o0000oooo0?l0003o
0000oooo0?l000L0oooo00<0k@3o0?ooo`3oool00`3oool50?l0ZPT0oooo00<0B@3o0?ooo`3oool0
0`3oool40:X0o`X0oooo00<005So0?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`03003j
o`3oool0oooo0140oooo00<00?mU0?ooo`3oool04@3oool00`0go`00oooo0?ooo`0A0?ooo`030<co
003oool0oooo0180oooo00<0okX00?ooo`3oool05P3oool00`000000oooo000000030?ooo`00:`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0o`1_00L0oooo1@3o00060?ooo`030>d0o`3o
ool0oooo00D0oooo103o0:X80?ooo`0304T0o`3oool0oooo00<0oooo1@2Z0?l90?ooo`03001Ho`3o
ool0oooo00<0oooo0`000?l;0?ooo`03003jo`3oool0oooo00@0oooo00<00:[o0?ooo`3oool02P3o
ool00`00ofD0oooo0?ooo`0A0?ooo`0303Oo003oool0oooo0180oooo00<0c?l00?ooo`3oool0:`3o
ool00`000000oooo000000030?ooo`00;03oool00`000000oooo0?ooo`0:0?ooo`030000003o06l0
oooo00L0oooo00@0o`000?ooo`3o0000o`001`3oool00`3]0?l0oooo0?ooo`050?ooo`<0o`2Z2@3o
ool00`190?l0oooo0?ooo`040?ooo`@0ZP3o2@3oool00`00F?l0oooo0?ooo`020?ooo`@0003o2`3o
ool00`00n_l0oooo0?ooo`020?ooo`<00:[o303oool00`00ofD0oooo0?ooo`020?ooo`800?nZD03o
ool2000000@0oooo000]0?ooo`030000003oool0oooo00T0oooo00<000000?l0K`3oool01P3oool0
0`3o0000oooo0?ooo`080?ooo`030>d0o`3oool0oooo00H0oooo00<0o`2Z0?ooo`3o0:X0203oool0
0`190?l0oooo0?ooo`050?ooo`030:X0o`3oool0ZP3o00T0oooo00<005So0?ooo`3oool0103oool3
0000o`X0oooo00<00?[o0?ooo`3oool0103oool2002Zoa00oooo0`00ojXA0?ooo`800?l0?@3oool2
000000@0oooo000]0?ooo`030000003oool0oooo00T0oooo00<0o`1_0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`080?ooo`030>d0o`3oool0oooo00D0oooo00<0o`2Z0?ooo`3oool02@3oool00`19
0?l0oooo0?ooo`050?ooo`030:X0o`3oool0oooo00T0oooo00<005So0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0@0?ooo`03002Zo`3oool00:[o0140oooo0P00ojXA0?ooo`800?l04@3oool20:[o
02X0oooo0P0000040?ooo`00;P3oool00`000000oooo0?ooo`080?ooo`030?l0K`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0203oool00`3]0?l0oooo0?ooo`050?ooo`030?l0ZP3oool0oooo00T0
oooo00<0B@3o0?ooo`3oool01@3oool00`2Z0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo0100
oooo00<00:[o0?ooo`3oool04@3oool00`00ojX0oooo0?ooo`0A0?ooo`03003o003oool0oooo0100
oooo0P2Zo`0B0?ooo`030?nZ003oool0oooo0100oooo0P3o00040?ooo`030000003oool0oooo0080
oooo000_0?ooo`030000003oool0oooo00H0oooo00<0o`1_0000003oool01P3oool00`3o0000oooo
0?ooo`0@0?ooo`030?l0ZP3oool0oooo0100oooo00<0ZP3o0?ooo`3oool0403oool00`000?l0oooo
0?ooo`0A0?ooo`03002Zo`3oool0oooo0140oooo00<00?nZ0?ooo`3oool0403oool00`00o`00oooo
0?ooo`0A0?ooo`030:[o003oool0oooo0100oooo00<0ojX00?ooo`3oool04@3oool20?l000@0oooo
00<000000?ooo`3oool00P3oool00300oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030?l0003oool0oooo0100oooo00<0o`2Z0?ooo`3oool04@3oool00`2Z0?l0oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0100oooo00<00:[o0?ooo`3oool04@3oool00`00ojX0oooo0?oo
o`0A0?ooo`03003o003oool0oooo0100oooo00<0Z_l00?ooo`3oool0:`3oool00`000000oooo0?oo
o`020?ooo`00<03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<0o`00
0?ooo`3oool04@3oool00`3o0:X0oooo0?ooo`0@0?ooo`030:X0o`3oool0oooo0100oooo00<0003o
0?ooo`3oool04@3oool00`00Z_l0oooo0?ooo`0A0?ooo`03003oZP3oool0oooo0100oooo00<00?l0
0?ooo`3oool0?`3oool00`000000oooo0?ooo`020?ooo`00<@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0403oool00`3o0:X0oooo0?ooo`0@0?oo
o`030:X0o`3oool0oooo0140oooo00<0003o0?ooo`3oool0403oool00`00Z_l0oooo0?ooo`0A0?oo
o`03003oZP3oool0oooo05<0oooo00<000000?ooo`3oool00P3oool00380oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0100oooo00<0o`2Z0?ooo`3o
ool04@3oool00`2Z0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3o
ool00P3oool003<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030?l0
003oool0oooo0100oooo00<0o`2Z0?ooo`3oool0403oool00`2Z0?l0oooo0?ooo`220?ooo`h00000
103oool003<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030?l0003o
ool0oooo0100oooo00<0o`2Z0?ooo`3oool0N`3ooolK00000180oooo000d0?ooo`050000003oool0
oooo0?ooo`000000NP3ooolK000002d0oooo000e0?ooo`040000003oool0oooo000005l0oooo6`00
00180?ooo`00=P3oool00`000000oooo000000130?oooa`00000H`3oool003H0oooo00<000000?oo
o`000000:03ooolK000007l0oooo000g0?ooo`8000003@3ooolK000009X0oooo000h0?ooo`h00000
]@3oool00001\
\>"],
  ImageRangeCache->{{{94.125, 344.688}, {420.25, 133.25}} -> {-0.253248, 
  0.431813, 0.00324326, 0.00324326}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell["\<\
What comes as no suprise we see that \"hunting for a hare\" is a \
stable equilibrium. It's also risk dominant equilibrium.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ultimatum bargaining", "Subsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
Consider the following situation. There are two players and 4 units \
do divide between these players. First player proposes distribution and \
second player judges this proposal. If the second player says \"no\" then \
nobdy gets anything. If he says \"yes\" then proposed distribution is \
implemented. First player can play \"fair\" or \"tough\". Now  the game looks \
something like this:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(A\  = \ {\ {2, \ 0}, {3, 0}}; \nB\  = \ {{2, 0}, \ {1, 0}}; \n
    MatrixForm[A]\), 
    \(MatrixForm[B]\), 
    \(\(g\  = \ 
      Game[{\((#[\([1]\)] . A . #[\([2]\)]\ &)\), \ 
          \((#[\([1]\)] . B . #[\([2]\)]\ &)\)}, \ {2, 2}]; \)\)}], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"2", "0"},
            {"3", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[27]//MatrixForm="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"2", "0"},
            {"1", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[28]//MatrixForm="]
}, Open  ]],

Cell["First, we solve for 1-sampling equilibrium.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquilibriumFilter[\ 
        Solve[\ SamplingEquilibriumEqs[g, {x, y}], \ VarList[g, {x, y}]]] // 
      ColumnForm\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            \({x[1.`] \[Rule] 0, x[2.`] \[Rule] 1.`, y[1.`] \[Rule] 1.`, 
              y[2.`] \[Rule] 0}\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {{x[ 1.0] -> 0, x[ 2.0] -> 1.0, y[ 1.0] -> 1.0, y[ 2.0] -> 
        0}}],
      Editable->False]], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["\<\
There is only one sampling equilibrium. First player plays \
\"tough\" and second player accepts this. We can look at 1-sampling dynamics \
to actually see that this equilibrium is stable.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ode\  = \ WinningProbabilityDiff[g, {x, y}]; \n
    ode\  = \ Drop[ode, {4}]; \ ode\  = \ Drop[ode, \ {2}]; \n
    ode\  = \ \(\(ode\  /. \ x[2] -> \((1 - x[1])\)\) /. 
          y[2] -> \((1 - y[1])\)\) /. z[2] -> \((1 - z[1])\); \ ode\)], 
  "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \({\(-x[1]\) + 1\/2\ \((1 - y[1])\)\^2 + \((1 - y[1])\)\ y[1], 
      \((1 - x[1])\)\^2 + 2\ \((1 - x[1])\)\ x[1] + x[1]\^2 - y[1]}\)], 
  "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlotVectorField[ode, \ {x[1], \ 0, \ 1}, \n\ \ \ \ {y[1], \ 0, \ 1}, 
      PlotPoints\  -> \ 20, \n\ \ \ \ VectorHeads\  -> \ True, \ 
      ColorFunction -> Hue]\)], "Input",
  CellLabel->"In[32]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
1 0 0 r
.0001 w
.02381 .02381 m
.04623 .06864 L
s
% Start of user PostScript
0 0 0.0235376 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .255 r
.02381 .07393 m
.04616 .11641 L
s
% Start of user PostScript
0 0.0526316 0.0234724 0.0972291 MAarrowhead1
% End of user PostScript
1 0 .514 r
.02381 .12406 m
.04598 .16417 L
s
% Start of user PostScript
0 0.105263 0.0232768 0.147383 MAarrowhead1
% End of user PostScript
1 0 .778 r
.02381 .17419 m
.04567 .21194 L
s
% Start of user PostScript
0 0.157895 0.0229507 0.197537 MAarrowhead1
% End of user PostScript
.952 0 1 r
.02381 .22431 m
.04523 .25971 L
s
% Start of user PostScript
0 0.210526 0.0224943 0.247691 MAarrowhead1
% End of user PostScript
.677 0 1 r
.02381 .27444 m
.04467 .30747 L
s
% Start of user PostScript
0 0.263158 0.0219075 0.297845 MAarrowhead1
% End of user PostScript
.395 0 1 r
.02381 .32456 m
.04399 .35524 L
s
% Start of user PostScript
0 0.315789 0.0211903 0.347999 MAarrowhead1
% End of user PostScript
.107 0 1 r
.02381 .37469 m
.04318 .403 L
s
% Start of user PostScript
0 0.368421 0.0203427 0.398153 MAarrowhead1
% End of user PostScript
0 .189 1 r
.02381 .42481 m
.04225 .45077 L
s
% Start of user PostScript
0 0.421053 0.0193647 0.448307 MAarrowhead1
% End of user PostScript
0 .492 1 r
.02381 .47494 m
.0412 .49853 L
s
% Start of user PostScript
0 0.473684 0.0182563 0.498461 MAarrowhead1
% End of user PostScript
0 .802 1 r
.02381 .52506 m
.04002 .5463 L
s
% Start of user PostScript
0 0.526316 0.0170175 0.548615 MAarrowhead1
% End of user PostScript
0 1 .879 r
.02381 .57519 m
.03871 .59407 L
s
% Start of user PostScript
0 0.578947 0.0156482 0.598768 MAarrowhead1
% End of user PostScript
0 1 .552 r
.02381 .62531 m
.03728 .64183 L
s
% Start of user PostScript
0 0.631579 0.0141486 0.648922 MAarrowhead1
% End of user PostScript
0 1 .216 r
.02381 .67544 m
.03573 .6896 L
s
% Start of user PostScript
0 0.684211 0.0125186 0.699076 MAarrowhead1
% End of user PostScript
.13 1 0 r
.02381 .72556 m
.03406 .73736 L
s
% Start of user PostScript
0 0.736842 0.0107582 0.74923 MAarrowhead1
% End of user PostScript
.484 1 0 r
.02381 .77569 m
.03225 .78513 L
s
% Start of user PostScript
0 0.789474 0.00886733 0.799384 MAarrowhead1
% End of user PostScript
.848 1 0 r
.02381 .82581 m
.03033 .83289 L
s
% Start of user PostScript
0 0.842105 0.0068461 0.849538 MAarrowhead1
% End of user PostScript
1 .778 0 r
.02381 .87594 m
.02828 .88066 L
s
% Start of user PostScript
0 0.894737 0.00469447 0.899692 MAarrowhead1
% End of user PostScript
1 .394 0 r
.02381 .92607 m
.02611 .92842 L
s
% Start of user PostScript
0 0.947368 0.00241244 0.949846 MAarrowhead1
% End of user PostScript
1 0 0 r
.02381 .97619 m
.02381 .97619 L
s
% Start of user PostScript
0 1. MAarrowzero1
% End of user PostScript
1 0 .121 r
.07393 .02381 m
.09399 .06864 L
s
% Start of user PostScript
0.0526316 0 0.0736915 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .381 r
.07393 .07393 m
.09393 .11641 L
s
% Start of user PostScript
0.0526316 0.0526316 0.0736263 0.0972291 MAarrowhead1
% End of user PostScript
1 0 .645 r
.07393 .12406 m
.09374 .16417 L
s
% Start of user PostScript
0.0526316 0.105263 0.0734307 0.147383 MAarrowhead1
% End of user PostScript
1 0 .914 r
.07393 .17419 m
.09343 .21194 L
s
% Start of user PostScript
0.0526316 0.157895 0.0731047 0.197537 MAarrowhead1
% End of user PostScript
.812 0 1 r
.07393 .22431 m
.093 .25971 L
s
% Start of user PostScript
0.0526316 0.210526 0.0726483 0.247691 MAarrowhead1
% End of user PostScript
.532 0 1 r
.07393 .27444 m
.09244 .30747 L
s
% Start of user PostScript
0.0526316 0.263158 0.0720615 0.297845 MAarrowhead1
% End of user PostScript
.247 0 1 r
.07393 .32456 m
.09176 .35524 L
s
% Start of user PostScript
0.0526316 0.315789 0.0713443 0.347999 MAarrowhead1
% End of user PostScript
0 .046 1 r
.07393 .37469 m
.09095 .403 L
s
% Start of user PostScript
0.0526316 0.368421 0.0704967 0.398153 MAarrowhead1
% End of user PostScript
0 .345 1 r
.07393 .42481 m
.09002 .45077 L
s
% Start of user PostScript
0.0526316 0.421053 0.0695186 0.448307 MAarrowhead1
% End of user PostScript
0 .651 1 r
.07393 .47494 m
.08896 .49853 L
s
% Start of user PostScript
0.0526316 0.473684 0.0684102 0.498461 MAarrowhead1
% End of user PostScript
0 .965 1 r
.07393 .52506 m
.08778 .5463 L
s
% Start of user PostScript
0.0526316 0.526316 0.0671714 0.548615 MAarrowhead1
% End of user PostScript
0 1 .713 r
.07393 .57519 m
.08648 .59407 L
s
% Start of user PostScript
0.0526316 0.578947 0.0658022 0.598768 MAarrowhead1
% End of user PostScript
0 1 .383 r
.07393 .62531 m
.08505 .64183 L
s
% Start of user PostScript
0.0526316 0.631579 0.0643026 0.648922 MAarrowhead1
% End of user PostScript
0 1 .045 r
.07393 .67544 m
.0835 .6896 L
s
% Start of user PostScript
0.0526316 0.684211 0.0626725 0.699076 MAarrowhead1
% End of user PostScript
.301 1 0 r
.07393 .72556 m
.08182 .73736 L
s
% Start of user PostScript
0.0526316 0.736842 0.0609121 0.74923 MAarrowhead1
% End of user PostScript
.656 1 0 r
.07393 .77569 m
.08002 .78513 L
s
% Start of user PostScript
0.0526316 0.789474 0.0590213 0.799384 MAarrowhead1
% End of user PostScript
1 .983 0 r
.07393 .82581 m
.0781 .83289 L
s
% Start of user PostScript
0.0526316 0.842105 0.057 0.849538 MAarrowhead1
% End of user PostScript
1 .619 0 r
.07393 .87594 m
.07605 .88066 L
s
% Start of user PostScript
0.0526316 0.894737 0.0548484 0.899692 MAarrowhead1
% End of user PostScript
1 .283 0 r
.07393 .92607 m
.07387 .92842 L
s
% Start of user PostScript
0.0526316 0.947368 0.0525664 0.949846 MAarrowhead1
% End of user PostScript
1 .282 0 r
.07393 .97619 m
.07158 .97619 L
s
% Start of user PostScript
0.0526316 1. 0.0501539 1. MAarrowhead1
% End of user PostScript
1 0 .23 r
.12406 .02381 m
.14176 .06864 L
s
% Start of user PostScript
0.105263 0 0.123845 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .495 r
.12406 .07393 m
.1417 .11641 L
s
% Start of user PostScript
0.105263 0.0526316 0.12378 0.0972291 MAarrowhead1
% End of user PostScript
1 0 .764 r
.12406 .12406 m
.14151 .16417 L
s
% Start of user PostScript
0.105263 0.105263 0.123585 0.147383 MAarrowhead1
% End of user PostScript
.963 0 1 r
.12406 .17419 m
.1412 .21194 L
s
% Start of user PostScript
0.105263 0.157895 0.123259 0.197537 MAarrowhead1
% End of user PostScript
.685 0 1 r
.12406 .22431 m
.14076 .25971 L
s
% Start of user PostScript
0.105263 0.210526 0.122802 0.247691 MAarrowhead1
% End of user PostScript
.401 0 1 r
.12406 .27444 m
.14021 .30747 L
s
% Start of user PostScript
0.105263 0.263158 0.122215 0.297845 MAarrowhead1
% End of user PostScript
.112 0 1 r
.12406 .32456 m
.13952 .35524 L
s
% Start of user PostScript
0.105263 0.315789 0.121498 0.347999 MAarrowhead1
% End of user PostScript
0 .184 1 r
.12406 .37469 m
.13871 .403 L
s
% Start of user PostScript
0.105263 0.368421 0.120651 0.398153 MAarrowhead1
% End of user PostScript
0 .486 1 r
.12406 .42481 m
.13778 .45077 L
s
% Start of user PostScript
0.105263 0.421053 0.119673 0.448307 MAarrowhead1
% End of user PostScript
0 .794 1 r
.12406 .47494 m
.13673 .49853 L
s
% Start of user PostScript
0.105263 0.473684 0.118564 0.498461 MAarrowhead1
% End of user PostScript
0 1 .89 r
.12406 .52506 m
.13555 .5463 L
s
% Start of user PostScript
0.105263 0.526316 0.117325 0.548615 MAarrowhead1
% End of user PostScript
0 1 .567 r
.12406 .57519 m
.13424 .59407 L
s
% Start of user PostScript
0.105263 0.578947 0.115956 0.598768 MAarrowhead1
% End of user PostScript
0 1 .238 r
.12406 .62531 m
.13282 .64183 L
s
% Start of user PostScript
0.105263 0.631579 0.114456 0.648922 MAarrowhead1
% End of user PostScript
.099 1 0 r
.12406 .67544 m
.13126 .6896 L
s
% Start of user PostScript
0.105263 0.684211 0.112826 0.699076 MAarrowhead1
% End of user PostScript
.44 1 0 r
.12406 .72556 m
.12959 .73736 L
s
% Start of user PostScript
0.105263 0.736842 0.111066 0.74923 MAarrowhead1
% End of user PostScript
.785 1 0 r
.12406 .77569 m
.12779 .78513 L
s
% Start of user PostScript
0.105263 0.789474 0.109175 0.799384 MAarrowhead1
% End of user PostScript
1 .874 0 r
.12406 .82581 m
.12586 .83289 L
s
% Start of user PostScript
0.105263 0.842105 0.107154 0.849538 MAarrowhead1
% End of user PostScript
1 .566 0 r
.12406 .87594 m
.12381 .88066 L
s
% Start of user PostScript
0.105263 0.894737 0.105002 0.899692 MAarrowhead1
% End of user PostScript
1 .405 0 r
.12406 .92607 m
.12164 .92842 L
s
% Start of user PostScript
0.105263 0.947368 0.10272 0.949846 MAarrowhead1
% End of user PostScript
1 .565 0 r
.12406 .97619 m
.11934 .97619 L
s
% Start of user PostScript
0.105263 1. 0.100308 1. MAarrowhead1
% End of user PostScript
1 0 .328 r
.17419 .02381 m
.18952 .06864 L
s
% Start of user PostScript
0.157895 0 0.173999 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .597 r
.17419 .07393 m
.18946 .11641 L
s
% Start of user PostScript
0.157895 0.0526316 0.173934 0.0972291 MAarrowhead1
% End of user PostScript
1 0 .87 r
.17419 .12406 m
.18927 .16417 L
s
% Start of user PostScript
0.157895 0.105263 0.173739 0.147383 MAarrowhead1
% End of user PostScript
.853 0 1 r
.17419 .17419 m
.18896 .21194 L
s
% Start of user PostScript
0.157895 0.157895 0.173413 0.197537 MAarrowhead1
% End of user PostScript
.571 0 1 r
.17419 .22431 m
.18853 .25971 L
s
% Start of user PostScript
0.157895 0.210526 0.172956 0.247691 MAarrowhead1
% End of user PostScript
.285 0 1 r
.17419 .27444 m
.18797 .30747 L
s
% Start of user PostScript
0.157895 0.263158 0.172369 0.297845 MAarrowhead1
% End of user PostScript
0 .007 1 r
.17419 .32456 m
.18729 .35524 L
s
% Start of user PostScript
0.157895 0.315789 0.171652 0.347999 MAarrowhead1
% End of user PostScript
0 .305 1 r
.17419 .37469 m
.18648 .403 L
s
% Start of user PostScript
0.157895 0.368421 0.170805 0.398153 MAarrowhead1
% End of user PostScript
0 .608 1 r
.17419 .42481 m
.18555 .45077 L
s
% Start of user PostScript
0.157895 0.421053 0.169827 0.448307 MAarrowhead1
% End of user PostScript
0 .918 1 r
.17419 .47494 m
.18449 .49853 L
s
% Start of user PostScript
0.157895 0.473684 0.168718 0.498461 MAarrowhead1
% End of user PostScript
0 1 .767 r
.17419 .52506 m
.18331 .5463 L
s
% Start of user PostScript
0.157895 0.526316 0.167479 0.548615 MAarrowhead1
% End of user PostScript
0 1 .446 r
.17419 .57519 m
.18201 .59407 L
s
% Start of user PostScript
0.157895 0.578947 0.16611 0.598768 MAarrowhead1
% End of user PostScript
0 1 .12 r
.17419 .62531 m
.18058 .64183 L
s
% Start of user PostScript
0.157895 0.631579 0.16461 0.648922 MAarrowhead1
% End of user PostScript
.209 1 0 r
.17419 .67544 m
.17903 .6896 L
s
% Start of user PostScript
0.157895 0.684211 0.16298 0.699076 MAarrowhead1
% End of user PostScript
.538 1 0 r
.17419 .72556 m
.17735 .73736 L
s
% Start of user PostScript
0.157895 0.736842 0.16122 0.74923 MAarrowhead1
% End of user PostScript
.858 1 0 r
.17419 .77569 m
.17555 .78513 L
s
% Start of user PostScript
0.157895 0.789474 0.159329 0.799384 MAarrowhead1
% End of user PostScript
1 .85 0 r
.17419 .82581 m
.17363 .83289 L
s
% Start of user PostScript
0.157895 0.842105 0.157308 0.849538 MAarrowhead1
% End of user PostScript
1 .645 0 r
.17419 .87594 m
.17158 .88066 L
s
% Start of user PostScript
0.157895 0.894737 0.155156 0.899692 MAarrowhead1
% End of user PostScript
1 .638 0 r
.17419 .92607 m
.1694 .92842 L
s
% Start of user PostScript
0.157895 0.947368 0.152874 0.949846 MAarrowhead1
% End of user PostScript
1 .847 0 r
.17419 .97619 m
.16711 .97619 L
s
% Start of user PostScript
0.157895 1. 0.150462 1. MAarrowhead1
% End of user PostScript
1 0 .413 r
.22431 .02381 m
.23729 .06864 L
s
% Start of user PostScript
0.210526 0 0.224153 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .686 r
.22431 .07393 m
.23723 .11641 L
s
% Start of user PostScript
0.210526 0.0526316 0.224088 0.0972291 MAarrowhead1
% End of user PostScript
1 0 .962 r
.22431 .12406 m
.23704 .16417 L
s
% Start of user PostScript
0.210526 0.105263 0.223893 0.147383 MAarrowhead1
% End of user PostScript
.757 0 1 r
.22431 .17419 m
.23673 .21194 L
s
% Start of user PostScript
0.210526 0.157895 0.223567 0.197537 MAarrowhead1
% End of user PostScript
.473 0 1 r
.22431 .22431 m
.2363 .25971 L
s
% Start of user PostScript
0.210526 0.210526 0.22311 0.247691 MAarrowhead1
% End of user PostScript
.184 0 1 r
.22431 .27444 m
.23574 .30747 L
s
% Start of user PostScript
0.210526 0.263158 0.222523 0.297845 MAarrowhead1
% End of user PostScript
0 .109 1 r
.22431 .32456 m
.23505 .35524 L
s
% Start of user PostScript
0.210526 0.315789 0.221806 0.347999 MAarrowhead1
% End of user PostScript
0 .408 1 r
.22431 .37469 m
.23425 .403 L
s
% Start of user PostScript
0.210526 0.368421 0.220958 0.398153 MAarrowhead1
% End of user PostScript
0 .711 1 r
.22431 .42481 m
.23331 .45077 L
s
% Start of user PostScript
0.210526 0.421053 0.21998 0.448307 MAarrowhead1
% End of user PostScript
0 1 .98 r
.22431 .47494 m
.23226 .49853 L
s
% Start of user PostScript
0.210526 0.473684 0.218872 0.498461 MAarrowhead1
% End of user PostScript
0 1 .668 r
.22431 .52506 m
.23108 .5463 L
s
% Start of user PostScript
0.210526 0.526316 0.217633 0.548615 MAarrowhead1
% End of user PostScript
0 1 .352 r
.22431 .57519 m
.22978 .59407 L
s
% Start of user PostScript
0.210526 0.578947 0.216264 0.598768 MAarrowhead1
% End of user PostScript
0 1 .035 r
.22431 .62531 m
.22835 .64183 L
s
% Start of user PostScript
0.210526 0.631579 0.214764 0.648922 MAarrowhead1
% End of user PostScript
.279 1 0 r
.22431 .67544 m
.22679 .6896 L
s
% Start of user PostScript
0.210526 0.684211 0.213134 0.699076 MAarrowhead1
% End of user PostScript
.584 1 0 r
.22431 .72556 m
.22512 .73736 L
s
% Start of user PostScript
0.210526 0.736842 0.211374 0.74923 MAarrowhead1
% End of user PostScript
.864 1 0 r
.22431 .77569 m
.22332 .78513 L
s
% Start of user PostScript
0.210526 0.789474 0.209483 0.799384 MAarrowhead1
% End of user PostScript
1 .917 0 r
.22431 .82581 m
.22139 .83289 L
s
% Start of user PostScript
0.210526 0.842105 0.207462 0.849538 MAarrowhead1
% End of user PostScript
1 .82 0 r
.22431 .87594 m
.21934 .88066 L
s
% Start of user PostScript
0.210526 0.894737 0.20531 0.899692 MAarrowhead1
% End of user PostScript
1 .9 0 r
.22431 .92607 m
.21717 .92842 L
s
% Start of user PostScript
0.210526 0.947368 0.203028 0.949846 MAarrowhead1
% End of user PostScript
.87 1 0 r
.22431 .97619 m
.21487 .97619 L
s
% Start of user PostScript
0.210526 1. 0.200616 1. MAarrowhead1
% End of user PostScript
1 0 .485 r
.27444 .02381 m
.28505 .06864 L
s
% Start of user PostScript
0.263158 0 0.274307 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .761 r
.27444 .07393 m
.28499 .11641 L
s
% Start of user PostScript
0.263158 0.0526316 0.274242 0.0972291 MAarrowhead1
% End of user PostScript
.96 0 1 r
.27444 .12406 m
.28481 .16417 L
s
% Start of user PostScript
0.263158 0.105263 0.274046 0.147383 MAarrowhead1
% End of user PostScript
.677 0 1 r
.27444 .17419 m
.2845 .21194 L
s
% Start of user PostScript
0.263158 0.157895 0.27372 0.197537 MAarrowhead1
% End of user PostScript
.391 0 1 r
.27444 .22431 m
.28406 .25971 L
s
% Start of user PostScript
0.263158 0.210526 0.273264 0.247691 MAarrowhead1
% End of user PostScript
.101 0 1 r
.27444 .27444 m
.2835 .30747 L
s
% Start of user PostScript
0.263158 0.263158 0.272677 0.297845 MAarrowhead1
% End of user PostScript
0 .193 1 r
.27444 .32456 m
.28282 .35524 L
s
% Start of user PostScript
0.263158 0.315789 0.27196 0.347999 MAarrowhead1
% End of user PostScript
0 .491 1 r
.27444 .37469 m
.28201 .403 L
s
% Start of user PostScript
0.263158 0.368421 0.271112 0.398153 MAarrowhead1
% End of user PostScript
0 .793 1 r
.27444 .42481 m
.28108 .45077 L
s
% Start of user PostScript
0.263158 0.421053 0.270134 0.448307 MAarrowhead1
% End of user PostScript
0 1 .903 r
.27444 .47494 m
.28002 .49853 L
s
% Start of user PostScript
0.263158 0.473684 0.269026 0.498461 MAarrowhead1
% End of user PostScript
0 1 .596 r
.27444 .52506 m
.27884 .5463 L
s
% Start of user PostScript
0.263158 0.526316 0.267787 0.548615 MAarrowhead1
% End of user PostScript
0 1 .29 r
.27444 .57519 m
.27754 .59407 L
s
% Start of user PostScript
0.263158 0.578947 0.266418 0.598768 MAarrowhead1
% End of user PostScript
.013 1 0 r
.27444 .62531 m
.27611 .64183 L
s
% Start of user PostScript
0.263158 0.631579 0.264918 0.648922 MAarrowhead1
% End of user PostScript
.305 1 0 r
.27444 .67544 m
.27456 .6896 L
s
% Start of user PostScript
0.263158 0.684211 0.263288 0.699076 MAarrowhead1
% End of user PostScript
.576 1 0 r
.27444 .72556 m
.27288 .73736 L
s
% Start of user PostScript
0.263158 0.736842 0.261528 0.74923 MAarrowhead1
% End of user PostScript
.801 1 0 r
.27444 .77569 m
.27108 .78513 L
s
% Start of user PostScript
0.263158 0.789474 0.259637 0.799384 MAarrowhead1
% End of user PostScript
.943 1 0 r
.27444 .82581 m
.26916 .83289 L
s
% Start of user PostScript
0.263158 0.842105 0.257616 0.849538 MAarrowhead1
% End of user PostScript
.957 1 0 r
.27444 .87594 m
.26711 .88066 L
s
% Start of user PostScript
0.263158 0.894737 0.255464 0.899692 MAarrowhead1
% End of user PostScript
.828 1 0 r
.27444 .92607 m
.26494 .92842 L
s
% Start of user PostScript
0.263158 0.947368 0.253182 0.949846 MAarrowhead1
% End of user PostScript
.588 1 0 r
.27444 .97619 m
.26264 .97619 L
s
% Start of user PostScript
0.263158 1. 0.25077 1. MAarrowhead1
% End of user PostScript
1 0 .543 r
.32456 .02381 m
.33282 .06864 L
s
% Start of user PostScript
0.315789 0 0.324461 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .822 r
.32456 .07393 m
.33276 .11641 L
s
% Start of user PostScript
0.315789 0.0526316 0.324396 0.0972291 MAarrowhead1
% End of user PostScript
.896 0 1 r
.32456 .12406 m
.33257 .16417 L
s
% Start of user PostScript
0.315789 0.105263 0.3242 0.147383 MAarrowhead1
% End of user PostScript
.612 0 1 r
.32456 .17419 m
.33226 .21194 L
s
% Start of user PostScript
0.315789 0.157895 0.323874 0.197537 MAarrowhead1
% End of user PostScript
.325 0 1 r
.32456 .22431 m
.33183 .25971 L
s
% Start of user PostScript
0.315789 0.210526 0.323418 0.247691 MAarrowhead1
% End of user PostScript
.035 0 1 r
.32456 .27444 m
.33127 .30747 L
s
% Start of user PostScript
0.315789 0.263158 0.322831 0.297845 MAarrowhead1
% End of user PostScript
0 .258 1 r
.32456 .32456 m
.33058 .35524 L
s
% Start of user PostScript
0.315789 0.315789 0.322114 0.347999 MAarrowhead1
% End of user PostScript
0 .554 1 r
.32456 .37469 m
.32978 .403 L
s
% Start of user PostScript
0.315789 0.368421 0.321266 0.398153 MAarrowhead1
% End of user PostScript
0 .851 1 r
.32456 .42481 m
.32885 .45077 L
s
% Start of user PostScript
0.315789 0.421053 0.320288 0.448307 MAarrowhead1
% End of user PostScript
0 1 .851 r
.32456 .47494 m
.32779 .49853 L
s
% Start of user PostScript
0.315789 0.473684 0.31918 0.498461 MAarrowhead1
% End of user PostScript
0 1 .554 r
.32456 .52506 m
.32661 .5463 L
s
% Start of user PostScript
0.315789 0.526316 0.317941 0.548615 MAarrowhead1
% End of user PostScript
0 1 .261 r
.32456 .57519 m
.32531 .59407 L
s
% Start of user PostScript
0.315789 0.578947 0.316572 0.598768 MAarrowhead1
% End of user PostScript
.021 1 0 r
.32456 .62531 m
.32388 .64183 L
s
% Start of user PostScript
0.315789 0.631579 0.315072 0.648922 MAarrowhead1
% End of user PostScript
.284 1 0 r
.32456 .67544 m
.32233 .6896 L
s
% Start of user PostScript
0.315789 0.684211 0.313442 0.699076 MAarrowhead1
% End of user PostScript
.512 1 0 r
.32456 .72556 m
.32065 .73736 L
s
% Start of user PostScript
0.315789 0.736842 0.311682 0.74923 MAarrowhead1
% End of user PostScript
.679 1 0 r
.32456 .77569 m
.31885 .78513 L
s
% Start of user PostScript
0.315789 0.789474 0.309791 0.799384 MAarrowhead1
% End of user PostScript
.753 1 0 r
.32456 .82581 m
.31692 .83289 L
s
% Start of user PostScript
0.315789 0.842105 0.30777 0.849538 MAarrowhead1
% End of user PostScript
.71 1 0 r
.32456 .87594 m
.31487 .88066 L
s
% Start of user PostScript
0.315789 0.894737 0.305618 0.899692 MAarrowhead1
% End of user PostScript
.552 1 0 r
.32456 .92607 m
.3127 .92842 L
s
% Start of user PostScript
0.315789 0.947368 0.303336 0.949846 MAarrowhead1
% End of user PostScript
.305 1 0 r
.32456 .97619 m
.3104 .97619 L
s
% Start of user PostScript
0.315789 1. 0.300924 1. MAarrowhead1
% End of user PostScript
1 0 .587 r
.37469 .02381 m
.38059 .06864 L
s
% Start of user PostScript
0.368421 0 0.374615 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .868 r
.37469 .07393 m
.38052 .11641 L
s
% Start of user PostScript
0.368421 0.0526316 0.37455 0.0972291 MAarrowhead1
% End of user PostScript
.849 0 1 r
.37469 .12406 m
.38034 .16417 L
s
% Start of user PostScript
0.368421 0.105263 0.374354 0.147383 MAarrowhead1
% End of user PostScript
.564 0 1 r
.37469 .17419 m
.38003 .21194 L
s
% Start of user PostScript
0.368421 0.157895 0.374028 0.197537 MAarrowhead1
% End of user PostScript
.277 0 1 r
.37469 .22431 m
.37959 .25971 L
s
% Start of user PostScript
0.368421 0.210526 0.373572 0.247691 MAarrowhead1
% End of user PostScript
0 .012 1 r
.37469 .27444 m
.37903 .30747 L
s
% Start of user PostScript
0.368421 0.263158 0.372985 0.297845 MAarrowhead1
% End of user PostScript
0 .302 1 r
.37469 .32456 m
.37835 .35524 L
s
% Start of user PostScript
0.368421 0.315789 0.372268 0.347999 MAarrowhead1
% End of user PostScript
0 .593 1 r
.37469 .37469 m
.37754 .403 L
s
% Start of user PostScript
0.368421 0.368421 0.37142 0.398153 MAarrowhead1
% End of user PostScript
0 .885 1 r
.37469 .42481 m
.37661 .45077 L
s
% Start of user PostScript
0.368421 0.421053 0.370442 0.448307 MAarrowhead1
% End of user PostScript
0 1 .826 r
.37469 .47494 m
.37556 .49853 L
s
% Start of user PostScript
0.368421 0.473684 0.369334 0.498461 MAarrowhead1
% End of user PostScript
0 1 .542 r
.37469 .52506 m
.37438 .5463 L
s
% Start of user PostScript
0.368421 0.526316 0.368095 0.548615 MAarrowhead1
% End of user PostScript
0 1 .268 r
.37469 .57519 m
.37307 .59407 L
s
% Start of user PostScript
0.368421 0.578947 0.366726 0.598768 MAarrowhead1
% End of user PostScript
0 1 .01 r
.37469 .62531 m
.37164 .64183 L
s
% Start of user PostScript
0.368421 0.631579 0.365226 0.648922 MAarrowhead1
% End of user PostScript
.218 1 0 r
.37469 .67544 m
.37009 .6896 L
s
% Start of user PostScript
0.368421 0.684211 0.363596 0.699076 MAarrowhead1
% End of user PostScript
.401 1 0 r
.37469 .72556 m
.36842 .73736 L
s
% Start of user PostScript
0.368421 0.736842 0.361836 0.74923 MAarrowhead1
% End of user PostScript
.513 1 0 r
.37469 .77569 m
.36661 .78513 L
s
% Start of user PostScript
0.368421 0.789474 0.359945 0.799384 MAarrowhead1
% End of user PostScript
.534 1 0 r
.37469 .82581 m
.36469 .83289 L
s
% Start of user PostScript
0.368421 0.842105 0.357924 0.849538 MAarrowhead1
% End of user PostScript
.451 1 0 r
.37469 .87594 m
.36264 .88066 L
s
% Start of user PostScript
0.368421 0.894737 0.355772 0.899692 MAarrowhead1
% End of user PostScript
.275 1 0 r
.37469 .92607 m
.36047 .92842 L
s
% Start of user PostScript
0.368421 0.947368 0.35349 0.949846 MAarrowhead1
% End of user PostScript
.023 1 0 r
.37469 .97619 m
.35817 .97619 L
s
% Start of user PostScript
0.368421 1. 0.351078 1. MAarrowhead1
% End of user PostScript
1 0 .617 r
.42481 .02381 m
.42835 .06864 L
s
% Start of user PostScript
0.421053 0 0.424769 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .899 r
.42481 .07393 m
.42829 .11641 L
s
% Start of user PostScript
0.421053 0.0526316 0.424704 0.0972291 MAarrowhead1
% End of user PostScript
.818 0 1 r
.42481 .12406 m
.4281 .16417 L
s
% Start of user PostScript
0.421053 0.105263 0.424508 0.147383 MAarrowhead1
% End of user PostScript
.533 0 1 r
.42481 .17419 m
.42779 .21194 L
s
% Start of user PostScript
0.421053 0.157895 0.424182 0.197537 MAarrowhead1
% End of user PostScript
.248 0 1 r
.42481 .22431 m
.42736 .25971 L
s
% Start of user PostScript
0.421053 0.210526 0.423726 0.247691 MAarrowhead1
% End of user PostScript
0 .039 1 r
.42481 .27444 m
.4268 .30747 L
s
% Start of user PostScript
0.421053 0.263158 0.423139 0.297845 MAarrowhead1
% End of user PostScript
0 .325 1 r
.42481 .32456 m
.42612 .35524 L
s
% Start of user PostScript
0.421053 0.315789 0.422422 0.347999 MAarrowhead1
% End of user PostScript
0 .61 1 r
.42481 .37469 m
.42531 .403 L
s
% Start of user PostScript
0.421053 0.368421 0.421574 0.398153 MAarrowhead1
% End of user PostScript
0 .893 1 r
.42481 .42481 m
.42438 .45077 L
s
% Start of user PostScript
0.421053 0.421053 0.420596 0.448307 MAarrowhead1
% End of user PostScript
0 1 .83 r
.42481 .47494 m
.42332 .49853 L
s
% Start of user PostScript
0.421053 0.473684 0.419488 0.498461 MAarrowhead1
% End of user PostScript
0 1 .562 r
.42481 .52506 m
.42214 .5463 L
s
% Start of user PostScript
0.421053 0.526316 0.418249 0.548615 MAarrowhead1
% End of user PostScript
0 1 .309 r
.42481 .57519 m
.42084 .59407 L
s
% Start of user PostScript
0.421053 0.578947 0.41688 0.598768 MAarrowhead1
% End of user PostScript
0 1 .08 r
.42481 .62531 m
.41941 .64183 L
s
% Start of user PostScript
0.421053 0.631579 0.41538 0.648922 MAarrowhead1
% End of user PostScript
.112 1 0 r
.42481 .67544 m
.41786 .6896 L
s
% Start of user PostScript
0.421053 0.684211 0.41375 0.699076 MAarrowhead1
% End of user PostScript
.25 1 0 r
.42481 .72556 m
.41618 .73736 L
s
% Start of user PostScript
0.421053 0.736842 0.41199 0.74923 MAarrowhead1
% End of user PostScript
.316 1 0 r
.42481 .77569 m
.41438 .78513 L
s
% Start of user PostScript
0.421053 0.789474 0.410099 0.799384 MAarrowhead1
% End of user PostScript
.295 1 0 r
.42481 .82581 m
.41245 .83289 L
s
% Start of user PostScript
0.421053 0.842105 0.408078 0.849538 MAarrowhead1
% End of user PostScript
.185 1 0 r
.42481 .87594 m
.41041 .88066 L
s
% Start of user PostScript
0.421053 0.894737 0.405926 0.899692 MAarrowhead1
% End of user PostScript
0 1 .005 r
.42481 .92607 m
.40823 .92842 L
s
% Start of user PostScript
0.421053 0.947368 0.403644 0.949846 MAarrowhead1
% End of user PostScript
0 1 .26 r
.42481 .97619 m
.40593 .97619 L
s
% Start of user PostScript
0.421053 1. 0.401232 1. MAarrowhead1
% End of user PostScript
1 0 .632 r
.47494 .02381 m
.47612 .06864 L
s
% Start of user PostScript
0.473684 0 0.474923 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .914 r
.47494 .07393 m
.47606 .11641 L
s
% Start of user PostScript
0.473684 0.0526316 0.474858 0.0972291 MAarrowhead1
% End of user PostScript
.803 0 1 r
.47494 .12406 m
.47587 .16417 L
s
% Start of user PostScript
0.473684 0.105263 0.474662 0.147383 MAarrowhead1
% End of user PostScript
.52 0 1 r
.47494 .17419 m
.47556 .21194 L
s
% Start of user PostScript
0.473684 0.157895 0.474336 0.197537 MAarrowhead1
% End of user PostScript
.237 0 1 r
.47494 .22431 m
.47512 .25971 L
s
% Start of user PostScript
0.473684 0.210526 0.47388 0.247691 MAarrowhead1
% End of user PostScript
0 .045 1 r
.47494 .27444 m
.47456 .30747 L
s
% Start of user PostScript
0.473684 0.263158 0.473293 0.297845 MAarrowhead1
% End of user PostScript
0 .326 1 r
.47494 .32456 m
.47388 .35524 L
s
% Start of user PostScript
0.473684 0.315789 0.472576 0.347999 MAarrowhead1
% End of user PostScript
0 .603 1 r
.47494 .37469 m
.47307 .403 L
s
% Start of user PostScript
0.473684 0.368421 0.471728 0.398153 MAarrowhead1
% End of user PostScript
0 .875 1 r
.47494 .42481 m
.47214 .45077 L
s
% Start of user PostScript
0.473684 0.421053 0.47075 0.448307 MAarrowhead1
% End of user PostScript
0 1 .862 r
.47494 .47494 m
.47109 .49853 L
s
% Start of user PostScript
0.473684 0.473684 0.469642 0.498461 MAarrowhead1
% End of user PostScript
0 1 .612 r
.47494 .52506 m
.46991 .5463 L
s
% Start of user PostScript
0.473684 0.526316 0.468403 0.548615 MAarrowhead1
% End of user PostScript
0 1 .383 r
.47494 .57519 m
.4686 .59407 L
s
% Start of user PostScript
0.473684 0.578947 0.467034 0.598768 MAarrowhead1
% End of user PostScript
0 1 .185 r
.47494 .62531 m
.46718 .64183 L
s
% Start of user PostScript
0.473684 0.631579 0.465534 0.648922 MAarrowhead1
% End of user PostScript
0 1 .029 r
.47494 .67544 m
.46562 .6896 L
s
% Start of user PostScript
0.473684 0.684211 0.463904 0.699076 MAarrowhead1
% End of user PostScript
.07 1 0 r
.47494 .72556 m
.46395 .73736 L
s
% Start of user PostScript
0.473684 0.736842 0.462144 0.74923 MAarrowhead1
% End of user PostScript
.097 1 0 r
.47494 .77569 m
.46215 .78513 L
s
% Start of user PostScript
0.473684 0.789474 0.460253 0.799384 MAarrowhead1
% End of user PostScript
.045 1 0 r
.47494 .82581 m
.46022 .83289 L
s
% Start of user PostScript
0.473684 0.842105 0.458232 0.849538 MAarrowhead1
% End of user PostScript
0 1 .085 r
.47494 .87594 m
.45817 .88066 L
s
% Start of user PostScript
0.473684 0.894737 0.45608 0.899692 MAarrowhead1
% End of user PostScript
0 1 .285 r
.47494 .92607 m
.456 .92842 L
s
% Start of user PostScript
0.473684 0.947368 0.453798 0.949846 MAarrowhead1
% End of user PostScript
0 1 .542 r
.47494 .97619 m
.4537 .97619 L
s
% Start of user PostScript
0.473684 1. 0.451385 1. MAarrowhead1
% End of user PostScript
1 0 .632 r
.52506 .02381 m
.52388 .06864 L
s
% Start of user PostScript
0.526316 0 0.525077 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .914 r
.52506 .07393 m
.52382 .11641 L
s
% Start of user PostScript
0.526316 0.0526316 0.525012 0.0972291 MAarrowhead1
% End of user PostScript
.805 0 1 r
.52506 .12406 m
.52363 .16417 L
s
% Start of user PostScript
0.526316 0.105263 0.524816 0.147383 MAarrowhead1
% End of user PostScript
.524 0 1 r
.52506 .17419 m
.52332 .21194 L
s
% Start of user PostScript
0.526316 0.157895 0.52449 0.197537 MAarrowhead1
% End of user PostScript
.245 0 1 r
.52506 .22431 m
.52289 .25971 L
s
% Start of user PostScript
0.526316 0.210526 0.524034 0.247691 MAarrowhead1
% End of user PostScript
0 .032 1 r
.52506 .27444 m
.52233 .30747 L
s
% Start of user PostScript
0.526316 0.263158 0.523447 0.297845 MAarrowhead1
% End of user PostScript
0 .305 1 r
.52506 .32456 m
.52165 .35524 L
s
% Start of user PostScript
0.526316 0.315789 0.52273 0.347999 MAarrowhead1
% End of user PostScript
0 .573 1 r
.52506 .37469 m
.52084 .403 L
s
% Start of user PostScript
0.526316 0.368421 0.521882 0.398153 MAarrowhead1
% End of user PostScript
0 .832 1 r
.52506 .42481 m
.51991 .45077 L
s
% Start of user PostScript
0.526316 0.421053 0.520904 0.448307 MAarrowhead1
% End of user PostScript
0 1 .921 r
.52506 .47494 m
.51885 .49853 L
s
% Start of user PostScript
0.526316 0.473684 0.519796 0.498461 MAarrowhead1
% End of user PostScript
0 1 .692 r
.52506 .52506 m
.51767 .5463 L
s
% Start of user PostScript
0.526316 0.526316 0.518557 0.548615 MAarrowhead1
% End of user PostScript
0 1 .488 r
.52506 .57519 m
.51637 .59407 L
s
% Start of user PostScript
0.526316 0.578947 0.517188 0.598768 MAarrowhead1
% End of user PostScript
0 1 .319 r
.52506 .62531 m
.51494 .64183 L
s
% Start of user PostScript
0.526316 0.631579 0.515688 0.648922 MAarrowhead1
% End of user PostScript
0 1 .197 r
.52506 .67544 m
.51339 .6896 L
s
% Start of user PostScript
0.526316 0.684211 0.514058 0.699076 MAarrowhead1
% End of user PostScript
0 1 .133 r
.52506 .72556 m
.51171 .73736 L
s
% Start of user PostScript
0.526316 0.736842 0.512298 0.74923 MAarrowhead1
% End of user PostScript
0 1 .137 r
.52506 .77569 m
.50991 .78513 L
s
% Start of user PostScript
0.526316 0.789474 0.510407 0.799384 MAarrowhead1
% End of user PostScript
0 1 .213 r
.52506 .82581 m
.50799 .83289 L
s
% Start of user PostScript
0.526316 0.842105 0.508386 0.849538 MAarrowhead1
% End of user PostScript
0 1 .358 r
.52506 .87594 m
.50594 .88066 L
s
% Start of user PostScript
0.526316 0.894737 0.506234 0.899692 MAarrowhead1
% End of user PostScript
0 1 .565 r
.52506 .92607 m
.50376 .92842 L
s
% Start of user PostScript
0.526316 0.947368 0.503952 0.949846 MAarrowhead1
% End of user PostScript
0 1 .825 r
.52506 .97619 m
.50147 .97619 L
s
% Start of user PostScript
0.526316 1. 0.501539 1. MAarrowhead1
% End of user PostScript
1 0 .617 r
.57519 .02381 m
.57165 .06864 L
s
% Start of user PostScript
0.578947 0 0.575231 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .898 r
.57519 .07393 m
.57159 .11641 L
s
% Start of user PostScript
0.578947 0.0526316 0.575166 0.0972291 MAarrowhead1
% End of user PostScript
.823 0 1 r
.57519 .12406 m
.5714 .16417 L
s
% Start of user PostScript
0.578947 0.105263 0.57497 0.147383 MAarrowhead1
% End of user PostScript
.546 0 1 r
.57519 .17419 m
.57109 .21194 L
s
% Start of user PostScript
0.578947 0.157895 0.574644 0.197537 MAarrowhead1
% End of user PostScript
.271 0 1 r
.57519 .22431 m
.57065 .25971 L
s
% Start of user PostScript
0.578947 0.210526 0.574188 0.247691 MAarrowhead1
% End of user PostScript
.001 0 1 r
.57519 .27444 m
.5701 .30747 L
s
% Start of user PostScript
0.578947 0.263158 0.573601 0.297845 MAarrowhead1
% End of user PostScript
0 .264 1 r
.57519 .32456 m
.56941 .35524 L
s
% Start of user PostScript
0.578947 0.315789 0.572884 0.347999 MAarrowhead1
% End of user PostScript
0 .52 1 r
.57519 .37469 m
.56861 .403 L
s
% Start of user PostScript
0.578947 0.368421 0.572036 0.398153 MAarrowhead1
% End of user PostScript
0 .765 1 r
.57519 .42481 m
.56767 .45077 L
s
% Start of user PostScript
0.578947 0.421053 0.571058 0.448307 MAarrowhead1
% End of user PostScript
0 .995 1 r
.57519 .47494 m
.56662 .49853 L
s
% Start of user PostScript
0.578947 0.473684 0.56995 0.498461 MAarrowhead1
% End of user PostScript
0 1 .797 r
.57519 .52506 m
.56544 .5463 L
s
% Start of user PostScript
0.578947 0.526316 0.568711 0.548615 MAarrowhead1
% End of user PostScript
0 1 .618 r
.57519 .57519 m
.56413 .59407 L
s
% Start of user PostScript
0.578947 0.578947 0.567342 0.598768 MAarrowhead1
% End of user PostScript
0 1 .478 r
.57519 .62531 m
.56271 .64183 L
s
% Start of user PostScript
0.578947 0.631579 0.565842 0.648922 MAarrowhead1
% End of user PostScript
0 1 .386 r
.57519 .67544 m
.56115 .6896 L
s
% Start of user PostScript
0.578947 0.684211 0.564212 0.699076 MAarrowhead1
% End of user PostScript
0 1 .352 r
.57519 .72556 m
.55948 .73736 L
s
% Start of user PostScript
0.578947 0.736842 0.562452 0.74923 MAarrowhead1
% End of user PostScript
0 1 .381 r
.57519 .77569 m
.55768 .78513 L
s
% Start of user PostScript
0.578947 0.789474 0.560561 0.799384 MAarrowhead1
% End of user PostScript
0 1 .476 r
.57519 .82581 m
.55575 .83289 L
s
% Start of user PostScript
0.578947 0.842105 0.558539 0.849538 MAarrowhead1
% End of user PostScript
0 1 .633 r
.57519 .87594 m
.5537 .88066 L
s
% Start of user PostScript
0.578947 0.894737 0.556388 0.899692 MAarrowhead1
% End of user PostScript
0 1 .846 r
.57519 .92607 m
.55153 .92842 L
s
% Start of user PostScript
0.578947 0.947368 0.554106 0.949846 MAarrowhead1
% End of user PostScript
0 .893 1 r
.57519 .97619 m
.54923 .97619 L
s
% Start of user PostScript
0.578947 1. 0.551693 1. MAarrowhead1
% End of user PostScript
1 0 .587 r
.62531 .02381 m
.61941 .06864 L
s
% Start of user PostScript
0.631579 0 0.625385 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .866 r
.62531 .07393 m
.61935 .11641 L
s
% Start of user PostScript
0.631579 0.0526316 0.62532 0.0972291 MAarrowhead1
% End of user PostScript
.858 0 1 r
.62531 .12406 m
.61917 .16417 L
s
% Start of user PostScript
0.631579 0.105263 0.625124 0.147383 MAarrowhead1
% End of user PostScript
.585 0 1 r
.62531 .17419 m
.61886 .21194 L
s
% Start of user PostScript
0.631579 0.157895 0.624798 0.197537 MAarrowhead1
% End of user PostScript
.316 0 1 r
.62531 .22431 m
.61842 .25971 L
s
% Start of user PostScript
0.631579 0.210526 0.624342 0.247691 MAarrowhead1
% End of user PostScript
.054 0 1 r
.62531 .27444 m
.61786 .30747 L
s
% Start of user PostScript
0.631579 0.263158 0.623755 0.297845 MAarrowhead1
% End of user PostScript
0 .201 1 r
.62531 .32456 m
.61718 .35524 L
s
% Start of user PostScript
0.631579 0.315789 0.623038 0.347999 MAarrowhead1
% End of user PostScript
0 .446 1 r
.62531 .37469 m
.61637 .403 L
s
% Start of user PostScript
0.631579 0.368421 0.62219 0.398153 MAarrowhead1
% End of user PostScript
0 .676 1 r
.62531 .42481 m
.61544 .45077 L
s
% Start of user PostScript
0.631579 0.421053 0.621212 0.448307 MAarrowhead1
% End of user PostScript
0 .887 1 r
.62531 .47494 m
.61438 .49853 L
s
% Start of user PostScript
0.631579 0.473684 0.620104 0.498461 MAarrowhead1
% End of user PostScript
0 1 .926 r
.62531 .52506 m
.6132 .5463 L
s
% Start of user PostScript
0.631579 0.526316 0.618865 0.548615 MAarrowhead1
% End of user PostScript
0 1 .772 r
.62531 .57519 m
.6119 .59407 L
s
% Start of user PostScript
0.631579 0.578947 0.617496 0.598768 MAarrowhead1
% End of user PostScript
0 1 .658 r
.62531 .62531 m
.61047 .64183 L
s
% Start of user PostScript
0.631579 0.631579 0.615996 0.648922 MAarrowhead1
% End of user PostScript
0 1 .593 r
.62531 .67544 m
.60892 .6896 L
s
% Start of user PostScript
0.631579 0.684211 0.614366 0.699076 MAarrowhead1
% End of user PostScript
0 1 .583 r
.62531 .72556 m
.60724 .73736 L
s
% Start of user PostScript
0.631579 0.736842 0.612605 0.74923 MAarrowhead1
% End of user PostScript
0 1 .633 r
.62531 .77569 m
.60544 .78513 L
s
% Start of user PostScript
0.631579 0.789474 0.610715 0.799384 MAarrowhead1
% End of user PostScript
0 1 .743 r
.62531 .82581 m
.60352 .83289 L
s
% Start of user PostScript
0.631579 0.842105 0.608693 0.849538 MAarrowhead1
% End of user PostScript
0 1 .91 r
.62531 .87594 m
.60147 .88066 L
s
% Start of user PostScript
0.631579 0.894737 0.606542 0.899692 MAarrowhead1
% End of user PostScript
0 .873 1 r
.62531 .92607 m
.59929 .92842 L
s
% Start of user PostScript
0.631579 0.947368 0.60426 0.949846 MAarrowhead1
% End of user PostScript
0 .611 1 r
.62531 .97619 m
.597 .97619 L
s
% Start of user PostScript
0.631579 1. 0.601847 1. MAarrowhead1
% End of user PostScript
1 0 .543 r
.67544 .02381 m
.66718 .06864 L
s
% Start of user PostScript
0.684211 0 0.675539 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .819 r
.67544 .07393 m
.66712 .11641 L
s
% Start of user PostScript
0.684211 0.0526316 0.675474 0.0972291 MAarrowhead1
% End of user PostScript
.908 0 1 r
.67544 .12406 m
.66693 .16417 L
s
% Start of user PostScript
0.684211 0.105263 0.675278 0.147383 MAarrowhead1
% End of user PostScript
.641 0 1 r
.67544 .17419 m
.66662 .21194 L
s
% Start of user PostScript
0.684211 0.157895 0.674952 0.197537 MAarrowhead1
% End of user PostScript
.379 0 1 r
.67544 .22431 m
.66619 .25971 L
s
% Start of user PostScript
0.684211 0.210526 0.674496 0.247691 MAarrowhead1
% End of user PostScript
.125 0 1 r
.67544 .27444 m
.66563 .30747 L
s
% Start of user PostScript
0.684211 0.263158 0.673909 0.297845 MAarrowhead1
% End of user PostScript
0 .119 1 r
.67544 .32456 m
.66494 .35524 L
s
% Start of user PostScript
0.684211 0.315789 0.673192 0.347999 MAarrowhead1
% End of user PostScript
0 .351 1 r
.67544 .37469 m
.66414 .403 L
s
% Start of user PostScript
0.684211 0.368421 0.672344 0.398153 MAarrowhead1
% End of user PostScript
0 .565 1 r
.67544 .42481 m
.66321 .45077 L
s
% Start of user PostScript
0.684211 0.421053 0.671366 0.448307 MAarrowhead1
% End of user PostScript
0 .758 1 r
.67544 .47494 m
.66215 .49853 L
s
% Start of user PostScript
0.684211 0.473684 0.670258 0.498461 MAarrowhead1
% End of user PostScript
0 .924 1 r
.67544 .52506 m
.66097 .5463 L
s
% Start of user PostScript
0.684211 0.526316 0.669019 0.548615 MAarrowhead1
% End of user PostScript
0 1 .945 r
.67544 .57519 m
.65967 .59407 L
s
% Start of user PostScript
0.684211 0.578947 0.667649 0.598768 MAarrowhead1
% End of user PostScript
0 1 .855 r
.67544 .62531 m
.65824 .64183 L
s
% Start of user PostScript
0.684211 0.631579 0.66615 0.648922 MAarrowhead1
% End of user PostScript
0 1 .813 r
.67544 .67544 m
.65669 .6896 L
s
% Start of user PostScript
0.684211 0.684211 0.66452 0.699076 MAarrowhead1
% End of user PostScript
0 1 .824 r
.67544 .72556 m
.65501 .73736 L
s
% Start of user PostScript
0.684211 0.736842 0.662759 0.74923 MAarrowhead1
% End of user PostScript
0 1 .891 r
.67544 .77569 m
.65321 .78513 L
s
% Start of user PostScript
0.684211 0.789474 0.660869 0.799384 MAarrowhead1
% End of user PostScript
0 .987 1 r
.67544 .82581 m
.65128 .83289 L
s
% Start of user PostScript
0.684211 0.842105 0.658847 0.849538 MAarrowhead1
% End of user PostScript
0 .813 1 r
.67544 .87594 m
.64923 .88066 L
s
% Start of user PostScript
0.684211 0.894737 0.656696 0.899692 MAarrowhead1
% End of user PostScript
0 .591 1 r
.67544 .92607 m
.64706 .92842 L
s
% Start of user PostScript
0.684211 0.947368 0.654414 0.949846 MAarrowhead1
% End of user PostScript
0 .328 1 r
.67544 .97619 m
.64476 .97619 L
s
% Start of user PostScript
0.684211 1. 0.652001 1. MAarrowhead1
% End of user PostScript
1 0 .485 r
.72556 .02381 m
.71495 .06864 L
s
% Start of user PostScript
0.736842 0 0.725693 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .758 r
.72556 .07393 m
.71488 .11641 L
s
% Start of user PostScript
0.736842 0.0526316 0.725628 0.0972291 MAarrowhead1
% End of user PostScript
.975 0 1 r
.72556 .12406 m
.7147 .16417 L
s
% Start of user PostScript
0.736842 0.105263 0.725432 0.147383 MAarrowhead1
% End of user PostScript
.713 0 1 r
.72556 .17419 m
.71439 .21194 L
s
% Start of user PostScript
0.736842 0.157895 0.725106 0.197537 MAarrowhead1
% End of user PostScript
.459 0 1 r
.72556 .22431 m
.71395 .25971 L
s
% Start of user PostScript
0.736842 0.210526 0.72465 0.247691 MAarrowhead1
% End of user PostScript
.214 0 1 r
.72556 .27444 m
.71339 .30747 L
s
% Start of user PostScript
0.736842 0.263158 0.724063 0.297845 MAarrowhead1
% End of user PostScript
0 .019 1 r
.72556 .32456 m
.71271 .35524 L
s
% Start of user PostScript
0.736842 0.315789 0.723346 0.347999 MAarrowhead1
% End of user PostScript
0 .237 1 r
.72556 .37469 m
.7119 .403 L
s
% Start of user PostScript
0.736842 0.368421 0.722498 0.398153 MAarrowhead1
% End of user PostScript
0 .436 1 r
.72556 .42481 m
.71097 .45077 L
s
% Start of user PostScript
0.736842 0.421053 0.72152 0.448307 MAarrowhead1
% End of user PostScript
0 .611 1 r
.72556 .47494 m
.70992 .49853 L
s
% Start of user PostScript
0.736842 0.473684 0.720411 0.498461 MAarrowhead1
% End of user PostScript
0 .757 1 r
.72556 .52506 m
.70874 .5463 L
s
% Start of user PostScript
0.736842 0.526316 0.719173 0.548615 MAarrowhead1
% End of user PostScript
0 .867 1 r
.72556 .57519 m
.70743 .59407 L
s
% Start of user PostScript
0.736842 0.578947 0.717803 0.598768 MAarrowhead1
% End of user PostScript
0 .936 1 r
.72556 .62531 m
.706 .64183 L
s
% Start of user PostScript
0.736842 0.631579 0.716304 0.648922 MAarrowhead1
% End of user PostScript
0 .957 1 r
.72556 .67544 m
.70445 .6896 L
s
% Start of user PostScript
0.736842 0.684211 0.714674 0.699076 MAarrowhead1
% End of user PostScript
0 .928 1 r
.72556 .72556 m
.70277 .73736 L
s
% Start of user PostScript
0.736842 0.736842 0.712913 0.74923 MAarrowhead1
% End of user PostScript
0 .847 1 r
.72556 .77569 m
.70097 .78513 L
s
% Start of user PostScript
0.736842 0.789474 0.711023 0.799384 MAarrowhead1
% End of user PostScript
0 .715 1 r
.72556 .82581 m
.69905 .83289 L
s
% Start of user PostScript
0.736842 0.842105 0.709001 0.849538 MAarrowhead1
% End of user PostScript
0 .535 1 r
.72556 .87594 m
.697 .88066 L
s
% Start of user PostScript
0.736842 0.894737 0.70685 0.899692 MAarrowhead1
% End of user PostScript
0 .31 1 r
.72556 .92607 m
.69483 .92842 L
s
% Start of user PostScript
0.736842 0.947368 0.704568 0.949846 MAarrowhead1
% End of user PostScript
0 .046 1 r
.72556 .97619 m
.69253 .97619 L
s
% Start of user PostScript
0.736842 1. 0.702155 1. MAarrowhead1
% End of user PostScript
1 0 .413 r
.77569 .02381 m
.76271 .06864 L
s
% Start of user PostScript
0.789474 0 0.775847 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .682 r
.77569 .07393 m
.76265 .11641 L
s
% Start of user PostScript
0.789474 0.0526316 0.775781 0.0972291 MAarrowhead1
% End of user PostScript
1 0 .944 r
.77569 .12406 m
.76246 .16417 L
s
% Start of user PostScript
0.789474 0.105263 0.775586 0.147383 MAarrowhead1
% End of user PostScript
.801 0 1 r
.77569 .17419 m
.76215 .21194 L
s
% Start of user PostScript
0.789474 0.157895 0.77526 0.197537 MAarrowhead1
% End of user PostScript
.555 0 1 r
.77569 .22431 m
.76172 .25971 L
s
% Start of user PostScript
0.789474 0.210526 0.774803 0.247691 MAarrowhead1
% End of user PostScript
.32 0 1 r
.77569 .27444 m
.76116 .30747 L
s
% Start of user PostScript
0.789474 0.263158 0.774217 0.297845 MAarrowhead1
% End of user PostScript
.099 0 1 r
.77569 .32456 m
.76048 .35524 L
s
% Start of user PostScript
0.789474 0.315789 0.773499 0.347999 MAarrowhead1
% End of user PostScript
0 .106 1 r
.77569 .37469 m
.75967 .403 L
s
% Start of user PostScript
0.789474 0.368421 0.772652 0.398153 MAarrowhead1
% End of user PostScript
0 .289 1 r
.77569 .42481 m
.75874 .45077 L
s
% Start of user PostScript
0.789474 0.421053 0.771674 0.448307 MAarrowhead1
% End of user PostScript
0 .447 1 r
.77569 .47494 m
.75768 .49853 L
s
% Start of user PostScript
0.789474 0.473684 0.770565 0.498461 MAarrowhead1
% End of user PostScript
0 .574 1 r
.77569 .52506 m
.7565 .5463 L
s
% Start of user PostScript
0.789474 0.526316 0.769327 0.548615 MAarrowhead1
% End of user PostScript
0 .665 1 r
.77569 .57519 m
.7552 .59407 L
s
% Start of user PostScript
0.789474 0.578947 0.767957 0.598768 MAarrowhead1
% End of user PostScript
0 .715 1 r
.77569 .62531 m
.75377 .64183 L
s
% Start of user PostScript
0.789474 0.631579 0.766458 0.648922 MAarrowhead1
% End of user PostScript
0 .719 1 r
.77569 .67544 m
.75222 .6896 L
s
% Start of user PostScript
0.789474 0.684211 0.764828 0.699076 MAarrowhead1
% End of user PostScript
0 .675 1 r
.77569 .72556 m
.75054 .73736 L
s
% Start of user PostScript
0.789474 0.736842 0.763067 0.74923 MAarrowhead1
% End of user PostScript
0 .582 1 r
.77569 .77569 m
.74874 .78513 L
s
% Start of user PostScript
0.789474 0.789474 0.761176 0.799384 MAarrowhead1
% End of user PostScript
0 .441 1 r
.77569 .82581 m
.74681 .83289 L
s
% Start of user PostScript
0.789474 0.842105 0.759155 0.849538 MAarrowhead1
% End of user PostScript
0 .256 1 r
.77569 .87594 m
.74477 .88066 L
s
% Start of user PostScript
0.789474 0.894737 0.757004 0.899692 MAarrowhead1
% End of user PostScript
0 .028 1 r
.77569 .92607 m
.74259 .92842 L
s
% Start of user PostScript
0.789474 0.947368 0.754722 0.949846 MAarrowhead1
% End of user PostScript
.237 0 1 r
.77569 .97619 m
.74029 .97619 L
s
% Start of user PostScript
0.789474 1. 0.752309 1. MAarrowhead1
% End of user PostScript
1 0 .328 r
.82581 .02381 m
.81048 .06864 L
s
% Start of user PostScript
0.842105 0 0.826001 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .592 r
.82581 .07393 m
.81041 .11641 L
s
% Start of user PostScript
0.842105 0.0526316 0.825935 0.0972291 MAarrowhead1
% End of user PostScript
1 0 .849 r
.82581 .12406 m
.81023 .16417 L
s
% Start of user PostScript
0.842105 0.105263 0.82574 0.147383 MAarrowhead1
% End of user PostScript
.903 0 1 r
.82581 .17419 m
.80992 .21194 L
s
% Start of user PostScript
0.842105 0.157895 0.825414 0.197537 MAarrowhead1
% End of user PostScript
.666 0 1 r
.82581 .22431 m
.80948 .25971 L
s
% Start of user PostScript
0.842105 0.210526 0.824957 0.247691 MAarrowhead1
% End of user PostScript
.441 0 1 r
.82581 .27444 m
.80892 .30747 L
s
% Start of user PostScript
0.842105 0.263158 0.824371 0.297845 MAarrowhead1
% End of user PostScript
.232 0 1 r
.82581 .32456 m
.80824 .35524 L
s
% Start of user PostScript
0.842105 0.315789 0.823653 0.347999 MAarrowhead1
% End of user PostScript
.041 0 1 r
.82581 .37469 m
.80743 .403 L
s
% Start of user PostScript
0.842105 0.368421 0.822806 0.398153 MAarrowhead1
% End of user PostScript
0 .127 1 r
.82581 .42481 m
.8065 .45077 L
s
% Start of user PostScript
0.842105 0.421053 0.821828 0.448307 MAarrowhead1
% End of user PostScript
0 .269 1 r
.82581 .47494 m
.80545 .49853 L
s
% Start of user PostScript
0.842105 0.473684 0.820719 0.498461 MAarrowhead1
% End of user PostScript
0 .379 1 r
.82581 .52506 m
.80427 .5463 L
s
% Start of user PostScript
0.842105 0.526316 0.819481 0.548615 MAarrowhead1
% End of user PostScript
0 .452 1 r
.82581 .57519 m
.80296 .59407 L
s
% Start of user PostScript
0.842105 0.578947 0.818111 0.598768 MAarrowhead1
% End of user PostScript
0 .485 1 r
.82581 .62531 m
.80153 .64183 L
s
% Start of user PostScript
0.842105 0.631579 0.816612 0.648922 MAarrowhead1
% End of user PostScript
0 .474 1 r
.82581 .67544 m
.79998 .6896 L
s
% Start of user PostScript
0.842105 0.684211 0.814982 0.699076 MAarrowhead1
% End of user PostScript
0 .417 1 r
.82581 .72556 m
.79831 .73736 L
s
% Start of user PostScript
0.842105 0.736842 0.813221 0.74923 MAarrowhead1
% End of user PostScript
0 .314 1 r
.82581 .77569 m
.79651 .78513 L
s
% Start of user PostScript
0.842105 0.789474 0.81133 0.799384 MAarrowhead1
% End of user PostScript
0 .166 1 r
.82581 .82581 m
.79458 .83289 L
s
% Start of user PostScript
0.842105 0.842105 0.809309 0.849538 MAarrowhead1
% End of user PostScript
.024 0 1 r
.82581 .87594 m
.79253 .88066 L
s
% Start of user PostScript
0.842105 0.894737 0.807158 0.899692 MAarrowhead1
% End of user PostScript
.254 0 1 r
.82581 .92607 m
.79036 .92842 L
s
% Start of user PostScript
0.842105 0.947368 0.804875 0.949846 MAarrowhead1
% End of user PostScript
.519 0 1 r
.82581 .97619 m
.78806 .97619 L
s
% Start of user PostScript
0.842105 1. 0.802463 1. MAarrowhead1
% End of user PostScript
1 0 .23 r
.87594 .02381 m
.85824 .06864 L
s
% Start of user PostScript
0.894737 0 0.876155 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .489 r
.87594 .07393 m
.85818 .11641 L
s
% Start of user PostScript
0.894737 0.0526316 0.876089 0.0972291 MAarrowhead1
% End of user PostScript
1 0 .74 r
.87594 .12406 m
.85799 .16417 L
s
% Start of user PostScript
0.894737 0.105263 0.875894 0.147383 MAarrowhead1
% End of user PostScript
1 0 .98 r
.87594 .17419 m
.85768 .21194 L
s
% Start of user PostScript
0.894737 0.157895 0.875568 0.197537 MAarrowhead1
% End of user PostScript
.791 0 1 r
.87594 .22431 m
.85725 .25971 L
s
% Start of user PostScript
0.894737 0.210526 0.875111 0.247691 MAarrowhead1
% End of user PostScript
.577 0 1 r
.87594 .27444 m
.85669 .30747 L
s
% Start of user PostScript
0.894737 0.263158 0.874525 0.297845 MAarrowhead1
% End of user PostScript
.379 0 1 r
.87594 .32456 m
.85601 .35524 L
s
% Start of user PostScript
0.894737 0.315789 0.873807 0.347999 MAarrowhead1
% End of user PostScript
.201 0 1 r
.87594 .37469 m
.8552 .403 L
s
% Start of user PostScript
0.894737 0.368421 0.87296 0.398153 MAarrowhead1
% End of user PostScript
.048 0 1 r
.87594 .42481 m
.85427 .45077 L
s
% Start of user PostScript
0.894737 0.421053 0.871982 0.448307 MAarrowhead1
% End of user PostScript
0 .078 1 r
.87594 .47494 m
.85321 .49853 L
s
% Start of user PostScript
0.894737 0.473684 0.870873 0.498461 MAarrowhead1
% End of user PostScript
0 .172 1 r
.87594 .52506 m
.85203 .5463 L
s
% Start of user PostScript
0.894737 0.526316 0.869634 0.548615 MAarrowhead1
% End of user PostScript
0 .23 1 r
.87594 .57519 m
.85073 .59407 L
s
% Start of user PostScript
0.894737 0.578947 0.868265 0.598768 MAarrowhead1
% End of user PostScript
0 .248 1 r
.87594 .62531 m
.8493 .64183 L
s
% Start of user PostScript
0.894737 0.631579 0.866766 0.648922 MAarrowhead1
% End of user PostScript
0 .224 1 r
.87594 .67544 m
.84775 .6896 L
s
% Start of user PostScript
0.894737 0.684211 0.865136 0.699076 MAarrowhead1
% End of user PostScript
0 .156 1 r
.87594 .72556 m
.84607 .73736 L
s
% Start of user PostScript
0.894737 0.736842 0.863375 0.74923 MAarrowhead1
% End of user PostScript
0 .044 1 r
.87594 .77569 m
.84427 .78513 L
s
% Start of user PostScript
0.894737 0.789474 0.861484 0.799384 MAarrowhead1
% End of user PostScript
.11 0 1 r
.87594 .82581 m
.84235 .83289 L
s
% Start of user PostScript
0.894737 0.842105 0.859463 0.849538 MAarrowhead1
% End of user PostScript
.304 0 1 r
.87594 .87594 m
.8403 .88066 L
s
% Start of user PostScript
0.894737 0.894737 0.857311 0.899692 MAarrowhead1
% End of user PostScript
.535 0 1 r
.87594 .92607 m
.83812 .92842 L
s
% Start of user PostScript
0.894737 0.947368 0.855029 0.949846 MAarrowhead1
% End of user PostScript
.802 0 1 r
.87594 .97619 m
.83583 .97619 L
s
% Start of user PostScript
0.894737 1. 0.852617 1. MAarrowhead1
% End of user PostScript
1 0 .121 r
.92607 .02381 m
.90601 .06864 L
s
% Start of user PostScript
0.947368 0 0.926309 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .374 r
.92607 .07393 m
.90595 .11641 L
s
% Start of user PostScript
0.947368 0.0526316 0.926243 0.0972291 MAarrowhead1
% End of user PostScript
1 0 .618 r
.92607 .12406 m
.90576 .16417 L
s
% Start of user PostScript
0.947368 0.105263 0.926048 0.147383 MAarrowhead1
% End of user PostScript
1 0 .851 r
.92607 .17419 m
.90545 .21194 L
s
% Start of user PostScript
0.947368 0.157895 0.925722 0.197537 MAarrowhead1
% End of user PostScript
.929 0 1 r
.92607 .22431 m
.90501 .25971 L
s
% Start of user PostScript
0.947368 0.210526 0.925265 0.247691 MAarrowhead1
% End of user PostScript
.725 0 1 r
.92607 .27444 m
.90446 .30747 L
s
% Start of user PostScript
0.947368 0.263158 0.924678 0.297845 MAarrowhead1
% End of user PostScript
.539 0 1 r
.92607 .32456 m
.90377 .35524 L
s
% Start of user PostScript
0.947368 0.315789 0.923961 0.347999 MAarrowhead1
% End of user PostScript
.374 0 1 r
.92607 .37469 m
.90297 .403 L
s
% Start of user PostScript
0.947368 0.368421 0.923114 0.398153 MAarrowhead1
% End of user PostScript
.234 0 1 r
.92607 .42481 m
.90203 .45077 L
s
% Start of user PostScript
0.947368 0.421053 0.922136 0.448307 MAarrowhead1
% End of user PostScript
.123 0 1 r
.92607 .47494 m
.90098 .49853 L
s
% Start of user PostScript
0.947368 0.473684 0.921027 0.498461 MAarrowhead1
% End of user PostScript
.043 0 1 r
.92607 .52506 m
.8998 .5463 L
s
% Start of user PostScript
0.947368 0.526316 0.919788 0.548615 MAarrowhead1
% End of user PostScript
0 0 1 r
.92607 .57519 m
.89849 .59407 L
s
% Start of user PostScript
0.947368 0.578947 0.918419 0.598768 MAarrowhead1
% End of user PostScript
0 .005 1 r
.92607 .62531 m
.89707 .64183 L
s
% Start of user PostScript
0.947368 0.631579 0.91692 0.648922 MAarrowhead1
% End of user PostScript
.031 0 1 r
.92607 .67544 m
.89551 .6896 L
s
% Start of user PostScript
0.947368 0.684211 0.91529 0.699076 MAarrowhead1
% End of user PostScript
.108 0 1 r
.92607 .72556 m
.89384 .73736 L
s
% Start of user PostScript
0.947368 0.736842 0.913529 0.74923 MAarrowhead1
% End of user PostScript
.227 0 1 r
.92607 .77569 m
.89204 .78513 L
s
% Start of user PostScript
0.947368 0.789474 0.911638 0.799384 MAarrowhead1
% End of user PostScript
.386 0 1 r
.92607 .82581 m
.89011 .83289 L
s
% Start of user PostScript
0.947368 0.842105 0.909617 0.849538 MAarrowhead1
% End of user PostScript
.584 0 1 r
.92607 .87594 m
.88806 .88066 L
s
% Start of user PostScript
0.947368 0.894737 0.907465 0.899692 MAarrowhead1
% End of user PostScript
.817 0 1 r
.92607 .92607 m
.88589 .92842 L
s
% Start of user PostScript
0.947368 0.947368 0.905183 0.949846 MAarrowhead1
% End of user PostScript
1 0 .916 r
.92607 .97619 m
.88359 .97619 L
s
% Start of user PostScript
0.947368 1. 0.902771 1. MAarrowhead1
% End of user PostScript
1 0 0 r
.97619 .02381 m
.95377 .06864 L
s
% Start of user PostScript
1. 0 0.976462 0.0470751 MAarrowhead1
% End of user PostScript
1 0 .248 r
.97619 .07393 m
.95371 .11641 L
s
% Start of user PostScript
1. 0.0526316 0.976397 0.0972291 MAarrowhead1
% End of user PostScript
1 0 .485 r
.97619 .12406 m
.95353 .16417 L
s
% Start of user PostScript
1. 0.105263 0.976202 0.147383 MAarrowhead1
% End of user PostScript
1 0 .71 r
.97619 .17419 m
.95321 .21194 L
s
% Start of user PostScript
1. 0.157895 0.975876 0.197537 MAarrowhead1
% End of user PostScript
1 0 .92 r
.97619 .22431 m
.95278 .25971 L
s
% Start of user PostScript
1. 0.210526 0.975419 0.247691 MAarrowhead1
% End of user PostScript
.886 0 1 r
.97619 .27444 m
.95222 .30747 L
s
% Start of user PostScript
1. 0.263158 0.974832 0.297845 MAarrowhead1
% End of user PostScript
.711 0 1 r
.97619 .32456 m
.95154 .35524 L
s
% Start of user PostScript
1. 0.315789 0.974115 0.347999 MAarrowhead1
% End of user PostScript
.558 0 1 r
.97619 .37469 m
.95073 .403 L
s
% Start of user PostScript
1. 0.368421 0.973268 0.398153 MAarrowhead1
% End of user PostScript
.431 0 1 r
.97619 .42481 m
.9498 .45077 L
s
% Start of user PostScript
1. 0.421053 0.97229 0.448307 MAarrowhead1
% End of user PostScript
.333 0 1 r
.97619 .47494 m
.94874 .49853 L
s
% Start of user PostScript
1. 0.473684 0.971181 0.498461 MAarrowhead1
% End of user PostScript
.267 0 1 r
.97619 .52506 m
.94756 .5463 L
s
% Start of user PostScript
1. 0.526316 0.969942 0.548615 MAarrowhead1
% End of user PostScript
.236 0 1 r
.97619 .57519 m
.94626 .59407 L
s
% Start of user PostScript
1. 0.578947 0.968573 0.598768 MAarrowhead1
% End of user PostScript
.243 0 1 r
.97619 .62531 m
.94483 .64183 L
s
% Start of user PostScript
1. 0.631579 0.967073 0.648922 MAarrowhead1
% End of user PostScript
.289 0 1 r
.97619 .67544 m
.94328 .6896 L
s
% Start of user PostScript
1. 0.684211 0.965443 0.699076 MAarrowhead1
% End of user PostScript
.374 0 1 r
.97619 .72556 m
.9416 .73736 L
s
% Start of user PostScript
1. 0.736842 0.963683 0.74923 MAarrowhead1
% End of user PostScript
.5 0 1 r
.97619 .77569 m
.9398 .78513 L
s
% Start of user PostScript
1. 0.789474 0.961792 0.799384 MAarrowhead1
% End of user PostScript
.664 0 1 r
.97619 .82581 m
.93788 .83289 L
s
% Start of user PostScript
1. 0.842105 0.959771 0.849538 MAarrowhead1
% End of user PostScript
.864 0 1 r
.97619 .87594 m
.93583 .88066 L
s
% Start of user PostScript
1. 0.894737 0.957619 0.899692 MAarrowhead1
% End of user PostScript
1 0 .901 r
.97619 .92607 m
.93365 .92842 L
s
% Start of user PostScript
1. 0.947368 0.955337 0.949846 MAarrowhead1
% End of user PostScript
1 0 .633 r
.97619 .97619 m
.93136 .97619 L
s
% Start of user PostScript
1. 1. 0.952925 1. MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l07P3oool0oooo00/0
oooo00<0o`0j0?ooo`3oool02`3oool00`3o05<0oooo0?ooo`0<0?ooo`030?l0J@3oool0oooo00/0
oooo00<0o`1l0?ooo`3oool0303oool00`3o08/0oooo0?ooo`0;0?ooo`030?l0UP3oool0oooo00/0
oooo00<0o`2M0?ooo`3oool0303oool00`3o0:40oooo0?ooo`0;0?ooo`030?l0X@3oool0oooo00`0
oooo00<0o`2M0?ooo`3oool02`3oool00`3o09H0oooo0?ooo`0;0?ooo`030?l0R`3oool0oooo00`0
oooo00<0o`1l0?ooo`3oool02`3oool00`3o06T0oooo0?ooo`0<0?ooo`030?l0D`3oool0oooo00/0
oooo00<0o`0j0?ooo`3oool02`3oool00`3o01h0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00D0
oooo00070?ooo`030?l0003oool0oooo00/0oooo00<0o`0N0?ooo`3oool02`3oool00`3o03X0oooo
0?ooo`0;0?ooo`030?l0D`3oool0oooo00`0oooo00<0o`1Y0?ooo`3oool02`3oool00`3o07`0oooo
0?ooo`0<0?ooo`030?l0R`3oool0oooo00/0oooo00<0o`2F0?ooo`3oool02`3oool00`3o09d0oooo
0?ooo`0<0?ooo`030?l0X@3oool0oooo00/0oooo00<0o`2Q0?ooo`3oool0303oool00`3o09d0oooo
0?ooo`0;0?ooo`030?l0UP3oool0oooo00/0oooo00<0o`2;0?ooo`3oool0303oool00`3o07`0oooo
0?ooo`0;0?ooo`030?l0J@3oool0oooo00`0oooo00<0o`1C0?ooo`3oool02`3oool00`3o03X0oooo
0?ooo`0;0?ooo`030?l07P3oool0oooo00/0oooo00<0o`000?ooo`3oool01P3oool000L0oooo00<0
o`000?ooo`3oool0303oool00`3o01h0oooo0?ooo`0;0?ooo`030?l0>P3oool0oooo00/0oooo00<0
o`1C0?ooo`3oool0303oool00`3o06T0oooo0?ooo`0:0?ooo`030?l0O03oool0oooo00`0oooo00<0
o`2;0?ooo`3oool02`3oool00`3o09H0oooo0?ooo`0;0?ooo`030?l0W@3oool0oooo00`0oooo00<0
o`2Q0?ooo`3oool02`3oool00`3o0:40oooo0?ooo`0<0?ooo`030?l0W@3oool0oooo00/0oooo00<0
o`2F0?ooo`3oool02`3oool00`3o08/0oooo0?ooo`0<0?ooo`030?l0O03oool0oooo00X0oooo00<0
o`1Y0?ooo`3oool0303oool00`3o05<0oooo0?ooo`0;0?ooo`030?l0>P3oool0oooo00/0oooo00<0
o`0N0?ooo`3oool0303oool00`3o0000oooo0?ooo`060?ooo`00203oool00`3o0000oooo0?ooo`0;
0?ooo`030?l07P3oool0oooo00/0oooo00<0o`0j0?ooo`3oool02`3oool00`3o05<0oooo0?ooo`0<
0?ooo`030?l0J@3oool0oooo00/0oooo00<0o`1l0?ooo`3oool02`3oool00`3o08/0oooo0?ooo`0;
0?ooo`030?l0UP3oool0oooo00/0oooo00<0o`2M0?ooo`3oool0303oool00`3o0:40oooo0?ooo`0;
0?ooo`030?l0X@3oool0oooo00`0oooo00<0o`2M0?ooo`3oool02`3oool00`3o09H0oooo0?ooo`0;
0?ooo`030?l0R`3oool0oooo00/0oooo00<0o`1l0?ooo`3oool02`3oool00`3o06T0oooo0?ooo`0<
0?ooo`030?l0D`3oool0oooo00/0oooo00<0o`0j0?ooo`3oool02`3oool00`3o01h0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00L0oooo00080?ooo`030?l0003oool0oooo00`0oooo00<0o`0N0?oo
o`3oool02`3oool00`3o03X0oooo0?ooo`0;0?ooo`030?l0D`3oool0oooo00/0oooo00<0o`1Y0?oo
o`3oool02`3oool00`3o07`0oooo0?ooo`0<0?ooo`030?l0R`3oool0oooo00/0oooo00<0o`2F0?oo
o`3oool02P3oool00`3o09d0oooo0?ooo`0<0?ooo`030?l0X@3oool0oooo00/0oooo00<0o`2Q0?oo
o`3oool0303oool00`3o09d0oooo0?ooo`0:0?ooo`030?l0UP3oool0oooo00/0oooo00<0o`2;0?oo
o`3oool0303oool00`3o07`0oooo0?ooo`0;0?ooo`030?l0J@3oool0oooo00/0oooo00<0o`1C0?oo
o`3oool02`3oool00`3o03X0oooo0?ooo`0;0?ooo`030?l07P3oool0oooo00`0oooo00<0o`000?oo
o`3oool01`3oool000T0oooo00<0o`000?ooo`3oool02`3oool00`3o01h0oooo0?ooo`0;0?ooo`03
0?l0>P3oool0oooo00/0oooo00<0o`1C0?ooo`3oool0303oool00`3o06T0oooo0?ooo`0:0?ooo`03
0?l0O03oool0oooo00`0oooo00<0o`2;0?ooo`3oool02`3oool00`3o09H0oooo0?ooo`0:0?ooo`03
0?l0W@3oool0oooo00`0oooo00<0o`2Q0?ooo`3oool02`3oool00`3o0:40oooo0?ooo`0<0?ooo`03
0?l0W@3oool0oooo00X0oooo00<0o`2F0?ooo`3oool02`3oool00`3o08/0oooo0?ooo`0<0?ooo`03
0?l0O03oool0oooo00X0oooo00<0o`1Y0?ooo`3oool0303oool00`3o05<0oooo0?ooo`0;0?ooo`03
0?l0>P3oool0oooo00/0oooo00<0o`0N0?ooo`3oool02`3oool00`3o0000oooo0?ooo`080?ooo`00
2@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l07P3oool0oooo00/0oooo00<0o`0j0?ooo`3oool0
2`3oool00`3o05<0oooo0?ooo`0<0?ooo`030?l0J@3oool0oooo00X0oooo00<0o`1l0?ooo`3oool0
303oool00`3o08/0oooo0?ooo`0;0?ooo`030?l0UP3oool0oooo00X0oooo00<0o`2M0?ooo`3oool0
303oool00`3o0:40oooo0?ooo`0;0?ooo`030?l0X@3oool0oooo00`0oooo00<0o`2M0?ooo`3oool0
2P3oool00`3o09H0oooo0?ooo`0;0?ooo`030?l0R`3oool0oooo00`0oooo00<0o`1l0?ooo`3oool0
2P3oool00`3o06T0oooo0?ooo`0<0?ooo`030?l0D`3oool0oooo00/0oooo00<0o`0j0?ooo`3oool0
2`3oool00`3o01h0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00P0oooo000:0?ooo`80o`00303o
ool20?l07P`0oooo0P3o03X<0?ooo`80o`1C303oool20?l0J@`0oooo0P3o07`<0?ooo`80o`2;303o
ool20?l0UP`0oooo0P3o09d<0?ooo`80o`2Q2`3oool20?l0X@`0oooo0P3o09d<0?ooo`80o`2F303o
ool20?l0R``0oooo0P3o07`<0?ooo`80o`1Y303oool20?l0D``0oooo0P3o03X<0?ooo`80o`0N2`3o
ool00`3o0000oooo0?l0000;0?ooo`002P3oool20?l000`0oooo0P3o01h;0?ooo`<0o`0j2`3oool3
0?l0D`/0oooo0`3o06T;0?ooo`<0o`1l2`3oool30?l0R`/0oooo0`3o09H;0?ooo`<0o`2M2`3oool3
0?l0X@/0oooo0`3o0:4;0?ooo`<0o`2M2`3oool30?l0UP/0oooo0`3o08/;0?ooo`<0o`1l2`3oool3
0?l0J@/0oooo0`3o05<;0?ooo`<0o`0j2`3oool20?l07P/0oooo0`3o000;0?ooo`002@3oool40?l0
00X0oooo0`3o01h<0?ooo`80o`0j303oool20?l0D``0oooo0P3o06T;0?ooo`<0o`1l2`3oool30?l0
R`/0oooo0`3o09H;0?ooo`<0o`2M2`3oool30?l0X@/0oooo0`3o0:4;0?ooo`<0o`2M2`3oool30?l0
UP/0oooo0`3o08/;0?ooo`<0o`1l2`3oool20?l0J@`0oooo0P3o05<<0?ooo`80o`0j303oool30?l0
7PX0oooo103o000:0?ooo`002P3oool30?l000/0oooo0P3o01h<0?ooo`80o`0j303oool20?l0D``0
oooo0P3o06T<0?ooo`80o`1l303oool20?l0R``0oooo0P3o09H;0?ooo`80o`2M303oool20?l0X@`0
oooo0`3o0:4;0?ooo`<0o`2M2`3oool20?l0UP`0oooo0P3o08/<0?ooo`80o`1l2`3oool30?l0J@/0
oooo0`3o05<;0?ooo`<0o`0j2`3oool30?l07PX0oooo103o000;0?ooo`002`3oool20?l000/0oooo
0`3o01h<0?ooo`80o`0j303oool20?l0D``0oooo0P3o06T;0?ooo`80o`1l303oool20?l0R``0oooo
0P3o09H<0?ooo`030?l0W@3oool0oooo00/0oooo00<0o`2Q0?ooo`3oool02`3oool00`3o0:40oooo
0?ooo`0;0?ooo`030?l0W@3oool0oooo00X0oooo0P3o09H<0?ooo`80o`2;303oool20?l0O0/0oooo
0P3o06T<0?ooo`80o`1C303oool20?l0>P`0oooo0P3o01h;0?ooo`<0o`00303oool000`0oooo0P3o
000;0?ooo`80o`0N303oool20?l0>P`0oooo0P3o05<<0?ooo`80o`1Y303oool00`3o07`0oooo0?oo
o`0;0?ooo`030?l0R`3oool0oooo00/0oooo00<0o`2F0?ooo`3oool02P3oool00`3o09d0oooo0?oo
o`0;0?ooo`030?l0X@3oool0oooo00/0oooo00<0o`2Q0?ooo`3oool02`3oool00`3o09d0oooo0?oo
o`0:0?ooo`030?l0UP3oool0oooo00/0oooo00<0o`2;0?ooo`3oool02`3oool00`3o07`0oooo0?oo
o`0:0?ooo`80o`1Y303oool20?l0D``0oooo0P3o03X<0?ooo`80o`0N2`3oool20?l000d0oooo000=
0?ooo`030?l0003oool0oooo00X0oooo00<0o`0N0?ooo`3oool02`3oool00`3o03X0oooo0?ooo`0;
0?ooo`030?l0D`3oool0oooo00/0oooo00<0o`1Y0?ooo`3oool02P3oool00`3o07`0oooo0?ooo`0;
0?ooo`030?l0R`3oool0oooo00/0oooo00<0o`2F0?ooo`3oool02P3oool00`3o09d0oooo0?ooo`0;
0?ooo`030?l0X@3oool0oooo00/0oooo00<0o`2Q0?ooo`3oool02`3oool00`3o09d0oooo0?ooo`0:
0?ooo`030?l0UP3oool0oooo00/0oooo00<0o`2;0?ooo`3oool02`3oool00`3o07`0oooo0?ooo`0:
0?ooo`030?l0J@3oool0oooo00/0oooo00<0o`1C0?ooo`3oool02`3oool00`3o03X0oooo0?ooo`0;
0?ooo`030?l07P3oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool00?l0oooo8@3oool000H0
oooo00<0o`110?ooo`3oool0303oool00`3o0640oooo0?ooo`0;0?ooo`030?l0OP3oool0oooo00/0
oooo00<0o`2H0?ooo`3oool0303oool00`3o0:l0oooo0?ooo`0;0?ooo`030?l0`P3oool0oooo00`0
oooo00<0o`3B0?ooo`3oool02`3oool00`3o0=h0oooo0?ooo`0;0?ooo`030?l0iP3oool0oooo00`0
oooo00<0o`3Y0?ooo`3oool02`3oool00`3o0>T0oooo0?ooo`0<0?ooo`030?l0i@3oool0oooo00/0
oooo00<0o`3M0?ooo`3oool02`3oool00`3o0=40oooo0?ooo`0<0?ooo`030?l0`P3oool0oooo00/0
oooo00<0o`2^0?ooo`3oool0303oool00`3o09L0oooo0?ooo`0;0?ooo`030?l0O@3oool0oooo00/0
oooo00<0o`1O0?ooo`3oool0303oool00`3o03l0oooo0?ooo`050?ooo`001`3oool00`3o0440oooo
0?ooo`0;0?ooo`030?l0H@3oool0oooo00/0oooo00<0o`1n0?ooo`3oool02`3oool00`3o09P0oooo
0?ooo`0<0?ooo`030?l0[`3oool0oooo00/0oooo00<0o`320?ooo`3oool0303oool00`3o0=80oooo
0?ooo`0;0?ooo`030?l0gP3oool0oooo00/0oooo00<0o`3V0?ooo`3oool0303oool00`3o0>T0oooo
0?ooo`0;0?ooo`030?l0j@3oool0oooo00`0oooo00<0o`3U0?ooo`3oool02`3oool00`3o0=d0oooo
0?ooo`0;0?ooo`030?l0d@3oool0oooo00`0oooo00<0o`320?ooo`3oool02`3oool00`3o0:h0oooo
0?ooo`0<0?ooo`030?l0U`3oool0oooo00/0oooo00<0o`1m0?ooo`3oool02`3oool00`3o05l0oooo
0?ooo`0;0?ooo`030?l0?`3oool0oooo00H0oooo00070?ooo`030?l0@@3oool0oooo00`0oooo00<0
o`1Q0?ooo`3oool02`3oool00`3o07h0oooo0?ooo`0;0?ooo`030?l0V03oool0oooo00`0oooo00<0
o`2_0?ooo`3oool02P3oool00`3o0<80oooo0?ooo`0<0?ooo`030?l0dP3oool0oooo00/0oooo00<0
o`3N0?ooo`3oool02`3oool00`3o0>H0oooo0?ooo`0<0?ooo`030?l0j@3oool0oooo00/0oooo00<0
o`3Y0?ooo`3oool0303oool00`3o0>D0oooo0?ooo`0;0?ooo`030?l0g@3oool0oooo00/0oooo00<0
o`3A0?ooo`3oool02`3oool00`3o0<80oooo0?ooo`0;0?ooo`030?l0[P3oool0oooo00`0oooo00<0
o`2G0?ooo`3oool02`3oool00`3o07d0oooo0?ooo`0;0?ooo`030?l0G`3oool0oooo00`0oooo00<0
o`0o0?ooo`3oool01P3oool000P0oooo00<0o`110?ooo`3oool02`3oool00`3o0640oooo0?ooo`0;
0?ooo`030?l0OP3oool0oooo00/0oooo00<0o`2H0?ooo`3oool0303oool00`3o0:l0oooo0?ooo`0;
0?ooo`030?l0`P3oool0oooo00/0oooo00<0o`3B0?ooo`3oool02`3oool00`3o0=h0oooo0?ooo`0;
0?ooo`030?l0iP3oool0oooo00`0oooo00<0o`3Y0?ooo`3oool02`3oool00`3o0>T0oooo0?ooo`0<
0?ooo`030?l0i@3oool0oooo00X0oooo00<0o`3M0?ooo`3oool02`3oool00`3o0=40oooo0?ooo`0<
0?ooo`030?l0`P3oool0oooo00/0oooo00<0o`2^0?ooo`3oool0303oool00`3o09L0oooo0?ooo`0;
0?ooo`030?l0O@3oool0oooo00/0oooo00<0o`1O0?ooo`3oool02`3oool00`3o03l0oooo0?ooo`07
0?ooo`00203oool00`3o0440oooo0?ooo`0<0?ooo`030?l0H@3oool0oooo00/0oooo00<0o`1n0?oo
o`3oool02`3oool00`3o09P0oooo0?ooo`0;0?ooo`030?l0[`3oool0oooo00/0oooo00<0o`320?oo
o`3oool0303oool00`3o0=80oooo0?ooo`0;0?ooo`030?l0gP3oool0oooo00X0oooo00<0o`3V0?oo
o`3oool0303oool00`3o0>T0oooo0?ooo`0;0?ooo`030?l0j@3oool0oooo00`0oooo00<0o`3U0?oo
o`3oool02P3oool00`3o0=d0oooo0?ooo`0;0?ooo`030?l0d@3oool0oooo00`0oooo00<0o`320?oo
o`3oool02`3oool00`3o0:h0oooo0?ooo`0;0?ooo`030?l0U`3oool0oooo00/0oooo00<0o`1m0?oo
o`3oool02`3oool00`3o05l0oooo0?ooo`0<0?ooo`030?l0?`3oool0oooo00L0oooo00090?ooo`03
0?l0@@3oool0oooo00/0oooo00<0o`1Q0?ooo`3oool02`3oool00`3o07h0oooo0?ooo`0;0?ooo`03
0?l0V03oool0oooo00`0oooo00<0o`2_0?ooo`3oool02P3oool00`3o0<80oooo0?ooo`0<0?ooo`03
0?l0dP3oool0oooo00/0oooo00<0o`3N0?ooo`3oool02P3oool00`3o0>H0oooo0?ooo`0<0?ooo`03
0?l0j@3oool0oooo00/0oooo00<0o`3Y0?ooo`3oool0303oool00`3o0>D0oooo0?ooo`0:0?ooo`03
0?l0g@3oool0oooo00/0oooo00<0o`3A0?ooo`3oool0303oool00`3o0<80oooo0?ooo`0:0?ooo`03
0?l0[P3oool0oooo00`0oooo00<0o`2G0?ooo`3oool02`3oool00`3o07d0oooo0?ooo`0;0?ooo`03
0?l0G`3oool0oooo00/0oooo00<0o`0o0?ooo`3oool0203oool000T0oooo00<0o`110?ooo`3o0440
2`3oool00`3o0640oooo0?l0H@0;0?ooo`030?l0OP3oool0o`1n00/0oooo00<0o`2H0?ooo`3o09P0
303oool20?l0[`/0oooo0`3o0<8<0?ooo`80o`3B2P3oool40?l0gPX0oooo103o0>H;0?ooo`<0o`3Y
2`3oool30?l0j@/0oooo0`3o0>D;0?ooo`<0o`3M2`3oool20?l0d@`0oooo0P3o0<8<0?ooo`80o`2^
303oool20?l0U``0oooo0P3o07d<0?ooo`80o`1O303oool20?l0?`/0oooo000:0?ooo`80o`112`3o
ool30?l0H@/0oooo0`3o07h;0?ooo`<0o`2H2`3oool30?l0[`X0oooo103o0<8:0?ooo`@0o`3B2P3o
ool40?l0gPX0oooo103o0>H;0?ooo`<0o`3Y2`3oool30?l0j@/0oooo0`3o0>D;0?ooo`<0o`3M2`3o
ool30?l0d@/0oooo0`3o0<8;0?ooo`<0o`2^2`3oool30?l0U`/0oooo0`3o07d;0?ooo`<0o`1O2`3o
ool20?l0?`/0oooo00090?ooo`@0o`112`3oool20?l0H@`0oooo0P3o07h<0?ooo`80o`2H303oool2
0?l0[`/0oooo0`3o0<8;0?ooo`<0o`3B2`3oool30?l0gP/0oooo0`3o0>H;0?ooo`<0o`3Y2`3oool3
0?l0j@/0oooo0`3o0>D;0?ooo`80o`3M303oool30?l0d@/0oooo0`3o0<8;0?ooo`80o`2^303oool2
0?l0U``0oooo0P3o07d<0?ooo`80o`1O2`3oool40?l0?`X0oooo000:0?ooo`<0o`112`3oool20?l0
H@`0oooo0P3o07h<0?ooo`80o`2H303oool20?l0[`/0oooo0`3o0<8;0?ooo`<0o`3B2`3oool30?l0
gP/0oooo0P3o0>H<0?ooo`80o`3Y303oool20?l0j@`0oooo0P3o0>D<0?ooo`80o`3M303oool20?l0
d@`0oooo0P3o0<8;0?ooo`<0o`2^2`3oool30?l0U`/0oooo0`3o07d;0?ooo`<0o`1O2`3oool30?l0
?`/0oooo000;0?ooo`80o`11303oool20?l0H@`0oooo0P3o07h<0?ooo`80o`2H303oool20?l0[`/0
oooo0P3o0<8<0?ooo`80o`3B303oool20?l0gP/0oooo0P3o0>H=0?ooo`030?l0j@3oool0oooo00/0
oooo00<0o`3Y0?ooo`3oool02`3oool00`3o0>D0oooo0?ooo`0:0?ooo`80o`3M303oool20?l0d@`0
oooo0P3o0<8;0?ooo`80o`2^303oool20?l0U``0oooo0P3o07d<0?ooo`80o`1O303oool20?l0?``0
oooo000<0?ooo`80o`112`3oool20?l0H@`0oooo0P3o07h<0?ooo`80o`2H303oool20?l0[`/0oooo
0P3o0<8<0?ooo`80o`3B303oool20?l0gP`0oooo00<0o`3V0?ooo`3oool02`3oool00`3o0>T0oooo
0?ooo`0;0?ooo`030?l0j@3oool0oooo00/0oooo00<0o`3U0?ooo`3oool02P3oool00`3o0=d0oooo
0?ooo`0;0?ooo`030?l0d@3oool0oooo00/0oooo00<0o`320?ooo`3oool02P3oool20?l0[P`0oooo
0P3o09L<0?ooo`80o`1m303oool20?l0G`/0oooo0P3o03l=0?ooo`003@3oool00`3o0440oooo0?oo
o`0:0?ooo`030?l0H@3oool0oooo00/0oooo00<0o`1n0?ooo`3oool02`3oool00`3o09P0oooo0?oo
o`0;0?ooo`030?l0[`3oool0oooo00X0oooo00<0o`320?ooo`3oool02`3oool00`3o0=80oooo0?oo
o`0;0?ooo`030?l0gP3oool0oooo00X0oooo00<0o`3V0?ooo`3oool02`3oool00`3o0>T0oooo0?oo
o`0;0?ooo`030?l0j@3oool0oooo00/0oooo00<0o`3U0?ooo`3oool02P3oool00`3o0=d0oooo0?oo
o`0;0?ooo`030?l0d@3oool0oooo00/0oooo00<0o`320?ooo`3oool02P3oool00`3o0:h0oooo0?oo
o`0;0?ooo`030?l0U`3oool0oooo00/0oooo00<0o`1m0?ooo`3oool02`3oool00`3o05l0oooo0?oo
o`0:0?ooo`030?l0?`3oool0oooo00`0oooo003o0?ooob40oooo00060?ooo`030?l0P`3oool0oooo
00`0oooo00<0o`2U0?ooo`3oool02`3oool00`3o0<<0oooo0?ooo`0;0?ooo`030?l0gP3oool0oooo
00`0oooo00<0o`3f0?ooo`3oool02`3oool00`3e0?l0oooo0?ooo`0<0?ooo`030>D0o`3oool0oooo
00/0oooo00<0f@3o0?ooo`3oool02`3oool00`3A0?l0oooo0?ooo`0<0?ooo`030<d0o`3oool0oooo
00/0oooo00<0cP3o0?ooo`3oool0303oool00`3B0?l0oooo0?ooo`0;0?ooo`030=/0o`3oool0oooo
00/0oooo00<0j03o0?ooo`3oool0303oool00`3i0?l0oooo0?ooo`0;0?ooo`030?l0l@3oool0oooo
00`0oooo00<0o`3I0?ooo`3oool02`3oool00`3o0;d0oooo0?ooo`0;0?ooo`030?l0WP3oool0oooo
00`0oooo00<0o`1l0?ooo`3oool01@3oool000L0oooo00<0o`230?ooo`3oool02`3oool00`3o0:D0
oooo0?ooo`0;0?ooo`030?l0``3oool0oooo00/0oooo00<0o`3N0?ooo`3oool0303oool00`3o0?H0
oooo0?ooo`0;0?ooo`030?D0o`3oool0oooo00`0oooo00<0i@3o0?ooo`3oool02`3oool00`3I0?l0
oooo0?ooo`0;0?ooo`030=40o`3oool0oooo00`0oooo00<0c@3o0?ooo`3oool02`3oool00`3>0?l0
oooo0?ooo`0<0?ooo`030=80o`3oool0oooo00/0oooo00<0f`3o0?ooo`3oool02`3oool00`3X0?l0
oooo0?ooo`0<0?ooo`030?T0o`3oool0oooo00/0oooo00<0o`3a0?ooo`3oool0303oool00`3o0=T0
oooo0?ooo`0;0?ooo`030?l0_@3oool0oooo00X0oooo00<0o`2N0?ooo`3oool0303oool00`3o07`0
oooo0?ooo`060?ooo`001`3oool00`3o08<0oooo0?ooo`0<0?ooo`030?l0Y@3oool0oooo00/0oooo
00<0o`330?ooo`3oool02`3oool00`3o0=h0oooo0?ooo`0<0?ooo`030?l0mP3oool0oooo00X0oooo
00<0m@3o0?ooo`3oool0303oool00`3U0?l0oooo0?ooo`0;0?ooo`030=T0o`3oool0oooo00/0oooo
00<0d@3o0?ooo`3oool0303oool00`3=0?l0oooo0?ooo`0;0?ooo`030<h0o`3oool0oooo00`0oooo
00<0dP3o0?ooo`3oool02`3oool00`3K0?l0oooo0?ooo`0;0?ooo`030>P0o`3oool0oooo00/0oooo
00<0n@3o0?ooo`3oool02`3oool00`3o0?40oooo0?ooo`0<0?ooo`030?l0f@3oool0oooo00/0oooo
00<0o`2m0?ooo`3oool02`3oool00`3o09h0oooo0?ooo`0<0?ooo`030?l0O03oool0oooo00H0oooo
00080?ooo`030?l0P`3oool0oooo00/0oooo00<0o`2U0?ooo`3oool02`3oool00`3o0<<0oooo0?oo
o`0;0?ooo`030?l0gP3oool0oooo00`0oooo00<0o`3f0?ooo`3oool02`3oool00`3e0?l0oooo0?oo
o`0;0?ooo`030>D0o`3oool0oooo00/0oooo00<0f@3o0?ooo`3oool02`3oool00`3A0?l0oooo0?oo
o`0<0?ooo`030<d0o`3oool0oooo00/0oooo00<0cP3o0?ooo`3oool02`3oool00`3B0?l0oooo0?oo
o`0;0?ooo`030=/0o`3oool0oooo00/0oooo00<0j03o0?ooo`3oool0303oool00`3i0?l0oooo0?oo
o`0;0?ooo`030?l0l@3oool0oooo00`0oooo00<0o`3I0?ooo`3oool02`3oool00`3o0;d0oooo0?oo
o`0:0?ooo`030?l0WP3oool0oooo00`0oooo00<0o`1l0?ooo`3oool01`3oool000P0oooo00<0o`23
0?ooo`3oool0303oool00`3o0:D0oooo0?ooo`0;0?ooo`030?l0``3oool0oooo00/0oooo00<0o`3N
0?ooo`3oool02`3oool00`3o0?H0oooo0?ooo`0;0?ooo`030?D0o`3oool0oooo00`0oooo00<0i@3o
0?ooo`3oool02`3oool00`3I0?l0oooo0?ooo`0:0?ooo`030=40o`3oool0oooo00`0oooo00<0c@3o
0?ooo`3oool02`3oool00`3>0?l0oooo0?ooo`0;0?ooo`030=80o`3oool0oooo00/0oooo00<0f`3o
0?ooo`3oool02`3oool00`3X0?l0oooo0?ooo`0<0?ooo`030?T0o`3oool0oooo00/0oooo00<0o`3a
0?ooo`3oool02`3oool00`3o0=T0oooo0?ooo`0;0?ooo`030?l0_@3oool0oooo00/0oooo00<0o`2N
0?ooo`3oool0303oool00`3o07`0oooo0?ooo`070?ooo`002@3oool00`3o08<0oooo0?ooo`0;0?oo
o`030?l0Y@3oool0oooo00/0oooo00<0o`330?ooo`3oool02`3oool00`3o0=h0oooo0?ooo`0<0?oo
o`030?l0mP3oool0oooo00X0oooo00<0m@3o0?ooo`3oool0303oool00`3U0?l0oooo0?ooo`0;0?oo
o`030=T0o`3oool0oooo00X0oooo00<0d@3o0?ooo`3oool0303oool00`3=0?l0oooo0?ooo`0;0?oo
o`030<h0o`3oool0oooo00/0oooo00<0dP3o0?ooo`3oool02`3oool00`3K0?l0oooo0?ooo`0;0?oo
o`030>P0o`3oool0oooo00`0oooo00<0n@3o0?ooo`3oool02P3oool00`3o0?40oooo0?ooo`0<0?oo
o`030?l0f@3oool0oooo00/0oooo00<0o`2m0?ooo`3oool02P3oool00`3o09h0oooo0?ooo`0<0?oo
o`030?l0O03oool0oooo00P0oooo00090?ooo`030?l0P`3oool0o`2300/0oooo00<0o`2U0?ooo`3o
0:D02`3oool30?l0``/0oooo0`3o0=h<0?ooo`80o`3f2P3oool40?D0o`X0oooo103U0?l:0?ooo`@0
f@3o2P3oool40=40o`X0oooo103=0?l;0?ooo`<0cP3o2`3oool30=80o`/0oooo0`3K0?l;0?ooo`<0
j03o2`3oool30?T0o`/0oooo0P3o0?4<0?ooo`80o`3I303oool20?l0_@`0oooo0P3o09h<0?ooo`80
o`1l2`3oool000T0oooo0`3o08<;0?ooo`<0o`2U2P3oool40?l0``X0oooo103o0=h:0?ooo`@0o`3f
2P3oool40?D0o`X0oooo103U0?l:0?ooo`@0f@3o2P3oool40=40o`X0oooo103=0?l;0?ooo`<0cP3o
2`3oool30=80o`/0oooo0`3K0?l;0?ooo`<0j03o2`3oool30?T0o`/0oooo0`3o0?4;0?ooo`<0o`3I
2`3oool30?l0_@/0oooo0`3o09h;0?ooo`<0o`1l2P3oool000X0oooo0`3o08<;0?ooo`80o`2U2`3o
ool30?l0``/0oooo0`3o0=h;0?ooo`<0o`3f2`3oool30?D0o`/0oooo0`3U0?l;0?ooo`<0f@3o2`3o
ool30=40o`/0oooo0`3=0?l;0?ooo`<0cP3o2`3oool20=80o``0oooo0P3K0?l<0?ooo`80j03o303o
ool20?T0o``0oooo0P3o0?4<0?ooo`80o`3I303oool20?l0_@/0oooo0`3o09h;0?ooo`<0o`1l2`3o
ool000/0oooo0P3o08<;0?ooo`80o`2U303oool20?l0```0oooo0P3o0=h<0?ooo`80o`3f2`3oool3
0?D0o`/0oooo0`3U0?l;0?ooo`<0f@3o2`3oool20=40o``0oooo0P3=0?l<0?ooo`80cP3o303oool2
0=80o``0oooo0P3K0?l<0?ooo`80j03o303oool20?T0o`/0oooo0`3o0?4;0?ooo`<0o`3I2`3oool3
0?l0_@/0oooo0P3o09h<0?ooo`80o`1l303oool000/0oooo0P3o08<<0?ooo`80o`2U2`3oool30?l0
``/0oooo0`3o0=h;0?ooo`<0o`3f2`3oool20?D0o``0oooo0P3U0?l<0?ooo`80f@3o2`3oool20=40
o``0oooo0P3=0?l=0?ooo`030<h0o`3oool0oooo00X0oooo0P3B0?l<0?ooo`80f`3o303oool20>P0
o``0oooo0P3i0?l;0?ooo`80o`3a303oool20?l0f@`0oooo0P3o0;d<0?ooo`80o`2N303oool20?l0
O0`0oooo000<0?ooo`80o`232`3oool20?l0Y@`0oooo0P3o0<<<0?ooo`80o`3N303oool20?l0mP/0
oooo0P3e0?l<0?ooo`80i@3o303oool20=T0o``0oooo00<0d@3o0?ooo`3oool02`3oool00`3=0?l0
oooo0?ooo`0;0?ooo`030<h0o`3oool0oooo00X0oooo00<0dP3o0?ooo`3oool02`3oool00`3K0?l0
oooo0?ooo`0;0?ooo`030>P0o`3oool0oooo00/0oooo00<0n@3o0?ooo`3oool02P3oool20?l0l@`0
oooo0P3o0=T<0?ooo`80o`2m2`3oool20?l0WP`0oooo0P3o07`=0?ooo`003@3oool00`3o08<0oooo
0?ooo`0:0?ooo`030?l0Y@3oool0oooo00/0oooo00<0o`330?ooo`3oool02`3oool00`3o0=h0oooo
0?ooo`0;0?ooo`030?l0mP3oool0oooo00X0oooo00<0m@3o0?ooo`3oool02`3oool00`3U0?l0oooo
0?ooo`0;0?ooo`030=T0o`3oool0oooo00X0oooo00<0d@3o0?ooo`3oool02`3oool00`3=0?l0oooo
0?ooo`0;0?ooo`030<h0o`3oool0oooo00X0oooo00<0dP3o0?ooo`3oool02`3oool00`3K0?l0oooo
0?ooo`0;0?ooo`030>P0o`3oool0oooo00/0oooo00<0n@3o0?ooo`3oool02P3oool00`3o0?40oooo
0?ooo`0;0?ooo`030?l0f@3oool0oooo00/0oooo00<0o`2m0?ooo`3oool02P3oool00`3o09h0oooo
0?ooo`0;0?ooo`030?l0O03oool0oooo00`0oooo003o0?ooob40oooo00060?ooo`030?l0a`3oool0
oooo00`0oooo00<0o`3Y0?ooo`3oool02`3oool00`3f0?l0oooo0?ooo`0;0?ooo`030=X0o`3oool0
oooo00`0oooo00<0`@3o0?ooo`3oool02`3oool00`2]0?l0oooo0?ooo`0<0?ooo`0309`0o`3oool0
oooo00/0oooo00<0T03o0?ooo`3oool02`3oool00`280?l0oooo0?ooo`0<0?ooo`0308D0o`3oool0
oooo00/0oooo00<0QP3o0?ooo`3oool0303oool00`2;0?l0oooo0?ooo`0;0?ooo`0309D0o`3oool0
oooo00/0oooo00<0Y03o0?ooo`3oool0303oool00`2f0?l0oooo0?ooo`0;0?ooo`030<d0o`3oool0
oooo00`0oooo00<0i`3o0?ooo`3oool02`3oool00`3o0?X0oooo0?ooo`0;0?ooo`030?l0f@3oool0
oooo00`0oooo00<0o`2e0?ooo`3oool01@3oool000L0oooo00<0o`370?ooo`3oool02`3oool00`3o
0>T0oooo0?ooo`0;0?ooo`030?H0o`3oool0oooo00/0oooo00<0fP3o0?ooo`3oool0303oool00`31
0?l0oooo0?ooo`0;0?ooo`030:d0o`3oool0oooo00`0oooo00<0W03o0?ooo`3oool02`3oool00`2@
0?l0oooo0?ooo`0;0?ooo`0308P0o`3oool0oooo00`0oooo00<0Q@3o0?ooo`3oool02`3oool00`26
0?l0oooo0?ooo`0<0?ooo`0308/0o`3oool0oooo00/0oooo00<0U@3o0?ooo`3oool02`3oool00`2T
0?l0oooo0?ooo`0<0?ooo`030;H0o`3oool0oooo00/0oooo00<0c@3o0?ooo`3oool0303oool00`3W
0?l0oooo0?ooo`0;0?ooo`030?l0nP3oool0oooo00X0oooo00<0o`3I0?ooo`3oool0303oool00`3o
0;D0oooo0?ooo`060?ooo`001`3oool00`3o0<L0oooo0?ooo`0<0?ooo`030?l0j@3oool0oooo00/0
oooo00<0mP3o0?ooo`3oool02`3oool00`3J0?l0oooo0?ooo`0<0?ooo`030<40o`3oool0oooo00/0
oooo00<0[@3o0?ooo`3oool02`3oool00`2L0?l0oooo0?ooo`0;0?ooo`030900o`3oool0oooo00/0
oooo00<0R03o0?ooo`3oool0303oool00`250?l0oooo0?ooo`0;0?ooo`0308H0o`3oool0oooo00`0
oooo00<0R`3o0?ooo`3oool02`3oool00`2E0?l0oooo0?ooo`0;0?ooo`030:@0o`3oool0oooo00/0
oooo00<0]P3o0?ooo`3oool02`3oool00`3=0?l0oooo0?ooo`0<0?ooo`030>L0o`3oool0oooo00/0
oooo00<0o`3j0?ooo`3oool02`3oool00`3o0=T0oooo0?ooo`0<0?ooo`030?l0]@3oool0oooo00H0
oooo00080?ooo`030?l0a`3oool0oooo00/0oooo00<0o`3Y0?ooo`3oool02`3oool00`3f0?l0oooo
0?ooo`0;0?ooo`030=X0o`3oool0oooo00`0oooo00<0`@3o0?ooo`3oool02`3oool00`2]0?l0oooo
0?ooo`0<0?ooo`0309`0o`3oool0oooo00/0oooo00<0T03o0?ooo`3oool02P3oool00`280?l0oooo
0?ooo`0<0?ooo`0308D0o`3oool0oooo00/0oooo00<0QP3o0?ooo`3oool02`3oool00`2;0?l0oooo
0?ooo`0;0?ooo`0309D0o`3oool0oooo00/0oooo00<0Y03o0?ooo`3oool0303oool00`2f0?l0oooo
0?ooo`0;0?ooo`030<d0o`3oool0oooo00`0oooo00<0i`3o0?ooo`3oool02`3oool00`3o0?X0oooo
0?ooo`0:0?ooo`030?l0f@3oool0oooo00`0oooo00<0o`2e0?ooo`3oool01`3oool000T0oooo00<0
o`370?ooo`3oool02`3oool00`3o0>T0oooo0?ooo`0;0?ooo`030?H0o`3oool0oooo00/0oooo00<0
fP3o0?ooo`3oool02`3oool00`310?l0oooo0?ooo`0;0?ooo`030:d0o`3oool0oooo00`0oooo00<0
W03o0?ooo`3oool02`3oool00`2@0?l0oooo0?ooo`0:0?ooo`0308P0o`3oool0oooo00`0oooo00<0
Q@3o0?ooo`3oool02`3oool00`260?l0oooo0?ooo`0;0?ooo`0308/0o`3oool0oooo00/0oooo00<0
U@3o0?ooo`3oool02`3oool00`2T0?l0oooo0?ooo`0<0?ooo`030;H0o`3oool0oooo00/0oooo00<0
c@3o0?ooo`3oool02`3oool00`3W0?l0oooo0?ooo`0;0?ooo`030?l0nP3oool0oooo00/0oooo00<0
o`3I0?ooo`3oool02`3oool00`3o0;D0oooo0?ooo`080?ooo`002@3oool00`3o0<L0oooo0?ooo`0;
0?ooo`030?l0j@3oool0oooo00/0oooo00<0mP3o0?ooo`3oool02`3oool00`3J0?l0oooo0?ooo`0;
0?ooo`<0`@3o2`3oool30:d0o``0oooo0P2L0?l<0?ooo`80T03o2`3oool00`280?l0oooo0?ooo`0<
0?ooo`0308D0o`3oool0oooo00/0oooo00<0QP3o0?ooo`3oool02`3oool00`2;0?l0oooo0?ooo`0:
0?ooo`80U@3o303oool20:@0o``0oooo00<0]P3o0?ooo`2f0?l02`3oool20<d0o`h0oooo00<0i`3o
0?ooo`3oool02`3oool00`3o0?X0oooo0?ooo`0:0?ooo`030?l0f@3oool0oooo00`0oooo00<0o`2e
0?ooo`3oool0203oool000X0oooo0P3o0<L<0?ooo`80o`3Y303oool20?H0o``0oooo0P3J0?l:0?oo
o`@0`@3o2P3oool40:d0o`X0oooo102L0?l:0?ooo`@0T03o2P3oool408P0o`X0oooo10250?l;0?oo
o`<0QP3o2`3oool308/0o`/0oooo0`2E0?l;0?ooo`<0Y03o2`3oool30;H0o`/0oooo0`3=0?l;0?oo
o`80i`3o303oool20?l0nP`0oooo0P3o0=T<0?ooo`80o`2e2`3oool000P0oooo103o0<L:0?ooo`@0
o`3Y2P3oool40?H0o`X0oooo103J0?l;0?ooo`<0`@3o2`3oool30:d0o`/0oooo0`2L0?l;0?ooo`<0
T03o2P3oool408P0o`X0oooo10250?l;0?ooo`<0QP3o2`3oool308/0o`/0oooo0`2E0?l;0?ooo`<0
Y03o2`3oool30;H0o`/0oooo0P3=0?l<0?ooo`<0i`3o2`3oool30?l0nP/0oooo0`3o0=T;0?ooo`<0
o`2e2P3oool000T0oooo103o0<L:0?ooo`<0o`3Y2`3oool30?H0o`/0oooo0`3J0?l;0?ooo`<0`@3o
2`3oool30:d0o`/0oooo0`2L0?l;0?ooo`<0T03o2`3oool308P0o`/0oooo0`250?l;0?ooo`<0QP3o
2`3oool208/0o``0oooo0P2E0?l<0?ooo`80Y03o303oool20;H0o`/0oooo0`3=0?l<0?ooo`80i`3o
303oool20?l0nP/0oooo0`3o0=T;0?ooo`<0o`2e2`3oool000X0oooo0`3o0<L;0?ooo`<0o`3Y2`3o
ool30?H0o`/0oooo0`3J0?l;0?ooo`80`@3o303oool20:d0o``0oooo0P2L0?l<0?ooo`80T03o2`3o
ool208P0o``0oooo0P250?l=0?ooo`0308H0o`3oool0oooo00X0oooo0P2;0?l<0?ooo`80U@3o303o
ool20:@0o``0oooo0P2f0?l;0?ooo`80c@3o303oool20>L0o``0oooo0P3o0?X<0?ooo`80o`3I303o
ool20?l0]@`0oooo000<0?ooo`80o`372`3oool20?l0j@`0oooo0P3f0?l<0?ooo`80fP3o2`3oool2
0<40o``0oooo0P2]0?l<0?ooo`80W03o303oool20900o``0oooo00<0R03o0?ooo`3oool02`3oool0
0`250?l0oooo0?ooo`0;0?ooo`0308H0o`3oool0oooo00X0oooo00<0R`3o0?ooo`3oool02`3oool0
0`2E0?l0oooo0?ooo`0;0?ooo`030:@0o`3oool0oooo00/0oooo00<0]P3o0?ooo`3oool02P3oool2
0<d0o``0oooo0P3W0?l<0?ooo`80o`3j2`3oool20?l0f@`0oooo0P3o0;D=0?ooo`003@3oool00`3o
0<L0oooo0?ooo`0:0?ooo`030?l0j@3oool0oooo00/0oooo00<0mP3o0?ooo`3oool02`3oool00`3J
0?l0oooo0?ooo`0:0?ooo`030<40o`3oool0oooo00/0oooo00<0[@3o0?ooo`3oool02`3oool00`2L
0?l0oooo0?ooo`0;0?ooo`030900o`3oool0oooo00X0oooo00<0R03o0?ooo`3oool02`3oool00`25
0?l0oooo0?ooo`0;0?ooo`0308H0o`3oool0oooo00X0oooo00<0R`3o0?ooo`3oool02`3oool00`2E
0?l0oooo0?ooo`0;0?ooo`030:@0o`3oool0oooo00/0oooo00<0]P3o0?ooo`3oool02P3oool00`3=
0?l0oooo0?ooo`0;0?ooo`030>L0o`3oool0oooo00/0oooo00<0o`3j0?ooo`3oool02P3oool00`3o
0=T0oooo0?ooo`0;0?ooo`030?l0]@3oool0oooo00`0oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo00060?ooo`030?<0o`3oool0oooo00`0oooo00<0c`3o0?ooo`3oool02`3oool0
0`2_0?l0oooo0?ooo`0;0?ooo`030980o`3oool0oooo00`0oooo00<0N@3o0?ooo`3oool02`3oool0
0`1T0?l0oooo0?ooo`0<0?ooo`0305<0o`3oool0oooo00/0oooo00<0AP3o0?ooo`3oool02`3oool0
0`0o0?l0oooo0?ooo`0<0?ooo`0303`0o`3oool0oooo00/0oooo00<0?P3o0?ooo`3oool0303oool0
0`150?l0oooo0?ooo`0;0?ooo`030500o`3oool0oooo00/0oooo00<0H@3o0?ooo`3oool0303oool0
0`1e0?l0oooo0?ooo`0;0?ooo`0308h0o`3oool0oooo00`0oooo00<0ZP3o0?ooo`3oool02`3oool0
0`3:0?l0oooo0?ooo`0;0?ooo`030>d0o`3oool0oooo00`0oooo00<0o`3[0?ooo`3oool01@3oool0
00L0oooo00<0l`3o0?ooo`3oool02`3oool00`3?0?l0oooo0?ooo`0;0?ooo`030:l0o`3oool0oooo
00/0oooo00<0TP3o0?ooo`3oool0303oool00`1i0?l0oooo0?ooo`0;0?ooo`0306@0o`3oool0oooo
00`0oooo00<0D`3o0?ooo`3oool02`3oool00`160?l0oooo0?ooo`0;0?ooo`0303l0o`3oool0oooo
00`0oooo00<0?03o0?ooo`3oool02`3oool00`0n0?l0oooo0?ooo`0<0?ooo`0304D0o`3oool0oooo
00/0oooo00<0D03o0?ooo`3oool02`3oool00`1Q0?l0oooo0?ooo`0<0?ooo`0307D0o`3oool0oooo
00/0oooo00<0SP3o0?ooo`3oool02`3oool00`2Z0?l0oooo0?ooo`0;0?ooo`030<X0o`3oool0oooo
00/0oooo00<0k@3o0?ooo`3oool0303oool00`3o0>/0oooo0?ooo`060?ooo`001`3oool00`3c0?l0
oooo0?ooo`0<0?ooo`030<l0o`3oool0oooo00/0oooo00<0[`3o0?ooo`3oool02`3oool00`2B0?l0
oooo0?ooo`0<0?ooo`0307T0o`3oool0oooo00/0oooo00<0I03o0?ooo`3oool02`3oool00`1C0?l0
oooo0?ooo`0;0?ooo`0304H0o`3oool0oooo00/0oooo00<0?`3o0?ooo`3oool0303oool00`0l0?l0
oooo0?ooo`0;0?ooo`0303h0o`3oool0oooo00`0oooo00<0A@3o0?ooo`3oool02`3oool00`1@0?l0
oooo0?ooo`0;0?ooo`030640o`3oool0oooo00/0oooo00<0M@3o0?ooo`3oool02`3oool00`2>0?l0
oooo0?ooo`0<0?ooo`030:X0o`3oool0oooo00/0oooo00<0bP3o0?ooo`3oool02`3oool00`3]0?l0
oooo0?ooo`0<0?ooo`030?l0j`3oool0oooo00H0oooo00080?ooo`030?<0o`3oool0oooo00/0oooo
00<0c`3o0?ooo`3oool02`3oool00`2_0?l0oooo0?ooo`0;0?ooo`030980o`3oool0oooo00`0oooo
00<0N@3o0?ooo`3oool02`3oool00`1T0?l0oooo0?ooo`0<0?ooo`0305<0o`3oool0oooo00X0oooo
00<0AP3o0?ooo`3oool02`3oool00`0o0?l0oooo0?ooo`0<0?ooo`0303`0o`3oool0oooo00/0oooo
00<0?P3o0?ooo`3oool02`3oool00`150?l0oooo0?ooo`0;0?ooo`030500o`3oool0oooo00/0oooo
00<0H@3o0?ooo`3oool0303oool00`1e0?l0oooo0?ooo`0;0?ooo`0308h0o`3oool0oooo00/0oooo
00<0ZP3o0?ooo`3oool02`3oool00`3:0?l0oooo0?ooo`0;0?ooo`030>d0o`3oool0oooo00`0oooo
00<0o`3[0?ooo`3oool01`3oool000P0oooo00@0l`3o0?ooo`3oool0l`3o2`3oool00`3?0?l0oooo
0<l0o`0;0?ooo`<0[`3o2`3oool30980o`/0oooo0`1i0?l;0?ooo`<0I03o303oool205<0o`/0oooo
0`160?l:0?ooo`@0?`3o2P3oool403`0o`X0oooo100n0?l;0?ooo`80A@3o303oool20500o``0oooo
0P1Q0?l<0?ooo`80M@3o303oool208h0o``0oooo0`2Z0?l;0?ooo`030<X0o`3oool0bP3o00/0oooo
00<0k@3o0?ooo`3]0?l02`3oool00`3o0>/0oooo0?l0j`0:0?ooo`002@3oool30?<0o`/0oooo0`3?
0?l:0?ooo`@0[`3o2P3oool40980o`X0oooo101i0?l:0?ooo`@0I03o2P3oool405<0o`X0oooo1016
0?l:0?ooo`@0?`3o2P3oool403`0o`X0oooo100n0?l;0?ooo`<0A@3o2`3oool30500o`/0oooo101Q
0?l:0?ooo`@0M@3o2P3oool408h0o`X0oooo102Z0?l:0?ooo`80bP3o303oool20>d0o``0oooo0P3o
0>/;0?ooo`00203oool40?<0o`X0oooo103?0?l;0?ooo`<0[`3o2`3oool30980o`/0oooo0`1i0?l;
0?ooo`<0I03o2`3oool305<0o`X0oooo10160?l;0?ooo`<0?`3o2`3oool303`0o`/0oooo0`0n0?l;
0?ooo`<0A@3o2`3oool30500o`/0oooo0`1Q0?l;0?ooo`<0M@3o2`3oool308h0o`/0oooo0`2Z0?l;
0?ooo`<0bP3o2P3oool40>d0o`X0oooo103o0>/:0?ooo`002@3oool30?<0o`/0oooo0`3?0?l<0?oo
o`80[`3o303oool20980o`/0oooo0`1i0?l;0?ooo`<0I03o2`3oool305<0o`/0oooo0P160?l<0?oo
o`80?`3o303oool203`0o``0oooo0P0n0?l<0?ooo`80A@3o303oool20500o``0oooo0`1Q0?l:0?oo
o`<0M@3o2`3oool308h0o`/0oooo0`2Z0?l;0?ooo`<0bP3o2`3oool30>d0o`/0oooo0`3o0>/;0?oo
o`002P3oool30?<0o`/0oooo0`3?0?l;0?ooo`<0[`3o2`3oool30980o`/0oooo0P1i0?l<0?ooo`80
I03o303oool205<0o`/0oooo0P160?l<0?ooo`80?`3o303oool203`0o``0oooo0P0n0?l<0?ooo`80
A@3o303oool20500o``0oooo0P1Q0?l;0?ooo`<0M@3o2`3oool308h0o`/0oooo0`2Z0?l;0?ooo`80
bP3o303oool20>d0o``0oooo0P3o0>/<0?ooo`002`3oool20?<0o``0oooo0P3?0?l<0?ooo`80[`3o
303oool20980o`/0oooo0P1i0?l<0?ooo`80I03o303oool205<0o``0oooo00<0AP3o0?ooo`3oool0
2`3oool00`0o0?l0oooo0?ooo`0;0?ooo`0303`0o`3oool0oooo00/0oooo00<0?P3o0?ooo`3oool0
2P3oool00`150?l0oooo0?ooo`0;0?ooo`030500o`3oool0oooo00/0oooo0P1Q0?l;0?ooo`80M@3o
303oool208h0o``0oooo0P2Z0?l<0?ooo`80bP3o2`3oool20>d0o``0oooo0P3o0>/=0?ooo`00303o
ool00`3c0?l0oooo0?ooo`0;0?ooo`030<l0o`3oool0oooo00/0oooo00<0[`3o0?ooo`3oool02`3o
ool00`2B0?l0oooo0?ooo`0:0?ooo`0307T0o`3oool0oooo00/0oooo00<0I03o0?ooo`3oool02`3o
ool00`1C0?l0oooo0?ooo`0:0?ooo`0304H0o`3oool0oooo00/0oooo00<0?`3o0?ooo`3oool02`3o
ool00`0l0?l0oooo0?ooo`0;0?ooo`0303h0o`3oool0oooo00X0oooo00<0A@3o0?ooo`3oool02`3o
ool00`1@0?l0oooo0?ooo`0;0?ooo`030640o`3oool0oooo00X0oooo00<0M@3o0?ooo`3oool02`3o
ool00`2>0?l0oooo0?ooo`0;0?ooo`030:X0o`3oool0oooo00/0oooo00<0bP3o0?ooo`3oool02P3o
ool00`3]0?l0oooo0?ooo`0;0?ooo`030?l0j`3oool0oooo00`0oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo00060?ooo`030:d0o`3oool0oooo00`0oooo00<0R03o0?ooo`3oool0
2`3oool00`1V0?l0oooo0?ooo`0;0?ooo`0304P0o`3oool0oooo00`0oooo00<0;`3o0?ooo`3oool0
2`3oool00`0I0?l0oooo0?ooo`0<0?ooo`0300P0o`3oool0oooo00/0oooo00<000?o0?ooo`3oool0
2`3oool00`002Ol0oooo0?ooo`0<0?ooo`03000;o`3oool0oooo00/0oooo00<000So0?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`0300d0o`3oool0oooo00/0oooo00<07`3o0?ooo`3oool0
303oool00`0f0?l0oooo0?ooo`0;0?ooo`030540o`3oool0oooo00`0oooo00<0L03o0?ooo`3oool0
2`3oool00`2C0?l0oooo0?ooo`0;0?ooo`030;T0o`3oool0oooo00`0oooo00<0hP3o0?ooo`3oool0
1@3oool000L0oooo00<0[@3o0?ooo`3oool02`3oool00`280?l0oooo0?ooo`0;0?ooo`0306H0o`3o
ool0oooo00/0oooo00<0B03o0?ooo`3oool0303oool00`0_0?l0oooo0?ooo`0;0?ooo`0301T0o`3o
ool0oooo00`0oooo00<0203o0?ooo`3oool02`3oool00`000ol0oooo0?ooo`0;0?ooo`030009o`3o
ool0oooo00`0oooo00<000_o0?ooo`3oool02`3oool00`002?l0oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<03@3o0?ooo`3oool02`3oool00`0O0?l0oooo0?ooo`0<0?ooo`0303H0o`3o
ool0oooo00/0oooo00<0D@3o0?ooo`3oool02`3oool00`1`0?l0oooo0?ooo`0;0?ooo`0309<0o`3o
ool0oooo00/0oooo00<0^@3o0?ooo`3oool0303oool00`3R0?l0oooo0?ooo`060?ooo`001`3oool0
0`2]0?l0oooo0?ooo`0<0?ooo`0308P0o`3oool0oooo00/0oooo00<0IP3o0?ooo`3oool02`3oool0
0`180?l0oooo0?ooo`0<0?ooo`0302l0o`3oool0oooo00/0oooo00<06@3o0?ooo`3oool02`3oool0
0`080?l0oooo0?ooo`0;0?ooo`030003o`3oool0oooo00/0oooo00<000Wo0?ooo`3oool0303oool0
0`002ol0oooo0?ooo`0;0?ooo`030008o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`0=0?l0oooo0?ooo`0;0?ooo`0301l0o`3oool0oooo00/0oooo00<0=P3o0?ooo`3oool02`3oool0
0`1A0?l0oooo0?ooo`0<0?ooo`030700o`3oool0oooo00/0oooo00<0T`3o0?ooo`3oool02`3oool0
0`2i0?l0oooo0?ooo`0<0?ooo`030>80o`3oool0oooo00H0oooo00080?ooo`030:d0o`3oool0oooo
00/0oooo00<0R03o0?ooo`3oool02`3oool00`1V0?l0oooo0?ooo`0;0?ooo`0304P0o`3oool0oooo
00`0oooo00<0;`3o0?ooo`3oool02`3oool00`0I0?l0oooo0?ooo`0<0?ooo`0300P0o`3oool0oooo
00X0oooo00<000?o0?ooo`3oool02`3oool00`002Ol0oooo0?ooo`0<0?ooo`03000;o`3oool0oooo
00/0oooo00<000So0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`0300d0o`3oool0oooo
00/0oooo00<07`3o0?ooo`3oool0303oool00`0f0?l0oooo0?ooo`0;0?ooo`030540o`3oool0oooo
00/0oooo00<0L03o0?ooo`3oool02`3oool00`2C0?l0oooo0?ooo`0;0?ooo`030;T0o`3oool0oooo
00`0oooo00<0hP3o0?ooo`3oool01`3oool000P0oooo00<0[@3o0?ooo`2]0?l0303oool208P0o``0
oooo0P1V0?l<0?ooo`<0B03o2`3oool302l0o`/0oooo0`0I0?l:0?ooo`@0203o2P3oool40003o`X0
oooo10002Ol:0?ooo`@000_o2P3oool40008o`/0oooo0`000?l;0?ooo`<03@3o2`3oool201l0o``0
oooo0P0f0?l<0?ooo`80D@3o303oool30700o`/0oooo00<0T`3o0?ooo`2C0?l02`3oool00`2i0?l0
oooo0;T0o`0;0?ooo`030>80o`3oool0hP3o00X0oooo00090?ooo`80[@3o2`3oool308P0o`/0oooo
0`1V0?l;0?ooo`@0B03o2P3oool402l0o`X0oooo100I0?l:0?ooo`@0203o2P3oool40003o`X0oooo
10002Ol:0?ooo`@000_o2P3oool40008o`/0oooo0`000?l;0?ooo`<03@3o2`3oool401l0o`X0oooo
100f0?l:0?ooo`@0D@3o2P3oool40700o`X0oooo0P2C0?l<0?ooo`80^@3o303oool20>80o`/0oooo
00080?ooo`@0[@3o2`3oool308P0o`/0oooo0`1V0?l;0?ooo`<0B03o2`3oool302l0o`/0oooo0`0I
0?l;0?ooo`<0203o2`3oool30003o`/0oooo0`002Ol;0?ooo`<000_o2P3oool30008o``0oooo0P00
0?l<0?ooo`803@3o303oool301l0o`/0oooo0`0f0?l;0?ooo`<0D@3o2`3oool30700o`X0oooo102C
0?l:0?ooo`@0^@3o2P3oool40>80o`X0oooo00090?ooo`<0[@3o303oool208P0o``0oooo0P1V0?l;
0?ooo`<0B03o2`3oool302l0o`/0oooo0`0I0?l;0?ooo`<0203o2`3oool20003o``0oooo0P002Ol<
0?ooo`8000_o2`3oool30008o``0oooo0P000?l<0?ooo`803@3o303oool301l0o`X0oooo0`0f0?l;
0?ooo`<0D@3o2`3oool30700o`/0oooo0`2C0?l;0?ooo`<0^@3o2`3oool30>80o`/0oooo000:0?oo
o`80[@3o303oool208P0o``0oooo0P1V0?l<0?ooo`80B03o303oool202l0o``0oooo0P0I0?l<0?oo
o`80203o2`3oool20003o``0oooo0P002Ol<0?ooo`8000_o303oool20008o``0oooo0P000?l<0?oo
o`803@3o303oool201l0o`/0oooo0`0f0?l;0?ooo`<0D@3o2`3oool30700o`/0oooo0P2C0?l<0?oo
o`80^@3o303oool20>80o``0oooo000;0?ooo`80[@3o303oool208P0o``0oooo0P1V0?l;0?ooo`80
B03o303oool202l0o``0oooo0P0I0?l<0?ooo`80203o303oool00`000ol0oooo0?ooo`0;0?ooo`03
0009o`3oool0oooo00/0oooo00<000_o0?ooo`3oool02P3oool00`002?l0oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00/0oooo00<03@3o0?ooo`3oool02`3oool201l0o`/0oooo0P0f0?l<0?ooo`80
D@3o303oool20700o`/0oooo0P2C0?l<0?ooo`80^@3o303oool20>80o`d0oooo000<0?ooo`030:d0
o`3oool0oooo00/0oooo00<0R03o0?ooo`3oool02`3oool00`1V0?l0oooo0?ooo`0:0?ooo`0304P0
o`3oool0oooo00/0oooo00<0;`3o0?ooo`3oool02`3oool00`0I0?l0oooo0?ooo`0;0?ooo`0300P0
o`3oool0oooo00X0oooo00<000?o0?ooo`3oool02`3oool00`002Ol0oooo0?ooo`0;0?ooo`03000;
o`3oool0oooo00X0oooo00<000So0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`0300d0
o`3oool0oooo00/0oooo00<07`3o0?ooo`3oool02P3oool00`0f0?l0oooo0?ooo`0;0?ooo`030540
o`3oool0oooo00/0oooo00<0L03o0?ooo`3oool02P3oool00`2C0?l0oooo0?ooo`0;0?ooo`030;T0
o`3oool0oooo00/0oooo00<0hP3o0?ooo`3oool0303oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool000H0oooo00<0I@3o0?ooo`3oool0303oool00`0o0?l0oooo
0?ooo`0;0?ooo`0301`0o`3oool0oooo00/0oooo00<0007o0?ooo`3oool0303oool00`006ol0oooo
0?ooo`0;0?ooo`03000ao`3oool0oooo00`0oooo00<004;o0?ooo`3oool02`3oool00`00COl0oooo
0?ooo`0;0?ooo`03001Co`3oool0oooo00`0oooo00<005?o0?ooo`3oool02`3oool00`00C_l0oooo
0?ooo`0<0?ooo`030013o`3oool0oooo00/0oooo00<003?o0?ooo`3oool02`3oool00`007_l0oooo
0?ooo`0<0?ooo`030004o`3oool0oooo00/0oooo00<06@3o0?ooo`3oool0303oool00`0k0?l0oooo
0?ooo`0;0?ooo`030640o`3oool0oooo00/0oooo00<0R@3o0?ooo`3oool0303oool00`2f0?l0oooo
0?ooo`050?ooo`001`3oool00`1U0?l0oooo0?ooo`0<0?ooo`0303l0o`3oool0oooo00/0oooo00<0
703o0?ooo`3oool02P3oool00`000Ol0oooo0?ooo`0<0?ooo`03000Ko`3oool0oooo00/0oooo00<0
037o0?ooo`3oool0303oool00`00@_l0oooo0?ooo`0;0?ooo`03001=o`3oool0oooo00/0oooo00<0
05?o0?ooo`3oool0303oool00`00Dol0oooo0?ooo`0;0?ooo`03001>o`3oool0oooo00`0oooo00<0
04?o0?ooo`3oool02`3oool00`00<ol0oooo0?ooo`0;0?ooo`03000No`3oool0oooo00/0oooo00<0
00Co0?ooo`3oool02`3oool00`0I0?l0oooo0?ooo`0<0?ooo`0303/0o`3oool0oooo00/0oooo00<0
H@3o0?ooo`3oool02`3oool00`290?l0oooo0?ooo`0<0?ooo`030;H0o`3oool0oooo00H0oooo0007
0?ooo`0306D0o`3oool0oooo00`0oooo00<0?`3o0?ooo`3oool02`3oool00`0L0?l0oooo0?ooo`0;
0?ooo`030001o`3oool0oooo00`0oooo00<001_o0?ooo`3oool02`3oool00`00<Ol0oooo0?ooo`0;
0?ooo`030012o`3oool0oooo00/0oooo00<004go0?ooo`3oool02`3oool00`00Dol0oooo0?ooo`0<
0?ooo`03001Co`3oool0oooo00/0oooo00<004ko0?ooo`3oool02`3oool00`00@ol0oooo0?ooo`0;
0?ooo`03000co`3oool0oooo00/0oooo00<001ko0?ooo`3oool0303oool00`001?l0oooo0?ooo`0;
0?ooo`0301T0o`3oool0oooo00/0oooo00<0>`3o0?ooo`3oool02`3oool00`1Q0?l0oooo0?ooo`0;
0?ooo`0308T0o`3oool0oooo00`0oooo00<0]P3o0?ooo`3oool01`3oool000P0oooo00<0I@3o0?oo
o`1U0?l0303oool203l0o``0oooo0P0L0?l;0?ooo`030001o`3oool0007o00`0oooo0P006ol;0?oo
o`@0037o2P3oool40012o`X0oooo1000COl:0?ooo`@005?o2P3oool4001Co`X0oooo1000C_l;0?oo
o`<004?o2`3oool3000co`/0oooo0P007_l<0?ooo`8000Co303oool201T0o``0oooo0`0k0?l;0?oo
o`030640o`3oool0H@3o00/0oooo00<0R@3o0?ooo`290?l02`3oool00`2f0?l0oooo0;H0o`0:0?oo
o`00203oool306D0o`/0oooo0`0o0?l;0?ooo`<0703o2`3oool30001o`/0oooo0`006ol<0?ooo`<0
037o2P3oool40012o`X0oooo1000COl:0?ooo`@005?o2P3oool4001Co`X0oooo1000C_l;0?ooo`<0
04?o2`3oool3000co`/0oooo10007_l:0?ooo`@000Co2P3oool401T0o`X0oooo100k0?l:0?ooo`<0
H@3o2`3oool208T0o``0oooo0P2f0?l;0?ooo`002@3oool306D0o`/0oooo0`0o0?l;0?ooo`<0703o
2`3oool20001o``0oooo0P006ol<0?ooo`<0037o2`3oool30012o`/0oooo0`00COl;0?ooo`<005?o
2`3oool3001Co`X0oooo0`00C_l<0?ooo`8004?o303oool2000co``0oooo0`007_l;0?ooo`<000Co
2`3oool301T0o`X0oooo100k0?l:0?ooo`<0H@3o2`3oool408T0o`X0oooo102f0?l:0?ooo`002P3o
ool206D0o``0oooo0P0o0?l<0?ooo`80703o2`3oool30001o`/0oooo0`006ol<0?ooo`80037o2`3o
ool20012o``0oooo0P00COl<0?ooo`8005?o303oool2001Co``0oooo0P00C_l<0?ooo`8004?o303o
ool2000co`/0oooo0`007_l;0?ooo`<000Co2`3oool301T0o`/0oooo0`0k0?l;0?ooo`80H@3o303o
ool308T0o`/0oooo0`2f0?l;0?ooo`002`3oool206D0o``0oooo0P0o0?l<0?ooo`80703o2`3oool2
0001o``0oooo0P006ol<0?ooo`80037o303oool00`00@_l0oooo0?ooo`0;0?ooo`03001=o`3oool0
oooo00/0oooo00<005?o0?ooo`3oool02`3oool00`00Dol0oooo0?ooo`0:0?ooo`03001>o`3oool0
oooo00/0oooo00<004?o0?ooo`3oool02`3oool00`00<ol0oooo0?ooo`0:0?ooo`8001ko303oool2
0004o``0oooo0P0I0?l;0?ooo`80>`3o303oool20640o``0oooo0`290?l;0?ooo`<0]P3o303oool0
00`0oooo00<0I@3o0?ooo`3oool02`3oool00`0o0?l0oooo0?ooo`0;0?ooo`0301`0o`3oool0oooo
00X0oooo00<0007o0?ooo`3oool02`3oool00`006ol0oooo0?ooo`0;0?ooo`03000ao`3oool0oooo
00X0oooo00<004;o0?ooo`3oool02`3oool00`00COl0oooo0?ooo`0;0?ooo`03001Co`3oool0oooo
00/0oooo00<005?o0?ooo`3oool02P3oool00`00C_l0oooo0?ooo`0;0?ooo`030013o`3oool0oooo
00/0oooo00<003?o0?ooo`3oool02P3oool00`007_l0oooo0?ooo`0;0?ooo`030004o`3oool0oooo
00/0oooo00<06@3o0?ooo`3oool02P3oool00`0k0?l0oooo0?ooo`0;0?ooo`030640o`3oool0oooo
00/0oooo00<0R@3o0?ooo`3oool02`3oool00`2f0?l0oooo0?ooo`0<0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3oool00`0K0?l0
oooo0?ooo`0<0?ooo`03000;o`3oool0oooo00/0oooo00<002oo0?ooo`3oool02`3oool00`00C_l0
oooo0?ooo`0<0?ooo`03001Xo`3oool0oooo00/0oooo00<007go0?ooo`3oool0303oool00`00SOl0
oooo0?ooo`0;0?ooo`03002Go`3oool0oooo00/0oooo00<009co0?ooo`3oool0303oool00`00V_l0
oooo0?ooo`0;0?ooo`03002Bo`3oool0oooo00`0oooo00<008Go0?ooo`3oool02`3oool00`00L_l0
oooo0?ooo`0;0?ooo`03001Io`3oool0oooo00`0oooo00<003co0?ooo`3oool02`3oool00`006ol0
oooo0?ooo`0<0?ooo`0300X0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool02`3oool00`1O0?l0
oooo0?ooo`0<0?ooo`0308h0o`3oool0oooo00D0oooo00070?ooo`0301/0o`3oool0oooo00`0oooo
00<000_o0?ooo`3oool02P3oool00`00;ol0oooo0?ooo`0;0?ooo`03001>o`3oool0oooo00`0oooo
00<006So0?ooo`3oool02`3oool00`00OOl0oooo0?ooo`0<0?ooo`03002=o`3oool0oooo00/0oooo
00<009Oo0?ooo`3oool02`3oool00`00W?l0oooo0?ooo`0<0?ooo`03002Jo`3oool0oooo00/0oooo
00<009;o0?ooo`3oool0303oool00`00QOl0oooo0?ooo`0;0?ooo`03001bo`3oool0oooo00/0oooo
00<005Wo0?ooo`3oool02`3oool00`00??l0oooo0?ooo`0;0?ooo`03000Ko`3oool0oooo00`0oooo
00<02P3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0;0?ooo`0305l0o`3oool0oooo00`0oooo
00<0SP3o0?ooo`3oool01P3oool000L0oooo00<06`3o0?ooo`3oool0303oool00`002ol0oooo0?oo
o`0;0?ooo`03000_o`3oool002oo00/0oooo00<004ko0?ooo`00C_l0303oool2001Xo`/0oooo00<0
07go0?ooo`00OOl0303oool2002=o``0oooo0`00Uol:0?ooo`@009co2P3oool3002Jo`/0oooo0`00
T_l<0?ooo`8008Go303oool2001bo``0oooo0P00FOl<0?ooo`03000lo`3oool003co00/0oooo00<0
01_o0?ooo`006ol03@3oool00`0:0?l0oooo0?ooo`0;0?ooo`0303<0o`3oool0oooo00/0oooo00<0
G`3o0?ooo`3oool0303oool00`2>0?l0oooo0?ooo`070?ooo`00203oool301/0o``0oooo0P002ol;
0?ooo`<002oo2`3oool3001>o`X0oooo1000J?l;0?ooo`<007go2`3oool3002=o`/0oooo1000Uol:
0?ooo`@009co2P3oool4002Jo`X0oooo1000T_l;0?ooo`<008Go2`3oool3001bo`/0oooo1000FOl:
0?ooo`<003co2`3oool3000Ko`/0oooo0`0:0?l;0?ooo`0303<0o`3oool0<`3o00/0oooo00<0G`3o
0?ooo`1O0?l02`3oool00`2>0?l0oooo08h0o`0:0?ooo`001`3oool401/0o`X0oooo10002ol:0?oo
o`@002oo2P3oool4001>o`/0oooo0`00J?l;0?ooo`<007go2`3oool3002=o`/0oooo1000Uol;0?oo
o`<009co2P3oool4002Jo`X0oooo1000T_l;0?ooo`<008Go2`3oool2001bo``0oooo0`00FOl;0?oo
o`@003co2P3oool4000Ko`X0oooo100:0?l:0?ooo`<0<`3o2`3oool205l0o`/0oooo0`2>0?l;0?oo
o`00203oool401/0o`X0oooo10002ol:0?ooo`<002oo2`3oool3001>o``0oooo0P00J?l<0?ooo`80
07go303oool2002=o``0oooo0P00Uol<0?ooo`8009co2`3oool3002Jo`/0oooo0`00T_l<0?ooo`80
08Go2`3oool3001bo`/0oooo0`00FOl;0?ooo`@003co2P3oool4000Ko`X0oooo100:0?l:0?ooo`<0
<`3o2`3oool405l0o`X0oooo102>0?l:0?ooo`002@3oool301/0o`/0oooo0`002ol;0?ooo`<002oo
2`3oool3001>o`/0oooo0`00J?l;0?ooo`8007go303oool2002=o``0oooo0P00Uol<0?ooo`8009co
303oool2002Jo``0oooo0P00T_l<0?ooo`8008Go2`3oool2001bo``0oooo0`00FOl;0?ooo`<003co
2`3oool3000Ko`/0oooo0`0:0?l;0?ooo`80<`3o303oool305l0o`X0oooo102>0?l;0?ooo`002`3o
ool201/0o``0oooo0P002ol;0?ooo`8002oo303oool2001>o``0oooo0P00J?l<0?ooo`03001mo`3o
ool0oooo00/0oooo00<008go0?ooo`3oool02`3oool00`00Uol0oooo0?ooo`0;0?ooo`03002Lo`3o
ool0oooo00X0oooo00<009[o0?ooo`3oool02`3oool00`00T_l0oooo0?ooo`0;0?ooo`030025o`3o
ool0oooo00X0oooo0P00L_l<0?ooo`8005Wo303oool2000lo``0oooo0P006ol;0?ooo`802P3o303o
ool203<0o``0oooo0`1O0?l;0?ooo`80SP3o3@3oool000`0oooo00<06`3o0?ooo`3oool02`3oool0
0`002ol0oooo0?ooo`0:0?ooo`03000_o`3oool0oooo00/0oooo00<004ko0?ooo`3oool02`3oool0
0`00J?l0oooo0?ooo`0:0?ooo`03001mo`3oool0oooo00/0oooo00<008go0?ooo`3oool02`3oool0
0`00Uol0oooo0?ooo`0;0?ooo`03002Lo`3oool0oooo00X0oooo00<009[o0?ooo`3oool02`3oool0
0`00T_l0oooo0?ooo`0;0?ooo`030025o`3oool0oooo00X0oooo00<007;o0?ooo`3oool02`3oool0
0`00FOl0oooo0?ooo`0;0?ooo`03000lo`3oool0oooo00/0oooo00<001_o0?ooo`3oool02P3oool0
0`0:0?l0oooo0?ooo`0;0?ooo`0303<0o`3oool0oooo00/0oooo00<0G`3o0?ooo`3oool02P3oool0
0`2>0?l0oooo0?ooo`0=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`001P3oool00`00<?l0oooo0?ooo`0<0?ooo`03001Ho`3oool0oooo
00/0oooo00<007co0?ooo`3oool02`3oool00`00Vol0oooo0?ooo`0<0?ooo`03002fo`3oool0oooo
00/0oooo00<00<_o0?ooo`3oool0303oool00`00fOl0oooo0?ooo`0;0?ooo`03003Ro`3oool0oooo
00/0oooo00<00>Co0?ooo`3oool0303oool00`00gol0oooo0?ooo`0;0?ooo`03003Do`3oool0oooo
00`0oooo00<00<?o0?ooo`3oool02`3oool00`00[Ol0oooo0?ooo`0;0?ooo`03002@o`3oool0oooo
00`0oooo00<006oo0?ooo`3oool02`3oool00`00BOl0oooo0?ooo`0<0?ooo`03000Po`3oool0oooo
00/0oooo00<0303o0?ooo`3oool02`3oool00`0k0?l0oooo0?ooo`0<0?ooo`0306h0o`3oool0oooo
00D0oooo00070?ooo`03000`o`3oool0oooo00/0oooo00<005So0?ooo`3oool02`3oool00`00O?l0
oooo0?ooo`0;0?ooo`03002Ko`3oool0oooo00`0oooo00<00;Ko0?ooo`3oool02`3oool00`00bol0
oooo0?ooo`0<0?ooo`03003Io`3oool0oooo00/0oooo00<00>;o0?ooo`3oool02`3oool00`00i?l0
oooo0?ooo`0<0?ooo`03003Oo`3oool0oooo00/0oooo00<00=Co0?ooo`3oool0303oool00`00`ol0
oooo0?ooo`0;0?ooo`03002]o`3oool0oooo00/0oooo00<0093o0?ooo`3oool02`3oool00`00Kol0
oooo0?ooo`0;0?ooo`030019o`3oool0oooo00`0oooo00<0023o0?ooo`3oool02`3oool00`0<0?l0
oooo0?ooo`0;0?ooo`0303/0o`3oool0oooo00`0oooo00<0KP3o0?ooo`3oool01P3oool000L0oooo
00<0033o0?ooo`00<?l0303oool00`00F?l0oooo001Ho`0;0?ooo`<007co2`3oool3002Ko`/0oooo
0`00]_l;0?ooo`<00<_o2`3oool3003Io`/0oooo1000h_l:0?ooo`@00>Co2P3oool4003Oo`X0oooo
0`00e?l<0?ooo`800<?o303oool2002]o``0oooo0P00T?l<0?ooo`03001_o`3oool006oo00/0oooo
00<004Wo0?ooo`00BOl02`3oool00`008?l0oooo000Po`0=0?ooo`0300`0o`3oool0oooo00/0oooo
00<0>`3o0?ooo`3oool0303oool00`1^0?l0oooo0?ooo`070?ooo`00203oool2000`o``0oooo0`00
F?l:0?ooo`@007co2P3oool4002Ko`X0oooo1000]_l:0?ooo`@00<_o2`3oool3003Io`/0oooo1000
h_l:0?ooo`@00>Co2P3oool4003Oo`X0oooo1000e?l;0?ooo`<00<?o2`3oool3002]o`/0oooo1000
T?l:0?ooo`<006oo2`3oool30019o`/0oooo0`008?l;0?ooo`0300`0o`3oool0303o00/0oooo0P0k
0?l<0?ooo`0306h0o`3oool0KP3o00X0oooo00070?ooo`@0033o2P3oool4001Ho`/0oooo0`00O?l;
0?ooo`<009_o2`3oool3002fo`/0oooo0`00bol<0?ooo`800=Wo303oool3003Ro`X0oooo0`00i?l;
0?ooo`<00=oo2`3oool4003Do`/0oooo0P00`ol<0?ooo`800:go303oool3002@o`/0oooo1000Kol9
0?ooo`D004Wo2@3oool5000Po`X0oooo0`0<0?l:0?ooo`<0>`3o2`3oool306h0o`/0oooo00080?oo
o`<0033o2`3oool3001Ho``0oooo0P00O?l<0?ooo`8009_o2`3oool3002fo`/0oooo0`00bol<0?oo
o`800=Wo303oool2003Ro`/0oooo0`00i?l;0?ooo`<00=oo2`3oool3003Do`/0oooo0`00`ol;0?oo
o`<00:go2`3oool3002@o`/0oooo1000Kol:0?ooo`@004Wo2P3oool4000Po`X0oooo0`0<0?l;0?oo
o`@0>`3o2P3oool406h0o`X0oooo00090?ooo`<0033o2`3oool3001Ho`/0oooo0`00O?l;0?ooo`<0
09_o2`3oool2002fo``0oooo0P00bol<0?ooo`800=Wo303oool2003Ro``0oooo0P00i?l<0?ooo`80
0=oo303oool2003Do`/0oooo0P00`ol<0?ooo`800:go303oool3002@o`/0oooo0`00Kol;0?ooo`<0
04Wo2`3oool3000Po`/0oooo0P0<0?l;0?ooo`@0>`3o2P3oool406h0o`/0oooo000;0?ooo`03000`
o`3oool0oooo00X0oooo0P00F?l<0?ooo`8007co303oool2002Ko`/0oooo0P00]_l<0?ooo`800<_o
3@3oool00`00fOl0oooo0?ooo`0;0?ooo`03003Ro`3oool0oooo00X0oooo00<00>Co0?ooo`3oool0
2`3oool00`00gol0oooo0?ooo`0;0?ooo`03003Do`3oool0oooo00X0oooo0P00`ol<0?ooo`800:go
303oool2002@o``0oooo0P00Kol;0?ooo`8004Wo303oool2000Po``0oooo0P0<0?l<0?ooo`80>`3o
303oool206h0o`d0oooo000<0?ooo`03000`o`3oool0oooo00X0oooo00<005So0?ooo`3oool02`3o
ool00`00O?l0oooo0?ooo`0;0?ooo`03002Ko`3oool0oooo00X0oooo00<00;Ko0?ooo`3oool02`3o
ool00`00bol0oooo0?ooo`0;0?ooo`03003Io`3oool0oooo00/0oooo00<00>;o0?ooo`3oool02P3o
ool00`00i?l0oooo0?ooo`0;0?ooo`03003Oo`3oool0oooo00/0oooo00<00=Co0?ooo`3oool02P3o
ool00`00`ol0oooo0?ooo`0;0?ooo`03002]o`3oool0oooo00/0oooo00<0093o0?ooo`3oool02`3o
ool00`00Kol0oooo0?ooo`0:0?ooo`030019o`3oool0oooo00/0oooo00<0023o0?ooo`3oool02`3o
ool00`0<0?l0oooo0?ooo`0:0?ooo`0303/0o`3oool0oooo00/0oooo00<0KP3o0?ooo`3oool03@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool000H0oooo00<007go0?ooo`3oool0303oool00`00Y_l0oooo0?ooo`0;0?oo
o`03003;o`3oool0oooo00/0oooo00<00>_o0?ooo`3oool0303oool00`00ooX0oooo0?ooo`0;0?oo
o`03003oi`3oool0oooo00`0oooo00<00?oI0?ooo`3oool02`3oool00`00om<0oooo0?ooo`0;0?oo
o`03003oe03oool0oooo00`0oooo00<00?oL0?ooo`3oool02`3oool00`00on/0oooo0?ooo`0<0?oo
o`03003no`3oool0oooo00/0oooo00<00>?o0?ooo`3oool02`3oool00`00`_l0oooo0?ooo`0<0?oo
o`03002Lo`3oool0oooo00/0oooo00<007;o0?ooo`3oool0303oool00`00A?l0oooo0?ooo`0;0?oo
o`03000Co`3oool0oooo00/0oooo00<07`3o0?ooo`3oool0303oool00`1E0?l0oooo0?ooo`050?oo
o`001`3oool00`00OOl0oooo001mo`0<0?ooo`800:Ko303oool2003;o`/0oooo00<00>_o0?ooo`00
jol0303oool3003onPX0oooo1000onL:0?ooo`@00?oI2`3oool3003od`/0oooo1000om@:0?ooo`@0
0?oL2P3oool4003oj`/0oooo00<00?ko0?ooo`00o_l02`3oool3003So`/0oooo0`00`_l;0?ooo`03
002Lo`3oool009co00/0oooo00<007;o0?ooo`00L_l02`3oool01000A?l0oooo0?ooo`00A?l:0?oo
o`04000Co`3oool0oooo000Co`d0oooo00<07`3o0?ooo`3oool0303oool00`1E0?l0oooo0?ooo`06
0?ooo`001`3oool3001mo``0oooo0P00Y_l;0?ooo`<00<_o2`3oool3003[o`/0oooo1000ooX:0?oo
o`@00?oW2P3oool4003of@/0oooo0`00om<;0?ooo`@00?oD2P3oool4003og0X0oooo0`00on/<0?oo
o`<00?ko2`3oool4003So`X0oooo1000`_l:0?ooo`<009co2`3oool3001bo`/0oooo0`00A?l:0?oo
o`@001?o2`3oool00`0O0?l0oooo01l0o`0;0?ooo`0405D0o`3oool0oooo05D0o`T0oooo00070?oo
o`@007go2P3oool4002Vo`/0oooo0`00bol;0?ooo`800>_o303oool3003onP/0oooo0`00onL;0?oo
o`<00?oI2`3oool3003od`/0oooo0`00om@;0?ooo`<00?oL2`3oool3003oj``0oooo0P00o_l<0?oo
o`<00>?o2`3oool30032o`X0oooo1@00W?l90?ooo`D007;o2@3oool40014o`X0oooo10004ol:0?oo
o`<07`3o2`3oool405D0o`X0oooo00080?ooo`<007go2`3oool3002Vo``0oooo0P00bol;0?ooo`80
0>_o303oool3003onP/0oooo0`00onL;0?ooo`<00?oI2`3oool2003od``0oooo0`00om@;0?ooo`<0
0?oL2`3oool2003oj``0oooo0`00o_l;0?ooo`<00>?o2`3oool30032o`/0oooo1000W?l:0?ooo`@0
07;o2P3oool30014o`X0oooo10004ol;0?ooo`@07`3o2P3oool405D0o`X0oooo00090?ooo`8007go
303oool2002Vo``0oooo0P00bol<0?ooo`800>_o303oool2003onP`0oooo0P00onL<0?ooo`800?oI
303oool00`00om<0oooo0?ooo`0;0?ooo`800?oD303oool2003og0/0oooo0P00on/<0?ooo`800?ko
303oool3003So`/0oooo0`00`_l;0?ooo`<009co2`3oool3001bo`/0oooo0P00A?l;0?ooo`<001?o
2`3oool401l0o`X0oooo101E0?l;0?ooo`002P3oool2001mo``0oooo0P00Y_l<0?ooo`800<_o2`3o
ool2003[o``0oooo0P00ooX<0?ooo`800?oW303oool2003of@`0oooo00<00?oC0?ooo`3oool02`3o
ool00`00om@0oooo0?ooo`0;0?ooo`03003og03oool0oooo00X0oooo00<00?o[0?ooo`3oool02`3o
ool2003no``0oooo0P00hol<0?ooo`800<;o2`3oool2002Lo``0oooo0P00L_l<0?ooo`8004Co2`3o
ool2000Co`d0oooo0P0O0?l<0?ooo`80E@3o3@3oool000/0oooo00<007go0?ooo`3oool02`3oool0
0`00Y_l0oooo0?ooo`0;0?ooo`03003;o`3oool0oooo00X0oooo00<00>_o0?ooo`3oool02`3oool0
0`00ooX0oooo0?ooo`0;0?ooo`03003oi`3oool0oooo00/0oooo00<00?oI0?ooo`3oool02P3oool0
0`00om<0oooo0?ooo`0;0?ooo`03003oe03oool0oooo00/0oooo00<00?oL0?ooo`3oool02P3oool0
0`00on/0oooo0?ooo`0;0?ooo`03003no`3oool0oooo00/0oooo00<00>?o0?ooo`3oool02`3oool0
0`00`_l0oooo0?ooo`0:0?ooo`03002Lo`3oool0oooo00/0oooo00<007;o0?ooo`3oool02`3oool0
0`00A?l0oooo0?ooo`0:0?ooo`03000Co`3oool0oooo00/0oooo00<07`3o0?ooo`3oool02`3oool0
0`1E0?l0oooo0?ooo`0=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001P3oool00`00cOl0oooo0?ooo`0<0?ooo`03
003go`3oool0oooo00/0oooo00<00?oS0?ooo`3oool02`3oool00`00ol@0oooo003oa00<0?ooo`80
0?n[303oool3003oV0`0oooo0P00ohd<0?ooo`03003oRP3oool0oooo00X0oooo0P00ohl<0?ooo`<0
0?nL303oool2003o/@`0oooo00<00?o<0?ooo`00ol`03@3oool00`00ond0oooo0?ooo`0;0?ooo`03
003/o`3oool0oooo00`0oooo00<00<7o0?ooo`3oool02`3oool00`00T_l0oooo0?ooo`0<0?ooo`03
001Qo`3oool0oooo00/0oooo00<002co0?ooo`3oool02`3oool00`0;0?l0oooo0?ooo`0<0?ooo`03
04@0o`3oool0oooo00D0oooo00070?ooo`03003=o`3oool00<go00`0oooo0P00mol;0?ooo`<00?oS
2`3oool3003oa0/0oooo0`00oj/;0?ooo`@00?nH2P3oool4003oS@/0oooo0`00ohX;0?ooo`@00?n?
2P3oool4003oW0/0oooo0`00ok4;0?ooo`800?o<303oool2003ok@`0oooo0P00k?l<0?ooo`030031
o`3oool00<7o00/0oooo00<009;o0?ooo`00T_l02`3oool01000HOl0oooo0?ooo`00HOl:0?ooo`04
000/o`3oool0oooo000/o`d0oooo00<02`3o0?ooo`3oool02`3oool204@0o`P0oooo00070?ooo`<0
0<go2P3oool4003go`X0oooo1000on<:0?ooo`@00?o4303oool2003oZ``0oooo0`00oiP:0?ooo`@0
0?n=2`3oool3003oRP/0oooo1000ohl:0?ooo`<00?nL303oool2003o/@`0oooo0`00ol`;0?ooo`@0
0?o]2P3oool4003/o`X0oooo0`00`Ol;0?ooo`8009;o2`3oool4001Qo`X0oooo1000;?l;0?ooo`03
00/0o`3oool02`3o00/0oooo00<0A03o0?ooo`140?l02P3oool000H0oooo1@00cOl:0?ooo`@00?Oo
2P3oool3003oh`/0oooo0`00ol@<0?ooo`800?n[303oool3003oV0/0oooo0P00ohd<0?ooo`<00?n:
2`3oool3003oS`/0oooo0`00oi`;0?ooo`<00?na2`3oool3003oc0/0oooo1000ond:0?ooo`@00>co
2P3oool50031o`T0oooo1000T_l:0?ooo`@0067o2P3oool3000/o`/0oooo0`0;0?l;0?ooo`<0A03o
2`3oool000L0oooo1000cOl;0?ooo`<00?Oo2`3oool3003oh`/0oooo0`00ol@<0?ooo`800?n[303o
ool2003oV0/0oooo0P00ohd=0?ooo`03003oRP3oool0oooo00/0oooo0P00ohl;0?ooo`800?nL303o
ool2003o/@`0oooo0P00ol`<0?ooo`<00?o]2`3oool3003/o`/0oooo1000`Ol:0?ooo`<009;o2P3o
ool4001Qo`X0oooo1@00;?l90?ooo`D02`3o2@3oool504@0o`X0oooo00090?ooo`<00<go303oool2
003go`/0oooo0P00on<<0?ooo`800?o4303oool2003oZ``0oooo0P00oiP<0?ooo`03003oS@3oool0
oooo00/0oooo00<00?n:0?ooo`3oool02`3oool00`00ohl0oooo0?ooo`0:0?ooo`800?nL303oool2
003o/@`0oooo0P00ol`;0?ooo`800?o]303oool2003/o``0oooo0`00`Ol;0?ooo`<009;o2`3oool2
001Qo``0oooo0`00;?l;0?ooo`<02`3o2P3oool404@0o``0oooo000;0?ooo`03003=o`3oool0oooo
00/0oooo00<00?Oo0?ooo`3oool02P3oool00`00on<0oooo0?ooo`0;0?ooo`03003oa03oool0oooo
00/0oooo00<00?n[0?ooo`3oool02`3oool00`00oiP0oooo0?ooo`0:0?ooo`03003oS@3oool0oooo
00/0oooo00<00?n:0?ooo`3oool02`3oool00`00ohl0oooo0?ooo`0:0?ooo`03003oW03oool0oooo
00/0oooo00<00?na0?ooo`3oool02`3oool00`00ol`0oooo0?ooo`0:0?ooo`03003ok@3oool0oooo
00/0oooo00<00>co0?ooo`3oool02`3oool00`00`Ol0oooo0?ooo`0;0?ooo`03002Bo`3oool0oooo
00X0oooo00<0067o0?ooo`3oool02`3oool2000/o``0oooo0P0;0?l;0?ooo`80A03o3`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool001H0oooo00<00?nf0?ooo`3oool0303oool00`00oi40oooo0?oo
o`0:0?ooo`800?mb303oool2003oFPd0oooo0P00odX:0?ooo`@00?m22`3oool3003oA0/0oooo0P00
odl<0?ooo`800?mR3@3oool00`00og`0oooo0?ooo`0;0?ooo`03003oWP3oool0oooo07X0oooo0006
0?ooo`03003oh@3oool00?oQ00`0oooo0P00okH<0?ooo`<00?nA2P3oool4003oLPX0oooo1000oeX;
0?ooo`@00?m:2P3oool4003o@P/0oooo0`00od@;0?ooo`@00?m?2P3oool4003oHP/0oooo0`00og`;
0?ooo`<00?nN2`3oool3003oa@/0oooo00<00?oa0?ooo`00oo402`3oool01000gOl0oooo0?ooo`00
gOl:0?ooo`04002Zo`3oool0oooo002Zo`X0oooo00D007?o0?ooo`3oool0oooo001co`090?ooo`05
000jo`3oool0oooo0?ooo`00>_l03@3oool00`000?l0oooo0?ooo`0<0?ooo`0303`0o`3oool0oooo
00D0oooo00060?ooo`@00?oQ2P3oool4003o]PX0oooo1000oi4;0?ooo`<00?mb2`3oool3003oFP/0
oooo1000odX;0?ooo`<00?m22`3oool3003oA0/0oooo0`00odl;0?ooo`<00?mR303oool2003oO0/0
oooo1@00oih:0?ooo`@00?o52P3oool3003ol@/0oooo0`00gOl:0?ooo`@00:[o2P3oool5001co`T0
oooo1@00>_l:0?ooo`040000o`3oool0003o0000o`X0oooo00<0?03o0?ooo`3oool00P0l0?l80?oo
o`001`3oool3003oh@/0oooo0`00okH;0?ooo`<00?nA303oool2003oLP/0oooo0`00oeX<0?ooo`80
0?m:303oool2003o@P`0oooo0P00od@<0?ooo`<00?m?2`3oool3003oHP/0oooo0`00og`;0?ooo`@0
0?nN2P3oool4003oa@X0oooo1@00oo490?ooo`D00=go2@3oool4002Zo`X0oooo1000Lol:0?ooo`<0
03[o2`3oool30000o`/0oooo100l0?l:0?ooo`00203oool3003oh@/0oooo0P00okH<0?ooo`<00?nA
2`3oool3003oLP/0oooo0P00oeX<0?ooo`800?m:303oool2003o@Pd0oooo00<00?m40?ooo`3oool0
2P3oool2003oC``0oooo0P00of8<0?ooo`800?ml303oool3003oWP/0oooo0`00olD;0?ooo`@00?oa
2P3oool4003Mo`T0oooo1000Z_l:0?ooo`@007?o2P3oool5000jo`T0oooo1@000?l90?ooo`D0?03o
2P3oool000X0oooo00<00?oQ0?ooo`3oool02P3oool2003o]P`0oooo0P00oi4<0?ooo`800?mb2`3o
ool2003oFPd0oooo00<00?m:0?ooo`3oool02`3oool00`00od80oooo0?ooo`0;0?ooo`03003oA03o
ool0oooo00X0oooo0P00odl<0?ooo`800?mR303oool2003oO0/0oooo0P00oih<0?ooo`800?o5303o
ool3003ol@/0oooo0`00gOl;0?ooo`800:[o303oool2001co``0oooo0`00>_l:0?ooo`@0003o2P3o
ool403`0o``0oooo000;0?ooo`03003oh@3oool0oooo00X0oooo00<00?nf0?ooo`3oool02`3oool0
0`00oi40oooo0?ooo`0;0?ooo`03003oLP3oool0oooo00X0oooo00<00?mJ0?ooo`3oool02`3oool0
0`00odX0oooo0?ooo`0;0?ooo`03003o@P3oool0oooo00/0oooo00<00?m40?ooo`3oool02P3oool0
0`00odl0oooo0?ooo`0;0?ooo`03003oHP3oool0oooo00/0oooo00<00?ml0?ooo`3oool02P3oool0
0`00oih0oooo0?ooo`0;0?ooo`03003oa@3oool0oooo00/0oooo00<00?oa0?ooo`3oool02`3oool0
0`00gOl0oooo0?ooo`0:0?ooo`03002Zo`3oool0oooo00/0oooo00<007?o0?ooo`3oool02`3oool2
000jo`/0oooo0P000?l<0?ooo`80?03o3`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool000P0oooo
00<00?n=0?ooo`3oool02`3oool00`00of80oooo0?ooo`0;0?ooo`03003o?03oool0oooo00/0oooo
0P00oah:0?ooo`@00?l82`3oool400?o00X0oooo1005o`0;0?ooo`@00?l22P3oool2003o50d0oooo
00<00?l_0?ooo`3oool02`3oool00`00oe40oooo0?ooo`0;0?ooo`03003oNP3oool0oooo07X0oooo
00060?ooo`<00?n=2`3oool3003oHP/0oooo0`00oc`;0?ooo`@00?lN2P3oool4003o20/0oooo1003
o`0:0?ooo`@01Ol02`3oool3003o0P/0oooo1000oa@;0?ooo`<00?l_2`3oool2003oD@`0oooo0`00
ogX;0?ooo`<00?nX303oool2003ofP`0oooo00<00>oo0?ooo`00kol02`3oool00`00]ol0oooo002g
o`0:0?ooo`05001lo`3oool0oooo0?ooo`00O?l02@3oool01@00?ol0oooo0?ooo`3oool003oo00d0
oooo00<0007o0?ooo`3oool0303oool00`0n0?l0oooo0?ooo`050?ooo`001@3oool5003oS@T0oooo
1@00of8;0?ooo`<00?ll2`3oool3003o7P/0oooo0`00o`P<0?ooo`<00ol02P3oool300Go00`0oooo
0`00o`8;0?ooo`<00?lD303oool2003o;`/0oooo1000oe4:0?ooo`D00?mj2P3oool4003oZ0X0oooo
0`00omX;0?ooo`<00>oo2`3oool3002go`X0oooo1@00O?l90?ooo`D003oo2P3oool010000Ol0oooo
0001o`000Ol:0?ooo`0303h0o`3oool0oooo0080?P3o203oool000H0oooo1000ohd:0?ooo`@00?mR
303oool2003o?0/0oooo0`00oah;0?ooo`<00?l8303oool200?o00/0oooo0`05o`0<0?ooo`800?l2
303oool3003o50/0oooo0`00obl;0?ooo`<00?mA2`3oool4003oNPX0oooo1000ojP:0?ooo`D00?oJ
2@3oool4003_o`X0oooo1000]ol:0?ooo`<007co2P3oool4000oo`/0oooo0`000Ol;0?ooo`@0?P3o
2P3oool000L0oooo0`00ohd;0?ooo`<00?mR303oool2003o?0`0oooo0P00oah<0?ooo`800?l8303o
ool200?o00`0oooo0P05o`0<0?ooo`800?l2303oool2003o50`0oooo0P00obl<0?ooo`800?mA303o
ool3003oNP/0oooo0`00ojP;0?ooo`@00?oJ2P3oool3003_o`/0oooo0`00]ol:0?ooo`D007co2@3o
ool5000oo`T0oooo1@000Ol90?ooo`@0?P3o2`3oool000T0oooo0P00ohd<0?ooo`800?mR303oool2
003o?0/0oooo0P00oah<0?ooo`800?l83@3oool00`03o`00oooo0?ooo`0:0?ooo`0300Go003oool0
oooo00/0oooo00<00?l20?ooo`3oool02`3oool2003o50`0oooo0P00obl;0?ooo`800?mA303oool2
003oNP`0oooo0P00ojP<0?ooo`<00?oJ2`3oool2003_o``0oooo0P00]ol<0?ooo`<007co2P3oool4
000oo`X0oooo10000Ol:0?ooo`<0?P3o3@3oool000X0oooo00<00?n=0?ooo`3oool02`3oool00`00
of80oooo0?ooo`0;0?ooo`03003o?03oool0oooo00X0oooo00<00?lN0?ooo`3oool02`3oool00`00
o`P0oooo0?ooo`0;0?ooo`0300?o003oool0oooo00X0oooo00<01Ol00?ooo`3oool02`3oool00`00
o`80oooo0?ooo`0;0?ooo`03003o503oool0oooo00/0oooo00<00?l_0?ooo`3oool02P3oool00`00
oe40oooo0?ooo`0;0?ooo`03003oNP3oool0oooo00/0oooo00<00?nX0?ooo`3oool02P3oool2003o
fP`0oooo00<00>oo0?ooo`3oool02`3oool00`00]ol0oooo0?ooo`0;0?ooo`8007co2`3oool2000o
o``0oooo0P000Ol<0?ooo`80?P3o3`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool000L0oooo00<0
0?lg0?ooo`3oool02`3oool00`00o`/0oooo0?ooo`0;0?ooo`806Ol03@3oool00`0eo`00oooo0?oo
o`090?ooo`@0Aol02`3oool404ko00X0oooo1018o`0;0?ooo`@0=ol02`3oool00`0Lo`00oooo0?oo
o`0;0?ooo`03003o1`3oool0oooo00/0oooo00<00?lb0?ooo`3oool0303oool00`00of80oooo0?oo
o`1i0?ooo`001P3oool3003o=`X0oooo0`00o`/;0?ooo`@06Ol02`3oool303Go00`0oooo0`17o`0;
0?ooo`@0C_l02P3oool404So00/0oooo0`0go`0<0?ooo`<07?l02`3oool3003o1`/0oooo0`00oc8;
0?ooo`<00?mR303oool2003oU``0oooo0P00om0<0?ooo`03003do`3oool00?Co00/0oooo00<00;So
0?ooo`00^?l02P3oool01@00NOl0oooo0?ooo`3oool007Wo00d0oooo00<003Wo0?ooo`3oool02`3o
ool00`070?l0oooo0?ooo`0;0?ooo`80B@3o1`3oool000D0oooo1000ocL;0?ooo`<00?l;2`3oool3
01Wo00`0oooo0P0eo`0<0?ooo`<0Aol02`3oool304ko00/0oooo0`18o`0<0?ooo`<0=ol02`3oool3
01co00/0oooo0`00o`L;0?ooo`D00?lb2P3oool4003oHPX0oooo0`00oiL;0?ooo`800?o@303oool3
003do`/0oooo0`00^?l:0?ooo`D007Wo2P3oool01000>Ol0oooo000io`00>Ol:0?ooo`0400L0o`3o
ool01`3o00L0o`X0oooo00@0B@3o0?ooo`190?l0B@3o2@3oool000H0oooo1000ocL;0?ooo`800?l;
303oool301Wo00/0oooo0`0eo`0<0?ooo`80Aol0303oool204ko00`0oooo0P18o`0<0?ooo`80=ol0
303oool201co00`0oooo0P00o`L<0?ooo`@00?lb2P3oool4003oHPX0oooo1@00oiL90?ooo`@00?o@
2P3oool4003do`T0oooo1@00^?l90?ooo`@007Wo2`3oool3000io`/0oooo0`070?l:0?ooo`@0B@3o
2`3oool000P0oooo0P00ocL<0?ooo`800?l;303oool201Wo00`0oooo0P0eo`0<0?ooo`80Aol0303o
ool00`1>o`00oooo0?ooo`0;0?ooo`0304So003oool0oooo00/0oooo0P0go`0;0?ooo`807?l0303o
ool2003o1``0oooo0`00oc8<0?ooo`800?mR2`3oool4003oU`X0oooo0`00om0;0?ooo`<00?Co2P3o
ool6002ho`P0oooo1P00NOl80?ooo`H003Wo203oool500L0o`P0oooo1P190?l;0?ooo`002P3oool0
0`00ocL0oooo0?ooo`0:0?ooo`03003o2`3oool0oooo00/0oooo00<06Ol00?ooo`3oool02`3oool0
0`0eo`00oooo0?ooo`0;0?ooo`0304Oo003oool0oooo00X0oooo00<0C_l00?ooo`3oool02`3oool0
0`18o`00oooo0?ooo`0;0?ooo`0303Oo003oool0oooo00X0oooo00<07?l00?ooo`3oool02`3oool0
0`00o`L0oooo0?ooo`0;0?ooo`03003o<P3oool0oooo00/0oooo00<00?mR0?ooo`3oool02P3oool2
003oU``0oooo0P00om0<0?ooo`800?Co2`3oool4002ho`X0oooo1000NOl:0?ooo`@003Wo2P3oool3
00L0o`X0oooo10190?l>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`008`3oool00`1`o`00oooo
0?ooo`0;0?ooo`80ROl02`3oool409Go00/0oooo0P2Co`0=0?ooo`80Pol03@3oool00`1Vo`00oooo
0?ooo`2b0?ooo`001`3oool00`0Qo`00oooo0?ooo`0;0?ooo`0304go003oool0oooo00X0oooo0P1`
o`0;0?ooo`@0ROl02`3oool409Go00/0oooo102Co`0;0?ooo`@0Pol02`3oool206Ko00`0oooo00<0
?ol00?ooo`3oool02`3oool00`0Ao`00oooo0?ooo`0<0?ooo`03003o8P3oool0oooo08L0oooo0005
0?ooo`<08Ol02`3oool304go00/0oooo101`o`0;0?ooo`<0ROl0303oool309Go00/0oooo102Co`0;
0?ooo`<0Pol02`3oool406Ko00/0oooo0`0oo`0;0?ooo`<04Ol02`3oool3003o8P`0oooo00<00?mJ
0?ooo`3oool02`3oool00`00oiD0oooo0?ooo`0;0?ooo`03003odP3oool0oooo00/0oooo00<00>go
0?ooo`3oool02P3oool00`00[?l0oooo0?ooo`120?ooo`00103oool5027o00/0oooo0`1=o`0;0?oo
o`<0L?l02`3oool308Wo00`0oooo0P2Eo`0<0?ooo`<0Tol0303oool308?o00/0oooo0`1Vo`0;0?oo
o`<0?ol02`3oool5017o00T0oooo1@00ob8:0?ooo`<00?mJ2`3oool3003oU@/0oooo0`00om8;0?oo
o`@00>go2@3oool5002/o`X0oooo00<006[o0?ooo`3oool00P00J_l90?ooo`03000Wo`3oool0oooo
008002Oo2@3oool00`0K0?l0oooo0?ooo`0201/0o`T0oooo00@0G`3o0?ooo`3oool0oooo0P1O0?l7
0?ooo`001@3oool4027o00`0oooo0P1=o`0<0?ooo`80L?l0303oool208Wo00`0oooo0P2Eo`0=0?oo
o`80Tol0303oool208?o00`0oooo0P1Vo`0<0?ooo`80?ol0303oool4017o00X0oooo1000ob8:0?oo
o`D00?mJ2@3oool4003oU@T0oooo1@00om890?ooo`D00>go2@3oool4002/o`/0oooo1000J_l90?oo
o`D002Oo2@3oool501/0o`T0oooo1P1O0?l90?ooo`001`3oool3027o00`0oooo0P1=o`0<0?ooo`80
L?l02`3oool208Wo00d0oooo00<0UOl00?ooo`3oool02`3oool00`2Co`00oooo0?ooo`0;0?ooo`80
Pol02`3oool206Ko00`0oooo0P0oo`0<0?ooo`<04Ol02`3oool3003o8P/0oooo1000oeX:0?ooo`<0
0?nE2P3oool6003odPP0oooo1P00kOl80?ooo`H00:co203oool5001Zo`P0oooo1P009ol80?ooo`H0
6`3o203oool605l0o`/0oooo00090?ooo`03027o003oool0oooo00/0oooo00<0COl00?ooo`3oool0
2`3oool00`1`o`00oooo0?ooo`0:0?ooo`0308Wo003oool0oooo00/0oooo00<0UOl00?ooo`3oool0
2`3oool00`2Co`00oooo0?ooo`0;0?ooo`0308?o003oool0oooo00X0oooo00<0I_l00?ooo`3oool0
2`3oool00`0oo`00oooo0?ooo`0;0?ooo`03017o003oool0oooo00X0oooo0P00ob8<0?ooo`800?mJ
303oool2003oU@/0oooo1000om8:0?ooo`@00>go2P3oool4002/o`X0oooo0`00J_l:0?ooo`@002Oo
2P3oool701/0o`L0oooo1`1O0?l;0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`005@3oool00`2W
o`00oooo0?ooo`0;0?ooo`030<So003oool0oooo00X0oooo0`3Ko`0<0?ooo`@0gOl02`3oool20<go
00d0oooo00<0[Ol00?ooo`3oool0`03oool000H0oooo00<0Nol00?ooo`3oool02P3oool30:Oo00/0
oooo0`38o`0<0?ooo`<0fol0303oool40=go00/0oooo103=o`0;0?ooo`80[Ol0303oool00`23o`00
oooo0?ooo`0<0?ooo`03053o003oool0oooo00/0oooo00<06?l00?ooo`3oool0U@3oool000D0oooo
0`1ko`0:0?ooo`@0Yol0303oool20<So00d0oooo0P3Ko`0<0?ooo`<0gOl0303oool30<go00/0oooo
102]o`0;0?ooo`<0Pol02`3oool3053o00/0oooo0`0Ho`0<0?ooo`03003o8`3oool0oooo00/0oooo
00<00?mQ0?ooo`3oool02`3oool00`00oj80oooo0?ooo`0;0?ooo`03003oi03oool0oooo00X0oooo
00<00=So0?ooo`3oool0D03oool000@0oooo101ko`0;0?ooo`<0Yol0303oool20<So00d0oooo0P3K
o`0<0?ooo`<0gOl02`3oool30<go00`0oooo0`2]o`0;0?ooo`<0Pol02`3oool5053o00T0oooo100H
o`0;0?ooo`800?lS303oool3003oH@/0oooo0`00oj8;0?ooo`<00?oT2P3oool2003Ho`030?ooo`00
f?l00=So00X0oooo00@009Co0?ooo`00U?l009Co2P3oool00`00D?l0oooo0?ooo`02001@o`T0oooo
00<000_o0?ooo`3oool00P002ol90?ooo`0303X0o`3oool0oooo0080>P3o203oool00`1o0?l0oooo
0?ooo`020?ooo`80O`3o1`3oool000D0oooo101ko`0;0?ooo`<0Yol0303oool20<So00`0oooo0P3K
o`0=0?ooo`80gOl02`3oool30<go00`0oooo0P2]o`0<0?ooo`80Pol0303oool4053o00X0oooo1@0H
o`090?ooo`@00?lS2P3oool4003oH@T0oooo1@00oj890?ooo`D00?oT2@3oool4003Ho`X0oooo1000
U?l:0?ooo`D0053o2@3oool5000;o`T0oooo1@0j0?l80?ooo`L0O`3o2@3oool000L0oooo0P1ko`0<
0?ooo`80Yol0303oool20<So00d0oooo00<0fol00?ooo`3oool02`3oool00`3Mo`00oooo0?ooo`0:
0?ooo`80cOl0303oool20:go00`0oooo0P23o`0<0?ooo`<0D?l02`3oool401So00X0oooo0`00ob<;
0?ooo`<00?mQ2P3oool6003oXPP0oooo1P00on@80?ooo`D00=So203oool6002Do`P0oooo1P00D?l8
0?ooo`H000_o203oool503X0o`P0oooo1P1o0?l<0?ooo`002@3oool00`1ko`00oooo0?ooo`0:0?oo
o`030:Oo003oool0oooo00/0oooo00<0b?l00?ooo`3oool02`3oool00`3Ko`00oooo0?ooo`0;0?oo
o`030=go003oool0oooo00X0oooo00<0cOl00?ooo`3oool02`3oool00`2]o`00oooo0?ooo`0;0?oo
o`0308?o003oool0oooo00X0oooo0P1@o`0<0?ooo`806?l0303oool2003o8``0oooo0P00of4;0?oo
o`@00?nR2P3oool4003oi0X0oooo0`00f?l:0?ooo`@009Co2P3oool4001@o`X0oooo1`002ol70?oo
o`H0>P3o1`3oool707l0o``0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo00050?ooo`030=Wo003o
ool0oooo00`0oooo00<0oo/00?ooo`3oool02P3oool30?oO00`0oooo103of@0<0?ooo`80onX03@3o
ool00`3ao`00oooo0?ooo`3>0?ooo`00103oool20=Wo00`0oooo0`3on`0<0?ooo`<0oml0303oool4
0?oI00`0oooo103ojP0;0?ooo`80lOl03@3oool00`30o`00oooo0?ooo`0;0?ooo`0308So003oool0
oooo00/0oooo00<0Bol00?ooo`3oool0X`3oool000<0oooo103Io`0<0?ooo`<0oo/0303oool20?oO
00`0oooo0`3of@0=0?ooo`<0onX02`3oool40?7o00/0oooo0`30o`0;0?ooo`<0R?l02`3oool304_o
00`0oooo00<02ol00?ooo`3oool02`3oool00`00ocH0oooo0?ooo`0;0?ooo`03003oN@3oool0oooo
00/0oooo00<00?nn0?ooo`3oool0J`3oool000@0oooo0`3Io`0=0?ooo`80oo/0303oool20?oO00`0
oooo0`3of@0<0?ooo`<0onX0303oool30?7o00/0oooo1@30o`090?ooo`D0R?l02@3oool404_o00/0
oooo0P0;o`0<0?ooo`800?lf303oool2003oN@`0oooo0P00okh<0?ooo`03003lo`3oool0oooo00/0
oooo00<00;Oo0?ooo`3oool02`3oool00`00L?l0oooo0?ooo`0;0?ooo`03000Zo`3oool0oooo00/0
oooo00<0703o0?ooo`3oool02P3oool00`1R0?l0oooo0?ooo`0;0?ooo`030:T0o`3oool0oooo00/0
oooo00050?ooo`<0fOl0303oool20?ok00d0oooo0P3og`0<0?ooo`80omT0303oool30?oZ00`0oooo
0P3ao`0<0?ooo`@0`?l02P3oool408So00X0oooo1@1;o`090?ooo`@02ol02@3oool5003o=PT0oooo
1@00ogT90?ooo`D00?nn2@3oool5003lo`T0oooo0`00]ol00`3oool00;Oo002go`080?ooo`<0073o
00<0oooo001`o`00L?l0203oool3000Zo`040?ooo`00:_l002[o000Zo`L0oooo0`0L0?l0103oool0
703o01`0o`0L0?l60?ooo`<0HP3o0P3oool30680o`H0oooo0`2Y0?l30?ooo`<0Z@3o1`3oool000L0
oooo00<0fOl00?ooo`3oool02`3oool20?ok00`0oooo0P3og`0<0?ooo`030?oI003oool0oooo00/0
oooo0P3ojP0<0?ooo`80lOl0303oool30<3o00/0oooo0`28o`0;0?ooo`@0Bol02P3oool300_o00X0
oooo1P00ocH80?ooo`H00?mi203oool6003o_PL0oooo1P00o?l80?ooo`H00;Oo203oool6001`o`P0
oooo1P00:_l80?ooo`H0703o1`3oool70680o`L0oooo202Y0?l:0?ooo`00203oool00`3Io`00oooo
0?ooo`0;0?ooo`030?ok003oool0oooo00/0oooo00<0oml00?ooo`3oool02P3oool00`3of@00oooo
0?ooo`0;0?ooo`030?oZ003oool0oooo00/0oooo00<0lOl00?ooo`3oool02P3oool20<3o00`0oooo
0P28o`0<0?ooo`80Bol0303oool200_o00/0oooo1000ocH:0?ooo`@00?mi2P3oool4003o_PT0oooo
1000o?l:0?ooo`@00;Oo2P3oool7001`o`L0oooo1P00:_l70?ooo`L0703o1`3oool70680o`L0oooo
1`2Y0?l<0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503oool00`3oWP00oooo0?ooo`0;0?ooo`80oi00o03oool0
00D0oooo00<0olL00?ooo`3oool02`3oool20?nN00d0oooo103oT00<0?ooo`80ojD03P3oool00`3o
d@00oooo0?ooo`3K0?ooo`00103oool30?o700/0oooo0`3oWP0=0?ooo`@0oi00303oool40?nU00/0
oooo0`3od@0<0?ooo`030?Co003oool0oooo0<d0oooo00030?ooo`@0olL0303oool20?nN00d0oooo
0`3oT00=0?ooo`<0ojD02`3oool50?oA00X0oooo0`3do`0<0?ooo`030;Go003oool0oooo00/0oooo
00<0Lol00?ooo`3oool02`3oool00`0_o`00oooo0?ooo`0;0?ooo`03003o5@3oool0oooo09D0oooo
00040?ooo`@0olL02`3oool30?nN00d0oooo0P3oT00<0?ooo`<0ojD0303oool40?oA00X0oooo1@3d
o`0:0?ooo`<0]Ol02`3oool207?o00/0oooo0`0_o`0;0?ooo`<00?lE303oool2003oF``0oooo0P00
oj8;0?ooo`800?oX303oool2003@o``0oooo0P00R?l<0?ooo`80047o2`3oool200H0o``0oooo0P1=
0?l<0?ooo`80U@3o303oool20=d0o`d0oooo00060?ooo`80olL0303oool20?nN00d0oooo00<0oi00
0?ooo`3oool02`3oool20?nU00`0oooo0`3od@0;0?ooo`@0m?l02P3oool60;Go00P0oooo1@1co`08
0?ooo`H0;ol0203oool6003o5@T0oooo1000oe/90?ooo`H00?nR203oool6003oj0P0oooo1P00d?l8
0?ooo`L008So1P3oool80011o`H0oooo2@060?l50?ooo`T0C@3o103oool:09D0o`@0oooo2`3M0?l7
0?ooo`001`3oool20?o700`0oooo00<0oih00?ooo`3oool02`3oool00`3oT000oooo0?ooo`0;0?oo
o`030?nU003oool0oooo00X0oooo0P3od@0<0?ooo`80m?l0303oool40;Go00X0oooo1P1co`070?oo
o`L0;ol01`3oool7003o5@L0oooo1`00oe/60?ooo`L00?nR1`3oool7003oj0L0oooo1`00d?l70?oo
o`H008So1`3oool70011o`L0oooo1`060?l70?ooo`L0C@3o1P3oool709D0o`L0oooo1`3M0?l=0?oo
o`00[`3oool4003oj0X0oooo1000d?l:0?ooo`<008So2P3oool40011o`X0oooo10060?l:0?ooo`@0
C@3o2@3oool409D0o`X0oooo103M0?l=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`004`3oool40?m80?l0oooo2P3o
ool000@0oooo00<0of@00?ooo`3oool0303oool40?m800h0oooo00<0ofL00?ooo`3oool0n03oool0
00<0oooo0`3oI00>0?ooo`<0odP03@3oool30?mW00h0oooo00<0oj<00?ooo`3oool0j03oool00080
oooo103oI00>0?ooo`80odP03P3oool40?mW00`0oooo0P3oX`0=0?ooo`030?oV003oool0oooo00/0
oooo00<0dol00?ooo`3oool02`3oool00`2=o`00oooo0?ooo`2n0?ooo`000`3oool40?mT00d0oooo
0P3oB00=0?ooo`@0ofL02`3oool50?nS00X0oooo0`3oiP0;0?ooo`<0dol02`3oool308go00/0oooo
0P16o`0<0?ooo`800?l1303oool2003oB0`0oooo0P00oi0;0?ooo`800?oH303oool2003Oo``0oooo
0P00Uol;0?ooo`8004oo303oool20007o``0oooo0P110?l<0?ooo`80R03o2`3oool20=40o``0oooo
0P3o0>H>0?ooo`001@3oool20?mT00h0oooo00<0odP00?ooo`3oool02`3oool20?mW00`0oooo1P3o
X`080?ooo`H0onH0203oool50=?o00T0oooo1@2=o`090?ooo`@0A_l02P3oool4003o0@T0oooo1@00
odP90?ooo`D00?n@2@3oool6003of0L0oooo1`00gol70?ooo`L009Oo1`3oool8001?o`H0oooo2000
1ol50?ooo`X0@@3o103oool:08P0o`@0oooo2P3A0?l30?ooo``0o`3V1`3oool000L0oooo00<0of@0
0?ooo`3oool02`3oool00`3oB000oooo0?ooo`0:0?ooo`030?mW003oool0oooo00/0oooo103oX`0:
0?ooo`L0onH01`3oool60=?o00L0oooo1`2=o`070?ooo`L0A_l01`3oool7003o0@H0oooo1`00odP7
0?ooo`L00?n@1`3oool7003of0H0oooo1`00gol70?ooo`L009Oo1`3oool7001?o`L0oooo1P001ol7
0?ooo`L0@@3o1`3oool708P0o`L0oooo1`3A0?l60?ooo`L0o`3V3P3oool007P0oooo1000o`490?oo
o`@00?m82P3oool4003oT0X0oooo1000omP90?ooo`@00=oo2P3oool4002Go`X0oooo1000Col:0?oo
o`<000Oo2P3oool40440o`X0oooo10280?l:0?ooo`@0d@3o2@3oool40?l0iPh0oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000I0?ooo`80
odP02`3oool20?n@00`0oooo0P3of00<0?ooo`80g_l0303oool209Ko00/0oooo0P1>o`0<0?ooo`80
1Ol0303oool2003o@P/0oooo0P00ohX<0?ooo`800?oC303oool2003To``0oooo0P00W?l;0?ooo`80
05?o303oool2000;o``0oooo0P0l0?l;0?ooo`80Q03o303oool20<d0o``0oooo0P3o0>X;0?ooo`80
o`2R3`3oool001H0oooo1@3oB0090?ooo`@0oi002@3oool50?oH00T0oooo1@3No`090?ooo`D0U_l0
2@3oool404ko00T0oooo1@05o`090?ooo`D00?m22@3oool4003oRPT0oooo1@00om<90?ooo`D00>Co
2@3oool5002Lo`T0oooo1000Dol90?ooo`D000_o2@3oool503`0o`T0oooo10240?l90?ooo`D0c@3o
2@3oool50?l0jPT0oooo103o0:8?0?ooo`001P3oool00`3o0000oooo0?ooo`0;0?ooo`L0odP01`3o
ool60?n@00L0oooo1`3of0070?ooo`L0g_l01`3oool709Ko00L0oooo1P1>o`070?ooo`L01Ol01`3o
ool7003o@PL0oooo1`00ohX60?ooo`P00?oC1P3oool9003To`D0oooo2@00W?l50?ooo`T005?o103o
ool;000;o`<0oooo2`0l0?l30?ooo``0Q03o00<0oooo0<d0o`3=0?l02`3=0?l00`3oool0o`3Z0?l0
jP0;0?l0jP030?ooo`3o0:80o`2R00`0o`2R1`3oool001L0oooo103oB00:0?ooo`<0oi002P3oool4
0?oH00X0oooo103No`0:0?ooo`@0U_l02P3oool304ko00X0oooo1005o`0:0?ooo`@00?m22P3oool3
003oRPX0oooo1000om<:0?ooo`@00>Co2P3oool4002Lo`X0oooo0`00Dol:0?ooo`@000_o2P3oool4
03`0o`X0oooo0`240?l:0?ooo`@0c@3o2P3oool40?l0jPX0oooo0`3o0:8?0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{94.125, 381.125}, {406.5, 119.5}} -> {-0.369368, 
  0.412194, 0.00365857, 0.00365857}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[32]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conclusions", "Section",
  Background->GrayLevel[0.900008]],

Cell["\<\
The package Miscellaneous`Sampling` is a simple tool for dealing \
with 1-sampling equilibria and 1-sampling dynamics. Although it's not \
complete, aspecially support for 1-sampling dynamics, it can be used to find \
all 1-sampling equilibria in any normal form game either analytically or \
numerically. Even in relatively simple games it can be quite teadious task to \
compute all 1-sampling equilibria using only paper and pencil. Now the \
package comes in handy!

The other purpose of the package is its educational use. Sometimes it's quite \
difficult to show nice examples to students just because they are to complex. \
Now, it can be done within seconds hence the lecture can become more \
interesting and students can play with various games. The only results can be \
more complete understanding of the subject!

All in all, with all the drawbacks of this package it can be succesfuly used \
for both sientific and educational purposes.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{949, 614},
WindowMargins->{{2, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 154, 5, 120, "Title"],
Cell[1888, 58, 162, 6, 107, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2075, 68, 66, 1, 72, "Section"],
Cell[2144, 71, 1040, 17, 129, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3221, 93, 76, 1, 72, "Section"],
Cell[3300, 96, 214, 6, 27, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3551, 107, 71, 1, 72, "Section"],
Cell[3625, 110, 107, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[3757, 117, 75, 1, 54, "Subsection"],
Cell[3835, 120, 149, 3, 36, "Text"],
Cell[3987, 125, 83, 2, 23, "Input"],
Cell[4073, 129, 18, 0, 22, "Text"],
Cell[4094, 131, 93, 2, 23, "Input"],
Cell[4190, 135, 71, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[4286, 139, 69, 2, 23, "Input"],
Cell[4358, 143, 137, 3, 45, "Output"]
}, Open  ]],
Cell[4510, 149, 90, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[4625, 156, 86, 2, 23, "Input"],
Cell[4714, 160, 234, 5, 40, "Print"]
}, Open  ]],
Cell[4963, 168, 153, 3, 36, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5153, 176, 72, 1, 54, "Subsection"],
Cell[5228, 179, 399, 7, 65, "Text"],

Cell[CellGroupData[{
Cell[5652, 190, 66, 2, 23, "Input"],
Cell[5721, 194, 595, 8, 96, "Print"]
}, Open  ]],
Cell[6331, 205, 135, 3, 36, "Text"],

Cell[CellGroupData[{
Cell[6491, 212, 186, 4, 78, "Input"],
Cell[6680, 218, 222, 8, 57, "Output"],
Cell[6905, 228, 221, 8, 57, "Output"]
}, Open  ]],
Cell[7141, 239, 38, 0, 22, "Text"],
Cell[7182, 241, 183, 4, 23, "Input"],
Cell[7368, 247, 602, 9, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8007, 261, 88, 1, 54, "Subsection"],
Cell[8098, 264, 159, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[8282, 272, 80, 2, 23, "Input"],
Cell[8365, 276, 299, 4, 54, "Print"]
}, Open  ]],
Cell[8679, 283, 148, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[8852, 291, 96, 2, 23, "Input"],
Cell[8951, 295, 166, 3, 47, "Output"]
}, Open  ]],
Cell[9132, 301, 149, 3, 36, "Text"],

Cell[CellGroupData[{
Cell[9306, 308, 85, 2, 23, "Input"],
Cell[9394, 312, 79, 2, 33, "Output"]
}, Open  ]],
Cell[9488, 317, 98, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[9611, 324, 96, 2, 23, "Input"],
Cell[9710, 328, 187, 4, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9934, 337, 85, 2, 23, "Input"],
Cell[10022, 341, 86, 2, 33, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10157, 349, 88, 1, 54, "Subsection"],
Cell[10248, 352, 214, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[10487, 360, 85, 2, 23, "Input"],
Cell[10575, 364, 471, 6, 86, "Print"]
}, Open  ]],
Cell[11061, 373, 120, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[11206, 380, 93, 2, 23, "Input"],
Cell[11302, 384, 434, 7, 109, "Output"]
}, Open  ]],
Cell[11751, 394, 76, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[11852, 398, 107, 2, 23, "Input"],
Cell[11962, 402, 2474, 97, 122, "Output"]
}, Open  ]],
Cell[14451, 502, 229, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[14705, 510, 70, 2, 23, "Input"],
Cell[14778, 514, 325, 4, 54, "Print"]
}, Open  ]],
Cell[15118, 521, 39, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[15182, 525, 76, 2, 23, "Input"],
Cell[15261, 529, 89, 2, 32, "Output"]
}, Open  ]],
Cell[15365, 534, 120, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[15510, 541, 161, 4, 36, "Input"],
Cell[15674, 547, 287, 6, 45, "Output"]
}, Open  ]],
Cell[15976, 556, 270, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[16271, 565, 80, 2, 23, "Input"],
Cell[16354, 569, 315, 4, 54, "Print"]
}, Open  ]],
Cell[16684, 576, 37, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[16746, 580, 161, 4, 36, "Input"],
Cell[16910, 586, 287, 6, 45, "Output"]
}, Open  ]],
Cell[17212, 595, 88, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[17325, 602, 181, 4, 50, "Input"],
Cell[17509, 608, 670, 15, 32, "Output"]
}, Open  ]],
Cell[18194, 626, 112, 3, 22, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18343, 634, 85, 1, 54, "Subsection"],
Cell[18431, 637, 467, 9, 65, "Text"],

Cell[CellGroupData[{
Cell[18923, 650, 86, 2, 23, "Input"],
Cell[19012, 654, 305, 4, 54, "Print"]
}, Open  ]],
Cell[19332, 661, 213, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[19570, 669, 74, 2, 23, "Input"],
Cell[19647, 673, 360, 5, 65, "Print"]
}, Open  ]],
Cell[20022, 681, 93, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[20140, 688, 107, 2, 23, "Input"],
Cell[20250, 692, 391, 7, 93, "Output"]
}, Open  ]],
Cell[20656, 702, 95, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[20776, 709, 145, 4, 23, "Input"],
Cell[20924, 715, 967, 28, 45, "Output"]
}, Open  ]],
Cell[21906, 746, 62, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[21993, 750, 89, 2, 23, "Input"],
Cell[22085, 754, 260, 5, 45, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22394, 765, 74, 1, 54, "Subsection"],
Cell[22471, 768, 335, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[22831, 778, 85, 2, 23, "Input"],
Cell[22919, 782, 341, 5, 65, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23297, 792, 101, 2, 23, "Input"],
Cell[23401, 796, 362, 7, 93, "Output"]
}, Open  ]],
Cell[23778, 806, 137, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[23940, 813, 112, 2, 23, "Input"],
Cell[24055, 817, 230, 5, 56, "Output"]
}, Open  ]],
Cell[24300, 825, 148, 3, 36, "Text"],

Cell[CellGroupData[{
Cell[24473, 832, 154, 4, 23, "Input"],
Cell[24630, 838, 312, 5, 73, "Output"]
}, Open  ]],
Cell[24957, 846, 64, 0, 22, "Text"],
Cell[25024, 848, 92, 2, 23, "Input"],
Cell[25119, 852, 57, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[25201, 856, 245, 4, 50, "Input"],
Cell[25449, 862, 488411, 33118, 298, 350087, 31405, "GraphicsData", 
"PostScript", "Graphics"],
Cell[513863, 33982, 157, 4, 32, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[514081, 33993, 70, 1, 66, "Section"],
Cell[514154, 33996, 398, 7, 65, "Text"],

Cell[CellGroupData[{
Cell[514577, 34007, 74, 1, 54, "Subsection"],
Cell[514654, 34010, 574, 9, 79, "Text"],
Cell[515231, 34021, 350, 7, 64, "Input"],
Cell[515584, 34030, 52, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[515661, 34034, 182, 4, 50, "Input"],
Cell[515846, 34040, 736, 15, 45, "Output"]
}, Open  ]],
Cell[516597, 34058, 359, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[516981, 34068, 103, 2, 23, "Input"],
Cell[517087, 34072, 1056, 19, 188, "Output"]
}, Open  ]],
Cell[518158, 34094, 171, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[518354, 34102, 273, 6, 64, "Input"],
Cell[518630, 34110, 538, 10, 88, "Output"]
}, Open  ]],
Cell[519183, 34123, 146, 3, 36, "Text"],

Cell[CellGroupData[{
Cell[519354, 34130, 296, 5, 64, "Input"],
Cell[519653, 34137, 480481, 33015, 303, 350825, 31409, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1000137, 67154, 156, 4, 32, "Output"]
}, Open  ]],
Cell[1000308, 67161, 147, 3, 36, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1000492, 67169, 77, 1, 54, "Subsection"],
Cell[1000572, 67172, 416, 7, 65, "Text"],

Cell[CellGroupData[{
Cell[1001013, 67183, 301, 7, 78, "Input"],
Cell[1001317, 67192, 198, 7, 44, "Output"],
Cell[1001518, 67201, 198, 7, 44, "Output"]
}, Open  ]],
Cell[1001731, 67211, 59, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[1001815, 67215, 173, 4, 50, "Input"],
Cell[1001991, 67221, 408, 11, 32, "Output"]
}, Open  ]],
Cell[1002414, 67235, 212, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[1002651, 67243, 297, 6, 78, "Input"],
Cell[1002951, 67251, 191, 4, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1003179, 67260, 221, 4, 50, "Input"],
Cell[1003403, 67266, 126140, 3721, 303, 58884, 2886, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1129546, 70989, 155, 4, 32, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1129762, 71000, 65, 1, 66, "Section"],
Cell[1129830, 71003, 974, 17, 193, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

